
#include <pmu-events/pmu-events.h>
#include "util/header.h"
#include "util/pmu.h"
#include <string.h>
#include <stddef.h>

struct compact_pmu_event {
        int offset;
};

struct pmu_table_entry {
        const struct compact_pmu_event *entries;
        uint32_t num_entries;
        struct compact_pmu_event pmu_name;
};

static const char *const big_c_string =
/* offset=0 */ "default_core\000"
/* offset=13 */ "pm_run_inst_cmpl_conc\000cache\000PowerPC instruction completed by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\00000\000\000"
/* offset=156 */ "pm_br_mpred_cmpl\000cache\000A mispredicted branch completed. Includes direction and target\000event=0x400f6\000\00000\000\000"
/* offset=261 */ "pm_data_from_l2miss\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss\000event=0x200fe\000\00000\000\000"
/* offset=416 */ "pm_data_from_l3miss\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x300fe\000\00000\000\000"
/* offset=562 */ "pm_data_from_memory\000datasource\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss\000event=0x400fe\000\00000\000\000"
/* offset=711 */ "pm_inst_from_l2\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss\000event=0x300000000c040\000\00000\000\000"
/* offset=858 */ "pm_data_from_l2\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss\000event=0x340000000c040\000\00000\000\000"
/* offset=1001 */ "pm_inst_from_l2_all\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss or prefetch reload\000event=0x300000010c040\000\00000\000\000"
/* offset=1171 */ "pm_data_from_l2_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss or prefetch reload\000event=0x340000020c040\000\00000\000\000"
/* offset=1337 */ "pm_inst_from_l1miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss\000event=0x3f00000000c040\000\00000\000\000"
/* offset=1505 */ "pm_data_from_l1miss\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss\000event=0x3f40000000c040\000\00000\000\000"
/* offset=1669 */ "pm_inst_from_l1miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload\000event=0x3f00000010c040\000\00000\000\000"
/* offset=1860 */ "pm_data_from_l1miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload\000event=0x3f40000020c040\000\00000\000\000"
/* offset=2047 */ "pm_data_from_l2_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss\000event=0x40000000c040\000\00000\000\000"
/* offset=2260 */ "pm_data_from_l2_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss or prefetch reload\000event=0x40000020c040\000\00000\000\000"
/* offset=2496 */ "pm_data_from_l2_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss\000event=0x4040000000c040\000\00000\000\000"
/* offset=2700 */ "pm_data_from_l2_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss or prefetch reload\000event=0x4040000020c040\000\00000\000\000"
/* offset=2927 */ "pm_data_from_l2_ldhitst_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss\000event=0x8040000000c040\000\00000\000\000"
/* offset=3143 */ "pm_data_from_l2_ldhitst_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss or prefetch reload\000event=0x8040000020c040\000\00000\000\000"
/* offset=3382 */ "pm_data_from_l2_other_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss\000event=0xc040000000c040\000\00000\000\000"
/* offset=3604 */ "pm_data_from_l2_other_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss or prefetch reload\000event=0xc040000020c040\000\00000\000\000"
/* offset=3849 */ "pm_inst_from_l2miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss\000event=0x380000000c040\000\00000\000\000"
/* offset=4016 */ "pm_data_from_l2miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss\000event=0x3c0000000c040\000\00000\000\000"
/* offset=4184 */ "pm_inst_from_l2miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload\000event=0x380000010c040\000\00000\000\000"
/* offset=4374 */ "pm_data_from_l2miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload\000event=0x3c0000020c040\000\00000\000\000"
/* offset=4560 */ "pm_inst_from_l3\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss\000event=0x10300000000c040\000\00000\000\000"
/* offset=4709 */ "pm_data_from_l3\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss\000event=0x10340000000c040\000\00000\000\000"
/* offset=4854 */ "pm_inst_from_l3_all\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss or prefetch reload\000event=0x10300000010c040\000\00000\000\000"
/* offset=5026 */ "pm_data_from_l3_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload\000event=0x10340000020c040\000\00000\000\000"
/* offset=5194 */ "pm_data_from_l3_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss\000event=0x10040000000c040\000\00000\000\000"
/* offset=5410 */ "pm_data_from_l3_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss or prefetch reload\000event=0x10040000020c040\000\00000\000\000"
/* offset=5649 */ "pm_data_from_l3_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss\000event=0x14040000000c040\000\00000\000\000"
/* offset=5854 */ "pm_data_from_l3_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss or prefetch reload\000event=0x14040000020c040\000\00000\000\000"
/* offset=6082 */ "pm_data_from_l3_conflict\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss\000event=0x1c040000000c040\000\00000\000\000"
/* offset=6236 */ "pm_data_from_l3_conflict_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload\000event=0x1c040000020c040\000\00000\000\000"
/* offset=6413 */ "pm_inst_from_l3miss_dsrc\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x780000000c040\000\00000\000\000"
/* offset=6576 */ "pm_data_from_l3miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x7c0000000c040\000\00000\000\000"
/* offset=6735 */ "pm_inst_from_l3miss_all\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload\000event=0x780000010c040\000\00000\000\000"
/* offset=6916 */ "pm_data_from_l3miss_all\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload\000event=0x7c0000020c040\000\00000\000\000"
/* offset=7093 */ "pm_data_from_l21_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x80040000000c040\000\00000\000\000"
/* offset=7342 */ "pm_data_from_l21_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80040000020c040\000\00000\000\000"
/* offset=7614 */ "pm_data_from_l21_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x84040000000c040\000\00000\000\000"
/* offset=7844 */ "pm_data_from_l21_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x84040000020c040\000\00000\000\000"
/* offset=8097 */ "pm_inst_from_l21_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x80100000000c040\000\00000\000\000"
/* offset=8288 */ "pm_data_from_l21_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x80140000000c040\000\00000\000\000"
/* offset=8475 */ "pm_inst_from_l21_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80100000010c040\000\00000\000\000"
/* offset=8689 */ "pm_data_from_l21_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80140000020c040\000\00000\000\000"
/* offset=8899 */ "pm_data_from_l31_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x88040000000c040\000\00000\000\000"
/* offset=9148 */ "pm_data_from_l31_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x88040000020c040\000\00000\000\000"
/* offset=9420 */ "pm_data_from_l31_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x8c040000000c040\000\00000\000\000"
/* offset=9650 */ "pm_data_from_l31_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x8c040000020c040\000\00000\000\000"
/* offset=9903 */ "pm_inst_from_l31_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x88100000000c040\000\00000\000\000"
/* offset=10094 */ "pm_data_from_l31_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x88140000000c040\000\00000\000\000"
/* offset=10281 */ "pm_inst_from_l31_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x88100000010c040\000\00000\000\000"
/* offset=10495 */ "pm_data_from_l31_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x88140000020c040\000\00000\000\000"
/* offset=10705 */ "pm_data_from_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x80240000000c040\000\00000\000\000"
/* offset=10961 */ "pm_data_from_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80240000020c040\000\00000\000\000"
/* offset=11240 */ "pm_data_from_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x84240000000c040\000\00000\000\000"
/* offset=11477 */ "pm_data_from_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x84240000020c040\000\00000\000\000"
/* offset=11737 */ "pm_inst_from_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x80300000000c040\000\00000\000\000"
/* offset=11935 */ "pm_data_from_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x80340000000c040\000\00000\000\000"
/* offset=12129 */ "pm_inst_from_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80300000010c040\000\00000\000\000"
/* offset=12350 */ "pm_data_from_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80340000020c040\000\00000\000\000"
/* offset=12567 */ "pm_data_from_l21_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa0040000000c040\000\00000\000\000"
/* offset=12823 */ "pm_data_from_l21_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0040000020c040\000\00000\000\000"
/* offset=13102 */ "pm_data_from_l21_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa4040000000c040\000\00000\000\000"
/* offset=13339 */ "pm_data_from_l21_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa4040000020c040\000\00000\000\000"
/* offset=13599 */ "pm_inst_from_l21_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa0100000000c040\000\00000\000\000"
/* offset=13797 */ "pm_data_from_l21_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa0140000000c040\000\00000\000\000"
/* offset=13991 */ "pm_inst_from_l21_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0100000010c040\000\00000\000\000"
/* offset=14212 */ "pm_data_from_l21_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0140000020c040\000\00000\000\000"
/* offset=14429 */ "pm_data_from_l31_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xa8040000000c040\000\00000\000\000"
/* offset=14685 */ "pm_data_from_l31_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa8040000020c040\000\00000\000\000"
/* offset=14964 */ "pm_data_from_l31_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xac040000000c040\000\00000\000\000"
/* offset=15201 */ "pm_data_from_l31_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xac040000020c040\000\00000\000\000"
/* offset=15461 */ "pm_inst_from_l31_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xa8100000000c040\000\00000\000\000"
/* offset=15659 */ "pm_data_from_l31_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xa8140000000c040\000\00000\000\000"
/* offset=15853 */ "pm_inst_from_l31_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa8100000010c040\000\00000\000\000"
/* offset=16074 */ "pm_data_from_l31_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa8140000020c040\000\00000\000\000"
/* offset=16291 */ "pm_data_from_non_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa0240000000c040\000\00000\000\000"
/* offset=16554 */ "pm_data_from_non_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0240000020c040\000\00000\000\000"
/* offset=16840 */ "pm_data_from_non_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa4240000000c040\000\00000\000\000"
/* offset=17084 */ "pm_data_from_non_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa4240000020c040\000\00000\000\000"
/* offset=17351 */ "pm_inst_from_non_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa0300000000c040\000\00000\000\000"
/* offset=17556 */ "pm_data_from_non_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa0340000000c040\000\00000\000\000"
/* offset=17757 */ "pm_inst_from_non_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0300000010c040\000\00000\000\000"
/* offset=17985 */ "pm_data_from_non_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0340000020c040\000\00000\000\000"
/* offset=18209 */ "pm_inst_from_lmem\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss\000event=0x94100000000c040\000\00000\000\000"
/* offset=18364 */ "pm_data_from_lmem\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss\000event=0x94040000000c040\000\00000\000\000"
/* offset=18515 */ "pm_inst_from_lmem_all\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss or prefetch reload\000event=0x94100000010c040\000\00000\000\000"
/* offset=18693 */ "pm_data_from_lmem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss or prefetch reload\000event=0x94040000020c040\000\00000\000\000"
/* offset=18867 */ "pm_data_from_l_oc_cache\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss\000event=0x98040000000c040\000\00000\000\000"
/* offset=19032 */ "pm_data_from_l_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss or prefetch reload\000event=0x98040000020c040\000\00000\000\000"
/* offset=19220 */ "pm_data_from_l_oc_mem\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss\000event=0x9c040000000c040\000\00000\000\000"
/* offset=19384 */ "pm_data_from_l_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss or prefetch reload\000event=0x9c040000020c040\000\00000\000\000"
/* offset=19571 */ "pm_inst_from_l_oc_any\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss\000event=0x98100000000c040\000\00000\000\000"
/* offset=19748 */ "pm_data_from_l_oc_any\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss\000event=0x98140000000c040\000\00000\000\000"
/* offset=19921 */ "pm_inst_from_l_oc_any_all\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0x98100000010c040\000\00000\000\000"
/* offset=20121 */ "pm_data_from_l_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0x98140000020c040\000\00000\000\000"
/* offset=20317 */ "pm_data_from_rl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss\000event=0xc0040000000c040\000\00000\000\000"
/* offset=20542 */ "pm_data_from_rl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc0040000020c040\000\00000\000\000"
/* offset=20790 */ "pm_data_from_rl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss\000event=0xc4040000000c040\000\00000\000\000"
/* offset=20996 */ "pm_data_from_rl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc4040000020c040\000\00000\000\000"
/* offset=21225 */ "pm_inst_from_rl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss\000event=0xc0100000000c040\000\00000\000\000"
/* offset=21392 */ "pm_data_from_rl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss\000event=0xc0140000000c040\000\00000\000\000"
/* offset=21555 */ "pm_inst_from_rl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc0100000010c040\000\00000\000\000"
/* offset=21745 */ "pm_data_from_rl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc0140000020c040\000\00000\000\000"
/* offset=21931 */ "pm_data_from_rl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss\000event=0xc8040000000c040\000\00000\000\000"
/* offset=22156 */ "pm_data_from_rl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc8040000020c040\000\00000\000\000"
/* offset=22404 */ "pm_data_from_rl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss\000event=0xcc040000000c040\000\00000\000\000"
/* offset=22610 */ "pm_data_from_rl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xcc040000020c040\000\00000\000\000"
/* offset=22839 */ "pm_inst_from_rl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss\000event=0xc8100000000c040\000\00000\000\000"
/* offset=23006 */ "pm_data_from_rl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss\000event=0xc8140000000c040\000\00000\000\000"
/* offset=23169 */ "pm_inst_from_rl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc8100000010c040\000\00000\000\000"
/* offset=23359 */ "pm_data_from_rl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc8140000020c040\000\00000\000\000"
/* offset=23545 */ "pm_data_from_rl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc0240000000c040\000\00000\000\000"
/* offset=23778 */ "pm_data_from_rl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc0240000020c040\000\00000\000\000"
/* offset=24034 */ "pm_data_from_rl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc4240000000c040\000\00000\000\000"
/* offset=24248 */ "pm_data_from_rl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc4240000020c040\000\00000\000\000"
/* offset=24485 */ "pm_inst_from_rl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc0300000000c040\000\00000\000\000"
/* offset=24660 */ "pm_data_from_rl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc0340000000c040\000\00000\000\000"
/* offset=24831 */ "pm_inst_from_rl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc0300000010c040\000\00000\000\000"
/* offset=25029 */ "pm_data_from_rl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc0340000020c040\000\00000\000\000"
/* offset=25223 */ "pm_inst_from_rmem\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss\000event=0xd4100000000c040\000\00000\000\000"
/* offset=25378 */ "pm_data_from_rmem\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss\000event=0xd4040000000c040\000\00000\000\000"
/* offset=25529 */ "pm_inst_from_rmem_all\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload\000event=0xd4100000010c040\000\00000\000\000"
/* offset=25707 */ "pm_data_from_rmem_all\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload\000event=0xd4040000020c040\000\00000\000\000"
/* offset=25881 */ "pm_data_from_r_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss\000event=0xd8040000000c040\000\00000\000\000"
/* offset=26045 */ "pm_data_from_r_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss or prefetch reload\000event=0xd8040000020c040\000\00000\000\000"
/* offset=26232 */ "pm_data_from_r_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss\000event=0xdc040000000c040\000\00000\000\000"
/* offset=26395 */ "pm_data_from_r_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss or prefetch reload\000event=0xdc040000020c040\000\00000\000\000"
/* offset=26581 */ "pm_inst_from_r_oc_any\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss\000event=0xd8100000000c040\000\00000\000\000"
/* offset=26757 */ "pm_data_from_r_oc_any\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss\000event=0xd8140000000c040\000\00000\000\000"
/* offset=26929 */ "pm_inst_from_r_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xd8100000010c040\000\00000\000\000"
/* offset=27128 */ "pm_data_from_r_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xd8140000020c040\000\00000\000\000"
/* offset=27323 */ "pm_data_from_dl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss\000event=0xe0040000000c040\000\00000\000\000"
/* offset=27549 */ "pm_data_from_dl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe0040000020c040\000\00000\000\000"
/* offset=27798 */ "pm_data_from_dl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss\000event=0xe4040000000c040\000\00000\000\000"
/* offset=28005 */ "pm_data_from_dl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe4040000020c040\000\00000\000\000"
/* offset=28235 */ "pm_inst_from_dl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss\000event=0xe0100000000c040\000\00000\000\000"
/* offset=28403 */ "pm_data_from_dl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss\000event=0xe0140000000c040\000\00000\000\000"
/* offset=28567 */ "pm_inst_from_dl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe0100000010c040\000\00000\000\000"
/* offset=28758 */ "pm_data_from_dl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe0140000020c040\000\00000\000\000"
/* offset=28945 */ "pm_data_from_dl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss\000event=0xe8040000000c040\000\00000\000\000"
/* offset=29171 */ "pm_data_from_dl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe8040000020c040\000\00000\000\000"
/* offset=29420 */ "pm_data_from_dl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss\000event=0xec040000000c040\000\00000\000\000"
/* offset=29627 */ "pm_data_from_dl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xec040000020c040\000\00000\000\000"
/* offset=29857 */ "pm_inst_from_dl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss\000event=0xe8100000000c040\000\00000\000\000"
/* offset=30025 */ "pm_data_from_dl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss\000event=0xe8140000000c040\000\00000\000\000"
/* offset=30189 */ "pm_inst_from_dl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe8100000010c040\000\00000\000\000"
/* offset=30380 */ "pm_data_from_dl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe8140000020c040\000\00000\000\000"
/* offset=30567 */ "pm_data_from_dl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe0240000000c040\000\00000\000\000"
/* offset=30801 */ "pm_data_from_dl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe0240000020c040\000\00000\000\000"
/* offset=31058 */ "pm_data_from_dl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe4240000000c040\000\00000\000\000"
/* offset=31273 */ "pm_data_from_dl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe4240000020c040\000\00000\000\000"
/* offset=31511 */ "pm_inst_from_dl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe0300000000c040\000\00000\000\000"
/* offset=31687 */ "pm_data_from_dl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe0340000000c040\000\00000\000\000"
/* offset=31859 */ "pm_inst_from_dl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe0300000010c040\000\00000\000\000"
/* offset=32058 */ "pm_data_from_dl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe0340000020c040\000\00000\000\000"
/* offset=32253 */ "pm_inst_from_dmem\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss\000event=0xf4100000000c040\000\00000\000\000"
/* offset=32409 */ "pm_data_from_dmem\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss\000event=0xf4040000000c040\000\00000\000\000"
/* offset=32561 */ "pm_inst_from_dmem_all\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload\000event=0xf4100000010c040\000\00000\000\000"
/* offset=32740 */ "pm_data_from_dmem_all\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload\000event=0xf4040000020c040\000\00000\000\000"
/* offset=32915 */ "pm_data_from_d_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss\000event=0xf8040000000c040\000\00000\000\000"
/* offset=33080 */ "pm_data_from_d_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss or prefetch reload\000event=0xf8040000020c040\000\00000\000\000"
/* offset=33268 */ "pm_data_from_d_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss\000event=0xfc040000000c040\000\00000\000\000"
/* offset=33432 */ "pm_data_from_d_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss or prefetch reload\000event=0xfc040000020c040\000\00000\000\000"
/* offset=33619 */ "pm_inst_from_d_oc_any\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss\000event=0xf8100000000c040\000\00000\000\000"
/* offset=33796 */ "pm_data_from_d_oc_any\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss\000event=0xf8140000000c040\000\00000\000\000"
/* offset=33969 */ "pm_inst_from_d_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xf8100000010c040\000\00000\000\000"
/* offset=34169 */ "pm_data_from_d_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xf8140000020c040\000\00000\000\000"
/* offset=34365 */ "pm_inst_from_onchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss\000event=0x80b00000000c040\000\00000\000\000"
/* offset=34547 */ "pm_data_from_onchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss\000event=0x80b40000000c040\000\00000\000\000"
/* offset=34725 */ "pm_inst_from_onchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload\000event=0x80b00000010c040\000\00000\000\000"
/* offset=34930 */ "pm_data_from_onchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload\000event=0x80b40000020c040\000\00000\000\000"
/* offset=35131 */ "pm_inst_from_offchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss\000event=0xc0b00000000c040\000\00000\000\000"
/* offset=35317 */ "pm_data_from_offchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss\000event=0xc0b40000000c040\000\00000\000\000"
/* offset=35499 */ "pm_inst_from_offchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload\000event=0xc0b00000010c040\000\00000\000\000"
/* offset=35708 */ "pm_data_from_offchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload\000event=0xc0b40000020c040\000\00000\000\000"
/* offset=35913 */ "pm_inst_from_any_memory\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss\000event=0x95900000000c040\000\00000\000\000"
/* offset=36078 */ "pm_data_from_any_memory\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss\000event=0x95840000000c040\000\00000\000\000"
/* offset=36239 */ "pm_inst_from_any_memory_all\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload\000event=0x95900000010c040\000\00000\000\000"
/* offset=36427 */ "pm_data_from_any_memory_all\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload\000event=0x95840000020c040\000\00000\000\000"
/* offset=36611 */ "pm_mrk_inst_from_l2\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss for a marked instruction\000event=0x300000000c142\000\00000\000\000"
/* offset=36787 */ "pm_mrk_data_from_l2\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss for a marked instruction\000event=0x340000000c142\000\00000\000\000"
/* offset=36959 */ "pm_mrk_inst_from_l2_all\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x300000010c142\000\00000\000\000"
/* offset=37158 */ "pm_mrk_data_from_l2_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x340000020c142\000\00000\000\000"
/* offset=37353 */ "pm_mrk_inst_from_l1miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss for a marked instruction\000event=0x3f00000000c142\000\00000\000\000"
/* offset=37550 */ "pm_mrk_data_from_l1miss\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss for a marked instruction\000event=0x3f40000000c142\000\00000\000\000"
/* offset=37743 */ "pm_mrk_inst_from_l1miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload for a marked instruction\000event=0x3f00000010c142\000\00000\000\000"
/* offset=37963 */ "pm_mrk_data_from_l1miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload for a marked instruction\000event=0x3f40000020c142\000\00000\000\000"
/* offset=38179 */ "pm_mrk_data_from_l2_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss for a marked instruction\000event=0x40000000c142\000\00000\000\000"
/* offset=38421 */ "pm_mrk_data_from_l2_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x40000020c142\000\00000\000\000"
/* offset=38686 */ "pm_mrk_data_from_l2_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss for a marked instruction\000event=0x4040000000c142\000\00000\000\000"
/* offset=38919 */ "pm_mrk_data_from_l2_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x4040000020c142\000\00000\000\000"
/* offset=39175 */ "pm_mrk_data_from_l2_ldhitst_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss for a marked instruction\000event=0x8040000000c142\000\00000\000\000"
/* offset=39420 */ "pm_mrk_data_from_l2_ldhitst_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x8040000020c142\000\00000\000\000"
/* offset=39688 */ "pm_mrk_data_from_l2_other_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss for a marked instruction\000event=0xc040000000c142\000\00000\000\000"
/* offset=39939 */ "pm_mrk_data_from_l2_other_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0xc040000020c142\000\00000\000\000"
/* offset=40213 */ "pm_mrk_inst_from_l2miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss for a marked instruction\000event=0x380000000c142\000\00000\000\000"
/* offset=40409 */ "pm_mrk_data_from_l2miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss for a marked instruction\000event=0x3c0000000c142\000\00000\000\000"
/* offset=40606 */ "pm_mrk_inst_from_l2miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x380000010c142\000\00000\000\000"
/* offset=40825 */ "pm_mrk_data_from_l2miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x3c0000020c142\000\00000\000\000"
/* offset=41040 */ "pm_mrk_inst_from_l3\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss for a marked instruction\000event=0x10300000000c142\000\00000\000\000"
/* offset=41218 */ "pm_mrk_data_from_l3\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss for a marked instruction\000event=0x10340000000c142\000\00000\000\000"
/* offset=41392 */ "pm_mrk_inst_from_l3_all\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x10300000010c142\000\00000\000\000"
/* offset=41593 */ "pm_mrk_data_from_l3_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x10340000020c142\000\00000\000\000"
/* offset=41790 */ "pm_mrk_data_from_l3_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss for a marked instruction\000event=0x10040000000c142\000\00000\000\000"
/* offset=42035 */ "pm_mrk_data_from_l3_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x10040000020c142\000\00000\000\000"
/* offset=42303 */ "pm_mrk_data_from_l3_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss for a marked instruction\000event=0x14040000000c142\000\00000\000\000"
/* offset=42537 */ "pm_mrk_data_from_l3_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x14040000020c142\000\00000\000\000"
/* offset=42794 */ "pm_mrk_data_from_l3_conflict\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss for a marked instruction\000event=0x1c040000000c142\000\00000\000\000"
/* offset=42977 */ "pm_mrk_data_from_l3_conflict_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x1c040000020c142\000\00000\000\000"
/* offset=43183 */ "pm_mrk_inst_from_l3miss_dsrc\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss for a marked instruction\000event=0x780000000c142\000\00000\000\000"
/* offset=43375 */ "pm_mrk_data_from_l3miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss for a marked instruction\000event=0x7c0000000c142\000\00000\000\000"
/* offset=43563 */ "pm_mrk_inst_from_l3miss_all\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x780000010c142\000\00000\000\000"
/* offset=43773 */ "pm_mrk_data_from_l3miss_all\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x7c0000020c142\000\00000\000\000"
/* offset=43979 */ "pm_mrk_data_from_l21_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80040000000c142\000\00000\000\000"
/* offset=44257 */ "pm_mrk_data_from_l21_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80040000020c142\000\00000\000\000"
/* offset=44558 */ "pm_mrk_data_from_l21_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x84040000000c142\000\00000\000\000"
/* offset=44817 */ "pm_mrk_data_from_l21_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x84040000020c142\000\00000\000\000"
/* offset=45099 */ "pm_mrk_inst_from_l21_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80100000000c142\000\00000\000\000"
/* offset=45319 */ "pm_mrk_data_from_l21_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80140000000c142\000\00000\000\000"
/* offset=45535 */ "pm_mrk_inst_from_l21_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80100000010c142\000\00000\000\000"
/* offset=45778 */ "pm_mrk_data_from_l21_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80140000020c142\000\00000\000\000"
/* offset=46017 */ "pm_mrk_data_from_l31_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x88040000000c142\000\00000\000\000"
/* offset=46295 */ "pm_mrk_data_from_l31_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x88040000020c142\000\00000\000\000"
/* offset=46596 */ "pm_mrk_data_from_l31_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x8c040000000c142\000\00000\000\000"
/* offset=46855 */ "pm_mrk_data_from_l31_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x8c040000020c142\000\00000\000\000"
/* offset=47137 */ "pm_mrk_inst_from_l31_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x88100000000c142\000\00000\000\000"
/* offset=47357 */ "pm_mrk_data_from_l31_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x88140000000c142\000\00000\000\000"
/* offset=47573 */ "pm_mrk_inst_from_l31_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x88100000010c142\000\00000\000\000"
/* offset=47816 */ "pm_mrk_data_from_l31_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x88140000020c142\000\00000\000\000"
/* offset=48055 */ "pm_mrk_data_from_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80240000000c142\000\00000\000\000"
/* offset=48340 */ "pm_mrk_data_from_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80240000020c142\000\00000\000\000"
/* offset=48648 */ "pm_mrk_data_from_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x84240000000c142\000\00000\000\000"
/* offset=48914 */ "pm_mrk_data_from_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x84240000020c142\000\00000\000\000"
/* offset=49203 */ "pm_mrk_inst_from_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80300000000c142\000\00000\000\000"
/* offset=49430 */ "pm_mrk_data_from_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80340000000c142\000\00000\000\000"
/* offset=49653 */ "pm_mrk_inst_from_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80300000010c142\000\00000\000\000"
/* offset=49903 */ "pm_mrk_data_from_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80340000020c142\000\00000\000\000"
/* offset=50149 */ "pm_mrk_data_from_l21_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0040000000c142\000\00000\000\000"
/* offset=50434 */ "pm_mrk_data_from_l21_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0040000020c142\000\00000\000\000"
/* offset=50742 */ "pm_mrk_data_from_l21_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa4040000000c142\000\00000\000\000"
/* offset=51008 */ "pm_mrk_data_from_l21_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa4040000020c142\000\00000\000\000"
/* offset=51297 */ "pm_mrk_inst_from_l21_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0100000000c142\000\00000\000\000"
/* offset=51524 */ "pm_mrk_data_from_l21_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0140000000c142\000\00000\000\000"
/* offset=51747 */ "pm_mrk_inst_from_l21_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0100000010c142\000\00000\000\000"
/* offset=51997 */ "pm_mrk_data_from_l21_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0140000020c142\000\00000\000\000"
/* offset=52243 */ "pm_mrk_data_from_l31_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa8040000000c142\000\00000\000\000"
/* offset=52528 */ "pm_mrk_data_from_l31_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa8040000020c142\000\00000\000\000"
/* offset=52836 */ "pm_mrk_data_from_l31_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xac040000000c142\000\00000\000\000"
/* offset=53102 */ "pm_mrk_data_from_l31_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xac040000020c142\000\00000\000\000"
/* offset=53391 */ "pm_mrk_inst_from_l31_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa8100000000c142\000\00000\000\000"
/* offset=53618 */ "pm_mrk_data_from_l31_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa8140000000c142\000\00000\000\000"
/* offset=53841 */ "pm_mrk_inst_from_l31_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa8100000010c142\000\00000\000\000"
/* offset=54091 */ "pm_mrk_data_from_l31_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa8140000020c142\000\00000\000\000"
/* offset=54337 */ "pm_mrk_data_from_non_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0240000000c142\000\00000\000\000"
/* offset=54629 */ "pm_mrk_data_from_non_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0240000020c142\000\00000\000\000"
/* offset=54944 */ "pm_mrk_data_from_non_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa4240000000c142\000\00000\000\000"
/* offset=55217 */ "pm_mrk_data_from_non_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa4240000020c142\000\00000\000\000"
/* offset=55513 */ "pm_mrk_inst_from_non_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0300000000c142\000\00000\000\000"
/* offset=55747 */ "pm_mrk_data_from_non_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0340000000c142\000\00000\000\000"
/* offset=55977 */ "pm_mrk_inst_from_non_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0300000010c142\000\00000\000\000"
/* offset=56234 */ "pm_mrk_data_from_non_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0340000020c142\000\00000\000\000"
/* offset=56487 */ "pm_mrk_inst_from_lmem\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss for a marked instruction\000event=0x94100000000c142\000\00000\000\000"
/* offset=56671 */ "pm_mrk_data_from_lmem\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss for a marked instruction\000event=0x94040000000c142\000\00000\000\000"
/* offset=56851 */ "pm_mrk_inst_from_lmem_all\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss or prefetch reload for a marked instruction\000event=0x94100000010c142\000\00000\000\000"
/* offset=57058 */ "pm_mrk_data_from_lmem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss or prefetch reload for a marked instruction\000event=0x94040000020c142\000\00000\000\000"
/* offset=57261 */ "pm_mrk_data_from_l_oc_cache\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss for a marked instruction\000event=0x98040000000c142\000\00000\000\000"
/* offset=57455 */ "pm_mrk_data_from_l_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss or prefetch reload for a marked instruction\000event=0x98040000020c142\000\00000\000\000"
/* offset=57672 */ "pm_mrk_data_from_l_oc_mem\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss for a marked instruction\000event=0x9c040000000c142\000\00000\000\000"
/* offset=57865 */ "pm_mrk_data_from_l_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss or prefetch reload for a marked instruction\000event=0x9c040000020c142\000\00000\000\000"
/* offset=58081 */ "pm_mrk_inst_from_l_oc_any\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0x98100000000c142\000\00000\000\000"
/* offset=58287 */ "pm_mrk_data_from_l_oc_any\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0x98140000000c142\000\00000\000\000"
/* offset=58489 */ "pm_mrk_inst_from_l_oc_any_all\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0x98100000010c142\000\00000\000\000"
/* offset=58718 */ "pm_mrk_data_from_l_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0x98140000020c142\000\00000\000\000"
/* offset=58943 */ "pm_mrk_data_from_rl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc0040000000c142\000\00000\000\000"
/* offset=59197 */ "pm_mrk_data_from_rl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0040000020c142\000\00000\000\000"
/* offset=59474 */ "pm_mrk_data_from_rl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc4040000000c142\000\00000\000\000"
/* offset=59709 */ "pm_mrk_data_from_rl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc4040000020c142\000\00000\000\000"
/* offset=59967 */ "pm_mrk_inst_from_rl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc0100000000c142\000\00000\000\000"
/* offset=60163 */ "pm_mrk_data_from_rl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc0140000000c142\000\00000\000\000"
/* offset=60355 */ "pm_mrk_inst_from_rl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0100000010c142\000\00000\000\000"
/* offset=60574 */ "pm_mrk_data_from_rl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0140000020c142\000\00000\000\000"
/* offset=60789 */ "pm_mrk_data_from_rl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc8040000000c142\000\00000\000\000"
/* offset=61043 */ "pm_mrk_data_from_rl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc8040000020c142\000\00000\000\000"
/* offset=61320 */ "pm_mrk_data_from_rl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xcc040000000c142\000\00000\000\000"
/* offset=61555 */ "pm_mrk_data_from_rl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xcc040000020c142\000\00000\000\000"
/* offset=61813 */ "pm_mrk_inst_from_rl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc8100000000c142\000\00000\000\000"
/* offset=62009 */ "pm_mrk_data_from_rl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc8140000000c142\000\00000\000\000"
/* offset=62201 */ "pm_mrk_inst_from_rl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc8100000010c142\000\00000\000\000"
/* offset=62420 */ "pm_mrk_data_from_rl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc8140000020c142\000\00000\000\000"
/* offset=62635 */ "pm_mrk_data_from_rl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc0240000000c142\000\00000\000\000"
/* offset=62897 */ "pm_mrk_data_from_rl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0240000020c142\000\00000\000\000"
/* offset=63182 */ "pm_mrk_data_from_rl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc4240000000c142\000\00000\000\000"
/* offset=63425 */ "pm_mrk_data_from_rl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc4240000020c142\000\00000\000\000"
/* offset=63691 */ "pm_mrk_inst_from_rl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc0300000000c142\000\00000\000\000"
/* offset=63895 */ "pm_mrk_data_from_rl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc0340000000c142\000\00000\000\000"
/* offset=64095 */ "pm_mrk_inst_from_rl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0300000010c142\000\00000\000\000"
/* offset=64322 */ "pm_mrk_data_from_rl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0340000020c142\000\00000\000\000"
/* offset=64545 */ "pm_mrk_inst_from_rmem\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss for a marked instruction\000event=0xd4100000000c142\000\00000\000\000"
/* offset=64729 */ "pm_mrk_data_from_rmem\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss for a marked instruction\000event=0xd4040000000c142\000\00000\000\000"
/* offset=64909 */ "pm_mrk_inst_from_rmem_all\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xd4100000010c142\000\00000\000\000"
/* offset=65116 */ "pm_mrk_data_from_rmem_all\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xd4040000020c142\000\00000\000\000"
/* offset=65319 */ "pm_mrk_data_from_r_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss for a marked instruction\000event=0xd8040000000c142\000\00000\000\000"
/* offset=65512 */ "pm_mrk_data_from_r_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss or prefetch reload for a marked instruction\000event=0xd8040000020c142\000\00000\000\000"
/* offset=65728 */ "pm_mrk_data_from_r_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss for a marked instruction\000event=0xdc040000000c142\000\00000\000\000"
/* offset=65920 */ "pm_mrk_data_from_r_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss or prefetch reload for a marked instruction\000event=0xdc040000020c142\000\00000\000\000"
/* offset=66135 */ "pm_mrk_inst_from_r_oc_any\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xd8100000000c142\000\00000\000\000"
/* offset=66340 */ "pm_mrk_data_from_r_oc_any\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xd8140000000c142\000\00000\000\000"
/* offset=66541 */ "pm_mrk_inst_from_r_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xd8100000010c142\000\00000\000\000"
/* offset=66769 */ "pm_mrk_data_from_r_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xd8140000020c142\000\00000\000\000"
/* offset=66993 */ "pm_mrk_data_from_dl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe0040000000c142\000\00000\000\000"
/* offset=67248 */ "pm_mrk_data_from_dl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0040000020c142\000\00000\000\000"
/* offset=67526 */ "pm_mrk_data_from_dl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe4040000000c142\000\00000\000\000"
/* offset=67762 */ "pm_mrk_data_from_dl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe4040000020c142\000\00000\000\000"
/* offset=68021 */ "pm_mrk_inst_from_dl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe0100000000c142\000\00000\000\000"
/* offset=68218 */ "pm_mrk_data_from_dl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe0140000000c142\000\00000\000\000"
/* offset=68411 */ "pm_mrk_inst_from_dl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0100000010c142\000\00000\000\000"
/* offset=68631 */ "pm_mrk_data_from_dl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0140000020c142\000\00000\000\000"
/* offset=68847 */ "pm_mrk_data_from_dl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe8040000000c142\000\00000\000\000"
/* offset=69102 */ "pm_mrk_data_from_dl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe8040000020c142\000\00000\000\000"
/* offset=69380 */ "pm_mrk_data_from_dl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xec040000000c142\000\00000\000\000"
/* offset=69616 */ "pm_mrk_data_from_dl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xec040000020c142\000\00000\000\000"
/* offset=69875 */ "pm_mrk_inst_from_dl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe8100000000c142\000\00000\000\000"
/* offset=70072 */ "pm_mrk_data_from_dl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe8140000000c142\000\00000\000\000"
/* offset=70265 */ "pm_mrk_inst_from_dl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe8100000010c142\000\00000\000\000"
/* offset=70485 */ "pm_mrk_data_from_dl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe8140000020c142\000\00000\000\000"
/* offset=70701 */ "pm_mrk_data_from_dl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe0240000000c142\000\00000\000\000"
/* offset=70964 */ "pm_mrk_data_from_dl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0240000020c142\000\00000\000\000"
/* offset=71250 */ "pm_mrk_data_from_dl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe4240000000c142\000\00000\000\000"
/* offset=71494 */ "pm_mrk_data_from_dl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe4240000020c142\000\00000\000\000"
/* offset=71761 */ "pm_mrk_inst_from_dl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe0300000000c142\000\00000\000\000"
/* offset=71966 */ "pm_mrk_data_from_dl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe0340000000c142\000\00000\000\000"
/* offset=72167 */ "pm_mrk_inst_from_dl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0300000010c142\000\00000\000\000"
/* offset=72395 */ "pm_mrk_data_from_dl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0340000020c142\000\00000\000\000"
/* offset=72619 */ "pm_mrk_inst_from_dmem\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss for a marked instruction\000event=0xf4100000000c142\000\00000\000\000"
/* offset=72804 */ "pm_mrk_data_from_dmem\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss for a marked instruction\000event=0xf4040000000c142\000\00000\000\000"
/* offset=72985 */ "pm_mrk_inst_from_dmem_all\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xf4100000010c142\000\00000\000\000"
/* offset=73193 */ "pm_mrk_data_from_dmem_all\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xf4040000020c142\000\00000\000\000"
/* offset=73397 */ "pm_mrk_data_from_d_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss for a marked instruction\000event=0xf8040000000c142\000\00000\000\000"
/* offset=73591 */ "pm_mrk_data_from_d_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss or prefetch reload for a marked instruction\000event=0xf8040000020c142\000\00000\000\000"
/* offset=73808 */ "pm_mrk_data_from_d_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss for a marked instruction\000event=0xfc040000000c142\000\00000\000\000"
/* offset=74001 */ "pm_mrk_data_from_d_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss or prefetch reload for a marked instruction\000event=0xfc040000020c142\000\00000\000\000"
/* offset=74217 */ "pm_mrk_inst_from_d_oc_any\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xf8100000000c142\000\00000\000\000"
/* offset=74423 */ "pm_mrk_data_from_d_oc_any\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xf8140000000c142\000\00000\000\000"
/* offset=74625 */ "pm_mrk_inst_from_d_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xf8100000010c142\000\00000\000\000"
/* offset=74854 */ "pm_mrk_data_from_d_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xf8140000020c142\000\00000\000\000"
/* offset=75079 */ "pm_mrk_inst_from_onchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss for a marked instruction\000event=0x80b00000000c142\000\00000\000\000"
/* offset=75290 */ "pm_mrk_data_from_onchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss for a marked instruction\000event=0x80b40000000c142\000\00000\000\000"
/* offset=75497 */ "pm_mrk_inst_from_onchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload for a marked instruction\000event=0x80b00000010c142\000\00000\000\000"
/* offset=75731 */ "pm_mrk_data_from_onchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload for a marked instruction\000event=0x80b40000020c142\000\00000\000\000"
/* offset=75961 */ "pm_mrk_inst_from_offchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss for a marked instruction\000event=0xc0b00000000c142\000\00000\000\000"
/* offset=76176 */ "pm_mrk_data_from_offchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss for a marked instruction\000event=0xc0b40000000c142\000\00000\000\000"
/* offset=76387 */ "pm_mrk_inst_from_offchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0b00000010c142\000\00000\000\000"
/* offset=76625 */ "pm_mrk_data_from_offchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0b40000020c142\000\00000\000\000"
/* offset=76859 */ "pm_mrk_inst_from_any_memory\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss for a marked instruction\000event=0x95900000000c142\000\00000\000\000"
/* offset=77053 */ "pm_mrk_data_from_any_memory\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss for a marked instruction\000event=0x95840000000c142\000\00000\000\000"
/* offset=77243 */ "pm_mrk_inst_from_any_memory_all\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0x95900000010c142\000\00000\000\000"
/* offset=77460 */ "pm_mrk_data_from_any_memory_all\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0x95840000020c142\000\00000\000\000"
/* offset=77673 */ "pm_flop_cmpl\000floating_point\000Floating Point Operations Completed. Includes any type. It counts once for each 1, 2, 4 or 8 flop instruction. Use PM_1|2|4|8_FLOP_CMPL events to count flops\000event=0x100f4\000\00000\000\000"
/* offset=77878 */ "pm_1flop_cmpl\000floating_point\000One floating point instruction completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45050\000\00000\000\000"
/* offset=78031 */ "pm_4flop_cmpl\000floating_point\000Four floating point instruction completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45052\000\00000\000\000"
/* offset=78185 */ "pm_fma_cmpl\000floating_point\000Two floating point instruction completed (FMA class of instructions: fmadd, fnmadd, fmsub, fnmsub). Scalar instructions only\000event=0x45054\000\00000\000\000"
/* offset=78356 */ "pm_scalar_flop_cmpl\000floating_point\000Scalar floating point instruction completed\000event=0x45056\000\00000\000\000"
/* offset=78454 */ "pm_sp_flop_cmpl\000floating_point\000Single Precision floating point instruction completed\000event=0x4505a\000\00000\000\000"
/* offset=78558 */ "pm_math_flop_cmpl\000floating_point\000Math floating point instruction completed\000event=0x4505c\000\00000\000\000"
/* offset=78652 */ "pm_2flop_cmpl\000floating_point\000Double Precision vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg completed\000event=0x4d052\000\00000\000\000"
/* offset=78801 */ "pm_8flop_cmpl\000floating_point\000Four Double Precision vector instruction completed\000event=0x4d054\000\00000\000\000"
/* offset=78900 */ "pm_non_fma_flop_cmpl\000floating_point\000Non FMA instruction completed\000event=0x4d056\000\00000\000\000"
/* offset=78985 */ "pm_vector_flop_cmpl\000floating_point\000Vector floating point instruction completed\000event=0x4d058\000\00000\000\000"
/* offset=79083 */ "pm_non_math_flop_cmpl\000floating_point\000Non Math instruction completed\000event=0x4d05a\000\00000\000\000"
/* offset=79170 */ "pm_dpp_flop_cmpl\000floating_point\000Double-Precision or Quad-Precision instruction completed\000event=0x4d05c\000\00000\000\000"
/* offset=79278 */ "pm_dtlb_hit_2m\000frontend\000Data TLB hit (DERAT reload) page size 2M. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1d054\000\00000\000\000"
/* offset=79529 */ "pm_itlb_hit_64k\000frontend\000Instruction TLB hit (IERAT reload) page size 64K. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x1d058\000\00000\000\000"
/* offset=79748 */ "pm_dtlb_hit\000frontend\000The PTE required by the instruction was resident in the TLB (data TLB access). When MMCR1[16]=0 this event counts only demand hits. When MMCR1[16]=1 this event includes demand and prefetch. Applies to both HPT and RPT\000event=0x1f054\000\00000\000\000"
/* offset=80006 */ "pm_1plus_ppc_cmpl\000frontend\000Cycles in which at least one instruction is completed by this thread\000event=0x100f2\000\00000\000\000"
/* offset=80121 */ "pm_ierat_miss\000frontend\000IERAT Reloaded to satisfy an IERAT miss. All page sizes are counted by this event. This event only counts instruction demand access\000event=0x100f6\000\00000\000\000"
/* offset=80295 */ "pm_iops_disp\000frontend\000Internal Operations dispatched. PM_IOPS_DISP / PM_INST_DISP will show the average number of internal operations per PowerPC instruction\000event=0x24050\000\00000\000\000"
/* offset=80472 */ "pm_issue_cancel\000frontend\000An instruction issued and the issue was later cancelled. Only one cancel per PowerPC instruction\000event=0x2405e\000\00000\000\000"
/* offset=80613 */ "pm_br_taken_cmpl\000frontend\000Branch Taken instruction completed\000event=0x200fa\000\00000\000\000"
/* offset=80693 */ "pm_disp_stall_itlb_miss\000frontend\000Cycles when dispatch was stalled while waiting to resolve an instruction TLB miss\000event=0x3000a\000\00000\000\000"
/* offset=80827 */ "pm_flush_completion\000frontend\000The instruction that was next to complete (oldest in the pipeline) did not complete because it suffered a flush\000event=0x30012\000\00000\000\000"
/* offset=80987 */ "pm_itlb_hit_1g\000frontend\000Instruction TLB hit (IERAT reload) page size 1G, which implies Radix Page Table translation is in use. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x3f046\000\00000\000\000"
/* offset=81258 */ "pm_dtlb_hit_64k\000frontend\000Data TLB hit (DERAT reload) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c05a\000\00000\000\000"
/* offset=81470 */ "pm_ld_miss_l1\000frontend\000Load missed L1, counted at finish time. LMQ merges are not included in this count. i.e. if a load instruction misses on an address that is already allocated on the LMQ, this event will not increment for that load). Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x3e054\000\00000\000\000"
/* offset=81856 */ "pm_inst_from_l3miss\000frontend\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x300fa\000\00000\000\000"
/* offset=82004 */ "pm_issue_kill\000frontend\000Cycles in which an instruction or group of instructions were cancelled after being issued. This event increments once per occurrence, regardless of how many instructions are included in the issue group\000event=0x40006\000\00000\000\000"
/* offset=82248 */ "pm_vector_st_cmpl\000frontend\000Vector store instruction completed\000event=0x44056\000\00000\000\000"
/* offset=82329 */ "pm_dtlb_hit_1g\000frontend\000Data TLB hit (DERAT reload) page size 1G. Implies radix translation. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4e054\000\00000\000\000"
/* offset=82566 */ "pm_itlb_miss\000frontend\000Instruction TLB reload (after a miss), all page sizes. Includes only demand misses\000event=0x400fc\000\00000\000\000"
/* offset=82690 */ "pm_stcx_fail_fin\000locks\000Conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x1e058\000\00000\000\000"
/* offset=82831 */ "pm_stcx_pass_fin\000locks\000Conditional store instruction (STCX) passed. LARX and STCX are instructions used to acquire a lock\000event=0x4e050\000\00000\000\000"
/* offset=82972 */ "pm_mrk_inst_issued\000marked\000Marked instruction issued. Note that stores always get issued twice, the address gets issued to the LSU and the data gets issued to the VSU. Also, issues can sometimes get killed/cancelled and cause multiple sequential issues for the same instruction\000event=0x10132\000\00000\000\000"
/* offset=83268 */ "pm_mrk_st_done_l2\000marked\000Marked store completed in L2\000event=0x10134\000\00000\000\000"
/* offset=83341 */ "pm_mrk_xfer_from_src_pmc1\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c142\000\00000\000\000"
/* offset=83708 */ "pm_mrk_xfer_from_src_cyc_pmc1\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[0:12]\000event=0x1c144\000\00000\000\000"
/* offset=83860 */ "pm_mrk_dtlb_miss_1g\000marked\000Marked Data TLB reload (after a miss) page size 1G. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1d15c\000\00000\000\000"
/* offset=84119 */ "pm_mrk_st_l2_cyc\000marked\000Cycles from L2 RC dispatch to L2 RC completion\000event=0x1f150\000\00000\000\000"
/* offset=84209 */ "pm_mrk_inst_disp\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\00000\000\000"
/* offset=84316 */ "pm_mrk_br_taken_cmpl\000marked\000Marked Branch Taken instruction completed\000event=0x101e2\000\00000\000\000"
/* offset=84405 */ "pm_mrk_l1_icache_miss\000marked\000Marked instruction suffered an instruction cache miss\000event=0x101e4\000\00000\000\000"
/* offset=84507 */ "pm_mrk_l1_reload_valid\000marked\000Marked demand reload\000event=0x101ea\000\00000\000\000"
/* offset=84577 */ "pm_mrk_l2_rc_disp\000marked\000Marked instruction RC dispatched in L2\000event=0x20114\000\00000\000\000"
/* offset=84660 */ "pm_mrk_ntf_cyc\000marked\000Cycles in which the marked instruction is the oldest in the pipeline (next-to-finish or next-to-complete)\000event=0x2011c\000\00000\000\000"
/* offset=84807 */ "pm_mrk_inst_decoded\000marked\000An instruction was marked at decode time. Random Instruction Sampling (RIS) only\000event=0x20130\000\00000\000\000"
/* offset=84934 */ "pm_mrk_dfu_issue\000marked\000The marked instruction was a decimal floating point operation issued to the VSU. Measured at issue time\000event=0x20132\000\00000\000\000"
/* offset=85081 */ "pm_mrk_fxu_issue\000marked\000The marked instruction was a fixed point operation issued to the VSU. Measured at issue time\000event=0x20134\000\00000\000\000"
/* offset=85217 */ "pm_mrk_st_nest\000marked\000A store has been sampled/marked and is at the point of execution where it has completed in the core and can no longer be flushed. At this point the store is sent to the L2\000event=0x20138\000\00000\000\000"
/* offset=85430 */ "pm_mrk_bru_fin\000marked\000Marked Branch instruction finished\000event=0x2013a\000\00000\000\000"
/* offset=85506 */ "pm_mrk_fx_lsu_fin\000marked\000The marked instruction was simple fixed point that was issued to the store unit. Measured at finish time\000event=0x2013c\000\00000\000\000"
/* offset=85655 */ "pm_mrk_xfer_from_src_pmc2\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c142\000\00000\000\000"
/* offset=86023 */ "pm_mrk_xfer_from_src_cyc_pmc2\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[15:27]\000event=0x2c144\000\00000\000\000"
/* offset=86176 */ "pm_mrk_stcx_fin\000marked\000Marked conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x24156\000\00000\000\000"
/* offset=86326 */ "pm_mrk_inst\000marked\000An instruction was marked. Includes both Random Instruction Sampling (RIS) at decode time and Random Event Sampling (RES) at the time the configured event happens\000event=0x24158\000\00000\000\000"
/* offset=86527 */ "pm_mrk_br_cmpl\000marked\000A marked branch completed. All branches are included\000event=0x2415c\000\00000\000\000"
/* offset=86621 */ "pm_mrk_derat_miss_64k\000marked\000Data ERAT Miss (Data TLB Access) page size 64K for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2d154\000\00000\000\000"
/* offset=86881 */ "pm_mrk_data_from_memory\000marked\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss for a marked load\000event=0x201e0\000\00000\000\000"
/* offset=87048 */ "pm_mrk_ld_miss_l1\000marked\000Marked demand data load miss counted at finish time\000event=0x201e2\000\00000\000\000"
/* offset=87144 */ "pm_mrk_data_from_l3miss\000marked\000The processor's data cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss for a marked load\000event=0x201e4\000\00000\000\000"
/* offset=87329 */ "pm_mrk_l2_rc_done\000marked\000L2 RC machine completed the transaction for the marked instruction\000event=0x3012a\000\00000\000\000"
/* offset=87440 */ "pm_mrk_dtlb_miss_2m\000marked\000Marked Data TLB reload (after a miss) page size 2M, which implies Radix Page Table translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3012e\000\00000\000\000"
/* offset=87716 */ "pm_mrk_vsu_fin\000marked\000VSU marked instruction finished. Excludes simple FX instructions issued to the Store Unit\000event=0x30132\000\00000\000\000"
/* offset=87847 */ "pm_mrk_ld_cmpl\000marked\000Marked load instruction completed\000event=0x34146\000\00000\000\000"
/* offset=87922 */ "pm_mrk_xfer_from_src_pmc3\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c142\000\00000\000\000"
/* offset=88290 */ "pm_mrk_xfer_from_src_cyc_pmc3\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[30:42]\000event=0x3c144\000\00000\000\000"
/* offset=88443 */ "pm_mrk_stcx_fail\000marked\000Marked conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x3e158\000\00000\000\000"
/* offset=88592 */ "pm_mrk_st_fin\000marked\000Marked store instruction finished\000event=0x3e15a\000\00000\000\000"
/* offset=88666 */ "pm_mrk_st_drain_cyc\000marked\000Cycles in which the marked store drained from the core to the L2\000event=0x3f150\000\00000\000\000"
/* offset=88777 */ "pm_mrk_issue_dependent_load\000marked\000The marked instruction was dependent on a load. It is eligible for issue kill\000event=0x30162\000\00000\000\000"
/* offset=88909 */ "pm_mrk_st_cmpl\000marked\000Marked store completed and sent to nest. Note that this count excludes cache-inhibited stores\000event=0x301e2\000\00000\000\000"
/* offset=89044 */ "pm_mrk_br_mpred_cmpl\000marked\000Marked Branch Mispredicted. Includes direction and target\000event=0x301e4\000\00000\000\000"
/* offset=89149 */ "pm_mrk_derat_miss\000marked\000Marked Erat Miss (Data TLB Access) All page sizes. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x301e6\000\00000\000\000"
/* offset=89383 */ "pm_mrk_tlbie_fin\000marked\000Marked TLBIE instruction finished. Includes TLBIE and TLBIEL instructions\000event=0x4010e\000\00000\000\000"
/* offset=89500 */ "pm_mrk_larx_fin\000marked\000Marked load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x40116\000\00000\000\000"
/* offset=89649 */ "pm_mrk_lsu_fin\000marked\000LSU marked instruction finish\000event=0x40132\000\00000\000\000"
/* offset=89720 */ "pm_mrk_stcx_core_cyc\000marked\000Cycles spent in the core portion of a marked STCX instruction. It starts counting when the instruction is decoded and stops counting when it drains into the L2\000event=0x44146\000\00000\000\000"
/* offset=89927 */ "pm_mrk_xfer_from_src_pmc4\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c142\000\00000\000\000"
/* offset=90295 */ "pm_mrk_xfer_from_src_cyc_pmc4\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[45:57]\000event=0x4c144\000\00000\000\000"
/* offset=90448 */ "pm_mrk_derat_miss_1g\000marked\000Data ERAT Miss (Data TLB Access) page size 1G for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c15c\000\00000\000\000"
/* offset=90706 */ "pm_mrk_dtlb_miss_64k\000marked\000Marked Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c15e\000\00000\000\000"
/* offset=90931 */ "pm_mrk_inst_flushed\000marked\000The marked instruction was flushed\000event=0x4e15e\000\00000\000\000"
/* offset=91012 */ "pm_mrk_derat_miss_2m\000marked\000Data ERAT Miss (Data TLB Access) page size 2M for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x40164\000\00000\000\000"
/* offset=91270 */ "pm_mrk_inst_cmpl\000marked\000Marked instruction completed\000event=0x401e0\000\00000\000\000"
/* offset=91342 */ "pm_mrk_dtlb_miss\000marked\000The DPTEG required for the marked load/store instruction in execution was missing from the TLB. This event only counts for demand misses\000event=0x401e4\000\00000\000\000"
/* offset=91522 */ "pm_mrk_inst_from_l3miss\000marked\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss for a marked instruction\000event=0x401e6\000\00000\000\000"
/* offset=91697 */ "pm_mrk_data_from_l2miss\000marked\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss for a marked instruction\000event=0x401e8\000\00000\000\000"
/* offset=91877 */ "pm_xfer_from_src_pmc1\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c040\000\00000\000\000"
/* offset=92200 */ "pm_derat_miss_4k\000memory\000Data ERAT Miss (Data TLB Access) page size 4K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c056\000\00000\000\000"
/* offset=92429 */ "pm_dtlb_miss_16g\000memory\000Data TLB reload (after a miss) page size 16G. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c058\000\00000\000\000"
/* offset=92643 */ "pm_dtlb_miss_2m\000memory\000Data TLB reload (after a miss) page size 2M. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05c\000\00000\000\000"
/* offset=92891 */ "pm_ld_l3miss_pend_cyc\000memory\000Cycles in which an L3 miss was pending for this thread\000event=0x10062\000\00000\000\000"
/* offset=92994 */ "pm_itlb_hit\000memory\000The PTE required to translate the instruction address was resident in the TLB (instruction TLB access/IERAT reload). Applies to both HPT and RPT. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x2001a\000\00000\000\000"
/* offset=93303 */ "pm_ptesync_fin\000memory\000Ptesync instruction finished in the store unit. Only one ptesync can finish at a time\000event=0x2003e\000\00000\000\000"
/* offset=93430 */ "pm_xfer_from_src_pmc2\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c040\000\00000\000\000"
/* offset=93754 */ "pm_derat_miss_64k\000memory\000Data ERAT Miss (Data TLB Access) page size 64K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c054\000\00000\000\000"
/* offset=93985 */ "pm_dtlb_miss_4k\000memory\000Data TLB reload (after a miss) page size 4K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c056\000\00000\000\000"
/* offset=94197 */ "pm_derat_miss_1g\000memory\000Data ERAT Miss (Data TLB Access) page size 1G. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c05a\000\00000\000\000"
/* offset=94453 */ "pm_derat_miss\000memory\000DERAT Reloaded to satisfy a DERAT miss. All page sizes are counted by this event. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x200f6\000\00000\000\000"
/* offset=94714 */ "pm_derat_miss_pref\000memory\000DERAT miss (TLB access) while servicing a data prefetch\000event=0x34044\000\00000\000\000"
/* offset=94815 */ "pm_xfer_from_src_pmc3\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c040\000\00000\000\000"
/* offset=95139 */ "pm_derat_miss_16m\000memory\000Data ERAT Miss (Data TLB Access) page size 16M. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c054\000\00000\000\000"
/* offset=95370 */ "pm_dtlb_miss_64k\000memory\000Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c056\000\00000\000\000"
/* offset=95584 */ "pm_larx_fin\000memory\000Load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x3c058\000\00000\000\000"
/* offset=95722 */ "pm_dtlb_miss\000memory\000The DPTEG required for the load/store instruction in execution was missing from the TLB. This event only counts for demand misses\000event=0x300fc\000\00000\000\000"
/* offset=95891 */ "pm_ld_cmpl\000memory\000Load instruction completed\000event=0x4003e\000\00000\000\000"
/* offset=95955 */ "pm_xfer_from_src_pmc4\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c040\000\00000\000\000"
/* offset=96279 */ "pm_dtlb_miss_16m\000memory\000Data TLB reload (after a miss) page size 16M. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c056\000\00000\000\000"
/* offset=96493 */ "pm_dtlb_miss_1g\000memory\000Data TLB reload (after a miss) page size 1G. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c05a\000\00000\000\000"
/* offset=96741 */ "pm_ld_prefetch_cache_line_miss\000others\000The L1 cache was reloaded with a line that fulfills a prefetch request\000event=0x1002c\000\00000\000\000"
/* offset=96869 */ "pm_ld_hit_l1\000others\000Load finished without experiencing an L1 miss\000event=0x1505e\000\00000\000\000"
/* offset=96954 */ "pm_disp_ss0_2_instr_cyc\000others\000Cycles in which Superslice 0 dispatches either 1 or 2 instructions\000event=0x1f056\000\00000\000\000"
/* offset=97071 */ "pm_disp_held_sync_cyc\000others\000Cycles dispatch is held because of a synchronizing instruction that requires the ICT to be empty before dispatch\000event=0x1f05a\000\00000\000\000"
/* offset=97232 */ "pm_adjunct_cyc\000others\000Cycles in which the thread is in Adjunct state. MSR[S HV PR] bits = 011\000event=0x10066\000\00000\000\000"
/* offset=97345 */ "pm_ld_ref_l1\000others\000All L1 D cache load references counted at finish, gated by reject. In P9 and earlier this event counted only cacheable loads but in P10 both cacheable and non-cacheable loads are included\000event=0x100fc\000\00000\000\000"
/* offset=97572 */ "pm_adjunct_inst_cmpl\000others\000PowerPC instruction completed while the thread was in Adjunct state\000event=0x2e010\000\00000\000\000"
/* offset=97687 */ "pm_stcx_fin\000others\000Conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x2e014\000\00000\000\000"
/* offset=97826 */ "pm_disp_ss1_2_instr_cyc\000others\000Cycles in which Superslice 1 dispatches either 1 or 2 instructions\000event=0x2f054\000\00000\000\000"
/* offset=97943 */ "pm_disp_ss1_4_instr_cyc\000others\000Cycles in which Superslice 1 dispatches either 3 or 4 instructions\000event=0x2f056\000\00000\000\000"
/* offset=98060 */ "pm_inst_disp\000others\000PowerPC instruction dispatched\000event=0x200f2\000\00000\000\000"
/* offset=98130 */ "pm_l1_icache_miss\000others\000Demand instruction cache miss\000event=0x200fd\000\00000\000\000"
/* offset=98204 */ "pm_lsu_st5_fin\000others\000LSU Finished an internal operation in ST2 port\000event=0x3f04a\000\00000\000\000"
/* offset=98292 */ "pm_privileged_inst_cmpl\000others\000PowerPC instruction completed while the thread was in Privileged state\000event=0x3405a\000\00000\000\000"
/* offset=98413 */ "pm_disp_ss0_4_instr_cyc\000others\000Cycles in which Superslice 0 dispatches either 3 or 4 instructions\000event=0x3f054\000\00000\000\000"
/* offset=98530 */ "pm_disp_ss0_8_instr_cyc\000others\000Cycles in which Superslice 0 dispatches either 5, 6, 7 or 8 instructions\000event=0x3f056\000\00000\000\000"
/* offset=98653 */ "pm_l1_icache_reloaded_pref\000others\000Counts all instruction cache prefetch reloads (includes demand turned into prefetch)\000event=0x30068\000\00000\000\000"
/* offset=98791 */ "pm_ld_demand_miss_l1\000others\000The L1 cache was reloaded with a line that fulfills a demand miss request. Counted at reload time, before finish\000event=0x300f6\000\00000\000\000"
/* offset=98951 */ "pm_l1_icache_reloaded_all\000others\000Counts all instruction cache reloads includes demand, prefetch, prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\00000\000\000"
/* offset=99127 */ "pm_vector_ld_cmpl\000others\000Vector load instruction completed\000event=0x44054\000\00000\000\000"
/* offset=99205 */ "pm_br_cmpl\000others\000A branch completed. All branches are included\000event=0x4d05e\000\00000\000\000"
/* offset=99288 */ "pm_ld_demand_miss_l1_fin\000others\000Load missed L1, counted at finish time\000event=0x400f0\000\00000\000\000"
/* offset=99378 */ "pm_exec_stall_translation\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss or ERAT miss and waited for it to resolve\000event=0x10004\000\00000\000\000"
/* offset=99549 */ "pm_disp_stall_held_other_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch for any other reason\000event=0x10006\000\00000\000\000"
/* offset=99702 */ "pm_lsu_ld0_fin\000pipeline\000LSU Finished an internal operation in LD0 port\000event=0x1000c\000\00000\000\000"
/* offset=99792 */ "pm_mma_issued\000pipeline\000MMA instruction issued\000event=0x1000e\000\00000\000\000"
/* offset=99857 */ "pm_lsu_st0_fin\000pipeline\000LSU Finished an internal operation in ST0 port\000event=0x10012\000\00000\000\000"
/* offset=99947 */ "pm_lsu_st4_fin\000pipeline\000LSU Finished an internal operation in ST4 port\000event=0x10014\000\00000\000\000"
/* offset=100037 */ "pm_ic_demand_cyc\000pipeline\000Cycles in which an instruction reload is pending to satisfy a demand miss\000event=0x10018\000\00000\000\000"
/* offset=100156 */ "pm_ntc_flush\000pipeline\000The instruction was flushed after becoming next-to-complete (NTC)\000event=0x10028\000\00000\000\000"
/* offset=100263 */ "pm_disp_stall_translation\000pipeline\000Cycles when dispatch was stalled for this thread because the MMU was handling a translation miss\000event=0x10038\000\00000\000\000"
/* offset=100414 */ "pm_disp_stall_br_mpred_ic_l2\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L2 after suffering a branch mispredict\000event=0x1003a\000\00000\000\000"
/* offset=100592 */ "pm_exec_stall_dmiss_l2l3\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from either the local L2 or local L3\000event=0x1003c\000\00000\000\000"
/* offset=100776 */ "pm_exec_stall_fin_at_disp\000pipeline\000Cycles in which the oldest instruction in the pipeline finished at dispatch and did not require execution in the LSU, BRU or VSU\000event=0x10058\000\00000\000\000"
/* offset=100959 */ "pm_flush_mpred\000pipeline\000A flush occurred due to a mispredicted branch. Includes target and direction\000event=0x1005a\000\00000\000\000"
/* offset=101079 */ "pm_derat_miss_2m\000pipeline\000Data ERAT Miss (Data TLB Access) page size 2M. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05a\000\00000\000\000"
/* offset=101337 */ "pm_disp_stall_held_halt_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because of power management\000event=0x1d05e\000\00000\000\000"
/* offset=101496 */ "pm_disp_stall_held_stf_mapper_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because the STF mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR\000event=0x1e050\000\00000\000\000"
/* offset=101717 */ "pm_exec_stall_dmiss_l21_l31\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from another core's L2 or L3 on the same chip\000event=0x1e054\000\00000\000\000"
/* offset=101913 */ "pm_exec_stall_store_pipe\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the store unit. This does not include cycles spent handling store misses, PTESYNC instructions or TLBIE instructions\000event=0x1e056\000\00000\000\000"
/* offset=102155 */ "pm_cmpl_stall_lwsync\000pipeline\000Cycles in which the oldest instruction in the pipeline was a lwsync waiting to complete\000event=0x1e05a\000\00000\000\000"
/* offset=102292 */ "pm_disp_held_cyc\000pipeline\000Cycles dispatch is held\000event=0x1f058\000\00000\000\000"
/* offset=102361 */ "pm_disp_stall_ic_l2\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L2\000event=0x10064\000\00000\000\000"
/* offset=102494 */ "pm_br_fin\000pipeline\000A branch instruction finished. Includes predicted/mispredicted/unconditional\000event=0x10068\000\00000\000\000"
/* offset=102609 */ "pm_fx_lsu_fin\000pipeline\000Simple fixed point instruction issued to the store unit. Measured at finish time\000event=0x1006a\000\00000\000\000"
/* offset=102732 */ "pm_disp_stall_cyc\000pipeline\000Cycles the ICT has no itags assigned to this thread (no instructions were dispatched during these cycles)\000event=0x100f8\000\00000\000\000"
/* offset=102884 */ "pm_issue_stall\000pipeline\000Cycles in which the oldest instruction in the pipeline was dispatched but not issued yet\000event=0x20004\000\00000\000\000"
/* offset=103016 */ "pm_disp_stall_held_issq_full_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch due to Issue queue full. Includes issue queue and branch queue\000event=0x20006\000\00000\000\000"
/* offset=103215 */ "pm_lsu_ld1_fin\000pipeline\000LSU Finished an internal operation in LD1 port\000event=0x2000e\000\00000\000\000"
/* offset=103305 */ "pm_exec_stall_lsu\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the Load Store Unit. This does not include simple fixed point instructions\000event=0x2c010\000\00000\000\000"
/* offset=103498 */ "pm_cmpl_stall_special\000pipeline\000Cycles in which the oldest instruction in the pipeline required special handling before completing\000event=0x2c014\000\00000\000\000"
/* offset=103647 */ "pm_disp_stall_ierat_only_miss\000pipeline\000Cycles when dispatch was stalled while waiting to resolve an instruction ERAT miss\000event=0x2c016\000\00000\000\000"
/* offset=103788 */ "pm_exec_stall_dmiss_l3miss\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a source beyond the local L2 or local L3\000event=0x2c018\000\00000\000\000"
/* offset=103983 */ "pm_exec_stall_dmiss_off_chip\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a remote chip\000event=0x2c01c\000\00000\000\000"
/* offset=104153 */ "pm_disp_stall_br_mpred_ic_l3\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L3 after suffering a branch mispredict\000event=0x2c01e\000\00000\000\000"
/* offset=104331 */ "pm_lsu_st1_fin\000pipeline\000LSU Finished an internal operation in ST1 port\000event=0x2d010\000\00000\000\000"
/* offset=104421 */ "pm_vsu0_issue\000pipeline\000VSU instruction issued to VSU pipe 0\000event=0x10016\000\00000\000\000"
/* offset=104500 */ "pm_vsu1_issue\000pipeline\000VSU instruction issued to VSU pipe 1\000event=0x2d012\000\00000\000\000"
/* offset=104579 */ "pm_vsu_issue\000pipeline\000At least one VSU instruction was issued to one of the VSU pipes. Up to 4 per cycle. Includes fixed point operations\000event=0x2505c\000\00000\000\000"
/* offset=104736 */ "pm_vsu_fin\000pipeline\000VSU instruction finished\000event=0x4001c\000\00000\000\000"
/* offset=104800 */ "pm_exec_stall_vsu\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the VSU (includes FXU, VSU, CRU)\000event=0x2d018\000\00000\000\000"
/* offset=104951 */ "pm_disp_stall_ic_miss\000pipeline\000Cycles when dispatch was stalled for this thread due to an instruction cache miss\000event=0x2d01a\000\00000\000\000"
/* offset=105083 */ "pm_cmpl_stall_stcx\000pipeline\000Cycles in which the oldest instruction in the pipeline was a stcx waiting for resolution from the nest before completing\000event=0x2d01c\000\00000\000\000"
/* offset=105251 */ "pm_disp_stall_fetch\000pipeline\000Cycles when dispatch was stalled for this thread because Fetch was being held\000event=0x2e018\000\00000\000\000"
/* offset=105377 */ "pm_disp_stall_held_xvfc_mapper_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because the XVFC mapper/SRB was full\000event=0x2e01a\000\00000\000\000"
/* offset=105552 */ "pm_exec_stall_tlbie\000pipeline\000Cycles in which the oldest instruction in the pipeline was a TLBIE instruction executing in the Load Store Unit\000event=0x2e01c\000\00000\000\000"
/* offset=105712 */ "pm_exec_stall_ntc_flush\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in any unit before it was flushed. Note that if the flush of the oldest instruction happens after finish, the cycles from dispatch to issue will be included in PM_DISP_STALL and the cycles from issue to finish will be included in PM_EXEC_STALL and its corresponding children. This event will also count cycles when the previous next-to-finish (NTF) instruction is still completing and the new NTF instruction is stalled at dispatch\000event=0x2e01e\000\00000\000\000"
/* offset=106265 */ "pm_ntc_fin\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. Note that instructions can finish out of order, therefore not all the instructions that finish have a Next-to-complete status\000event=0x2405a\000\00000\000\000"
/* offset=106501 */ "pm_disp_held_other_cyc\000pipeline\000Cycles dispatch is held for any other reason\000event=0x20066\000\00000\000\000"
/* offset=106597 */ "pm_disp_held_stf_mapper_cyc\000pipeline\000Cycles dispatch is held because the STF mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR\000event=0x2006a\000\00000\000\000"
/* offset=106761 */ "pm_disp_stall_flush\000pipeline\000Cycles when dispatch was stalled because of a flush that happened to an instruction(s) that was not yet next-to-complete (NTC). PM_EXEC_STALL_NTC_FLUSH only includes instructions that were flushed after becoming NTC\000event=0x30004\000\00000\000\000"
/* offset=107025 */ "pm_exec_stall\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting to finish in one of the execution units (BRU, LSU, VSU). Only cycles between issue and finish are counted in this category\000event=0x30008\000\00000\000\000"
/* offset=107257 */ "pm_exec_stall_store\000pipeline\000Cycles in which the oldest instruction in the pipeline was a store instruction executing in the Load Store Unit\000event=0x30014\000\00000\000\000"
/* offset=107417 */ "pm_exec_stall_derat_dtlb_miss\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss and waited for it resolve\000event=0x30016\000\00000\000\000"
/* offset=107576 */ "pm_disp_stall_held_scoreboard_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch while waiting on the Scoreboard. This event combines VSCR and FPSCR together\000event=0x30018\000\00000\000\000"
/* offset=107790 */ "pm_lsu_st2_fin\000pipeline\000LSU Finished an internal operation in ST2 port\000event=0x3001a\000\00000\000\000"
/* offset=107880 */ "pm_exec_stall_store_miss\000pipeline\000Cycles in which the oldest instruction in the pipeline was a store whose cache line was not resident in the L1 and was waiting for allocation of the missing line into the L1\000event=0x30026\000\00000\000\000"
/* offset=108107 */ "pm_cmpl_stall_mem_ecc\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for the non-speculative finish of either a STCX waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\00000\000\000"
/* offset=108354 */ "pm_exec_stall_simple_fx\000pipeline\000Cycles in which the oldest instruction in the pipeline was a simple fixed point instruction executing in the Load Store Unit\000event=0x30036\000\00000\000\000"
/* offset=108531 */ "pm_exec_stall_dmiss_lmem\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local memory, local OpenCAPI cache, or local OpenCAPI memory\000event=0x30038\000\00000\000\000"
/* offset=108748 */ "pm_cmpl_stall_exception\000pipeline\000Cycles in which the oldest instruction in the pipeline was not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\00000\000\000"
/* offset=108989 */ "pm_vsu2_issue\000pipeline\000VSU instruction issued to VSU pipe 2\000event=0x3f044\000\00000\000\000"
/* offset=109068 */ "pm_tlbie_fin\000pipeline\000TLBIE instruction finished in the LSU. Two TLBIEs can finish each cycle. All will be counted\000event=0x30058\000\00000\000\000"
/* offset=109202 */ "pm_exec_stall_dmiss_l2l3_noconflict\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, without a dispatch conflict\000event=0x34054\000\00000\000\000"
/* offset=109419 */ "pm_exec_stall_load_finish\000pipeline\000Cycles in which the oldest instruction in the pipeline was finishing a load after its data was reloaded from a data source beyond the local L1; cycles in which the LSU was processing an L1-hit; cycles in which the next-to-finish (NTF) instruction merged with another load in the LMQ; cycles in which the NTF instruction is waiting for a data reload for a load miss, but the data comes back with a non-NTF instruction\000event=0x34056\000\00000\000\000"
/* offset=109890 */ "pm_disp_stall_br_mpred_icmiss\000pipeline\000Cycles when dispatch was stalled after a mispredicted branch resulted in an instruction cache miss\000event=0x34058\000\00000\000\000"
/* offset=110047 */ "pm_disp_stall_held_rename_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because the mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR and XVFC\000event=0x3d05c\000\00000\000\000"
/* offset=110269 */ "pm_disp_stall_ic_l3\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L3\000event=0x3e052\000\00000\000\000"
/* offset=110402 */ "pm_disp_held_xvfc_mapper_cyc\000pipeline\000Cycles dispatch is held because the XVFC mapper/SRB was full\000event=0x30060\000\00000\000\000"
/* offset=110520 */ "pm_lsu_fin\000pipeline\000LSU Finished an internal operation (up to 4 per cycle)\000event=0x30066\000\00000\000\000"
/* offset=110614 */ "pm_fxu_issue\000pipeline\000A fixed point instruction was issued to the VSU\000event=0x40004\000\00000\000\000"
/* offset=110703 */ "pm_ntc_all_fin\000pipeline\000Cycles in which both instructions in the ICT entry pair show as finished. These are the cycles between finish and completion for the oldest pair of instructions in the pipeline\000event=0x40008\000\00000\000\000"
/* offset=110923 */ "pm_disp_stall_br_mpred_ic_l3miss\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from sources beyond the local L3 after suffering a mispredicted branch\000event=0x4c010\000\00000\000\000"
/* offset=111122 */ "pm_exec_stall_derat_only_miss\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered an ERAT miss and waited for it resolve\000event=0x4c012\000\00000\000\000"
/* offset=111283 */ "pm_exec_stall_dmiss_l2l3_conflict\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, with a dispatch conflict\000event=0x4c016\000\00000\000\000"
/* offset=111495 */ "pm_cmpl_stall\000pipeline\000Cycles in which the oldest instruction in the pipeline cannot complete because the thread was blocked for any reason\000event=0x4c018\000\00000\000\000"
/* offset=111654 */ "pm_exec_stall_dmiss_off_node\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a distant chip\000event=0x4c01a\000\00000\000\000"
/* offset=111825 */ "pm_lsu_st3_fin\000pipeline\000LSU Finished an internal operation in ST3 port\000event=0x4c01e\000\00000\000\000"
/* offset=111915 */ "pm_exec_stall_load\000pipeline\000Cycles in which the oldest instruction in the pipeline was a load instruction executing in the Load Store Unit\000event=0x4d014\000\00000\000\000"
/* offset=112073 */ "pm_exec_stall_ptesync\000pipeline\000Cycles in which the oldest instruction in the pipeline was a PTESYNC instruction executing in the Load Store Unit\000event=0x4d016\000\00000\000\000"
/* offset=112237 */ "pm_exec_stall_bru\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the Branch unit\000event=0x4d018\000\00000\000\000"
/* offset=112371 */ "pm_cmpl_stall_hwsync\000pipeline\000Cycles in which the oldest instruction in the pipeline was a hwsync waiting for response from L2 before completing\000event=0x4d01a\000\00000\000\000"
/* offset=112535 */ "pm_exec_stall_tlbiel\000pipeline\000Cycles in which the oldest instruction in the pipeline was a TLBIEL instruction executing in the Load Store Unit. TLBIEL instructions have lower overhead than TLBIE instructions because they don't get set to the nest\000event=0x4d01c\000\00000\000\000"
/* offset=112801 */ "pm_disp_stall_br_mpred\000pipeline\000Cycles when dispatch was stalled for this thread due to a mispredicted branch\000event=0x4d01e\000\00000\000\000"
/* offset=112930 */ "pm_disp_stall_ic_l3miss\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000event=0x4e010\000\00000\000\000"
/* offset=113085 */ "pm_exec_stall_unknown\000pipeline\000Cycles in which the oldest instruction in the pipeline completed without an ntf_type pulse. The ntf_pulse was missed by the ISU because the next-to-finish (NTF) instruction finishes and completions came too close together\000event=0x4e012\000\00000\000\000"
/* offset=113357 */ "pm_disp_stall_held_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch for any reason\000event=0x4e01a\000\00000\000\000"
/* offset=113498 */ "pm_vsu3_issue\000pipeline\000VSU instruction was issued to VSU pipe 3\000event=0x4d020\000\00000\000\000"
/* offset=113581 */ "pm_disp_stall_held_sync_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000event=0x4003c\000\00000\000\000"
/* offset=113801 */ "pm_ic_miss_cmpl\000pipeline\000Non-speculative instruction cache miss, counted at completion\000event=0x45058\000\00000\000\000"
/* offset=113907 */ "pm_disp_held_scoreboard_cyc\000pipeline\000Cycles dispatch is held while waiting on the Scoreboard. This event combines VSCR and FPSCR together\000event=0x40060\000\00000\000\000"
/* offset=114064 */ "pm_disp_held_rename_cyc\000pipeline\000Cycles dispatch is held because the mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR and XVFC\000event=0x40062\000\00000\000\000"
/* offset=114229 */ "pm_1plus_ppc_disp\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\00000\000\000"
/* offset=114312 */ "pm_flush\000pipeline\000Flush (any type)\000event=0x400f8\000\00000\000\000"
/* offset=114366 */ "pm_inst_cmpl\000pmc\000PowerPC instruction completed\000event=0x100fe\000\00000\000\000"
/* offset=114432 */ "pm_pmc3_rewind\000pmc\000The speculative event selected for PMC3 rewinds and the counter for PMC3 is not charged\000event=0x1000a\000\00000\000\000"
/* offset=114558 */ "pm_pmc4_overflow\000pmc\000The event selected for PMC4 caused the event counter to overflow\000event=0x10010\000\00000\000\000"
/* offset=114663 */ "pm_ultravisor_inst_cmpl\000pmc\000PowerPC instruction completed while the thread was in ultravisor state\000event=0x1001c\000\00000\000\000"
/* offset=114781 */ "pm_cyc\000pmc\000Processor cycles\000event=0x100f0\000\00000\000\000"
/* offset=114828 */ "pm_pmc4_rewind\000pmc\000The speculative event selected for PMC4 rewinds and the counter for PMC4 is not charged\000event=0x10020\000\00000\000\000"
/* offset=114954 */ "pm_pmc2_saved\000pmc\000The conditions for the speculative event selected for PMC2 are met and PMC2 is charged\000event=0x10022\000\00000\000\000"
/* offset=115078 */ "pm_pmc5_overflow\000pmc\000The event selected for PMC5 caused the event counter to overflow\000event=0x10024\000\00000\000\000"
/* offset=115183 */ "pm_pmc3_held_cyc\000pmc\000Cycles when the speculative counter for PMC3 is frozen\000event=0x1002a\000\00000\000\000"
/* offset=115278 */ "pm_mrk_start_probe_nop_cmpl\000pmc\000Marked Start probe nop (AND R0,R0,R0) completed\000event=0x1f15e\000\00000\000\000"
/* offset=115377 */ "pm_run_cyc_st_mode\000pmc\000Cycles when the run latch is set and the core is in ST mode\000event=0x1006c\000\00000\000\000"
/* offset=115479 */ "pm_thresh_exc_256\000pmc\000Threshold counter exceeded a count of 256\000event=0x101e8\000\00000\000\000"
/* offset=115562 */ "pm_thresh_met\000pmc\000Threshold exceeded\000event=0x101ec\000\00000\000\000"
/* offset=115618 */ "pm_run_latch_any_thread_cyc\000pmc\000Cycles when at least one thread has the run latch set\000event=0x100fa\000\00000\000\000"
/* offset=115723 */ "pm_hypervisor_cyc\000pmc\000Cycles when the thread is in Hypervisor state. MSR[S HV PR]=010\000event=0x2000a\000\00000\000\000"
/* offset=115828 */ "pm_run_latch_all_threads_cyc\000pmc\000Cycles when the run latch is set for all threads\000event=0x2000c\000\00000\000\000"
/* offset=115929 */ "pm_pmc1_overflow\000pmc\000The event selected for PMC1 caused the event counter to overflow\000event=0x20010\000\00000\000\000"
/* offset=116034 */ "pm_run_cyc_smt4_mode\000pmc\000Cycles when this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\00000\000\000"
/* offset=116150 */ "pm_thresh_exc_32\000pmc\000Threshold counter exceeded a value of 32\000event=0x201e6\000\00000\000\000"
/* offset=116231 */ "pm_thresh_exc_512\000pmc\000Threshold counter exceeded a value of 512\000event=0x201e8\000\00000\000\000"
/* offset=116314 */ "pm_run_cyc\000pmc\000Processor cycles gated by the run latch\000event=0x200f4\000\00000\000\000"
/* offset=116388 */ "pm_pmc2_overflow\000pmc\000The event selected for PMC2 caused the event counter to overflow\000event=0x30010\000\00000\000\000"
/* offset=116493 */ "pm_pmc2_rewind\000pmc\000The speculative event selected for PMC2 rewinds and the counter for PMC2 is not charged\000event=0x30020\000\00000\000\000"
/* offset=116619 */ "pm_pmc4_saved\000pmc\000The conditions for the speculative event selected for PMC4 are met and PMC4 is charged\000event=0x30022\000\00000\000\000"
/* offset=116743 */ "pm_pmc6_overflow\000pmc\000The event selected for PMC6 caused the event counter to overflow\000event=0x30024\000\00000\000\000"
/* offset=116848 */ "pm_run_cyc_smt2_mode\000pmc\000Cycles when this thread's run latch is set and the core is in SMT2 mode\000event=0x3006c\000\00000\000\000"
/* offset=116964 */ "pm_thresh_exc_64\000pmc\000Threshold counter exceeded a value of 64\000event=0x301e8\000\00000\000\000"
/* offset=117045 */ "pm_thresh_exc_1024\000pmc\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\00000\000\000"
/* offset=117130 */ "pm_pmc3_overflow\000pmc\000The event selected for PMC3 caused the event counter to overflow\000event=0x40010\000\00000\000\000"
/* offset=117235 */ "pm_mrk_start_probe_nop_disp\000pmc\000Marked Start probe nop dispatched. Instruction AND R0,R0,R0\000event=0x40114\000\00000\000\000"
/* offset=117346 */ "pm_pmc1_saved\000pmc\000The conditions for the speculative event selected for PMC1 are met and PMC1 is charged\000event=0x4d010\000\00000\000\000"
/* offset=117470 */ "pm_pmc3_saved\000pmc\000The conditions for the speculative event selected for PMC3 are met and PMC3 is charged\000event=0x4d012\000\00000\000\000"
/* offset=117594 */ "pm_hypervisor_inst_cmpl\000pmc\000PowerPC instruction completed while the thread was in hypervisor state\000event=0x4d022\000\00000\000\000"
/* offset=117712 */ "pm_ultravisor_cyc\000pmc\000Cycles when the thread is in Ultravisor state. MSR[S HV PR]=110\000event=0x4d026\000\00000\000\000"
/* offset=117817 */ "pm_privileged_cyc\000pmc\000Cycles when the thread is in Privileged state. MSR[S HV PR]=x00\000event=0x4d028\000\00000\000\000"
/* offset=117922 */ "pm_pmc1_rewind\000pmc\000The speculative event selected for PMC1 rewinds and the counter for PMC1 is not charged\000event=0x4d02c\000\00000\000\000"
/* offset=118048 */ "pm_inst_fin\000pmc\000Instruction finished\000event=0x40030\000\00000\000\000"
/* offset=118104 */ "pm_mrk_inst_timeo\000pmc\000Marked instruction finish timeout (instruction was lost)\000event=0x40134\000\00000\000\000"
/* offset=118202 */ "pm_thresh_exc_128\000pmc\000Threshold counter exceeded a value of 128\000event=0x401ea\000\00000\000\000"
/* offset=118285 */ "pm_run_inst_cmpl\000pmc\000PowerPC instruction completed while the run latch is set\000event=0x500fa\000\00000\000\000"
/* offset=118382 */ "pm_st_fwd\000translation\000Store forwards that finished\000event=0x20018\000\00000\000\000"
/* offset=118452 */ "pm_st_cmpl\000translation\000Stores completed from S2Q (2nd-level store queue). This event includes regular stores, stcx and cache inhibited stores. The following operations are excluded (pteupdate, snoop tlbie complete, store atomics, miso, load atomic payloads, tlbie, tlbsync, slbieg, isync, msgsnd, slbiag, cpabort, copy, tcheck, tend, stsync, dcbst, icbi, dcbf, hwsync, lwsync, ptesync, eieio, msgsync)\000event=0x200f0\000\00000\000\000"
/* offset=118873 */ "pm_st_miss_l1\000translation\000Store Missed L1\000event=0x300f0\000\00000\000\000"
/* offset=118934 */ "pm_data_from_dl2l3_mod\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=119374 */ "pm_data_from_dl2l3_shr\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=119810 */ "pm_data_from_dl4\000cache\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\00000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=120158 */ "pm_data_from_l2\000cache\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\00000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=120423 */ "pm_data_from_l2miss\000cache\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\00000\000\000"
/* offset=120501 */ "pm_data_from_l2miss_mod\000cache\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=120826 */ "pm_data_from_l2_disp_conflict_ldhitst\000cache\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\00000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=121171 */ "pm_data_from_l2_disp_conflict_other\000cache\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\00000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=121502 */ "pm_data_from_l2_mepf\000cache\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\00000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=121862 */ "pm_data_from_l2_no_conflict\000cache\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\00000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=122173 */ "pm_data_from_l3\000cache\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\00000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=122438 */ "pm_data_from_l3miss\000cache\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\00000\000\000"
/* offset=122531 */ "pm_data_from_l3miss_mod\000cache\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=122856 */ "pm_data_from_l3_disp_conflict\000cache\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\00000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=123181 */ "pm_data_from_l3_mepf\000cache\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\00000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=123541 */ "pm_data_from_l3_no_conflict\000cache\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\00000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=123852 */ "pm_data_from_ll4\000cache\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\00000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=124138 */ "pm_data_from_off_chip_cache\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=124567 */ "pm_data_from_on_chip_cache\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=124949 */ "pm_data_from_rl2l3_mod\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=125381 */ "pm_data_from_rl2l3_shr\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=125809 */ "pm_data_tablewalk_cyc\000cache\000Tablwalk Cycles (could be 1 or 2 active)\000event=0x3001a\000\00000\000Data Tablewalk Active\000"
/* offset=125918 */ "pm_dpteg_from_l3miss\000cache\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request\000event=0x4e04e\000\00000\000\000"
/* offset=126081 */ "pm_dslb_miss\000cache\000Data SLB Miss - Total of all segment sizes\000event=0xd094\000\00000\000Data SLB Miss - Total of all segment sizesData SLB misses\000"
/* offset=126218 */ "pm_l1_dcache_reloaded_all\000cache\000L1 data cache reloaded for demand or prefetch\000event=0x1002c\000\00000\000\000"
/* offset=126315 */ "pm_l1_dcache_reload_valid\000cache\000DL1 reloaded due to Demand Load\000event=0x300f6\000\00000\000\000"
/* offset=126398 */ "pm_ld_miss_l1\000cache\000Load Missed L1\000event=0x3e054\000\00000\000\000"
/* offset=126452 */ "pm_ld_ref_l1\000cache\000All L1 D cache load references counted at finish, gated by reject\000event=0x100ee\000\00000\000Load Ref count combined for all units\000"
/* offset=126593 */ "pm_st_miss_l1\000cache\000Store Missed L1\000event=0x300f0\000\00000\000\000"
/* offset=126648 */ "pm_fxu_busy\000floating point\000fxu0 busy and fxu1 busy\000event=0x2000e\000\00000\000\000"
/* offset=126718 */ "pm_fxu_idle\000floating point\000fxu0 idle and fxu1 idle\000event=0x1000e\000\00000\000\000"
/* offset=126788 */ "pm_back_br_cmpl\000frontend\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\00000\000\000"
/* offset=126921 */ "pm_bru_fin\000frontend\000Branch Instruction Finished\000event=0x10068\000\00000\000\000"
/* offset=126988 */ "pm_br_2path\000frontend\000two path branch\000event=0x20036\000\00000\000\000"
/* offset=127044 */ "pm_br_cmpl\000frontend\000Branch Instruction completed\000event=0x40060\000\00000\000\000"
/* offset=127112 */ "pm_br_mpred_cmpl\000frontend\000Number of Branch Mispredicts\000event=0x400f6\000\00000\000\000"
/* offset=127186 */ "pm_br_taken_cmpl\000frontend\000New event for Branch Taken\000event=0x200fa\000\00000\000\000"
/* offset=127258 */ "pm_ic_demand_cyc\000frontend\000Cycles when a demand ifetch was pending\000event=0x10018\000\00000\000Demand ifetch pending\000"
/* offset=127364 */ "pm_ierat_reload\000frontend\000Number of I-ERAT reloads\000event=0x100f6\000\00000\000IERAT Reloaded (Miss)\000"
/* offset=127454 */ "pm_ierat_reload_16m\000frontend\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\00000\000\000"
/* offset=127539 */ "pm_ierat_reload_4k\000frontend\000IERAT Miss (Not implemented as DI on POWER6)\000event=0x20064\000\00000\000IERAT Reloaded (Miss) for a 4k page\000"
/* offset=127666 */ "pm_ierat_reload_64k\000frontend\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\00000\000\000"
/* offset=127751 */ "pm_inst_chip_pump_cpred\000frontend\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000"
/* offset=128015 */ "pm_inst_cmpl\000frontend\000Number of PowerPC Instructions that completed\000event=0x2\000\00000\000PPC Instructions Finished (completed)\000"
/* offset=128135 */ "pm_inst_disp\000frontend\000PPC Dispatched\000event=0x200f2\000\00000\000\000"
/* offset=128191 */ "pm_inst_from_dl2l3_mod\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=128676 */ "pm_inst_from_dl2l3_shr\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=129157 */ "pm_inst_from_dl4\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=129550 */ "pm_inst_from_dmem\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=129946 */ "pm_inst_from_l2\000frontend\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\00000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=130256 */ "pm_inst_from_l2miss\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=130622 */ "pm_inst_from_l2_disp_conflict_ldhitst\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=131012 */ "pm_inst_from_l2_disp_conflict_other\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=131388 */ "pm_inst_from_l2_mepf\000frontend\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=131795 */ "pm_inst_from_l2_no_conflict\000frontend\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=132151 */ "pm_inst_from_l3\000frontend\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=132461 */ "pm_inst_from_l3miss\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\00000\000Inst from L3 miss\000"
/* offset=132599 */ "pm_inst_from_l3miss_mod\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=132953 */ "pm_inst_from_l3_disp_conflict\000frontend\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=133323 */ "pm_inst_from_l3_mepf\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=133730 */ "pm_inst_from_l3_no_conflict\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=134086 */ "pm_inst_from_ll4\000frontend\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\00000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=134417 */ "pm_inst_from_lmem\000frontend\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\00000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=134745 */ "pm_inst_from_memory\000frontend\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\00000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=135147 */ "pm_inst_from_off_chip_cache\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=135621 */ "pm_inst_from_on_chip_cache\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=136048 */ "pm_inst_from_rl2l3_mod\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=136525 */ "pm_inst_from_rl2l3_shr\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=136998 */ "pm_inst_from_rl4\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=137385 */ "pm_inst_from_rmem\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=137781 */ "pm_inst_grp_pump_cpred\000frontend\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch\000event=0x24050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000"
/* offset=138025 */ "pm_inst_grp_pump_mpred\000frontend\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch\000event=0x24052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=138434 */ "pm_inst_grp_pump_mpred_rty\000frontend\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000"
/* offset=138758 */ "pm_inst_imc_match_cmpl\000frontend\000IMC Match Count ( Not architected in P8)\000event=0x1003a\000\00000\000\000"
/* offset=138850 */ "pm_inst_pump_cpred\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000"
/* offset=139061 */ "pm_inst_pump_mpred\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000"
/* offset=139262 */ "pm_inst_sys_pump_cpred\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000"
/* offset=139508 */ "pm_inst_sys_pump_mpred\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=139999 */ "pm_inst_sys_pump_mpred_rty\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000"
/* offset=140284 */ "pm_ipteg_from_dl2l3_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x45048\000\00000\000\000"
/* offset=140518 */ "pm_ipteg_from_dl2l3_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\00000\000\000"
/* offset=140750 */ "pm_ipteg_from_dl4\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\00000\000\000"
/* offset=140935 */ "pm_ipteg_from_dmem\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\00000\000\000"
/* offset=141122 */ "pm_ipteg_from_l2\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\00000\000\000"
/* offset=141265 */ "pm_ipteg_from_l2miss\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\00000\000\000"
/* offset=141438 */ "pm_ipteg_from_l2_mepf\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\00000\000\000"
/* offset=141632 */ "pm_ipteg_from_l2_no_conflict\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\00000\000\000"
/* offset=141804 */ "pm_ipteg_from_l3\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\00000\000\000"
/* offset=141947 */ "pm_ipteg_from_l3miss\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a instruction side request\000event=0x4504e\000\00000\000\000"
/* offset=142120 */ "pm_ipteg_from_l3_disp_conflict\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\00000\000\000"
/* offset=142300 */ "pm_ipteg_from_l3_mepf\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a instruction side request\000event=0x25042\000\00000\000\000"
/* offset=142494 */ "pm_ipteg_from_l3_no_conflict\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a instruction side request\000event=0x15044\000\00000\000\000"
/* offset=142666 */ "pm_ipteg_from_ll4\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\00000\000\000"
/* offset=142820 */ "pm_ipteg_from_lmem\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\00000\000\000"
/* offset=142973 */ "pm_ipteg_from_memory\000frontend\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\00000\000\000"
/* offset=143164 */ "pm_ipteg_from_off_chip_cache\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\00000\000\000"
/* offset=143395 */ "pm_ipteg_from_on_chip_cache\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\00000\000\000"
/* offset=143602 */ "pm_ipteg_from_rl2l3_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\00000\000\000"
/* offset=143832 */ "pm_ipteg_from_rl2l3_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\00000\000\000"
/* offset=144060 */ "pm_ipteg_from_rl4\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\00000\000\000"
/* offset=144242 */ "pm_ipteg_from_rmem\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\00000\000\000"
/* offset=144429 */ "pm_islb_miss\000frontend\000I SLB Miss\000event=0xd096\000\00000\000\000"
/* offset=144480 */ "pm_itlb_miss\000frontend\000ITLB Reloaded (always zero on POWER6)\000event=0x400fc\000\00000\000\000"
/* offset=144559 */ "pm_l1_icache_miss\000frontend\000Demand iCache Miss\000event=0x200fd\000\00000\000\000"
/* offset=144624 */ "pm_l1_icache_reloaded_all\000frontend\000Counts all Icache reloads includes demand, prefetchm prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\00000\000\000"
/* offset=144791 */ "pm_l1_icache_reloaded_pref\000frontend\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\00000\000\000"
/* offset=144921 */ "pm_thrd_conc_run_inst\000frontend\000PPC Instructions Finished when both threads in run_cycles\000event=0x300f4\000\00000\000Concurrent Run Instructions\000"
/* offset=145056 */ "pm_tm_trans_run_inst\000frontend\000Instructions completed in transactional state\000event=0x30060\000\00000\000\000"
/* offset=145151 */ "pm_tm_tx_pass_run_inst\000frontend\000run instructions spent in successful transactions\000event=0x4e014\000\00000\000\000"
/* offset=145252 */ "pm_mrk_back_br_cmpl\000marked\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\00000\000\000"
/* offset=145394 */ "pm_mrk_bru_fin\000marked\000bru marked instr finish\000event=0x2013a\000\00000\000\000"
/* offset=145459 */ "pm_mrk_br_cmpl\000marked\000Branch Instruction completed\000event=0x1016e\000\00000\000\000"
/* offset=145529 */ "pm_mrk_br_mpred_cmpl\000marked\000Marked Branch Mispredicted\000event=0x301e4\000\00000\000\000"
/* offset=145603 */ "pm_mrk_br_taken_cmpl\000marked\000Marked Branch Taken completed\000event=0x101e2\000\00000\000\000"
/* offset=145680 */ "pm_mrk_data_from_dl2l3_mod\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d148\000\00000\000\000"
/* offset=145899 */ "pm_mrk_data_from_dl2l3_mod_cyc\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2d128\000\00000\000\000"
/* offset=146111 */ "pm_mrk_data_from_dl2l3_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d148\000\00000\000\000"
/* offset=146328 */ "pm_mrk_data_from_dl2l3_shr_cyc\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2c128\000\00000\000\000"
/* offset=146538 */ "pm_mrk_data_from_dl4\000marked\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x3d14c\000\00000\000\000"
/* offset=146708 */ "pm_mrk_data_from_dl4_cyc\000marked\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\00000\000\000"
/* offset=146871 */ "pm_mrk_data_from_dmem\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4d14c\000\00000\000\000"
/* offset=147043 */ "pm_mrk_data_from_dmem_cyc\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x2d12c\000\00000\000\000"
/* offset=147208 */ "pm_mrk_data_from_l2\000marked\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x1d142\000\00000\000\000"
/* offset=147336 */ "pm_mrk_data_from_l2miss\000marked\000Data cache reload L2 miss\000event=0x1d14e\000\00000\000\000"
/* offset=147412 */ "pm_mrk_data_from_l2miss_cyc\000marked\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x4c12e\000\00000\000\000"
/* offset=147563 */ "pm_mrk_data_from_l2_cyc\000marked\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x4c122\000\00000\000\000"
/* offset=147684 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst\000marked\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x3d140\000\00000\000\000"
/* offset=147863 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000marked\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x2c120\000\00000\000\000"
/* offset=148035 */ "pm_mrk_data_from_l2_disp_conflict_other\000marked\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x4d140\000\00000\000\000"
/* offset=148206 */ "pm_mrk_data_from_l2_disp_conflict_other_cyc\000marked\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x2d120\000\00000\000\000"
/* offset=148370 */ "pm_mrk_data_from_l2_mepf\000marked\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x2d140\000\00000\000\000"
/* offset=148549 */ "pm_mrk_data_from_l2_mepf_cyc\000marked\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4d120\000\00000\000\000"
/* offset=148721 */ "pm_mrk_data_from_l2_no_conflict\000marked\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x1d140\000\00000\000\000"
/* offset=148878 */ "pm_mrk_data_from_l2_no_conflict_cyc\000marked\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x4c120\000\00000\000\000"
/* offset=149028 */ "pm_mrk_data_from_l3\000marked\000The processor's data cache was reloaded from local core's L3 due to a marked load\000event=0x4d142\000\00000\000\000"
/* offset=149156 */ "pm_mrk_data_from_l3miss\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\00000\000\000"
/* offset=149314 */ "pm_mrk_data_from_l3miss_cyc\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x2d12e\000\00000\000\000"
/* offset=149465 */ "pm_mrk_data_from_l3_cyc\000marked\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x2d122\000\00000\000\000"
/* offset=149586 */ "pm_mrk_data_from_l3_disp_conflict\000marked\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x3d142\000\00000\000\000"
/* offset=149751 */ "pm_mrk_data_from_l3_disp_conflict_cyc\000marked\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\00000\000\000"
/* offset=149909 */ "pm_mrk_data_from_l3_mepf\000marked\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\00000\000\000"
/* offset=150088 */ "pm_mrk_data_from_l3_mepf_cyc\000marked\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x4d122\000\00000\000\000"
/* offset=150260 */ "pm_mrk_data_from_l3_no_conflict\000marked\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x1d144\000\00000\000\000"
/* offset=150417 */ "pm_mrk_data_from_l3_no_conflict_cyc\000marked\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\00000\000\000"
/* offset=150567 */ "pm_mrk_data_from_ll4\000marked\000The processor's data cache was reloaded from the local chip's L4 cache due to a marked load\000event=0x1d14c\000\00000\000\000"
/* offset=150706 */ "pm_mrk_data_from_ll4_cyc\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x4c12c\000\00000\000\000"
/* offset=150838 */ "pm_mrk_data_from_lmem\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x2d148\000\00000\000\000"
/* offset=150976 */ "pm_mrk_data_from_lmem_cyc\000marked\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\00000\000\000"
/* offset=151107 */ "pm_mrk_data_from_memory\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x2d14c\000\00000\000\000"
/* offset=151283 */ "pm_mrk_data_from_memory_cyc\000marked\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x4d12c\000\00000\000\000"
/* offset=151452 */ "pm_mrk_data_from_off_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x4d14a\000\00000\000\000"
/* offset=151668 */ "pm_mrk_data_from_off_chip_cache_cyc\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d12a\000\00000\000\000"
/* offset=151877 */ "pm_mrk_data_from_on_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x1d148\000\00000\000\000"
/* offset=152069 */ "pm_mrk_data_from_on_chip_cache_cyc\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4c128\000\00000\000\000"
/* offset=152254 */ "pm_mrk_data_from_rl2l3_mod\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d146\000\00000\000\000"
/* offset=152469 */ "pm_mrk_data_from_rl2l3_mod_cyc\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4d126\000\00000\000\000"
/* offset=152677 */ "pm_mrk_data_from_rl2l3_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\00000\000\000"
/* offset=152890 */ "pm_mrk_data_from_rl2l3_shr_cyc\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\00000\000\000"
/* offset=153096 */ "pm_mrk_data_from_rl4\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x2d14a\000\00000\000\000"
/* offset=153263 */ "pm_mrk_data_from_rl4_cyc\000marked\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\00000\000\000"
/* offset=153423 */ "pm_mrk_data_from_rmem\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x3d14a\000\00000\000\000"
/* offset=153595 */ "pm_mrk_data_from_rmem_cyc\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\00000\000\000"
/* offset=153760 */ "pm_mrk_dcache_reload_intv\000marked\000Combined Intervention event\000event=0x40118\000\00000\000\000"
/* offset=153840 */ "pm_mrk_derat_miss\000marked\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\00000\000\000"
/* offset=153922 */ "pm_mrk_derat_miss_16g\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4d154\000\00000\000\000"
/* offset=154024 */ "pm_mrk_derat_miss_16m\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3d154\000\00000\000\000"
/* offset=154126 */ "pm_mrk_derat_miss_4k\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1d156\000\00000\000\000"
/* offset=154226 */ "pm_mrk_derat_miss_64k\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\00000\000\000"
/* offset=154328 */ "pm_mrk_dfu_fin\000marked\000Decimal Unit marked Instruction Finish\000event=0x20132\000\00000\000\000"
/* offset=154408 */ "pm_mrk_dpteg_from_dl2l3_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x4f148\000\00000\000\000"
/* offset=154644 */ "pm_mrk_dpteg_from_dl2l3_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x3f148\000\00000\000\000"
/* offset=154878 */ "pm_mrk_dpteg_from_dl4\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request\000event=0x3f14c\000\00000\000\000"
/* offset=155065 */ "pm_mrk_dpteg_from_dmem\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request\000event=0x4f14c\000\00000\000\000"
/* offset=155254 */ "pm_mrk_dpteg_from_l2\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request\000event=0x1f142\000\00000\000\000"
/* offset=155399 */ "pm_mrk_dpteg_from_l2miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request\000event=0x1f14e\000\00000\000\000"
/* offset=155574 */ "pm_mrk_dpteg_from_l2_mepf\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request\000event=0x2f140\000\00000\000\000"
/* offset=155770 */ "pm_mrk_dpteg_from_l2_no_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request\000event=0x1f140\000\00000\000\000"
/* offset=155944 */ "pm_mrk_dpteg_from_l3\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request\000event=0x4f142\000\00000\000\000"
/* offset=156089 */ "pm_mrk_dpteg_from_l3miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request\000event=0x4f14e\000\00000\000\000"
/* offset=156264 */ "pm_mrk_dpteg_from_l3_disp_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request\000event=0x3f142\000\00000\000\000"
/* offset=156446 */ "pm_mrk_dpteg_from_l3_mepf\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request\000event=0x2f142\000\00000\000\000"
/* offset=156642 */ "pm_mrk_dpteg_from_l3_no_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request\000event=0x1f144\000\00000\000\000"
/* offset=156816 */ "pm_mrk_dpteg_from_ll4\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request\000event=0x1f14c\000\00000\000\000"
/* offset=156972 */ "pm_mrk_dpteg_from_lmem\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request\000event=0x2f148\000\00000\000\000"
/* offset=157127 */ "pm_mrk_dpteg_from_memory\000marked\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request\000event=0x2f14c\000\00000\000\000"
/* offset=157320 */ "pm_mrk_dpteg_from_off_chip_cache\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request\000event=0x4f14a\000\00000\000\000"
/* offset=157553 */ "pm_mrk_dpteg_from_on_chip_cache\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request\000event=0x1f148\000\00000\000\000"
/* offset=157762 */ "pm_mrk_dpteg_from_rl2l3_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x2f146\000\00000\000\000"
/* offset=157994 */ "pm_mrk_dpteg_from_rl2l3_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x1f14a\000\00000\000\000"
/* offset=158224 */ "pm_mrk_dpteg_from_rl4\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request\000event=0x2f14a\000\00000\000\000"
/* offset=158408 */ "pm_mrk_dpteg_from_rmem\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request\000event=0x3f14a\000\00000\000\000"
/* offset=158597 */ "pm_mrk_dtlb_miss\000marked\000Marked dtlb miss\000event=0x401e4\000\00000\000\000"
/* offset=158657 */ "pm_mrk_dtlb_miss_16g\000marked\000Marked Data TLB Miss page size 16G\000event=0x1d158\000\00000\000\000"
/* offset=158739 */ "pm_mrk_dtlb_miss_16m\000marked\000Marked Data TLB Miss page size 16M\000event=0x4d156\000\00000\000\000"
/* offset=158821 */ "pm_mrk_dtlb_miss_4k\000marked\000Marked Data TLB Miss page size 4k\000event=0x2d156\000\00000\000\000"
/* offset=158901 */ "pm_mrk_dtlb_miss_64k\000marked\000Marked Data TLB Miss page size 64K\000event=0x3d156\000\00000\000\000"
/* offset=158983 */ "pm_mrk_fab_rsp_bkill\000marked\000Marked store had to do a bkill\000event=0x40154\000\00000\000\000"
/* offset=159061 */ "pm_mrk_fab_rsp_bkill_cyc\000marked\000cycles L2 RC took for a bkill\000event=0x2f150\000\00000\000\000"
/* offset=159142 */ "pm_mrk_fab_rsp_claim_rty\000marked\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\00000\000\000"
/* offset=159233 */ "pm_mrk_fab_rsp_dclaim\000marked\000Marked store had to do a dclaim\000event=0x30154\000\00000\000\000"
/* offset=159313 */ "pm_mrk_fab_rsp_dclaim_cyc\000marked\000cycles L2 RC took for a dclaim\000event=0x2f152\000\00000\000\000"
/* offset=159396 */ "pm_mrk_fab_rsp_rd_rty\000marked\000Sampled L2 reads retry count\000event=0x4015e\000\00000\000\000"
/* offset=159473 */ "pm_mrk_fab_rsp_rd_t_intv\000marked\000Sampled Read got a T intervention\000event=0x1015e\000\00000\000\000"
/* offset=159558 */ "pm_mrk_fab_rsp_rwitm_cyc\000marked\000cycles L2 RC took for a rwitm\000event=0x4f150\000\00000\000\000"
/* offset=159639 */ "pm_mrk_fab_rsp_rwitm_rty\000marked\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\00000\000\000"
/* offset=159730 */ "pm_mrk_fxu_fin\000marked\000fxu marked instr finish\000event=0x20134\000\00000\000\000"
/* offset=159795 */ "pm_mrk_inst_cmpl\000marked\000marked instruction completed\000event=0x401e0\000\00000\000\000"
/* offset=159867 */ "pm_mrk_inst_decoded\000marked\000marked instruction decoded\000event=0x20130\000\00000\000marked instruction decoded. Name from ISU?\000"
/* offset=159982 */ "pm_mrk_inst_disp\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\00000\000Marked Instruction dispatched\000"
/* offset=160118 */ "pm_mrk_inst_fin\000marked\000marked instruction finished\000event=0x30130\000\00000\000marked instr finish any unit\000"
/* offset=160216 */ "pm_mrk_inst_from_l3miss\000marked\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\00000\000n/a\000"
/* offset=160342 */ "pm_mrk_inst_issued\000marked\000Marked instruction issued\000event=0x10132\000\00000\000\000"
/* offset=160413 */ "pm_mrk_inst_timeo\000marked\000marked Instruction finish timeout (instruction lost)\000event=0x40134\000\00000\000\000"
/* offset=160510 */ "pm_mrk_l1_icache_miss\000marked\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\00000\000Marked L1 Icache Miss\000"
/* offset=160623 */ "pm_mrk_l2_rc_disp\000marked\000Marked Instruction RC dispatched in L2\000event=0x20114\000\00000\000\000"
/* offset=160706 */ "pm_mrk_l2_rc_done\000marked\000Marked RC done\000event=0x3012a\000\00000\000\000"
/* offset=160765 */ "pm_mrk_larx_fin\000marked\000Larx finished\000event=0x40116\000\00000\000\000"
/* offset=160821 */ "pm_mrk_ld_miss_exposed_cyc\000marked\000Marked Load exposed Miss cycles\000event=0x1013e\000\00000\000Marked Load exposed Miss (use edge detect to count #)\000"
/* offset=160959 */ "pm_mrk_ld_miss_l1\000marked\000Marked DL1 Demand Miss counted at exec time\000event=0x201e2\000\00000\000\000"
/* offset=161047 */ "pm_mrk_ld_miss_l1_cyc\000marked\000Marked ld latency\000event=0x4013e\000\00000\000\000"
/* offset=161113 */ "pm_mrk_lsu_fin\000marked\000lsu marked instr finish\000event=0x40132\000\00000\000\000"
/* offset=161178 */ "pm_mrk_ntf_fin\000marked\000Marked next to finish instruction finished\000event=0x20112\000\00000\000\000"
/* offset=161262 */ "pm_mrk_run_cyc\000marked\000Marked run cycles\000event=0x1d15e\000\00000\000\000"
/* offset=161321 */ "pm_mrk_stall_cmplu_cyc\000marked\000Marked Group completion Stall\000event=0x3013e\000\00000\000Marked Group Completion Stall cycles (use edge detect to count #)\000"
/* offset=161465 */ "pm_mrk_stcx_fail\000marked\000marked stcx failed\000event=0x3e158\000\00000\000\000"
/* offset=161527 */ "pm_mrk_st_cmpl\000marked\000marked store completed and sent to nest\000event=0x10134\000\00000\000Marked store completed\000"
/* offset=161630 */ "pm_mrk_st_cmpl_int\000marked\000marked store finished with intervention\000event=0x30134\000\00000\000marked store complete (data home) with intervention\000"
/* offset=161766 */ "pm_mrk_st_drain_to_l2disp_cyc\000marked\000cycles to drain st from core to L2\000event=0x3f150\000\00000\000\000"
/* offset=161857 */ "pm_mrk_st_fwd\000marked\000Marked st forwards\000event=0x3012c\000\00000\000\000"
/* offset=161916 */ "pm_mrk_st_l2disp_to_cmpl_cyc\000marked\000cycles from L2 rc disp to l2 rc completion\000event=0x1f150\000\00000\000\000"
/* offset=162014 */ "pm_mrk_st_nest\000marked\000Marked store sent to nest\000event=0x20138\000\00000\000\000"
/* offset=162081 */ "pm_mrk_vsu_fin\000marked\000VSU marked instr finish\000event=0x30132\000\00000\000vsu (fpu) marked instr finish\000"
/* offset=162175 */ "pm_mult_mrk\000marked\000mult marked instr\000event=0x3d15e\000\00000\000\000"
/* offset=162231 */ "pm_sync_mrk_br_link\000marked\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\00000\000\000"
/* offset=162346 */ "pm_sync_mrk_br_mpred\000marked\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\00000\000\000"
/* offset=162457 */ "pm_sync_mrk_fx_divide\000marked\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\00000\000\000"
/* offset=162570 */ "pm_sync_mrk_l2hit\000marked\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\00000\000\000"
/* offset=162668 */ "pm_sync_mrk_l2miss\000marked\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\00000\000\000"
/* offset=162767 */ "pm_sync_mrk_l3miss\000marked\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\00000\000\000"
/* offset=162868 */ "pm_sync_mrk_probe_nop\000marked\000Marked probeNops which can cause synchronous interrupts\000event=0x15150\000\00000\000\000"
/* offset=162972 */ "pm_chip_pump_cpred\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000"
/* offset=163345 */ "pm_data_chip_pump_cpred\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000"
/* offset=163593 */ "pm_data_from_dmem\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=163945 */ "pm_data_from_lmem\000memory\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\00000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=164229 */ "pm_data_from_memory\000memory\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x2c04c\000\00000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=164587 */ "pm_data_from_rl4\000memory\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\00000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=164930 */ "pm_data_from_rmem\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=165282 */ "pm_data_grp_pump_cpred\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000"
/* offset=165510 */ "pm_data_grp_pump_mpred\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=165910 */ "pm_data_grp_pump_mpred_rty\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000"
/* offset=166218 */ "pm_data_pump_cpred\000memory\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\00000\000\000"
/* offset=166339 */ "pm_data_pump_mpred\000memory\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000"
/* offset=166524 */ "pm_data_sys_pump_cpred\000memory\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000"
/* offset=166754 */ "pm_data_sys_pump_mpred\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=167236 */ "pm_data_sys_pump_mpred_rty\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000"
/* offset=167505 */ "pm_dpteg_from_dl4\000memory\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request\000event=0x3e04c\000\00000\000\000"
/* offset=167681 */ "pm_dpteg_from_dmem\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request\000event=0x4e04c\000\00000\000\000"
/* offset=167859 */ "pm_dpteg_from_rmem\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request\000event=0x3e04a\000\00000\000\000"
/* offset=168037 */ "pm_grp_pump_cpred\000memory\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\00000\000\000"
/* offset=168248 */ "pm_grp_pump_mpred\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=168713 */ "pm_grp_pump_mpred_rty\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=169156 */ "pm_l3_co_mepf\000memory\000L3 CO of line in Mep state ( includes casthrough\000event=0x18082\000\00000\000\000"
/* offset=169245 */ "pm_mem_co\000memory\000Memory castouts from this lpar\000event=0x4c058\000\00000\000\000"
/* offset=169312 */ "pm_mem_loc_thresh_ifu\000memory\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\00000\000\000"
/* offset=169417 */ "pm_mem_loc_thresh_lsu_high\000memory\000Local memory above threshold for LSU medium\000event=0x40056\000\00000\000\000"
/* offset=169514 */ "pm_mem_loc_thresh_lsu_med\000memory\000Local memory above theshold for data prefetch\000event=0x1c05e\000\00000\000\000"
/* offset=169612 */ "pm_mem_pref\000memory\000Memory prefetch for this lpar. Includes L4\000event=0x2c058\000\00000\000\000"
/* offset=169693 */ "pm_mem_read\000memory\000Reads from Memory from this lpar (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\00000\000\000"
/* offset=169829 */ "pm_mem_rwitm\000memory\000Memory rwitm for this lpar\000event=0x3c05e\000\00000\000\000"
/* offset=169895 */ "pm_nest_ref_clk\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\00000\000Nest reference clocks\000"
/* offset=170006 */ "pm_pump_cpred\000memory\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=170336 */ "pm_pump_mpred\000memory\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=170656 */ "pm_sys_pump_cpred\000memory\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=171000 */ "pm_sys_pump_mpred\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=171547 */ "pm_sys_pump_mpred_rty\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=171951 */ "pm_1lpar_cyc\000other\000Number of cycles in single lpar mode. All threads in the core are assigned to the same lpar\000event=0x1f05e\000\00000\000\000"
/* offset=172081 */ "pm_2lpar_cyc\000other\000Cycles in 2-lpar mode. Threads 0-3 belong to Lpar0 and threads 4-7 belong to Lpar1\000event=0x2006e\000\00000\000Number of cycles in 2 lpar mode\000"
/* offset=172233 */ "pm_4lpar_cyc\000other\000Number of cycles in 4 LPAR mode. Threads 0-1 belong to lpar0, threads 2-3 belong to lpar1, threads 4-5 belong to lpar2, and threads 6-7 belong to lpar3\000event=0x4e05e\000\00000\000\000"
/* offset=172423 */ "pm_all_chip_pump_cpred\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000"
/* offset=172790 */ "pm_all_grp_pump_cpred\000other\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x520050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=173161 */ "pm_all_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x620052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=173620 */ "pm_all_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=174057 */ "pm_all_pump_cpred\000other\000Pump prediction correct. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=174381 */ "pm_all_pump_mpred\000other\000Pump misprediction. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=174695 */ "pm_all_sys_pump_cpred\000other\000Initial and Final Pump Scope was system pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=175033 */ "pm_all_sys_pump_mpred\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=175574 */ "pm_all_sys_pump_mpred_rty\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000"
/* offset=175972 */ "pm_bank_conflict\000other\000Read blocked due to interleave conflict. The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4082\000\00000\000\000"
/* offset=176147 */ "pm_br_bc_8\000other\000Pairable BC+8 branch that has not been converted to a Resolve Finished in the BRU pipeline\000event=0x5086\000\00000\000\000"
/* offset=176273 */ "pm_br_bc_8_conv\000other\000Pairable BC+8 branch that was converted to a Resolve Finished in the BRU pipeline\000event=0x5084\000\00000\000\000"
/* offset=176395 */ "pm_br_mpred_ccache\000other\000Conditional Branch Completed that was Mispredicted due to the Count Cache Target Prediction\000event=0x40ac\000\00000\000\000"
/* offset=176530 */ "pm_br_mpred_cr\000other\000Conditional Branch Completed that was Mispredicted due to the BHT Direction Prediction (taken/not taken)\000event=0x40b8\000\00000\000\000"
/* offset=176674 */ "pm_br_mpred_lstack\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x40ae\000\00000\000\000"
/* offset=176808 */ "pm_br_mpred_ta\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack. Only XL-form branches that resolved Taken set this event\000event=0x40ba\000\00000\000\000"
/* offset=177028 */ "pm_br_mrk_2path\000other\000marked two path branch\000event=0x10138\000\00000\000\000"
/* offset=177092 */ "pm_br_pred_br0\000other\000Conditional Branch Completed on BR0 (1st branch in group) in which the HW predicted the Direction or Target\000event=0x409c\000\00000\000\000"
/* offset=177239 */ "pm_br_pred_br1\000other\000Conditional Branch Completed on BR1 (2nd branch in group) in which the HW predicted the Direction or Target. Note: BR1 can only be used in Single Thread Mode. In all of the SMT modes, only one branch can complete, thus BR1 is unused\000event=0x409e\000\00000\000\000"
/* offset=177511 */ "pm_br_pred_br_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) OR if_pc_br0_br_pred(1)\000event=0x489c\000\00000\000IFU\000"
/* offset=177691 */ "pm_br_pred_ccache_br0\000other\000Conditional Branch Completed on BR0 that used the Count Cache for Target Prediction\000event=0x40a4\000\00000\000\000"
/* offset=177821 */ "pm_br_pred_ccache_br1\000other\000Conditional Branch Completed on BR1 that used the Count Cache for Target Prediction\000event=0x40a6\000\00000\000\000"
/* offset=177951 */ "pm_br_pred_ccache_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND if_pc_br0_pred_type\000event=0x48a4\000\00000\000IFU\000"
/* offset=178135 */ "pm_br_pred_cr_br0\000other\000Conditional Branch Completed on BR0 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\00000\000\000"
/* offset=178432 */ "pm_br_pred_cr_br1\000other\000Conditional Branch Completed on BR1 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b2\000\00000\000\000"
/* offset=178729 */ "pm_br_pred_cr_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(1)='1'\000event=0x48b0\000\00000\000IFU\000"
/* offset=178889 */ "pm_br_pred_lstack_br0\000other\000Conditional Branch Completed on BR0 that used the Link Stack for Target Prediction\000event=0x40a8\000\00000\000\000"
/* offset=179018 */ "pm_br_pred_lstack_br1\000other\000Conditional Branch Completed on BR1 that used the Link Stack for Target Prediction\000event=0x40aa\000\00000\000\000"
/* offset=179147 */ "pm_br_pred_lstack_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND (not if_pc_br0_pred_type)\000event=0x48a8\000\00000\000IFU\000"
/* offset=179337 */ "pm_br_pred_ta_br0\000other\000Conditional Branch Completed on BR0 that had its target address predicted. Only XL-form branches set this event\000event=0x40b4\000\00000\000\000"
/* offset=179491 */ "pm_br_pred_ta_br1\000other\000Conditional Branch Completed on BR1 that had its target address predicted. Only XL-form branches set this event\000event=0x40b6\000\00000\000\000"
/* offset=179645 */ "pm_br_pred_ta_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0)='1'\000event=0x48b4\000\00000\000IFU\000"
/* offset=179805 */ "pm_br_uncond_br0\000other\000Unconditional Branch Completed on BR0. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a0\000\00000\000\000"
/* offset=180069 */ "pm_br_uncond_br1\000other\000Unconditional Branch Completed on BR1. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a2\000\00000\000\000"
/* offset=180333 */ "pm_br_uncond_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred=00 AND if_pc_br0_completed\000event=0x48a0\000\00000\000IFU\000"
/* offset=180512 */ "pm_castout_issued\000other\000Castouts issued\000event=0x3094\000\00000\000\000"
/* offset=180570 */ "pm_castout_issued_gpr\000other\000Castouts issued GPR\000event=0x3096\000\00000\000\000"
/* offset=180636 */ "pm_clb_held\000other\000CLB Hold: Any Reason\000event=0x2090\000\00000\000\000"
/* offset=180693 */ "pm_cmplu_stall_bru_cru\000other\000Completion stall due to IFU\000event=0x2d018\000\00000\000\000"
/* offset=180769 */ "pm_cmplu_stall_coq_full\000other\000Completion stall due to CO q full\000event=0x30026\000\00000\000\000"
/* offset=180852 */ "pm_cmplu_stall_flush\000other\000completion stall due to flush by own thread\000event=0x30038\000\00000\000\000"
/* offset=180942 */ "pm_cmplu_stall_mem_ecc_delay\000other\000Completion stall due to mem ECC delay\000event=0x30028\000\00000\000\000"
/* offset=181034 */ "pm_cmplu_stall_no_ntf\000other\000Completion stall due to nop\000event=0x2e01c\000\00000\000\000"
/* offset=181109 */ "pm_cmplu_stall_ntcg_flush\000other\000Completion stall due to ntcg flush\000event=0x2e01e\000\00000\000Completion stall due to reject (load hit store)\000"
/* offset=181242 */ "pm_cmplu_stall_reject\000other\000Completion stall due to LSU reject\000event=0x4c010\000\00000\000\000"
/* offset=181324 */ "pm_cmplu_stall_reject_lhs\000other\000Completion stall due to reject (load hit store)\000event=0x2c01a\000\00000\000\000"
/* offset=181423 */ "pm_cmplu_stall_rej_lmq_full\000other\000Completion stall due to LSU reject LMQ full\000event=0x4c014\000\00000\000\000"
/* offset=181520 */ "pm_cmplu_stall_scalar\000other\000Completion stall due to VSU scalar instruction\000event=0x4d010\000\00000\000\000"
/* offset=181614 */ "pm_cmplu_stall_scalar_long\000other\000Completion stall due to VSU scalar long latency instruction\000event=0x2d010\000\00000\000\000"
/* offset=181726 */ "pm_cmplu_stall_store\000other\000Completion stall by stores this includes store agen finishes in pipe LS0/LS1 and store data finishes in LS2/LS3\000event=0x2c014\000\00000\000\000"
/* offset=181884 */ "pm_cmplu_stall_vector\000other\000Completion stall due to VSU vector instruction\000event=0x2d014\000\00000\000\000"
/* offset=181978 */ "pm_cmplu_stall_vector_long\000other\000Completion stall due to VSU vector long instruction\000event=0x4d012\000\00000\000\000"
/* offset=182082 */ "pm_cmplu_stall_vsu\000other\000Completion stall due to VSU instruction\000event=0x2d012\000\00000\000\000"
/* offset=182166 */ "pm_co0_alloc\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16083\000\00000\0000.0\000"
/* offset=182289 */ "pm_co0_busy\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16082\000\00000\000\000"
/* offset=182408 */ "pm_co_usage\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3608a\000\00000\000\000"
/* offset=182627 */ "pm_cru_fin\000other\000IFU Finished a (non-branch) instruction\000event=0x40066\000\00000\000\000"
/* offset=182703 */ "pm_data_all_chip_pump_cpred\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for either demand loads or data prefetch\000event=0x61c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000"
/* offset=182978 */ "pm_data_all_from_dl2l3_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x64c048\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=183446 */ "pm_data_all_from_dl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x63c048\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=183910 */ "pm_data_all_from_dl4\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either demand loads or data prefetch\000event=0x63c04c\000\00000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=184286 */ "pm_data_all_from_dmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either demand loads or data prefetch\000event=0x64c04c\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=184665 */ "pm_data_all_from_l2\000other\000The processor's data cache was reloaded from local core's L2 due to either demand loads or data prefetch\000event=0x61c042\000\00000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=184958 */ "pm_data_all_from_l21_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x64c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=185340 */ "pm_data_all_from_l21_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x63c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=185718 */ "pm_data_all_from_l2miss_mod\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to either demand loads or data prefetch\000event=0x61c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=186071 */ "pm_data_all_from_l2_disp_conflict_ldhitst\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either demand loads or data prefetch\000event=0x63c040\000\00000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=186444 */ "pm_data_all_from_l2_disp_conflict_other\000other\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either demand loads or data prefetch\000event=0x64c040\000\00000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=186803 */ "pm_data_all_from_l2_mepf\000other\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either demand loads or data prefetch\000event=0x62c040\000\00000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=187191 */ "pm_data_all_from_l2_no_conflict\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to either demand loads or data prefetch\000event=0x61c040\000\00000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=187530 */ "pm_data_all_from_l3\000other\000The processor's data cache was reloaded from local core's L3 due to either demand loads or data prefetch\000event=0x64c042\000\00000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=187823 */ "pm_data_all_from_l31_eco_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x64c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=188217 */ "pm_data_all_from_l31_eco_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x63c044\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=188607 */ "pm_data_all_from_l31_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x62c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=188989 */ "pm_data_all_from_l31_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x61c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=189367 */ "pm_data_all_from_l3miss_mod\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to either demand loads or data prefetch\000event=0x64c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=189720 */ "pm_data_all_from_l3_disp_conflict\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either demand loads or data prefetch\000event=0x63c042\000\00000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=190073 */ "pm_data_all_from_l3_mepf\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either demand loads or data prefetch\000event=0x62c042\000\00000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=190461 */ "pm_data_all_from_l3_no_conflict\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to either demand loads or data prefetch\000event=0x61c044\000\00000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=190800 */ "pm_data_all_from_ll4\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to either demand loads or data prefetch\000event=0x61c04c\000\00000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=191114 */ "pm_data_all_from_lmem\000other\000The processor's data cache was reloaded from the local chip's Memory due to either demand loads or data prefetch\000event=0x62c048\000\00000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=191425 */ "pm_data_all_from_memory\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either demand loads or data prefetch\000event=0x62c04c\000\00000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=191810 */ "pm_data_all_from_off_chip_cache\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either demand loads or data prefetch\000event=0x64c04a\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=192267 */ "pm_data_all_from_on_chip_cache\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either demand loads or data prefetch\000event=0x61c048\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=192677 */ "pm_data_all_from_rl2l3_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x62c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=193137 */ "pm_data_all_from_rl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x61c04a\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=193593 */ "pm_data_all_from_rl4\000other\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x62c04a\000\00000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=193963 */ "pm_data_all_from_rmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x63c04a\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=194342 */ "pm_data_all_grp_pump_cpred\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for either demand loads or data prefetch\000event=0x62c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000"
/* offset=194597 */ "pm_data_all_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for either demand loads or data prefetch\000event=0x62c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=195024 */ "pm_data_all_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for either demand loads or data prefetch\000event=0x61c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000"
/* offset=195359 */ "pm_data_all_pump_cpred\000other\000Pump prediction correct. Counts across all types of pumps for either demand loads or data prefetch\000event=0x61c054\000\00000\000Pump prediction correct. Counts across all types of pumps for a demand load\000"
/* offset=195582 */ "pm_data_all_pump_mpred\000other\000Pump misprediction. Counts across all types of pumps for either demand loads or data prefetch\000event=0x64c052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000"
/* offset=195794 */ "pm_data_all_sys_pump_cpred\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for either demand loads or data prefetch\000event=0x63c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000"
/* offset=196051 */ "pm_data_all_sys_pump_mpred\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for either demand loads or data prefetch\000event=0x63c052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=196560 */ "pm_data_all_sys_pump_mpred_rty\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for either demand loads or data prefetch\000event=0x64c050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000"
/* offset=196856 */ "pm_data_from_l21_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=197210 */ "pm_data_from_l21_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=197560 */ "pm_data_from_l31_eco_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=197926 */ "pm_data_from_l31_eco_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=198288 */ "pm_data_from_l31_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=198642 */ "pm_data_from_l31_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000"
/* offset=198992 */ "pm_data_from_mem\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\00000\000Data cache reload from memory (including L4)\000"
/* offset=199204 */ "pm_dc_collisions\000other\000DATA Cache collisions\000event=0xe0bc\000\00000\000DATA Cache collisions42\000"
/* offset=199290 */ "pm_dc_pref_stream_alloc\000other\000Stream marked valid. The stream could have been allocated through the hardware prefetch mechanism or through software. This is combined ls0 and ls1\000event=0x1e050\000\00000\000\000"
/* offset=199487 */ "pm_dc_pref_stream_conf\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Combine up + down\000event=0x2e050\000\00000\000\000"
/* offset=199713 */ "pm_dc_pref_stream_fuzzy_conf\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0x4e050\000\00000\000\000"
/* offset=199996 */ "pm_dc_pref_stream_strided_conf\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0x3e050\000\00000\000\000"
/* offset=200219 */ "pm_dfu\000other\000Finish DFU (all finish)\000event=0xb0ba\000\00000\000\000"
/* offset=200274 */ "pm_dfu_dcffix\000other\000Convert from fixed opcode finish (dcffix,dcffixq)\000event=0xb0be\000\00000\000\000"
/* offset=200362 */ "pm_dfu_denbcd\000other\000BCD->DPD opcode finish (denbcd, denbcdq)\000event=0xb0bc\000\00000\000\000"
/* offset=200441 */ "pm_dfu_mc\000other\000Finish DFU multicycle\000event=0xb0b8\000\00000\000\000"
/* offset=200497 */ "pm_disp_clb_held_bal\000other\000Dispatch/CLB Hold: Balance\000event=0x2092\000\00000\000\000"
/* offset=200569 */ "pm_disp_clb_held_res\000other\000Dispatch/CLB Hold: Resource\000event=0x2094\000\00000\000\000"
/* offset=200642 */ "pm_disp_clb_held_sb\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x20a8\000\00000\000\000"
/* offset=200716 */ "pm_disp_clb_held_sync\000other\000Dispatch/CLB Hold: Sync type instruction\000event=0x2098\000\00000\000\000"
/* offset=200803 */ "pm_disp_clb_held_tlbie\000other\000Dispatch Hold: Due to TLBIE\000event=0x2096\000\00000\000\000"
/* offset=200878 */ "pm_disp_held_iq_full\000other\000Dispatch held due to Issue q full\000event=0x20006\000\00000\000\000"
/* offset=200958 */ "pm_disp_held_map_full\000other\000Dispatch for this thread was held because the Mappers were full\000event=0x1002a\000\00000\000Dispatch held due to Mapper full\000"
/* offset=201101 */ "pm_disp_held_srq_full\000other\000Dispatch held due SRQ no room\000event=0x30018\000\00000\000\000"
/* offset=201178 */ "pm_disp_hold_gct_full\000other\000Dispatch Hold Due to no space in the GCT\000event=0x30a6\000\00000\000\000"
/* offset=201265 */ "pm_disp_wt\000other\000Dispatched Starved\000event=0x30008\000\00000\000Dispatched Starved (not held, nothing to dispatch)\000"
/* offset=201370 */ "pm_dpteg_from_l21_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request\000event=0x4e046\000\00000\000\000"
/* offset=201550 */ "pm_dpteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request\000event=0x3e046\000\00000\000\000"
/* offset=201728 */ "pm_dpteg_from_l2_disp_conflict_ldhitst\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a data side request\000event=0x3e040\000\00000\000\000"
/* offset=201912 */ "pm_dpteg_from_l2_disp_conflict_other\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a data side request\000event=0x4e040\000\00000\000\000"
/* offset=202088 */ "pm_dpteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request\000event=0x4e044\000\00000\000\000"
/* offset=202276 */ "pm_dpteg_from_l31_eco_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request\000event=0x3e044\000\00000\000\000"
/* offset=202462 */ "pm_dpteg_from_l31_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request\000event=0x2e044\000\00000\000\000"
/* offset=202642 */ "pm_dpteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request\000event=0x1e046\000\00000\000\000"
/* offset=202820 */ "pm_eat_force_mispred\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT. The EAT forces a mispredict in this case since there is no predicated target to validate. This is a rare case that may occur when the EAT is full and a branch is issue\000event=0x50a8\000\00000\000\000"
/* offset=203119 */ "pm_eat_full_cyc\000other\000Cycles No room in EAT\000event=0x4084\000\00000\000Cycles No room in EATSet on bank conflict and case where no ibuffers available\000"
/* offset=203259 */ "pm_ee_off_ext_int\000other\000Ee off and external interrupt\000event=0x2080\000\00000\000\000"
/* offset=203331 */ "pm_fav_tbegin\000other\000Dispatch time Favored tbegin\000event=0x20b4\000\00000\000\000"
/* offset=203398 */ "pm_flop\000other\000Floating Point Operation Finished\000event=0x100f4\000\00000\000Floating Point Operations Finished\000"
/* offset=203499 */ "pm_flop_sum_scalar\000other\000flops summary scalar instructions\000event=0xa0ae\000\00000\000\000"
/* offset=203576 */ "pm_flop_sum_vec\000other\000flops summary vector instructions\000event=0xa0ac\000\00000\000\000"
/* offset=203650 */ "pm_flush_br_mpred\000other\000Flush caused by branch mispredict\000event=0x2084\000\00000\000\000"
/* offset=203726 */ "pm_flush_disp\000other\000Dispatch flush\000event=0x2082\000\00000\000\000"
/* offset=203779 */ "pm_flush_disp_sb\000other\000Dispatch Flush: Scoreboard\000event=0x208c\000\00000\000\000"
/* offset=203847 */ "pm_flush_disp_sync\000other\000Dispatch Flush: Sync\000event=0x2088\000\00000\000\000"
/* offset=203911 */ "pm_flush_disp_tlbie\000other\000Dispatch Flush: TLBIE\000event=0x208a\000\00000\000\000"
/* offset=203977 */ "pm_flush_lsu\000other\000Flush initiated by LSU\000event=0x208e\000\00000\000\000"
/* offset=204037 */ "pm_flush_partial\000other\000Partial flush\000event=0x2086\000\00000\000\000"
/* offset=204092 */ "pm_fpu0_fconv\000other\000Convert instruction executed\000event=0xa0b0\000\00000\000\000"
/* offset=204159 */ "pm_fpu0_fest\000other\000Estimate instruction executed\000event=0xa0b8\000\00000\000\000"
/* offset=204226 */ "pm_fpu0_frsp\000other\000Round to single precision instruction executed\000event=0xa0b4\000\00000\000\000"
/* offset=204310 */ "pm_fpu1_fconv\000other\000Convert instruction executed\000event=0xa0b2\000\00000\000\000"
/* offset=204377 */ "pm_fpu1_fest\000other\000Estimate instruction executed\000event=0xa0ba\000\00000\000\000"
/* offset=204444 */ "pm_fpu1_frsp\000other\000Round to single precision instruction executed\000event=0xa0b6\000\00000\000\000"
/* offset=204528 */ "pm_fusion_toc_grp0_1\000other\000One pair of instructions fused with TOC in Group0\000event=0x50b0\000\00000\000\000"
/* offset=204623 */ "pm_fusion_toc_grp0_2\000other\000Two pairs of instructions fused with TOCin Group0\000event=0x50ae\000\00000\000\000"
/* offset=204718 */ "pm_fusion_toc_grp0_3\000other\000Three pairs of instructions fused with TOC in Group0\000event=0x50ac\000\00000\000\000"
/* offset=204816 */ "pm_fusion_toc_grp1_1\000other\000One pair of instructions fused with TOX in Group1\000event=0x50b2\000\00000\000\000"
/* offset=204911 */ "pm_fusion_vsx_grp0_1\000other\000One pair of instructions fused with VSX in Group0\000event=0x50b8\000\00000\000\000"
/* offset=205006 */ "pm_fusion_vsx_grp0_2\000other\000Two pairs of instructions fused with VSX in Group0\000event=0x50b6\000\00000\000\000"
/* offset=205102 */ "pm_fusion_vsx_grp0_3\000other\000Three pairs of instructions fused with VSX in Group0\000event=0x50b4\000\00000\000\000"
/* offset=205200 */ "pm_fusion_vsx_grp1_1\000other\000One pair of instructions fused with VSX in Group1\000event=0x50ba\000\00000\000\000"
/* offset=205295 */ "pm_fxu0_busy_fxu1_idle\000other\000fxu0 busy and fxu1 idle\000event=0x3000e\000\00000\000\000"
/* offset=205367 */ "pm_fxu0_fin\000other\000The fixed point unit Unit 0 finished an instruction. Instructions that finish may not necessary complete\000event=0x10004\000\00000\000FXU0 Finished\000"
/* offset=205522 */ "pm_fxu1_busy_fxu0_idle\000other\000fxu0 idle and fxu1 busy\000event=0x4000e\000\00000\000\000"
/* offset=205594 */ "pm_fxu1_fin\000other\000FXU1 Finished\000event=0x40004\000\00000\000\000"
/* offset=205645 */ "pm_gct_empty_cyc\000other\000No itags assigned either thread (GCT Empty)\000event=0x20008\000\00000\000\000"
/* offset=205731 */ "pm_gct_merge\000other\000Group dispatched on a merged GCT empty. GCT entries can be merged only within the same thread\000event=0x30a4\000\00000\000\000"
/* offset=205862 */ "pm_gct_noslot_br_mpred\000other\000Gct empty for this thread due to branch mispred\000event=0x4d01e\000\00000\000\000"
/* offset=205958 */ "pm_gct_noslot_br_mpred_icmiss\000other\000Gct empty for this thread due to Icache Miss and branch mispred\000event=0x4d01a\000\00000\000\000"
/* offset=206077 */ "pm_gct_noslot_cyc\000other\000No itags assigned\000event=0x100f8\000\00000\000Pipeline empty (No itags assigned , no GCT slots used)\000"
/* offset=206192 */ "pm_gct_noslot_disp_held_issq\000other\000Gct empty for this thread due to dispatch hold on this thread due to Issue q full\000event=0x2d01e\000\00000\000\000"
/* offset=206328 */ "pm_gct_noslot_disp_held_map\000other\000Gct empty for this thread due to dispatch hold on this thread due to Mapper full\000event=0x4d01c\000\00000\000\000"
/* offset=206462 */ "pm_gct_noslot_disp_held_other\000other\000Gct empty for this thread due to dispatch hold on this thread due to sync\000event=0x2e010\000\00000\000\000"
/* offset=206591 */ "pm_gct_noslot_disp_held_srq\000other\000Gct empty for this thread due to dispatch hold on this thread due to SRQ full\000event=0x2d01c\000\00000\000\000"
/* offset=206722 */ "pm_gct_noslot_ic_l3miss\000other\000Gct empty for this thread due to icache l3 miss\000event=0x4e010\000\00000\000\000"
/* offset=206819 */ "pm_gct_noslot_ic_miss\000other\000Gct empty for this thread due to Icache Miss\000event=0x2d01a\000\00000\000\000"
/* offset=206911 */ "pm_gct_util_11_14_entries\000other\000GCT Utilization 11-14 entries\000event=0x20a2\000\00000\000\000"
/* offset=206991 */ "pm_gct_util_15_17_entries\000other\000GCT Utilization 15-17 entries\000event=0x20a4\000\00000\000\000"
/* offset=207071 */ "pm_gct_util_18_entries\000other\000GCT Utilization 18+ entries\000event=0x20a6\000\00000\000\000"
/* offset=207146 */ "pm_gct_util_1_2_entries\000other\000GCT Utilization 1-2 entries\000event=0x209c\000\00000\000\000"
/* offset=207222 */ "pm_gct_util_3_6_entries\000other\000GCT Utilization 3-6 entries\000event=0x209e\000\00000\000\000"
/* offset=207298 */ "pm_gct_util_7_10_entries\000other\000GCT Utilization 7-10 entries\000event=0x20a0\000\00000\000\000"
/* offset=207376 */ "pm_grp_br_mpred_nonspec\000other\000Group experienced non-speculative branch redirect\000event=0x1000a\000\00000\000Group experienced Non-speculative br mispredicct\000"
/* offset=207523 */ "pm_grp_cmpl\000other\000group completed\000event=0x30004\000\00000\000\000"
/* offset=207576 */ "pm_grp_disp\000other\000group dispatch\000event=0x3000a\000\00000\000dispatch_success (Group Dispatched)\000"
/* offset=207663 */ "pm_grp_ic_miss_nonspec\000other\000Group experienced non-speculative I cache miss\000event=0x1000c\000\00000\000Group experi enced Non-specu lative I cache miss\000"
/* offset=207806 */ "pm_grp_mrk\000other\000Instruction Marked\000event=0x10130\000\00000\000Instruction marked in idu\000"
/* offset=207886 */ "pm_grp_non_full_group\000other\000GROUPs where we did not have 6 non branch instructions in the group(ST mode), in SMT mode 3 non branches\000event=0x509c\000\00000\000\000"
/* offset=208037 */ "pm_grp_term_2nd_branch\000other\000There were enough instructions in the Ibuffer, but 2nd branch ends group\000event=0x50a4\000\00000\000\000"
/* offset=208157 */ "pm_grp_term_fpu_after_br\000other\000There were enough instructions in the Ibuffer, but FPU OP IN same group after a branch terminates a group, cant do partial flushes\000event=0x50a6\000\00000\000\000"
/* offset=208337 */ "pm_grp_term_noinst\000other\000Do not fill every slot in the group, Not enough instructions in the Ibuffer. This includes cases where the group started with enough instructions, but some got knocked out by a cache miss or branch redirect (which would also empty the Ibuffer)\000event=0x509e\000\00000\000\000"
/* offset=208624 */ "pm_grp_term_other\000other\000There were enough instructions in the Ibuffer, but the group terminated early for some other reason, most likely due to a First or Last\000event=0x50a0\000\00000\000\000"
/* offset=208802 */ "pm_grp_term_slot_limit\000other\000There were enough instructions in the Ibuffer, but 3 src RA/RB/RC , 2 way crack caused a group termination\000event=0x50a2\000\00000\000\000"
/* offset=208956 */ "pm_ibuf_full_cyc\000other\000Cycles No room in ibuff\000event=0x4086\000\00000\000Cycles No room in ibufffully qualified transfer (if5 valid)\000"
/* offset=209080 */ "pm_ic_demand_l2_bht_redirect\000other\000L2 I cache demand request due to BHT redirect, branch redirect ( 2 bubbles 3 cycles)\000event=0x4098\000\00000\000\000"
/* offset=209218 */ "pm_ic_demand_l2_br_redirect\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x409a\000\00000\000\000"
/* offset=209338 */ "pm_ic_demand_req\000other\000Demand Instruction fetch request\000event=0x4088\000\00000\000\000"
/* offset=209412 */ "pm_ic_invalidate\000other\000Ic line invalidated\000event=0x508a\000\00000\000\000"
/* offset=209473 */ "pm_ic_pref_cancel_hit\000other\000Prefetch Canceled due to icache hit\000event=0x4092\000\00000\000\000"
/* offset=209555 */ "pm_ic_pref_cancel_l2\000other\000L2 Squashed request\000event=0x4094\000\00000\000\000"
/* offset=209620 */ "pm_ic_pref_cancel_page\000other\000Prefetch Canceled due to page boundary\000event=0x4090\000\00000\000\000"
/* offset=209706 */ "pm_ic_pref_req\000other\000Instruction prefetch requests\000event=0x408a\000\00000\000\000"
/* offset=209775 */ "pm_ic_pref_write\000other\000Instruction prefetch written into IL1\000event=0x408e\000\00000\000\000"
/* offset=209854 */ "pm_ic_reload_private\000other\000Reloading line was brought in private for a specific thread. Most lines are brought in shared for all eight thrreads. If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4096\000\00000\000\000"
/* offset=210154 */ "pm_ifu_l2_touch\000other\000L2 touch to update MRU on a line\000event=0x5088\000\00000\000\000"
/* offset=210227 */ "pm_inst_all_chip_pump_cpred\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for instruction fetches and prefetches\000event=0x514050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000"
/* offset=210507 */ "pm_inst_all_from_dl2l3_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x544048\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=210993 */ "pm_inst_all_from_dl2l3_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x534048\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=211475 */ "pm_inst_all_from_dl4\000other\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to instruction fetches and prefetches\000event=0x53404c\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=211869 */ "pm_inst_all_from_dmem\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to instruction fetches and prefetches\000event=0x54404c\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=212266 */ "pm_inst_all_from_l2\000other\000The processor's Instruction cache was reloaded from local core's L2 due to instruction fetches and prefetches\000event=0x514042\000\00000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=212577 */ "pm_inst_all_from_l21_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x544046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=212977 */ "pm_inst_all_from_l21_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x534046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=213373 */ "pm_inst_all_from_l2miss\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to instruction fetches and prefetches\000event=0x51404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=213740 */ "pm_inst_all_from_l2_disp_conflict_ldhitst\000other\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to instruction fetches and prefetches\000event=0x534040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=214131 */ "pm_inst_all_from_l2_disp_conflict_other\000other\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to instruction fetches and prefetches\000event=0x544040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=214508 */ "pm_inst_all_from_l2_mepf\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to instruction fetches and prefetches\000event=0x524040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=214916 */ "pm_inst_all_from_l2_no_conflict\000other\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to instruction fetches and prefetches\000event=0x514040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=215273 */ "pm_inst_all_from_l3\000other\000The processor's Instruction cache was reloaded from local core's L3 due to instruction fetches and prefetches\000event=0x544042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=215584 */ "pm_inst_all_from_l31_eco_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x544044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=215996 */ "pm_inst_all_from_l31_eco_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x534044\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=216404 */ "pm_inst_all_from_l31_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x524044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=216804 */ "pm_inst_all_from_l31_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x514046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=217200 */ "pm_inst_all_from_l3miss_mod\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x54404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=217556 */ "pm_inst_all_from_l3_disp_conflict\000other\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to instruction fetches and prefetches\000event=0x534042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=217927 */ "pm_inst_all_from_l3_mepf\000other\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to instruction fetches and prefetches\000event=0x524042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=218335 */ "pm_inst_all_from_l3_no_conflict\000other\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to instruction fetches and prefetches\000event=0x514044\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=218692 */ "pm_inst_all_from_ll4\000other\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to instruction fetches and prefetches\000event=0x51404c\000\00000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=219024 */ "pm_inst_all_from_lmem\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to instruction fetches and prefetches\000event=0x524048\000\00000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=219353 */ "pm_inst_all_from_memory\000other\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to instruction fetches and prefetches\000event=0x52404c\000\00000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=219756 */ "pm_inst_all_from_off_chip_cache\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to instruction fetches and prefetches\000event=0x54404a\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=220231 */ "pm_inst_all_from_on_chip_cache\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to instruction fetches and prefetches\000event=0x514048\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=220659 */ "pm_inst_all_from_rl2l3_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x524046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=221137 */ "pm_inst_all_from_rl2l3_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x51404a\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=221611 */ "pm_inst_all_from_rl4\000other\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x52404a\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=221999 */ "pm_inst_all_from_rmem\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x53404a\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=222396 */ "pm_inst_all_grp_pump_cpred\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for instruction fetches and prefetches\000event=0x524050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000"
/* offset=222656 */ "pm_inst_all_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for instruction fetches and prefetches\000event=0x524052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000"
/* offset=223081 */ "pm_inst_all_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for instruction fetches and prefetches\000event=0x514052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000"
/* offset=223421 */ "pm_inst_all_pump_cpred\000other\000Pump prediction correct. Counts across all types of pumps for instruction fetches and prefetches\000event=0x514054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000"
/* offset=223648 */ "pm_inst_all_pump_mpred\000other\000Pump misprediction. Counts across all types of pumps for instruction fetches and prefetches\000event=0x544052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000"
/* offset=223865 */ "pm_inst_all_sys_pump_cpred\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for instruction fetches and prefetches\000event=0x534050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000"
/* offset=224127 */ "pm_inst_all_sys_pump_mpred\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for instruction fetches and prefetches\000event=0x534052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000"
/* offset=224634 */ "pm_inst_all_sys_pump_mpred_rty\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for instruction fetches and prefetches\000event=0x544050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000"
/* offset=224935 */ "pm_inst_from_l1\000other\000Instruction fetches from L1\000event=0x4080\000\00000\000\000"
/* offset=225003 */ "pm_inst_from_l21_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=225399 */ "pm_inst_from_l21_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=225791 */ "pm_inst_from_l31_eco_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=226199 */ "pm_inst_from_l31_eco_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=226603 */ "pm_inst_from_l31_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=226999 */ "pm_inst_from_l31_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000"
/* offset=227391 */ "pm_inst_imc_match_disp\000other\000Matched Instructions Dispatched\000event=0x30016\000\00000\000IMC Matches dispatched\000"
/* offset=227493 */ "pm_iops_disp\000other\000Internal Operations dispatched\000event=0x30014\000\00000\000IOPS dispatched\000"
/* offset=227577 */ "pm_ipteg_from_l21_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\00000\000\000"
/* offset=227764 */ "pm_ipteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\00000\000\000"
/* offset=227949 */ "pm_ipteg_from_l2_disp_conflict_ldhitst\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a instruction side request\000event=0x35040\000\00000\000\000"
/* offset=228140 */ "pm_ipteg_from_l2_disp_conflict_other\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a instruction side request\000event=0x45040\000\00000\000\000"
/* offset=228323 */ "pm_ipteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\00000\000\000"
/* offset=228518 */ "pm_ipteg_from_l31_eco_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\00000\000\000"
/* offset=228711 */ "pm_ipteg_from_l31_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\00000\000\000"
/* offset=228898 */ "pm_ipteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\00000\000\000"
/* offset=229083 */ "pm_iside_l2memacc\000other\000valid when first beat of data comes in for an i-side fetch where data came from mem(or L4)\000event=0x4608e\000\00000\000\000"
/* offset=229217 */ "pm_isu_ref_fx0\000other\000FX0 ISU reject\000event=0x30ac\000\00000\000\000"
/* offset=229271 */ "pm_isu_ref_fx1\000other\000FX1 ISU reject\000event=0x30ae\000\00000\000\000"
/* offset=229325 */ "pm_isu_ref_fxu\000other\000FXU ISU reject from either pipe\000event=0x38ac\000\00000\000\000"
/* offset=229396 */ "pm_isu_ref_ls0\000other\000LS0 ISU reject\000event=0x30b0\000\00000\000\000"
/* offset=229450 */ "pm_isu_ref_ls1\000other\000LS1 ISU reject\000event=0x30b2\000\00000\000\000"
/* offset=229504 */ "pm_isu_ref_ls2\000other\000LS2 ISU reject\000event=0x30b4\000\00000\000\000"
/* offset=229558 */ "pm_isu_ref_ls3\000other\000LS3 ISU reject\000event=0x30b6\000\00000\000\000"
/* offset=229612 */ "pm_isu_rejects_all\000other\000All isu rejects could be more than 1 per cycle\000event=0x309c\000\00000\000\000"
/* offset=229702 */ "pm_isu_reject_res_na\000other\000ISU reject due to resource not available\000event=0x30a2\000\00000\000\000"
/* offset=229788 */ "pm_isu_reject_sar_bypass\000other\000Reject because of SAR bypass\000event=0x309e\000\00000\000\000"
/* offset=229866 */ "pm_isu_reject_src_na\000other\000ISU reject due to source not available\000event=0x30a0\000\00000\000\000"
/* offset=229950 */ "pm_isu_rej_vs0\000other\000VS0 ISU reject\000event=0x30a8\000\00000\000\000"
/* offset=230004 */ "pm_isu_rej_vs1\000other\000VS1 ISU reject\000event=0x30aa\000\00000\000\000"
/* offset=230058 */ "pm_isu_rej_vsu\000other\000VSU ISU reject from either pipe\000event=0x38a8\000\00000\000\000"
/* offset=230129 */ "pm_isync\000other\000Isync count per thread\000event=0x30b8\000\00000\000\000"
/* offset=230185 */ "pm_l1miss_lat_exc_1024\000other\000L1 misses that took longer than 1024 cyles to resolve (miss to reload)\000event=0x200301ea\000\00000\000Reload latency exceeded 1024 cyc\000"
/* offset=230339 */ "pm_l1miss_lat_exc_2048\000other\000L1 misses that took longer than 2048 cyles to resolve (miss to reload)\000event=0x200401ec\000\00000\000Reload latency exceeded 2048 cyc\000"
/* offset=230493 */ "pm_l1miss_lat_exc_256\000other\000L1 misses that took longer than 256 cyles to resolve (miss to reload)\000event=0x200101e8\000\00000\000Reload latency exceeded 256 cyc\000"
/* offset=230644 */ "pm_l1miss_lat_exc_32\000other\000L1 misses that took longer than 32 cyles to resolve (miss to reload)\000event=0x200201e6\000\00000\000Reload latency exceeded 32 cyc\000"
/* offset=230792 */ "pm_l1pf_l2memacc\000other\000valid when first beat of data comes in for an L1pref where data came from mem(or L4)\000event=0x26086\000\00000\000\000"
/* offset=230919 */ "pm_l1_demand_write\000other\000Instruction Demand sectors wriittent into IL1\000event=0x408c\000\00000\000\000"
/* offset=231008 */ "pm_l2_chip_pump\000other\000RC requests that were local on chip pump attempts\000event=0x27084\000\00000\000\000"
/* offset=231099 */ "pm_l2_group_pump\000other\000RC requests that were on Node Pump attempts\000event=0x27086\000\00000\000\000"
/* offset=231185 */ "pm_l2_rty_st\000other\000RC retries on PB for any store from core\000event=0x3708a\000\00000\000\000"
/* offset=231264 */ "pm_l2_st\000other\000All successful D-side store dispatches for this thread\000event=0x17080\000\00000\000\000"
/* offset=231353 */ "pm_l2_st_miss\000other\000All successful D-side store dispatches for this thread that were L2 Miss\000event=0x17082\000\00000\000\000"
/* offset=231465 */ "pm_l2_tm_req_abort\000other\000TM abort\000event=0x1e05e\000\00000\000\000"
/* offset=231518 */ "pm_l2_tm_st_abort_sister\000other\000TM marked store abort\000event=0x3e05c\000\00000\000\000"
/* offset=231590 */ "pm_l3_ci_usage\000other\000rotating sample of 16 CI or CO actives\000event=0x819082\000\00000\000\000"
/* offset=231670 */ "pm_l3_co0_alloc\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908b\000\00000\0000.0\000"
/* offset=231754 */ "pm_l3_co0_busy\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908a\000\00000\000\000"
/* offset=231834 */ "pm_l3_co_l31\000other\000L3 CO to L3.1 OR of port 0 and 1 ( lossy)\000event=0x28086\000\00000\000\000"
/* offset=231914 */ "pm_l3_co_mem\000other\000L3 CO to memory OR of port 0 and 1 ( lossy)\000event=0x28084\000\00000\000\000"
/* offset=231996 */ "pm_l3_ld_pref\000other\000L3 Load Prefetches\000event=0x1e052\000\00000\000\000"
/* offset=232054 */ "pm_l3_pf0_alloc\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908d\000\00000\0000.0\000"
/* offset=232138 */ "pm_l3_pf0_busy\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908c\000\00000\000\000"
/* offset=232218 */ "pm_l3_pf_miss_l3\000other\000L3 Prefetch missed in L3\000event=0x18080\000\00000\000\000"
/* offset=232285 */ "pm_l3_pf_off_chip_cache\000other\000L3 Prefetch from Off chip cache\000event=0x3808a\000\00000\000\000"
/* offset=232366 */ "pm_l3_pf_off_chip_mem\000other\000L3 Prefetch from Off chip memory\000event=0x4808e\000\00000\000\000"
/* offset=232446 */ "pm_l3_pf_on_chip_cache\000other\000L3 Prefetch from On chip cache\000event=0x38088\000\00000\000\000"
/* offset=232525 */ "pm_l3_pf_on_chip_mem\000other\000L3 Prefetch from On chip memory\000event=0x4808c\000\00000\000\000"
/* offset=232603 */ "pm_l3_pf_usage\000other\000rotating sample of 32 PF actives\000event=0x829084\000\00000\000\000"
/* offset=232677 */ "pm_l3_pref_all\000other\000Total HW L3 prefetches(Load+store)\000event=0x4e052\000\00000\000\000"
/* offset=232752 */ "pm_l3_rd0_alloc\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908f\000\00000\0000.0\000"
/* offset=232836 */ "pm_l3_rd0_busy\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908e\000\00000\000\000"
/* offset=232916 */ "pm_l3_rd_usage\000other\000rotating sample of 16 RD actives\000event=0x829086\000\00000\000\000"
/* offset=232990 */ "pm_l3_sn0_alloc\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839089\000\00000\0000.0\000"
/* offset=233079 */ "pm_l3_sn0_busy\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839088\000\00000\000\000"
/* offset=233164 */ "pm_l3_sn_usage\000other\000rotating sample of 8 snoop valids\000event=0x819080\000\00000\000\000"
/* offset=233239 */ "pm_l3_st_pref\000other\000L3 store Prefetches\000event=0x2e052\000\00000\000\000"
/* offset=233298 */ "pm_l3_sw_pref\000other\000Data stream touchto L3\000event=0x3e052\000\00000\000\000"
/* offset=233360 */ "pm_l3_wi0_alloc\000other\000lifetime, sample of Write Inject machine 0 valid\000event=0x18081\000\00000\0000.0\000"
/* offset=233453 */ "pm_ld_ref_l1_lsu0\000other\000LS0 L1 D cache load references counted at finish, gated by reject\000event=0xc080\000\00000\000LS0 L1 D cache load references counted at finish, gated by rejectLSU0 L1 D cache load references\000"
/* offset=233657 */ "pm_ld_ref_l1_lsu1\000other\000LS1 L1 D cache load references counted at finish, gated by reject\000event=0xc082\000\00000\000LS1 L1 D cache load references counted at finish, gated by rejectLSU1 L1 D cache load references\000"
/* offset=233861 */ "pm_ld_ref_l1_lsu2\000other\000LS2 L1 D cache load references counted at finish, gated by reject\000event=0xc094\000\00000\000LS2 L1 D cache load references counted at finish, gated by reject42\000"
/* offset=234036 */ "pm_ld_ref_l1_lsu3\000other\000LS3 L1 D cache load references counted at finish, gated by reject\000event=0xc096\000\00000\000LS3 L1 D cache load references counted at finish, gated by reject42\000"
/* offset=234211 */ "pm_link_stack_invalid_ptr\000other\000A flush were LS ptr is invalid, results in a pop , A lot of interrupts between push and pops\000event=0x509a\000\00000\000\000"
/* offset=234354 */ "pm_link_stack_wrong_add_pred\000other\000Link stack predicts wrong address, because of link stack design limitation\000event=0x5098\000\00000\000\000"
/* offset=234482 */ "pm_ls0_erat_miss_pref\000other\000LS0 Erat miss due to prefetch\000event=0xe080\000\00000\000LS0 Erat miss due to prefetch42\000"
/* offset=234589 */ "pm_ls0_l1_pref\000other\000LS0 L1 cache data prefetches\000event=0xd0b8\000\00000\000LS0 L1 cache data prefetches42\000"
/* offset=234687 */ "pm_ls0_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc098\000\00000\000Software L1 Prefetches, including SW Transient Prefetches42\000"
/* offset=234846 */ "pm_ls1_erat_miss_pref\000other\000LS1 Erat miss due to prefetch\000event=0xe082\000\00000\000LS1 Erat miss due to prefetch42\000"
/* offset=234953 */ "pm_ls1_l1_pref\000other\000LS1 L1 cache data prefetches\000event=0xd0ba\000\00000\000LS1 L1 cache data prefetches42\000"
/* offset=235051 */ "pm_ls1_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc09a\000\00000\000Software L1 Prefetches, including SW Transient Prefetches42\000"
/* offset=235210 */ "pm_lsu0_flush_lrq\000other\000LS0 Flush: LRQ\000event=0xc0b0\000\00000\000LS0 Flush: LRQLSU0 LRQ flushes\000"
/* offset=235297 */ "pm_lsu0_flush_srq\000other\000LS0 Flush: SRQ\000event=0xc0b8\000\00000\000LS0 Flush: SRQLSU0 SRQ lhs flushes\000"
/* offset=235388 */ "pm_lsu0_flush_uld\000other\000LS0 Flush: Unaligned Load\000event=0xc0a4\000\00000\000LS0 Flush: Unaligned LoadLSU0 unaligned load flushes\000"
/* offset=235508 */ "pm_lsu0_flush_ust\000other\000LS0 Flush: Unaligned Store\000event=0xc0ac\000\00000\000LS0 Flush: Unaligned StoreLSU0 unaligned store flushes\000"
/* offset=235631 */ "pm_lsu0_l1_cam_cancel\000other\000ls0 l1 tm cam cancel\000event=0xf088\000\00000\000ls0 l1 tm cam cancel42\000"
/* offset=235720 */ "pm_lsu0_larx_fin\000other\000Larx finished in LSU pipe0\000event=0x1e056\000\00000\000\000"
/* offset=235789 */ "pm_lsu0_lmq_lhr_merge\000other\000LS0 Load Merged with another cacheline request\000event=0xd08c\000\00000\000LS0 Load Merged with another cacheline request42\000"
/* offset=235930 */ "pm_lsu0_ncld\000other\000LS0 Non-cachable Loads counted at finish\000event=0xc08c\000\00000\000LS0 Non-cachable Loads counted at finishLSU0 non-cacheable loads\000"
/* offset=236072 */ "pm_lsu0_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe090\000\00000\000Primary ERAT hit42\000"
/* offset=236156 */ "pm_lsu0_reject\000other\000LSU0 reject\000event=0x1e05a\000\00000\000\000"
/* offset=236208 */ "pm_lsu0_srq_stfwd\000other\000LS0 SRQ forwarded data to a load\000event=0xc09c\000\00000\000LS0 SRQ forwarded data to a loadLSU0 SRQ store forwarded\000"
/* offset=236339 */ "pm_lsu0_store_reject\000other\000ls0 store reject\000event=0xf084\000\00000\000ls0 store reject42\000"
/* offset=236419 */ "pm_lsu0_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a8\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=236645 */ "pm_lsu0_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe098\000\00000\000Load tm hit in L142\000"
/* offset=236724 */ "pm_lsu0_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a0\000\00000\000Load tm L1 miss42\000"
/* offset=236800 */ "pm_lsu1_flush_lrq\000other\000LS1 Flush: LRQ\000event=0xc0b2\000\00000\000LS1 Flush: LRQLSU1 LRQ flushes\000"
/* offset=236887 */ "pm_lsu1_flush_srq\000other\000LS1 Flush: SRQ\000event=0xc0ba\000\00000\000LS1 Flush: SRQLSU1 SRQ lhs flushes\000"
/* offset=236978 */ "pm_lsu1_flush_uld\000other\000LS 1 Flush: Unaligned Load\000event=0xc0a6\000\00000\000LS 1 Flush: Unaligned LoadLSU1 unaligned load flushes\000"
/* offset=237100 */ "pm_lsu1_flush_ust\000other\000LS1 Flush: Unaligned Store\000event=0xc0ae\000\00000\000LS1 Flush: Unaligned StoreLSU1 unaligned store flushes\000"
/* offset=237223 */ "pm_lsu1_l1_cam_cancel\000other\000ls1 l1 tm cam cancel\000event=0xf08a\000\00000\000ls1 l1 tm cam cancel42\000"
/* offset=237312 */ "pm_lsu1_larx_fin\000other\000Larx finished in LSU pipe1\000event=0x2e056\000\00000\000\000"
/* offset=237381 */ "pm_lsu1_lmq_lhr_merge\000other\000LS1 Load Merge with another cacheline request\000event=0xd08e\000\00000\000LS1 Load Merge with another cacheline request42\000"
/* offset=237520 */ "pm_lsu1_ncld\000other\000LS1 Non-cachable Loads counted at finish\000event=0xc08e\000\00000\000LS1 Non-cachable Loads counted at finishLSU1 non-cacheable loads\000"
/* offset=237662 */ "pm_lsu1_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe092\000\00000\000Primary ERAT hit42\000"
/* offset=237746 */ "pm_lsu1_reject\000other\000LSU1 reject\000event=0x2e05a\000\00000\000\000"
/* offset=237798 */ "pm_lsu1_srq_stfwd\000other\000LS1 SRQ forwarded data to a load\000event=0xc09e\000\00000\000LS1 SRQ forwarded data to a loadLSU1 SRQ store forwarded\000"
/* offset=237929 */ "pm_lsu1_store_reject\000other\000ls1 store reject\000event=0xf086\000\00000\000ls1 store reject42\000"
/* offset=238009 */ "pm_lsu1_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0aa\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=238235 */ "pm_lsu1_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe09a\000\00000\000Load tm hit in L142\000"
/* offset=238314 */ "pm_lsu1_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a2\000\00000\000Load tm L1 miss42\000"
/* offset=238390 */ "pm_lsu2_flush_lrq\000other\000LS02Flush: LRQ\000event=0xc0b4\000\00000\000LS02Flush: LRQ42\000"
/* offset=238463 */ "pm_lsu2_flush_srq\000other\000LS2 Flush: SRQ\000event=0xc0bc\000\00000\000LS2 Flush: SRQ42\000"
/* offset=238536 */ "pm_lsu2_flush_uld\000other\000LS3 Flush: Unaligned Load\000event=0xc0a8\000\00000\000LS3 Flush: Unaligned Load42\000"
/* offset=238631 */ "pm_lsu2_l1_cam_cancel\000other\000ls2 l1 tm cam cancel\000event=0xf08c\000\00000\000ls2 l1 tm cam cancel42\000"
/* offset=238720 */ "pm_lsu2_larx_fin\000other\000Larx finished in LSU pipe2\000event=0x3e056\000\00000\000\000"
/* offset=238789 */ "pm_lsu2_ldf\000other\000LS2 Scalar Loads\000event=0xc084\000\00000\000LS2 Scalar Loads42\000"
/* offset=238860 */ "pm_lsu2_ldx\000other\000LS0 Vector Loads\000event=0xc088\000\00000\000LS0 Vector Loads42\000"
/* offset=238931 */ "pm_lsu2_lmq_lhr_merge\000other\000LS0 Load Merged with another cacheline request\000event=0xd090\000\00000\000LS0 Load Merged with another cacheline request42\000"
/* offset=239072 */ "pm_lsu2_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe094\000\00000\000Primary ERAT hit42\000"
/* offset=239156 */ "pm_lsu2_reject\000other\000LSU2 reject\000event=0x3e05a\000\00000\000\000"
/* offset=239208 */ "pm_lsu2_srq_stfwd\000other\000LS2 SRQ forwarded data to a load\000event=0xc0a0\000\00000\000LS2 SRQ forwarded data to a load42\000"
/* offset=239317 */ "pm_lsu2_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ac\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=239543 */ "pm_lsu2_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe09c\000\00000\000Load tm hit in L142\000"
/* offset=239622 */ "pm_lsu2_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a4\000\00000\000Load tm L1 miss42\000"
/* offset=239698 */ "pm_lsu3_flush_lrq\000other\000LS3 Flush: LRQ\000event=0xc0b6\000\00000\000LS3 Flush: LRQ42\000"
/* offset=239771 */ "pm_lsu3_flush_srq\000other\000LS13 Flush: SRQ\000event=0xc0be\000\00000\000LS13 Flush: SRQ42\000"
/* offset=239846 */ "pm_lsu3_flush_uld\000other\000LS 14Flush: Unaligned Load\000event=0xc0aa\000\00000\000LS 14Flush: Unaligned Load42\000"
/* offset=239943 */ "pm_lsu3_l1_cam_cancel\000other\000ls3 l1 tm cam cancel\000event=0xf08e\000\00000\000ls3 l1 tm cam cancel42\000"
/* offset=240032 */ "pm_lsu3_larx_fin\000other\000Larx finished in LSU pipe3\000event=0x4e056\000\00000\000\000"
/* offset=240101 */ "pm_lsu3_ldf\000other\000LS3 Scalar Loads\000event=0xc086\000\00000\000LS3 Scalar Loads 42\000"
/* offset=240173 */ "pm_lsu3_ldx\000other\000LS1 Vector Loads\000event=0xc08a\000\00000\000LS1 Vector Loads42\000"
/* offset=240244 */ "pm_lsu3_lmq_lhr_merge\000other\000LS1 Load Merge with another cacheline request\000event=0xd092\000\00000\000LS1 Load Merge with another cacheline request42\000"
/* offset=240383 */ "pm_lsu3_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe096\000\00000\000Primary ERAT hit42\000"
/* offset=240467 */ "pm_lsu3_reject\000other\000LSU3 reject\000event=0x4e05a\000\00000\000\000"
/* offset=240519 */ "pm_lsu3_srq_stfwd\000other\000LS3 SRQ forwarded data to a load\000event=0xc0a2\000\00000\000LS3 SRQ forwarded data to a load42\000"
/* offset=240628 */ "pm_lsu3_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ae\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000"
/* offset=240854 */ "pm_lsu3_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe09e\000\00000\000Load tm hit in L142\000"
/* offset=240933 */ "pm_lsu3_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a6\000\00000\000Load tm L1 miss42\000"
/* offset=241009 */ "pm_lsu_erat_miss_pref\000other\000Erat miss due to prefetch, on either pipe\000event=0xe880\000\00000\000LSU\000"
/* offset=241100 */ "pm_lsu_flush_ust\000other\000Unaligned Store Flush on either pipe\000event=0xc8ac\000\00000\000LSU\000"
/* offset=241181 */ "pm_lsu_four_tablewalk_cyc\000other\000Cycles when four tablewalks pending on this thread\000event=0xd0a4\000\00000\000Cycles when four tablewalks pending on this thread42\000"
/* offset=241334 */ "pm_lsu_fx_fin\000other\000LSU Finished a FX operation (up to 2 per cycle\000event=0x10066\000\00000\000\000"
/* offset=241420 */ "pm_lsu_l1_pref\000other\000hw initiated , include sw streaming forms as well , include sw streams as a separate event\000event=0xd8b8\000\00000\000LSU\000"
/* offset=241553 */ "pm_lsu_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches, on both pipes\000event=0xc898\000\00000\000LSU\000"
/* offset=241671 */ "pm_lsu_ldf\000other\000FPU loads only on LS2/LS3 ie LU0/LU1\000event=0xc884\000\00000\000LSU\000"
/* offset=241746 */ "pm_lsu_ldx\000other\000Vector loads can issue only on LS2/LS3\000event=0xc888\000\00000\000LSU\000"
/* offset=241823 */ "pm_lsu_lmq_full_cyc\000other\000LMQ full\000event=0xd0a2\000\00000\000LMQ fullCycles LMQ full\000"
/* offset=241899 */ "pm_lsu_lmq_s0_alloc\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd0a1\000\00000\0000.0\000"
/* offset=242352 */ "pm_lsu_lmq_s0_valid\000other\000Slot 0 of LMQ valid\000event=0xd0a0\000\00000\000Slot 0 of LMQ validLMQ slot 0 valid\000"
/* offset=242451 */ "pm_lsu_lmq_srq_empty_all_cyc\000other\000ALL threads lsu empty (lmq and srq empty)\000event=0x3001c\000\00000\000ALL threads lsu empty (lmq and srq empty). Issue HW016541\000"
/* offset=242604 */ "pm_lsu_lrq_s0_alloc\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09f\000\00000\0000.0\000"
/* offset=243057 */ "pm_lsu_lrq_s0_valid\000other\000Slot 0 of LRQ valid\000event=0xd09e\000\00000\000Slot 0 of LRQ validLRQ slot 0 valid\000"
/* offset=243156 */ "pm_lsu_lrq_s43_alloc\000other\000LRQ slot 43 was released\000event=0xf091\000\00000\0000.0\000"
/* offset=243229 */ "pm_lsu_lrq_s43_valid\000other\000LRQ slot 43 was busy\000event=0xf090\000\00000\000LRQ slot 43 was busy42\000"
/* offset=243317 */ "pm_lsu_mrk_derat_miss\000other\000DERAT Reloaded (Miss)\000event=0x30162\000\00000\000\000"
/* offset=243386 */ "pm_lsu_ncld\000other\000count at finish so can return only on ls0 or ls1\000event=0xc88c\000\00000\000LSU\000"
/* offset=243474 */ "pm_lsu_ncst\000other\000Non-cachable Stores sent to nest\000event=0xc092\000\00000\000Non-cachable Stores sent to nest42\000"
/* offset=243577 */ "pm_lsu_reject\000other\000LSU Reject (up to 4 per cycle)\000event=0x10064\000\00000\000\000"
/* offset=243647 */ "pm_lsu_set_mpred\000other\000Line already in cache at reload time\000event=0xd082\000\00000\000Line already in cache at reload time42\000"
/* offset=243763 */ "pm_lsu_srq_empty_cyc\000other\000ALL threads srq empty\000event=0x40008\000\00000\000All threads srq empty\000"
/* offset=243852 */ "pm_lsu_srq_s0_alloc\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09d\000\00000\0000.0\000"
/* offset=244305 */ "pm_lsu_srq_s0_valid\000other\000Slot 0 of SRQ valid\000event=0xd09c\000\00000\000Slot 0 of SRQ validSRQ slot 0 valid\000"
/* offset=244404 */ "pm_lsu_srq_s39_alloc\000other\000SRQ slot 39 was released\000event=0xf093\000\00000\0000.0\000"
/* offset=244477 */ "pm_lsu_srq_s39_valid\000other\000SRQ slot 39 was busy\000event=0xf092\000\00000\000SRQ slot 39 was busy42\000"
/* offset=244565 */ "pm_lsu_srq_sync\000other\000A sync in the SRQ ended\000event=0xd09b\000\00000\0000.0\000"
/* offset=244632 */ "pm_lsu_srq_sync_cyc\000other\000A sync is in the SRQ (edge detect to count)\000event=0xd09a\000\00000\000A sync is in the SRQ (edge detect to count)SRQ sync duration\000"
/* offset=244780 */ "pm_lsu_store_reject\000other\000Store reject on either pipe\000event=0xf084\000\00000\000LSU\000"
/* offset=244855 */ "pm_lsu_two_tablewalk_cyc\000other\000Cycles when two tablewalks pending on this thread\000event=0xd0a6\000\00000\000Cycles when two tablewalks pending on this thread42\000"
/* offset=245005 */ "pm_lwsync\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\00000\000\000"
/* offset=245140 */ "pm_lwsync_held\000other\000LWSYNC held at dispatch\000event=0x209a\000\00000\000\000"
/* offset=245203 */ "pm_mrk_cru_fin\000other\000IFU non-branch finished\000event=0x3013a\000\00000\000IFU non-branch marked instruction finished\000"
/* offset=245309 */ "pm_mrk_data_from_l21_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x4d146\000\00000\000\000"
/* offset=245483 */ "pm_mrk_data_from_l21_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x2d126\000\00000\000\000"
/* offset=245650 */ "pm_mrk_data_from_l21_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x3d146\000\00000\000\000"
/* offset=245822 */ "pm_mrk_data_from_l21_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2c126\000\00000\000\000"
/* offset=245987 */ "pm_mrk_data_from_l31_eco_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x4d144\000\00000\000\000"
/* offset=246169 */ "pm_mrk_data_from_l31_eco_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d124\000\00000\000\000"
/* offset=246344 */ "pm_mrk_data_from_l31_eco_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x3d144\000\00000\000\000"
/* offset=246524 */ "pm_mrk_data_from_l31_eco_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2c124\000\00000\000\000"
/* offset=246697 */ "pm_mrk_data_from_l31_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x2d144\000\00000\000\000"
/* offset=246871 */ "pm_mrk_data_from_l31_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\00000\000\000"
/* offset=247038 */ "pm_mrk_data_from_l31_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x1d146\000\00000\000\000"
/* offset=247210 */ "pm_mrk_data_from_l31_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4c126\000\00000\000\000"
/* offset=247375 */ "pm_mrk_data_from_mem\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\00000\000\000"
/* offset=247547 */ "pm_mrk_dpteg_from_l21_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request\000event=0x4f146\000\00000\000\000"
/* offset=247738 */ "pm_mrk_dpteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request\000event=0x3f146\000\00000\000\000"
/* offset=247927 */ "pm_mrk_dpteg_from_l2_disp_conflict_ldhitst\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a marked data side request\000event=0x3f140\000\00000\000\000"
/* offset=248122 */ "pm_mrk_dpteg_from_l2_disp_conflict_other\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a marked data side request\000event=0x4f140\000\00000\000\000"
/* offset=248309 */ "pm_mrk_dpteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x4f144\000\00000\000\000"
/* offset=248508 */ "pm_mrk_dpteg_from_l31_eco_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x3f144\000\00000\000\000"
/* offset=248705 */ "pm_mrk_dpteg_from_l31_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request\000event=0x2f144\000\00000\000\000"
/* offset=248896 */ "pm_mrk_dpteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request\000event=0x1f146\000\00000\000\000"
/* offset=249085 */ "pm_mrk_fab_rsp_match\000other\000ttype and cresp matched as specified in MMCR1\000event=0x30156\000\00000\000\000"
/* offset=249177 */ "pm_mrk_fab_rsp_match_cyc\000other\000cresp/ttype match cycles\000event=0x4f152\000\00000\000\000"
/* offset=249252 */ "pm_mrk_filt_match\000other\000Marked filter Match\000event=0x2013c\000\00000\000\000"
/* offset=249315 */ "pm_mrk_fin_stall_cyc\000other\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count )\000event=0x1013c\000\00000\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count #)\000"
/* offset=249547 */ "pm_mrk_grp_cmpl\000other\000marked instruction finished (completed)\000event=0x40130\000\00000\000\000"
/* offset=249628 */ "pm_mrk_grp_ic_miss\000other\000Marked Group experienced I cache miss\000event=0x4013a\000\00000\000\000"
/* offset=249710 */ "pm_mrk_grp_ntc\000other\000Marked group ntc cycles\000event=0x3013c\000\00000\000\000"
/* offset=249774 */ "pm_mrk_ld_miss_exposed\000other\000Marked Load exposed Miss (exposed period ended)\000event=0x1013f\000\00000\000Marked Load exposed Miss (use edge detect to count #)\000"
/* offset=249923 */ "pm_mrk_lsu_flush\000other\000Flush: (marked) : All Cases\000event=0xd180\000\00000\000Flush: (marked) : All Cases42\000"
/* offset=250021 */ "pm_mrk_lsu_flush_lrq\000other\000Flush: (marked) LRQ\000event=0xd188\000\00000\000Flush: (marked) LRQMarked LRQ flushes\000"
/* offset=250123 */ "pm_mrk_lsu_flush_srq\000other\000Flush: (marked) SRQ\000event=0xd18a\000\00000\000Flush: (marked) SRQMarked SRQ lhs flushes\000"
/* offset=250229 */ "pm_mrk_lsu_flush_uld\000other\000Flush: (marked) Unaligned Load\000event=0xd184\000\00000\000Flush: (marked) Unaligned LoadMarked unaligned load flushes\000"
/* offset=250364 */ "pm_mrk_lsu_flush_ust\000other\000Flush: (marked) Unaligned Store\000event=0xd186\000\00000\000Flush: (marked) Unaligned StoreMarked unaligned store flushes\000"
/* offset=250502 */ "pm_mrk_lsu_reject\000other\000LSU marked reject (up to 2 per cycle)\000event=0x40164\000\00000\000\000"
/* offset=250583 */ "pm_mrk_lsu_reject_erat_miss\000other\000LSU marked reject due to ERAT (up to 2 per cycle)\000event=0x30164\000\00000\000\000"
/* offset=250686 */ "pm_mrk_src_pref_track_eff\000other\000Marked src pref track was effective\000event=0x1d15a\000\00000\000\000"
/* offset=250773 */ "pm_mrk_src_pref_track_ineff\000other\000Prefetch tracked was ineffective for marked src\000event=0x3d15a\000\00000\000\000"
/* offset=250874 */ "pm_mrk_src_pref_track_mod\000other\000Prefetch tracked was moderate for marked src\000event=0x4d15c\000\00000\000\000"
/* offset=250970 */ "pm_mrk_src_pref_track_mod_l2\000other\000Marked src Prefetch Tracked was moderate (source L2)\000event=0x1d15c\000\00000\000\000"
/* offset=251077 */ "pm_mrk_src_pref_track_mod_l3\000other\000Prefetch tracked was moderate (L3 hit) for marked src\000event=0x3d15c\000\00000\000\000"
/* offset=251185 */ "pm_mrk_tgt_pref_track_eff\000other\000Marked target pref track was effective\000event=0x1c15a\000\00000\000\000"
/* offset=251275 */ "pm_mrk_tgt_pref_track_ineff\000other\000Prefetch tracked was ineffective for marked target\000event=0x3c15a\000\00000\000\000"
/* offset=251379 */ "pm_mrk_tgt_pref_track_mod\000other\000Prefetch tracked was moderate for marked target\000event=0x4c15c\000\00000\000\000"
/* offset=251478 */ "pm_mrk_tgt_pref_track_mod_l2\000other\000Marked target Prefetch Tracked was moderate (source L2)\000event=0x1c15c\000\00000\000\000"
/* offset=251588 */ "pm_mrk_tgt_pref_track_mod_l3\000other\000Prefetch tracked was moderate (L3 hit) for marked target\000event=0x3c15c\000\00000\000\000"
/* offset=251699 */ "pm_nested_tend\000other\000Completion time nested tend\000event=0x20b0\000\00000\000\000"
/* offset=251766 */ "pm_non_fav_tbegin\000other\000Dispatch time non favored tbegin\000event=0x20b6\000\00000\000\000"
/* offset=251841 */ "pm_ntcg_all_fin\000other\000Cycles after all instructions have finished to group completed\000event=0x2001a\000\00000\000Ccycles after all instructions have finished to group completed\000"
/* offset=252008 */ "pm_outer_tbegin\000other\000Completion time outer tbegin\000event=0x20ac\000\00000\000\000"
/* offset=252077 */ "pm_outer_tend\000other\000Completion time outer tend\000event=0x20ae\000\00000\000\000"
/* offset=252142 */ "pm_pref_tracked\000other\000Total number of Prefetch Operations that were tracked\000event=0x2005a\000\00000\000\000"
/* offset=252237 */ "pm_pref_track_eff\000other\000Prefetch Tracked was effective\000event=0x1005a\000\00000\000\000"
/* offset=252311 */ "pm_pref_track_ineff\000other\000Prefetch tracked was ineffective\000event=0x3005a\000\00000\000\000"
/* offset=252389 */ "pm_pref_track_mod\000other\000Prefetch tracked was moderate\000event=0x4005a\000\00000\000\000"
/* offset=252462 */ "pm_pref_track_mod_l2\000other\000Prefetch Tracked was moderate (source L2)\000event=0x1005c\000\00000\000\000"
/* offset=252550 */ "pm_pref_track_mod_l3\000other\000Prefetch tracked was moderate (L3)\000event=0x3005c\000\00000\000\000"
/* offset=252631 */ "pm_pte_prefetch\000other\000PTE prefetches\000event=0xe084\000\00000\000PTE prefetches42\000"
/* offset=252702 */ "pm_rc0_alloc\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16081\000\00000\0000.0\000"
/* offset=252825 */ "pm_rc0_busy\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16080\000\00000\000\000"
/* offset=252944 */ "pm_rc_lifetime_exc_1024\000other\000Number of times the RC machine for a sampled instruction was active for more than 1024 cycles\000event=0x200301ea\000\00000\000Reload latency exceeded 1024 cyc\000"
/* offset=253122 */ "pm_rc_lifetime_exc_2048\000other\000Number of times the RC machine for a sampled instruction was active for more than 2048 cycles\000event=0x200401ec\000\00000\000Threshold counter exceeded a value of 2048\000"
/* offset=253310 */ "pm_rc_lifetime_exc_256\000other\000Number of times the RC machine for a sampled instruction was active for more than 256 cycles\000event=0x200101e8\000\00000\000Threshold counter exceed a count of 256\000"
/* offset=253493 */ "pm_rc_lifetime_exc_32\000other\000Number of times the RC machine for a sampled instruction was active for more than 32 cycles\000event=0x200201e6\000\00000\000Reload latency exceeded 32 cyc\000"
/* offset=253665 */ "pm_rc_usage\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x36088\000\00000\000\000"
/* offset=253884 */ "pm_real_srq_full\000other\000Out of real srq entries\000event=0x20004\000\00000\000\000"
/* offset=253950 */ "pm_run_cyc_smt2_shrd_mode\000other\000cycles this threads run latch is set and the core is in SMT2 shared mode\000event=0x2006a\000\00000\000Cycles run latch is set and core is in SMT2-shared mode\000"
/* offset=254129 */ "pm_run_cyc_smt2_split_mode\000other\000Cycles run latch is set and core is in SMT2-split mode\000event=0x1006a\000\00000\000\000"
/* offset=254236 */ "pm_run_cyc_smt8_mode\000other\000Cycles run latch is set and core is in SMT8 mode\000event=0x4006c\000\00000\000\000"
/* offset=254331 */ "pm_sec_erat_hit\000other\000secondary ERAT Hit\000event=0xf082\000\00000\000secondary ERAT Hit42\000"
/* offset=254410 */ "pm_shl_created\000other\000Store-Hit-Load Table Entry Created\000event=0x508c\000\00000\000\000"
/* offset=254484 */ "pm_shl_st_convert\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x508e\000\00000\000\000"
/* offset=254575 */ "pm_shl_st_disable\000other\000Store-Hit-Load Table Read Hit with entry Disabled (entry was disabled due to the entry shown to not prevent the flush)\000event=0x5090\000\00000\000\000"
/* offset=254736 */ "pm_sn0_alloc\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26085\000\00000\0000.0\000"
/* offset=254859 */ "pm_sn0_busy\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26084\000\00000\000\000"
/* offset=254978 */ "pm_snoop_tlbie\000other\000TLBIE snoop\000event=0xd0b2\000\00000\000TLBIE snoopSnoop TLBIE\000"
/* offset=255051 */ "pm_sn_usage\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x4608c\000\00000\000\000"
/* offset=255270 */ "pm_stall_end_gct_empty\000other\000Count ended because GCT went empty\000event=0x10028\000\00000\000\000"
/* offset=255353 */ "pm_stcx_lsu\000other\000STCX executed reported at sent to nest\000event=0xc090\000\00000\000STCX executed reported at sent to nest42\000"
/* offset=255468 */ "pm_swap_cancel\000other\000SWAP cancel , rtag not available\000event=0x3090\000\00000\000\000"
/* offset=255540 */ "pm_swap_cancel_gpr\000other\000SWAP cancel , rtag not available for gpr\000event=0x3092\000\00000\000\000"
/* offset=255624 */ "pm_swap_complete\000other\000swap cast in completed\000event=0x308c\000\00000\000\000"
/* offset=255688 */ "pm_swap_complete_gpr\000other\000swap cast in completed fpr gpr\000event=0x308e\000\00000\000\000"
/* offset=255764 */ "pm_tablewalk_cyc_pref\000other\000tablewalk qualified for pte prefetches\000event=0xe086\000\00000\000tablewalk qualified for pte prefetches42\000"
/* offset=255889 */ "pm_tabort_treclaim\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x20b2\000\00000\000\000"
/* offset=255980 */ "pm_tend_pend_cyc\000other\000TEND latency per thread\000event=0xe0ba\000\00000\000TEND latency per thread42\000"
/* offset=256070 */ "pm_thrd_grp_cmpl_both_cyc\000other\000Cycles group completed on both completion slots by any thread\000event=0x10012\000\00000\000Two threads finished same cycle (gated by run latch)\000"
/* offset=256235 */ "pm_thrd_prio_0_1_cyc\000other\000Cycles thread running at priority level 0 or 1\000event=0x40bc\000\00000\000\000"
/* offset=256327 */ "pm_thrd_prio_2_3_cyc\000other\000Cycles thread running at priority level 2 or 3\000event=0x40be\000\00000\000\000"
/* offset=256419 */ "pm_thrd_prio_4_5_cyc\000other\000Cycles thread running at priority level 4 or 5\000event=0x5080\000\00000\000\000"
/* offset=256511 */ "pm_thrd_prio_6_7_cyc\000other\000Cycles thread running at priority level 6 or 7\000event=0x5082\000\00000\000\000"
/* offset=256603 */ "pm_thrd_rebal_cyc\000other\000cycles rebalance was active\000event=0x3098\000\00000\000\000"
/* offset=256673 */ "pm_tm_begin_all\000other\000Tm any tbegin\000event=0x20b8\000\00000\000\000"
/* offset=256727 */ "pm_tm_end_all\000other\000Tm any tend\000event=0x20ba\000\00000\000\000"
/* offset=256777 */ "pm_tm_fail_conf_non_tm\000other\000TEXAS fail reason @ completion\000event=0x3086\000\00000\000\000"
/* offset=256855 */ "pm_tm_fail_con_tm\000other\000TEXAS fail reason @ completion\000event=0x3088\000\00000\000\000"
/* offset=256928 */ "pm_tm_fail_disallow\000other\000TM fail disallow\000event=0xe0b2\000\00000\000TM fail disallow42\000"
/* offset=257007 */ "pm_tm_fail_footprint_overflow\000other\000TEXAS fail reason @ completion\000event=0x3084\000\00000\000\000"
/* offset=257092 */ "pm_tm_fail_non_tx_conflict\000other\000Non transactional conflict from LSU whtver gets repoted to texas\000event=0xe0b8\000\00000\000Non transactional conflict from LSU whtver gets repoted to texas42\000"
/* offset=257274 */ "pm_tm_fail_self\000other\000TEXAS fail reason @ completion\000event=0x308a\000\00000\000\000"
/* offset=257345 */ "pm_tm_fail_tlbie\000other\000TLBIE hit bloom filter\000event=0xe0b4\000\00000\000TLBIE hit bloom filter42\000"
/* offset=257433 */ "pm_tm_fail_tx_conflict\000other\000Transactional conflict from LSU, whatever gets reported to texas\000event=0xe0b6\000\00000\000Transactional conflict from LSU, whatever gets reported to texas 42\000"
/* offset=257612 */ "pm_tm_tbegin\000other\000Tm nested tbegin\000event=0x20bc\000\00000\000\000"
/* offset=257666 */ "pm_tm_tresume\000other\000Tm resume\000event=0x3080\000\00000\000\000"
/* offset=257714 */ "pm_tm_tsuspend\000other\000Tm suspend\000event=0x20be\000\00000\000\000"
/* offset=257764 */ "pm_up_pref_l3\000other\000Micropartition prefetch\000event=0xe08c\000\00000\000Micropartition prefetch42\000"
/* offset=257851 */ "pm_up_pref_pointer\000other\000Micrpartition pointer prefetches\000event=0xe08e\000\00000\000Micrpartition pointer prefetches42\000"
/* offset=257961 */ "pm_vsu0_16flop\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a4\000\00000\000\000"
/* offset=258059 */ "pm_vsu0_1flop\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa080\000\00000\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finishedDecode into 1,2,4 FLOP according to instr IOP, multiplied by #vector elements according to route( eg x1, x2, x4) Only if instr sends finish to ISU\000"
/* offset=258426 */ "pm_vsu0_2flop\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa098\000\00000\000\000"
/* offset=258573 */ "pm_vsu0_4flop\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09c\000\00000\000\000"
/* offset=258752 */ "pm_vsu0_8flop\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a0\000\00000\000\000"
/* offset=258899 */ "pm_vsu0_complex_issued\000other\000Complex VMX instruction issued\000event=0xb0a4\000\00000\000\000"
/* offset=258977 */ "pm_vsu0_cy_issued\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b4\000\00000\000\000"
/* offset=259061 */ "pm_vsu0_dd_issued\000other\00064BIT Decimal Issued\000event=0xb0a8\000\00000\000\000"
/* offset=259124 */ "pm_vsu0_dp_2flop\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08c\000\00000\000\000"
/* offset=259242 */ "pm_vsu0_dp_fma\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa090\000\00000\000\000"
/* offset=259328 */ "pm_vsu0_dp_fsqrt_fdiv\000other\000DP vector versions of fdiv,fsqrt\000event=0xa094\000\00000\000\000"
/* offset=259407 */ "pm_vsu0_dq_issued\000other\000128BIT Decimal Issued\000event=0xb0ac\000\00000\000\000"
/* offset=259471 */ "pm_vsu0_ex_issued\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b0\000\00000\000\000"
/* offset=259557 */ "pm_vsu0_fin\000other\000VSU0 Finished an instruction\000event=0xa0bc\000\00000\000\000"
/* offset=259622 */ "pm_vsu0_fma\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa084\000\00000\000\000"
/* offset=259735 */ "pm_vsu0_fpscr\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb098\000\00000\000\000"
/* offset=259826 */ "pm_vsu0_fsqrt_fdiv\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa088\000\00000\000\000"
/* offset=259929 */ "pm_vsu0_permute_issued\000other\000Permute VMX Instruction Issued\000event=0xb090\000\00000\000\000"
/* offset=260007 */ "pm_vsu0_scalar_dp_issued\000other\000Double Precision scalar instruction issued on Pipe0\000event=0xb088\000\00000\000\000"
/* offset=260108 */ "pm_vsu0_simple_issued\000other\000Simple VMX instruction issued\000event=0xb094\000\00000\000\000"
/* offset=260184 */ "pm_vsu0_single\000other\000FPU single precision\000event=0xa0a8\000\00000\000\000"
/* offset=260244 */ "pm_vsu0_sq\000other\000Store Vector Issued\000event=0xb09c\000\00000\000\000"
/* offset=260299 */ "pm_vsu0_stf\000other\000FPU store (SP or DP) issued on Pipe0\000event=0xb08c\000\00000\000\000"
/* offset=260372 */ "pm_vsu0_vector_dp_issued\000other\000Double Precision vector instruction issued on Pipe0\000event=0xb080\000\00000\000\000"
/* offset=260473 */ "pm_vsu0_vector_sp_issued\000other\000Single Precision vector instruction issued (executed)\000event=0xb084\000\00000\000\000"
/* offset=260576 */ "pm_vsu1_16flop\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a6\000\00000\000\000"
/* offset=260674 */ "pm_vsu1_1flop\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa082\000\00000\000\000"
/* offset=260804 */ "pm_vsu1_2flop\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa09a\000\00000\000\000"
/* offset=260951 */ "pm_vsu1_4flop\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09e\000\00000\000\000"
/* offset=261130 */ "pm_vsu1_8flop\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a2\000\00000\000\000"
/* offset=261277 */ "pm_vsu1_complex_issued\000other\000Complex VMX instruction issued\000event=0xb0a6\000\00000\000\000"
/* offset=261355 */ "pm_vsu1_cy_issued\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b6\000\00000\000\000"
/* offset=261439 */ "pm_vsu1_dd_issued\000other\00064BIT Decimal Issued\000event=0xb0aa\000\00000\000\000"
/* offset=261502 */ "pm_vsu1_dp_2flop\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08e\000\00000\000\000"
/* offset=261620 */ "pm_vsu1_dp_fma\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa092\000\00000\000\000"
/* offset=261706 */ "pm_vsu1_dp_fsqrt_fdiv\000other\000DP vector versions of fdiv,fsqrt\000event=0xa096\000\00000\000\000"
/* offset=261785 */ "pm_vsu1_dq_issued\000other\000128BIT Decimal Issued\000event=0xb0ae\000\00000\000\000"
/* offset=261849 */ "pm_vsu1_ex_issued\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b2\000\00000\000\000"
/* offset=261935 */ "pm_vsu1_fin\000other\000VSU1 Finished an instruction\000event=0xa0be\000\00000\000\000"
/* offset=262000 */ "pm_vsu1_fma\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa086\000\00000\000\000"
/* offset=262113 */ "pm_vsu1_fpscr\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb09a\000\00000\000\000"
/* offset=262204 */ "pm_vsu1_fsqrt_fdiv\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa08a\000\00000\000\000"
/* offset=262307 */ "pm_vsu1_permute_issued\000other\000Permute VMX Instruction Issued\000event=0xb092\000\00000\000\000"
/* offset=262385 */ "pm_vsu1_scalar_dp_issued\000other\000Double Precision scalar instruction issued on Pipe1\000event=0xb08a\000\00000\000\000"
/* offset=262486 */ "pm_vsu1_simple_issued\000other\000Simple VMX instruction issued\000event=0xb096\000\00000\000\000"
/* offset=262562 */ "pm_vsu1_single\000other\000FPU single precision\000event=0xa0aa\000\00000\000\000"
/* offset=262622 */ "pm_vsu1_sq\000other\000Store Vector Issued\000event=0xb09e\000\00000\000\000"
/* offset=262677 */ "pm_vsu1_stf\000other\000FPU store (SP or DP) issued on Pipe1\000event=0xb08e\000\00000\000\000"
/* offset=262750 */ "pm_vsu1_vector_dp_issued\000other\000Double Precision vector instruction issued on Pipe1\000event=0xb082\000\00000\000\000"
/* offset=262851 */ "pm_vsu1_vector_sp_issued\000other\000Single Precision vector instruction issued (executed)\000event=0xb086\000\00000\000\000"
/* offset=262954 */ "pm_1plus_ppc_cmpl\000pipeline\0001 or more ppc insts finished\000event=0x100f2\000\00000\0001 or more ppc insts finished (completed)\000"
/* offset=263069 */ "pm_1plus_ppc_disp\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\00000\000Cycles at least one Instr Dispatched. Could be a group with only microcode. Issue HW016521\000"
/* offset=263242 */ "pm_any_thrd_run_cyc\000pipeline\000One of threads in run_cycles\000event=0x100fa\000\00000\000Any thread in run_cycles (was one thread in run_cycles)\000"
/* offset=263374 */ "pm_cmplu_stall\000pipeline\000Completion stall\000event=0x4000a\000\00000\000\000"
/* offset=263434 */ "pm_cmplu_stall_bru\000pipeline\000Completion stall due to a Branch Unit\000event=0x4d018\000\00000\000\000"
/* offset=263519 */ "pm_cmplu_stall_dcache_miss\000pipeline\000Completion stall by Dcache miss\000event=0x2c012\000\00000\000\000"
/* offset=263606 */ "pm_cmplu_stall_dmiss_l21_l31\000pipeline\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000event=0x2c018\000\00000\000\000"
/* offset=263743 */ "pm_cmplu_stall_dmiss_l2l3\000pipeline\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x2c016\000\00000\000\000"
/* offset=263853 */ "pm_cmplu_stall_dmiss_l2l3_conflict\000pipeline\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\00000\000Completion stall due to cache miss resolving in core's L2/L3 with a conflict\000"
/* offset=264073 */ "pm_cmplu_stall_dmiss_l3miss\000pipeline\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\00000\000\000"
/* offset=264188 */ "pm_cmplu_stall_dmiss_lmem\000pipeline\000Completion stall due to cache miss that resolves in local memory\000event=0x4c018\000\00000\000Completion stall due to cache miss resolving in core's Local Memory\000"
/* offset=264374 */ "pm_cmplu_stall_dmiss_remote\000pipeline\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\00000\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000"
/* offset=264591 */ "pm_cmplu_stall_erat_miss\000pipeline\000Completion stall due to LSU reject ERAT miss\000event=0x4c012\000\00000\000\000"
/* offset=264689 */ "pm_cmplu_stall_fxlong\000pipeline\000Completion stall due to a long latency fixed point instruction\000event=0x4d016\000\00000\000\000"
/* offset=264802 */ "pm_cmplu_stall_fxu\000pipeline\000Completion stall due to FXU\000event=0x2d016\000\00000\000\000"
/* offset=264877 */ "pm_cmplu_stall_hwsync\000pipeline\000completion stall due to hwsync\000event=0x30036\000\00000\000\000"
/* offset=264958 */ "pm_cmplu_stall_load_finish\000pipeline\000Completion stall due to a Load finish\000event=0x4d014\000\00000\000\000"
/* offset=265051 */ "pm_cmplu_stall_lsu\000pipeline\000Completion stall by LSU instruction\000event=0x2c010\000\00000\000\000"
/* offset=265134 */ "pm_cmplu_stall_lwsync\000pipeline\000completion stall due to isync/lwsync\000event=0x10036\000\00000\000\000"
/* offset=265221 */ "pm_cmplu_stall_other_cmpl\000pipeline\000Instructions core completed while this tread was stalled\000event=0x30006\000\00000\000Instructions core completed while this thread was stalled\000"
/* offset=265389 */ "pm_cmplu_stall_st_fwd\000pipeline\000Completion stall due to store forward\000event=0x4c01c\000\00000\000\000"
/* offset=265477 */ "pm_cmplu_stall_thrd\000pipeline\000Completion Stalled due to thread conflict. Group ready to complete but it was another thread's turn\000event=0x1001c\000\00000\000Completion stall due to thread conflict\000"
/* offset=265664 */ "pm_cyc\000pipeline\000Cycles\000event=0x1e\000\00000\000\000"
/* offset=265703 */ "pm_disp_held\000pipeline\000Dispatch Held\000event=0x10006\000\00000\000\000"
/* offset=265758 */ "pm_disp_held_sync_hold\000pipeline\000Dispatch held due to SYNC hold\000event=0x4003c\000\00000\000\000"
/* offset=265840 */ "pm_ext_int\000pipeline\000external interrupt\000event=0x200f8\000\00000\000\000"
/* offset=265898 */ "pm_flush_completion\000pipeline\000Completion Flush\000event=0x30012\000\00000\000\000"
/* offset=265963 */ "pm_freq_down\000pipeline\000Power Management: Below Threshold B\000event=0x3000c\000\00000\000Frequency is being slewed down due to Power Management\000"
/* offset=266094 */ "pm_freq_up\000pipeline\000Power Management: Above Threshold A\000event=0x4000c\000\00000\000Frequency is being slewed up due to Power Management\000"
/* offset=266221 */ "pm_hv_cyc\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\00000\000cycles in hypervisor mode\000"
/* offset=266377 */ "pm_ifetch_throttle\000pipeline\000Cycles in which Instruction fetch throttle was active\000event=0x3405e\000\00000\000Cycles instruction fecth was throttled in IFU\000"
/* offset=266523 */ "pm_iops_cmpl\000pipeline\000Internal Operations completed\000event=0x10014\000\00000\000IOPS Completed\000"
/* offset=266608 */ "pm_larx_fin\000pipeline\000Larx finished\000event=0x3c058\000\00000\000\000"
/* offset=266662 */ "pm_ld_cmpl\000pipeline\000count of Loads completed\000event=0x1002e\000\00000\000\000"
/* offset=266726 */ "pm_ld_l3miss_pend_cyc\000pipeline\000Cycles L3 miss was pending for this thread\000event=0x10062\000\00000\000\000"
/* offset=266819 */ "pm_lsu_fin\000pipeline\000LSU Finished an instruction (up to 2 per cycle)\000event=0x30066\000\00000\000\000"
/* offset=266906 */ "pm_lsu_lmq_srq_empty_cyc\000pipeline\000LSU empty (lmq and srq empty)\000event=0x2003e\000\00000\000\000"
/* offset=266989 */ "pm_lsu_reject_erat_miss\000pipeline\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\00000\000\000"
/* offset=267085 */ "pm_lsu_reject_lhs\000pipeline\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\00000\000\000"
/* offset=267173 */ "pm_lsu_reject_lmq_full\000pipeline\000LSU reject due to LMQ full ( 4 per cycle)\000event=0x1e05c\000\00000\000\000"
/* offset=267266 */ "pm_lsu_srq_full_cyc\000pipeline\000Storage Queue is full and is blocking dispatch\000event=0x1001a\000\00000\000SRQ is Full\000"
/* offset=267372 */ "pm_probe_nop_disp\000pipeline\000ProbeNops dispatched\000event=0x40014\000\00000\000\000"
/* offset=267439 */ "pm_run_cyc\000pipeline\000Run_cycles\000event=0x600f4\000\00000\000\000"
/* offset=267489 */ "pm_run_cyc_smt2_mode\000pipeline\000Cycles run latch is set and core is in SMT2 mode\000event=0x3006c\000\00000\000\000"
/* offset=267587 */ "pm_run_cyc_smt4_mode\000pipeline\000cycles this threads run latch is set and the core is in SMT4 mode\000event=0x2006c\000\00000\000Cycles run latch is set and core is in SMT4 mode\000"
/* offset=267750 */ "pm_run_cyc_st_mode\000pipeline\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\00000\000\000"
/* offset=267844 */ "pm_run_inst_cmpl\000pipeline\000Run_Instructions\000event=0x500fa\000\00000\000\000"
/* offset=267906 */ "pm_stcx_fail\000pipeline\000stcx failed\000event=0x1e058\000\00000\000\000"
/* offset=267959 */ "pm_st_cmpl\000pipeline\000Store completion count\000event=0x20016\000\00000\000\000"
/* offset=268021 */ "pm_st_fin\000pipeline\000Store Instructions Finished\000event=0x200f0\000\00000\000Store Instructions Finished (store sent to nest)\000"
/* offset=268135 */ "pm_st_fwd\000pipeline\000Store forwards that finished\000event=0x20018\000\00000\000\000"
/* offset=268202 */ "pm_tablewalk_cyc\000pipeline\000Cycles when a tablewalk (I or D) is active\000event=0x10026\000\00000\000Tablewalk Active\000"
/* offset=268306 */ "pm_tb_bit_trans\000pipeline\000timebase event\000event=0x300f8\000\00000\000\000"
/* offset=268365 */ "pm_thrd_all_run_cyc\000pipeline\000All Threads in Run_cycles (was both threads in run_cycles)\000event=0x2000c\000\00000\000\000"
/* offset=268472 */ "pm_tlbie_fin\000pipeline\000tlbie finished\000event=0x30058\000\00000\000\000"
/* offset=268528 */ "pm_tm_trans_run_cyc\000pipeline\000run cycles in transactional state\000event=0x10060\000\00000\000\000"
/* offset=268610 */ "pm_tm_tx_pass_run_cyc\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\00000\000run cycles spent in successful transactions\000"
/* offset=268743 */ "pm_pmc1_overflow\000pmc\000Overflow from counter 1\000event=0x20010\000\00000\000\000"
/* offset=268807 */ "pm_pmc2_overflow\000pmc\000Overflow from counter 2\000event=0x30010\000\00000\000\000"
/* offset=268871 */ "pm_pmc2_rewind\000pmc\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\00000\000\000"
/* offset=268953 */ "pm_pmc2_saved\000pmc\000PMC2 Rewind Value saved\000event=0x10022\000\00000\000PMC2 Rewind Value saved (matched condition)\000"
/* offset=269057 */ "pm_pmc3_overflow\000pmc\000Overflow from counter 3\000event=0x40010\000\00000\000\000"
/* offset=269121 */ "pm_pmc4_overflow\000pmc\000Overflow from counter 4\000event=0x10010\000\00000\000\000"
/* offset=269185 */ "pm_pmc4_rewind\000pmc\000PMC4 Rewind Event\000event=0x10020\000\00000\000PMC4 Rewind Event (did not match condition)\000"
/* offset=269284 */ "pm_pmc4_saved\000pmc\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\00000\000\000"
/* offset=269365 */ "pm_pmc5_overflow\000pmc\000Overflow from counter 5\000event=0x10024\000\00000\000\000"
/* offset=269429 */ "pm_pmc6_overflow\000pmc\000Overflow from counter 6\000event=0x30024\000\00000\000\000"
/* offset=269493 */ "pm_run_purr\000pmc\000Run_PURR\000event=0x400f4\000\00000\000\000"
/* offset=269537 */ "pm_run_spurr\000pmc\000Run SPURR\000event=0x10008\000\00000\000\000"
/* offset=269583 */ "pm_suspended\000pmc\000Counter OFF\000event=0\000\00000\000\000"
/* offset=269625 */ "pm_thresh_exc_2048\000pmc\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\00000\000\000"
/* offset=269710 */ "pm_thresh_exc_256\000pmc\000Threshold counter exceed a count of 256\000event=0x101e8\000\00000\000\000"
/* offset=269791 */ "pm_thresh_exc_4096\000pmc\000Threshold counter exceed a count of 4096\000event=0x101e6\000\00000\000\000"
/* offset=269874 */ "pm_thresh_exc_64\000pmc\000IFU non-branch finished\000event=0x301e8\000\00000\000Threshold counter exceeded a value of 64\000"
/* offset=269978 */ "pm_thresh_met\000pmc\000threshold exceeded\000event=0x101ec\000\00000\000\000"
/* offset=270034 */ "pm_thresh_not_met\000pmc\000Threshold counter did not meet threshold\000event=0x4016e\000\00000\000\000"
/* offset=270116 */ "pm_derat_miss_16g\000translation\000Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4c054\000\00000\000\000"
/* offset=270212 */ "pm_derat_miss_16m\000translation\000Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3c054\000\00000\000\000"
/* offset=270308 */ "pm_derat_miss_4k\000translation\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\00000\000\000"
/* offset=270402 */ "pm_derat_miss_64k\000translation\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\00000\000\000"
/* offset=270498 */ "pm_dpteg_from_dl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x4e048\000\00000\000\000"
/* offset=270728 */ "pm_dpteg_from_dl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x3e048\000\00000\000\000"
/* offset=270956 */ "pm_dpteg_from_l2\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request\000event=0x1e042\000\00000\000\000"
/* offset=271095 */ "pm_dpteg_from_l2miss\000translation\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request\000event=0x1e04e\000\00000\000\000"
/* offset=271264 */ "pm_dpteg_from_l2_mepf\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request\000event=0x2e040\000\00000\000\000"
/* offset=271454 */ "pm_dpteg_from_l2_no_conflict\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request\000event=0x1e040\000\00000\000\000"
/* offset=271622 */ "pm_dpteg_from_l3\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request\000event=0x4e042\000\00000\000\000"
/* offset=271761 */ "pm_dpteg_from_l3_disp_conflict\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request\000event=0x3e042\000\00000\000\000"
/* offset=271937 */ "pm_dpteg_from_l3_mepf\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request\000event=0x2e042\000\00000\000\000"
/* offset=272127 */ "pm_dpteg_from_l3_no_conflict\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request\000event=0x1e044\000\00000\000\000"
/* offset=272295 */ "pm_dpteg_from_ll4\000translation\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request\000event=0x1e04c\000\00000\000\000"
/* offset=272445 */ "pm_dpteg_from_lmem\000translation\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request\000event=0x2e048\000\00000\000\000"
/* offset=272594 */ "pm_dpteg_from_memory\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request\000event=0x2e04c\000\00000\000\000"
/* offset=272781 */ "pm_dpteg_from_off_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request\000event=0x4e04a\000\00000\000\000"
/* offset=273008 */ "pm_dpteg_from_on_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request\000event=0x1e048\000\00000\000\000"
/* offset=273211 */ "pm_dpteg_from_rl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x2e046\000\00000\000\000"
/* offset=273437 */ "pm_dpteg_from_rl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x1e04a\000\00000\000\000"
/* offset=273661 */ "pm_dpteg_from_rl4\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request\000event=0x2e04a\000\00000\000\000"
/* offset=273839 */ "pm_dtlb_miss\000translation\000Data PTEG reload\000event=0x300fc\000\00000\000Data PTEG Reloaded (DTLB Miss)\000"
/* offset=273930 */ "pm_dtlb_miss_16g\000translation\000Data TLB Miss page size 16G\000event=0x1c058\000\00000\000\000"
/* offset=274006 */ "pm_dtlb_miss_16m\000translation\000Data TLB Miss page size 16M\000event=0x4c056\000\00000\000\000"
/* offset=274082 */ "pm_dtlb_miss_4k\000translation\000Data TLB Miss page size 4k\000event=0x2c056\000\00000\000\000"
/* offset=274156 */ "pm_dtlb_miss_64k\000translation\000Data TLB Miss page size 64K\000event=0x3c056\000\00000\000\000"
/* offset=274232 */ "pm_lsu_derat_miss\000translation\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\00000\000DERAT Reloaded (Miss)\000"
/* offset=274337 */ "pm_tlb_miss\000translation\000TLB Miss (I + D)\000event=0x20066\000\00000\000\000"
/* offset=274397 */ "pm_thrd_conc_run_inst\000cache\000PPC Instructions Finished by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\00000\000\000"
/* offset=274536 */ "pm_cmplu_stall_flush_any_thread\000cache\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000event=0x1e056\000\00000\000\000"
/* offset=274744 */ "pm_cmplu_stall_fxlong\000cache\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000event=0x4d016\000\00000\000\000"
/* offset=274885 */ "pm_cmplu_stall_fxu\000cache\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x2d016\000\00000\000\000"
/* offset=275077 */ "pm_mrk_data_from_rl4_cyc\000cache\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\00000\000\000"
/* offset=275236 */ "pm_cmplu_stall_dmiss_l2l3\000cache\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x1003c\000\00000\000\000"
/* offset=275343 */ "pm_cmplu_stall_lmq_full\000cache\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000event=0x4c014\000\00000\000\000"
/* offset=275542 */ "pm_inst_from_on_chip_cache\000cache\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\00000\000\000"
/* offset=275758 */ "pm_cmplu_stall_load_finish\000cache\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000event=0x4d014\000\00000\000\000"
/* offset=275952 */ "pm_inst_from_rl4\000cache\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\00000\000\000"
/* offset=276143 */ "pm_inst_from_rl2l3_shr\000cache\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\00000\000\000"
/* offset=276380 */ "pm_thresh_exc_128\000cache\000Threshold counter exceeded a value of 128\000event=0x401ea\000\00000\000\000"
/* offset=276465 */ "pm_br_mpred_cmpl\000cache\000Number of Branch Mispredicts\000event=0x400f6\000\00000\000\000"
/* offset=276536 */ "pm_mrk_dpteg_from_l2_mepf\000cache\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f140\000\00000\000\000"
/* offset=276830 */ "pm_thresh_exc_4096\000cache\000Threshold counter exceed a count of 4096\000event=0x101e6\000\00000\000\000"
/* offset=276915 */ "pm_mrk_dpteg_from_rmem\000cache\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14a\000\00000\000\000"
/* offset=277202 */ "pm_cmplu_stall_dmiss_l2l3_conflict\000cache\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\00000\000\000"
/* offset=277343 */ "pm_cmplu_stall_lhs\000cache\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000event=0x2c01a\000\00000\000\000"
/* offset=277500 */ "pm_mrk_dtlb_miss\000cache\000Marked dtlb miss\000event=0x401e4\000\00000\000\000"
/* offset=277559 */ "pm_inst_from_rl2l3_mod\000cache\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\00000\000\000"
/* offset=277798 */ "pm_cmplu_stall_larx\000cache\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000event=0x1002a\000\00000\000\000"
/* offset=277919 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000floating point\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x1415a\000\00000\000\000"
/* offset=278099 */ "pm_mem_loc_thresh_ifu\000floating point\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\00000\000\000"
/* offset=278212 */ "pm_radix_pwc_l2_pde_from_l2\000floating point\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L2 data cache\000event=0x2d028\000\00000\000\000"
/* offset=278369 */ "pm_flush_completion\000floating point\000The instruction that was next to complete did not complete because it suffered a flush\000event=0x30012\000\00000\000\000"
/* offset=278510 */ "pm_mrk_derat_miss_64k\000floating point\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\00000\000\000"
/* offset=278620 */ "pm_thresh_not_met\000floating point\000Threshold counter did not meet threshold\000event=0x4016e\000\00000\000\000"
/* offset=278713 */ "pm_ipteg_from_l31_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\00000\000\000"
/* offset=278903 */ "pm_thresh_exc_256\000frontend\000Threshold counter exceed a count of 256\000event=0x101e8\000\00000\000\000"
/* offset=278989 */ "pm_ntc_issue_held_darq_full\000frontend\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000event=0x1006a\000\00000\000\000"
/* offset=279137 */ "pm_cmplu_stall_lsaq_arb\000frontend\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000event=0x4e016\000\00000\000\000"
/* offset=279387 */ "pm_lsu_srq_full_cyc\000frontend\000Cycles in which the Store Queue is full on all 4 slices. This is event is not per thread. All the threads will see the same count for this core resource\000event=0x1001a\000\00000\000\000"
/* offset=279588 */ "pm_mrk_l2_tm_req_abort\000frontend\000TM abort\000event=0x1e15e\000\00000\000\000"
/* offset=279648 */ "pm_inst_sys_pump_mpred\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\00000\000\000"
/* offset=279890 */ "pm_mrk_l2_rc_disp\000frontend\000Marked Instruction RC dispatched in L2\000event=0x20114\000\00000\000\000"
/* offset=279975 */ "pm_data_from_l31_eco_mod\000frontend\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\00000\000\000"
/* offset=280156 */ "pm_data_from_l3_no_conflict\000frontend\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\00000\000\000"
/* offset=280311 */ "pm_inst_sys_pump_mpred_rty\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\00000\000\000"
/* offset=280470 */ "pm_mrk_fab_rsp_dclaim\000frontend\000Marked store had to do a dclaim\000event=0x30154\000\00000\000\000"
/* offset=280552 */ "pm_cmplu_stall_store_fin_arb\000frontend\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000event=0x30014\000\00000\000\000"
/* offset=280815 */ "pm_ld_miss_l1\000frontend\000Load Missed L1, counted at execution time (can be greater than loads finished). LMQ merges are not included in this count. i.e. if a load instruction misses on an address that is already allocated on the LMQ, this event will not increment for that load). Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x3e054\000\00000\000\000"
/* offset=281241 */ "pm_cmplu_stall_lsu_flush_next\000frontend\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000event=0x2e01a\000\00000\000\000"
/* offset=281497 */ "pm_cmplu_stall_stcx\000frontend\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000event=0x2d01c\000\00000\000\000"
/* offset=281626 */ "pm_cmplu_stall_lsu\000frontend\000Completion stall by LSU instruction\000event=0x2c010\000\00000\000\000"
/* offset=281709 */ "pm_data_from_l3_mepf\000frontend\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\00000\000\000"
/* offset=281885 */ "pm_cmplu_stall_mtfpscr\000frontend\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000event=0x4e012\000\00000\000\000"
/* offset=282042 */ "pm_1plus_ppc_cmpl\000frontend\0001 or more ppc insts finished\000event=0x100f2\000\00000\000\000"
/* offset=282117 */ "pm_lsu_reject_lmq_full\000frontend\000LSU Reject due to LMQ full (up to 4 per cycles)\000event=0x3001c\000\00000\000\000"
/* offset=282216 */ "pm_ipteg_from_l31_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\00000\000\000"
/* offset=282404 */ "pm_mrk_fab_rsp_rd_t_intv\000frontend\000Sampled Read got a T intervention\000event=0x1015e\000\00000\000\000"
/* offset=282491 */ "pm_thresh_met\000frontend\000threshold exceeded\000event=0x101ec\000\00000\000\000"
/* offset=282552 */ "pm_pmc4_rewind\000frontend\000PMC4 Rewind Event\000event=0x10020\000\00000\000\000"
/* offset=282613 */ "pm_thresh_exc_1024\000frontend\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\00000\000\000"
/* offset=282703 */ "pm_cmplu_stall_lsu_mfspr\000frontend\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000event=0x34056\000\00000\000\000"
/* offset=282898 */ "pm_vector_st_cmpl\000frontend\000Number of vector store instructions completed\000event=0x44056\000\00000\000\000"
/* offset=282990 */ "pm_mrk_data_from_l2_disp_conflict_other\000frontend\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x2c124\000\00000\000\000"
/* offset=283163 */ "pm_mrk_data_from_rl2l3_shr_cyc\000frontend\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\00000\000\000"
/* offset=283371 */ "pm_tm_trans_run_inst\000frontend\000Run instructions completed in transactional state (gated by the run latch)\000event=0x30060\000\00000\000\000"
/* offset=283495 */ "pm_cmplu_stall_store_finish\000frontend\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000event=0x2c014\000\00000\000\000"
/* offset=283685 */ "pm_mrk_data_from_on_chip_cache_cyc\000frontend\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x3515a\000\00000\000\000"
/* offset=283872 */ "pm_inst_sys_pump_cpred\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\00000\000\000"
/* offset=284014 */ "pm_mrk_fab_rsp_claim_rty\000frontend\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\00000\000\000"
/* offset=284107 */ "pm_suspended\000frontend\000Counter OFF\000event=0\000\00000\000\000"
/* offset=284154 */ "pm_pmc4_overflow\000frontend\000Overflow from counter 4\000event=0x10010\000\00000\000\000"
/* offset=284223 */ "pm_dpteg_from_rmem\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04a\000\00000\000\000"
/* offset=284502 */ "pm_mrk_fab_rsp_dclaim_cyc\000frontend\000cycles L2 RC took for a dclaim\000event=0x2f152\000\00000\000\000"
/* offset=284587 */ "pm_cmplu_stall_lrq_other\000frontend\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000event=0x10004\000\00000\000\000"
/* offset=284793 */ "pm_mrk_fab_rsp_rwitm_cyc\000frontend\000cycles L2 RC took for a rwitm\000event=0x4f150\000\00000\000\000"
/* offset=284876 */ "pm_dpteg_from_l3\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e042\000\00000\000\000"
/* offset=285111 */ "pm_tlb_hit\000frontend\000Number of times the TLB had the data required by the instruction. Applies to both HPT and RPT\000event=0x1f054\000\00000\000\000"
/* offset=285244 */ "pm_cmplu_stall_sync_pmu_int\000frontend\000Cycles in which the NTC instruction is waiting for a synchronous PMU interrupt\000event=0x2c01e\000\00000\000\000"
/* offset=285379 */ "pm_iops_cmpl\000frontend\000Internal Operations completed\000event=0x24050\000\00000\000\000"
/* offset=285450 */ "pm_sync_mrk_br_mpred\000frontend\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\00000\000\000"
/* offset=285563 */ "pm_inst_from_l3miss\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\00000\000\000"
/* offset=285684 */ "pm_sync_mrk_br_link\000frontend\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\00000\000\000"
/* offset=285801 */ "pm_cmplu_stall_tend\000frontend\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000event=0x1e050\000\00000\000\000"
/* offset=285939 */ "pm_mrk_ld_miss_exposed_cyc\000frontend\000Marked Load exposed Miss (use edge detect to count #)\000event=0x1013e\000\00000\000\000"
/* offset=286048 */ "pm_inst_pump_cpred\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\00000\000\000"
/* offset=286178 */ "pm_mrk_fab_rsp_rd_rty\000frontend\000Sampled L2 reads retry count\000event=0x4015e\000\00000\000\000"
/* offset=286257 */ "pm_inst_pump_mpred\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\00000\000\000"
/* offset=286382 */ "pm_cmplu_stall_store_data\000frontend\000Finish stall because the next to finish instruction was a store waiting on data\000event=0x30026\000\00000\000\000"
/* offset=286516 */ "pm_mrk_derat_miss\000frontend\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\00000\000\000"
/* offset=286600 */ "pm_thresh_acc\000frontend\000This event increments every time the threshold event counter ticks. Thresholding must be enabled (via MMCRA) and the thresholding start event must occur for this counter to increment. It will stop incrementing when the thresholding stop event occurs or when thresholding is disabled, until the next time a configured thresholding start event occurs\000event=0x24154\000\00000\000\000"
/* offset=286991 */ "pm_mrk_fab_rsp_rwitm_rty\000frontend\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\00000\000\000"
/* offset=287084 */ "pm_ipteg_from_l31_eco_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\00000\000\000"
/* offset=287280 */ "pm_cmplu_stall_store_pipe_arb\000frontend\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000event=0x4c010\000\00000\000\000"
/* offset=287543 */ "pm_cmplu_stall_st_fwd\000frontend\000Completion stall due to store forward\000event=0x4c01c\000\00000\000\000"
/* offset=287631 */ "pm_mrk_data_from_rl4\000frontend\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x3515c\000\00000\000\000"
/* offset=287800 */ "pm_mrk_data_from_l31_eco_shr\000frontend\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d14c\000\00000\000\000"
/* offset=287983 */ "pm_mrk_larx_fin\000frontend\000Larx finished\000event=0x40116\000\00000\000\000"
/* offset=288041 */ "pm_cmplu_stall_lsu_fin\000frontend\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000event=0x1003a\000\00000\000\000"
/* offset=288254 */ "pm_mrk_l2_rc_done\000frontend\000Marked RC done\000event=0x3012a\000\00000\000\000"
/* offset=288315 */ "pm_ipteg_from_l31_eco_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\00000\000\000"
/* offset=288513 */ "pm_mrk_stall_cmplu_cyc\000marked\000Number of cycles the marked instruction is experiencing a stall while it is next to complete (NTC)\000event=0x3013e\000\00000\000\000"
/* offset=288661 */ "pm_radix_pwc_l1_pde_from_l3miss\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from beyond the core's L3 data cache. The source could be local/remote/distant memory or another core's cache\000event=0x4f056\000\00000\000\000"
/* offset=288894 */ "pm_dpteg_from_l31_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e046\000\00000\000\000"
/* offset=289172 */ "pm_data_from_rmem\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\00000\000\000"
/* offset=289340 */ "pm_cmplu_stall_dmiss_remote\000marked\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\00000\000\000"
/* offset=289476 */ "pm_inst_from_l2_disp_conflict_other\000marked\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\00000\000\000"
/* offset=289672 */ "pm_darq0_7_9_entries\000marked\000Cycles in which 7,8, or 9 DARQ entries (out of 12) are in use\000event=0x2e050\000\00000\000\000"
/* offset=289781 */ "pm_radix_pwc_l3_pte_from_l2\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L2 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x2d02e\000\00000\000\000"
/* offset=290005 */ "pm_radix_pwc_l3_pte_from_l3\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x3f05e\000\00000\000\000"
/* offset=290229 */ "pm_cmplu_stall_ntc_flush\000marked\000Completion stall due to ntc flush\000event=0x2e01e\000\00000\000\000"
/* offset=290314 */ "pm_mrk_dpteg_from_ll4\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14c\000\00000\000\000"
/* offset=290570 */ "pm_mrk_dpteg_from_l31_eco_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f144\000\00000\000\000"
/* offset=290867 */ "pm_vector_flop_cmpl\000marked\000Vector FP instruction completed\000event=0x4d058\000\00000\000\000"
/* offset=290945 */ "pm_inst_from_l2_no_conflict\000marked\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\00000\000\000"
/* offset=291127 */ "pm_inst_from_l3miss_mod\000marked\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\00000\000\000"
/* offset=291298 */ "pm_cmplu_stall_exception\000marked\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\00000\000\000"
/* offset=291518 */ "pm_mrk_dpteg_from_l31_eco_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f144\000\00000\000\000"
/* offset=291817 */ "pm_dpteg_from_l31_eco_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e044\000\00000\000\000"
/* offset=292103 */ "pm_l1_dcache_reload_valid\000marked\000DL1 reloaded due to Demand Load\000event=0x300f6\000\00000\000\000"
/* offset=292187 */ "pm_mrk_data_from_l3miss_cyc\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x1415e\000\00000\000\000"
/* offset=292338 */ "pm_cmplu_stall_slb\000marked\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000event=0x1e052\000\00000\000\000"
/* offset=292460 */ "pm_inst_from_dmem\000marked\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\00000\000\000"
/* offset=292657 */ "pm_fxu_1plus_busy\000marked\000At least one of the 4 FXU units is busy\000event=0x3000e\000\00000\000\000"
/* offset=292741 */ "pm_data_from_lmem\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\00000\000\000"
/* offset=292875 */ "pm_cmplu_stall_pm\000marked\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish. Includes permute and decimal fixed point instructions (128 bit BCD arithmetic) + a few 128 bit fixpoint add/subtract instructions with carry. Not qualified by vector or multicycle\000event=0x3000a\000\00000\000\000"
/* offset=293204 */ "pm_ipteg_from_l2miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\00000\000\000"
/* offset=293375 */ "pm_data_grp_pump_mpred_rty\000marked\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\00000\000\000"
/* offset=293518 */ "pm_disp_starved\000marked\000Dispatched Starved\000event=0x30008\000\00000\000\000"
/* offset=293579 */ "pm_inst_from_l2\000marked\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\00000\000\000"
/* offset=293732 */ "pm_freq_up\000marked\000Power Management: Above Threshold A\000event=0x4000c\000\00000\000\000"
/* offset=293805 */ "pm_data_sys_pump_cpred\000marked\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\00000\000\000"
/* offset=293938 */ "pm_ipteg_from_l2_mepf\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\00000\000\000"
/* offset=294130 */ "pm_data_from_l31_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\00000\000\000"
/* offset=294299 */ "pm_data_from_l31_mod\000marked\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\00000\000\000"
/* offset=294470 */ "pm_data_from_rl4\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\00000\000\000"
/* offset=294633 */ "pm_inst_from_l31_mod\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\00000\000\000"
/* offset=294833 */ "pm_data_sys_pump_mpred_rty\000marked\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\00000\000\000"
/* offset=294983 */ "pm_data_grp_pump_mpred\000marked\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\00000\000\000"
/* offset=295133 */ "pm_mrk_dpteg_from_lmem\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f148\000\00000\000\000"
/* offset=295387 */ "pm_cmplu_stall_eieio\000marked\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000event=0x4d01a\000\00000\000\000"
/* offset=295516 */ "pm_mrk_dpteg_from_l3miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14e\000\00000\000\000"
/* offset=295790 */ "pm_radix_pwc_l4_pte_from_l3\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L3 data cache. This is the deepest level of PWC possible for a translation\000event=0x4f05a\000\00000\000\000"
/* offset=295996 */ "pm_radix_pwc_l4_pte_from_l2\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L2 data cache. This is the deepest level of PWC possible for a translation\000event=0x1f05a\000\00000\000\000"
/* offset=296202 */ "pm_l1_icache_reloaded_pref\000marked\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\00000\000\000"
/* offset=296330 */ "pm_data_from_off_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\00000\000\000"
/* offset=296542 */ "pm_data_from_memory\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\00000\000\000"
/* offset=296714 */ "pm_radix_pwc_l1_pde_from_l3\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L3 data cache\000event=0x3f058\000\00000\000\000"
/* offset=296863 */ "pm_data_sys_pump_mpred\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\00000\000\000"
/* offset=297096 */ "pm_sys_pump_cpred\000marked\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\00000\000\000"
/* offset=297273 */ "pm_cmplu_stall_spec_finish\000marked\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\00000\000\000"
/* offset=297483 */ "pm_run_purr\000marked\000Run_PURR\000event=0x400f4\000\00000\000\000"
/* offset=297530 */ "pm_inst_from_dl4\000marked\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\00000\000\000"
/* offset=297725 */ "pm_ntc_issue_held_other\000marked\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000event=0x3d05a\000\00000\000\000"
/* offset=297957 */ "pm_dpteg_from_lmem\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e048\000\00000\000\000"
/* offset=298200 */ "pm_radix_pwc_l3_pde_from_l2\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L2 data cache\000event=0x2d02a\000\00000\000\000"
/* offset=298349 */ "pm_radix_pwc_l3_pde_from_l3\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L3 data cache\000event=0x1f05c\000\00000\000\000"
/* offset=298498 */ "pm_darq0_0_3_entries\000marked\000Cycles in which 3 or less DARQ entries (out of 12) are in use\000event=0x4d04a\000\00000\000\000"
/* offset=298607 */ "pm_inst_from_ll4\000marked\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\00000\000\000"
/* offset=298771 */ "pm_l1_icache_miss\000marked\000Demand iCache Miss\000event=0x200fd\000\00000\000\000"
/* offset=298834 */ "pm_inst_from_l2_disp_conflict_ldhitst\000marked\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\00000\000\000"
/* offset=299038 */ "pm_inst_from_dl2l3_mod\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\00000\000\000"
/* offset=299282 */ "pm_ipteg_from_l21_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\00000\000\000"
/* offset=299468 */ "pm_data_from_l3miss_mod\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\00000\000\000"
/* offset=299626 */ "pm_inst_from_l31_eco_shr\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\00000\000\000"
/* offset=299832 */ "pm_cmplu_stall_ntc_disp_fin\000marked\000Finish stall because the NTF instruction was one that must finish at dispatch\000event=0x4e018\000\00000\000\000"
/* offset=299964 */ "pm_lmq_empty_cyc\000marked\000Cycles in which the LMQ has no pending load misses for this thread\000event=0x2e05e\000\00000\000\000"
/* offset=300074 */ "pm_darq1_0_3_entries\000marked\000Cycles in which 3 or fewer DARQ1 entries (out of 12) are in use\000event=0x4c122\000\00000\000\000"
/* offset=300185 */ "pm_radix_pwc_l2_pte_from_l3\000marked\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x4f058\000\00000\000\000"
/* offset=300422 */ "pm_inst_from_l31_shr\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\00000\000\000"
/* offset=300620 */ "pm_darq0_10_12_entries\000marked\000Cycles in which 10 or more DARQ entries (out of 12) are in use\000event=0x1d058\000\00000\000\000"
/* offset=300732 */ "pm_data_from_l3miss\000marked\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\00000\000\000"
/* offset=300826 */ "pm_cmplu_stall_other_cmpl\000marked\000Instructions the core completed while this tread was stalled\000event=0x30006\000\00000\000\000"
/* offset=300939 */ "pm_cmplu_stall_dp\000marked\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by NOT vector\000event=0x1005c\000\00000\000\000"
/* offset=301259 */ "pm_dpteg_from_l2\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e042\000\00000\000\000"
/* offset=301492 */ "pm_radix_pwc_l3_pte_from_l3miss\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from beyond the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05e\000\00000\000\000"
/* offset=301800 */ "pm_itlb_miss\000marked\000ITLB Reloaded. Counts 1 per ITLB miss for HPT but multiple for radix depending on number of levels traveresed\000event=0x400fc\000\00000\000\000"
/* offset=301949 */ "pm_dpteg_from_l3_no_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e044\000\00000\000\000"
/* offset=302211 */ "pm_non_math_flop_cmpl\000marked\000Non FLOP operation completed\000event=0x4d05a\000\00000\000\000"
/* offset=302288 */ "pm_data_from_on_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\00000\000\000"
/* offset=302476 */ "pm_data_pump_cpred\000marked\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\00000\000\000"
/* offset=302597 */ "pm_darq_store_reject\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry but It was rejected. Divide by PM_DARQ_STORE_XMIT to get reject ratio\000event=0x4405e\000\00000\000\000"
/* offset=302779 */ "pm_data_from_l2\000marked\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\00000\000\000"
/* offset=302903 */ "pm_run_cyc_st_mode\000marked\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\00000\000\000"
/* offset=302995 */ "pm_data_from_l31_eco_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\00000\000\000"
/* offset=303172 */ "pm_data_pump_mpred\000marked\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\00000\000\000"
/* offset=303288 */ "pm_grp_pump_cpred\000marked\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\00000\000\000"
/* offset=303499 */ "pm_sp_flop_cmpl\000marked\000SP instruction completed\000event=0x4505a\000\00000\000\000"
/* offset=303566 */ "pm_isq_36_44_entries\000marked\000Cycles in which 36 or more Issue Queue entries are in use. This is a shared event, not per thread. There are 44 issue queue entries across 4 slices in the whole core\000event=0x4000a\000\00000\000\000"
/* offset=303779 */ "pm_mrk_data_from_ll4_cyc\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x2c12e\000\00000\000\000"
/* offset=303911 */ "pm_mem_pref\000marked\000Memory prefetch for this thread. Includes L4\000event=0x2c058\000\00000\000\000"
/* offset=303994 */ "pm_l1_icache_reloaded_all\000marked\000Counts all Icache reloads includes demand, prefetch, prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\00000\000\000"
/* offset=304159 */ "pm_cmplu_stall_nested_tend\000marked\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000event=0x3003c\000\00000\000\000"
/* offset=304362 */ "pm_disp_held_hb_full\000marked\000Dispatch held due to History Buffer full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x3d05c\000\00000\000\000"
/* offset=304509 */ "pm_sys_pump_mpred\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\00000\000\000"
/* offset=304807 */ "pm_dpteg_from_l31_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e044\000\00000\000\000"
/* offset=305087 */ "pm_inst_from_dl2l3_shr\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\00000\000\000"
/* offset=305329 */ "pm_ipteg_from_l3\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\00000\000\000"
/* offset=305470 */ "pm_ipteg_from_l2\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\00000\000\000"
/* offset=305611 */ "pm_mem_loc_thresh_lsu_med\000marked\000Local memory above threshold for data prefetch\000event=0x1c05e\000\00000\000\000"
/* offset=305710 */ "pm_l1_dcache_reloaded_all\000marked\000L1 data cache reloaded for demand. If MMCR1[16] is 1, prefetches will be included as well\000event=0x1002c\000\00000\000\000"
/* offset=305852 */ "pm_mrk_inst_fin\000marked\000marked instruction finished\000event=0x30130\000\00000\000\000"
/* offset=305922 */ "pm_mrk_dpteg_from_rl2l3_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14a\000\00000\000\000"
/* offset=306252 */ "pm_darq0_4_6_entries\000marked\000Cycles in which 4, 5, or 6 DARQ entries (out of 12) are in use\000event=0x3504e\000\00000\000\000"
/* offset=306362 */ "pm_darq_store_xmit\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry. Includes rejects. Not qualified by thread, so it includes counts for the whole core\000event=0x30064\000\00000\000\000"
/* offset=306557 */ "pm_ipteg_from_l21_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\00000\000\000"
/* offset=306745 */ "pm_cmplu_stall_paste\000marked\000Finish stall because the NTF instruction was a paste waiting for response from L2\000event=0x2c016\000\00000\000\000"
/* offset=306874 */ "pm_mrk_stcx_fin\000marked\000Number of marked stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x24156\000\00000\000\000"
/* offset=307044 */ "pm_nest_ref_clk\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\00000\000\000"
/* offset=307134 */ "pm_pmc1_overflow\000memory\000Overflow from counter 1\000event=0x20010\000\00000\000\000"
/* offset=307201 */ "pm_darq1_7_9_entries\000memory\000Cycles in which 7 to 9 DARQ1 entries (out of 12) are in use\000event=0x2005a\000\00000\000\000"
/* offset=307308 */ "pm_data_from_dl2l3_shr\000memory\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\00000\000\000"
/* offset=307521 */ "pm_run_spurr\000memory\000Run SPURR\000event=0x10008\000\00000\000\000"
/* offset=307570 */ "pm_lsu_derat_miss\000memory\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\00000\000\000"
/* offset=307649 */ "pm_data_from_dl2l3_mod\000memory\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\00000\000\000"
/* offset=307864 */ "pm_mrk_run_cyc\000memory\000Run cycles in which a marked instruction is in the pipeline\000event=0x1d15e\000\00000\000\000"
/* offset=307965 */ "pm_ld_cmpl\000memory\000count of Loads completed\000event=0x4003e\000\00000\000\000"
/* offset=308027 */ "pm_data_from_l3\000memory\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\00000\000\000"
/* offset=308151 */ "pm_pmc1_rewind\000memory\000PMC1 rewind event\000event=0x4d02c\000\00000\000\000"
/* offset=308210 */ "pm_sync_mrk_l2hit\000memory\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\00000\000\000"
/* offset=308308 */ "pm_inst_from_rmem\000memory\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\00000\000\000"
/* offset=308505 */ "pm_mrk_st_cmpl\000memory\000Marked store completed and sent to nest\000event=0x301e2\000\00000\000\000"
/* offset=308586 */ "pm_data_chip_pump_cpred\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\00000\000\000"
/* offset=308718 */ "pm_data_from_l2_disp_conflict_other\000memory\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\00000\000\000"
/* offset=308885 */ "pm_lsu_reject_erat_miss\000memory\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\00000\000\000"
/* offset=308979 */ "pm_pmc3_rewind\000memory\000PMC3 rewind event. A rewind happens when a speculative event (such as latency or CPI stack) is selected on PMC3 and the stall reason or reload source did not match the one programmed in PMC3. When this occurs, the count in PMC3 will not change\000event=0x1000a\000\00000\000\000"
/* offset=309264 */ "pm_larx_fin\000memory\000Larx finished\000event=0x3c058\000\00000\000\000"
/* offset=309316 */ "pm_data_from_l2_no_conflict\000memory\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\00000\000\000"
/* offset=309469 */ "pm_data_from_l2_mepf\000memory\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\00000\000\000"
/* offset=309643 */ "pm_lrq_reject\000memory\000Internal LSU reject from LRQ. Rejects cause the load to go back to LRQ, but it stays contained within the LSU once it gets issued. This event counts the number of times the LRQ attempts to relaunch an instruction after a reject. Any load can suffer multiple rejects\000event=0x2e05a\000\00000\000\000"
/* offset=309949 */ "pm_inst_grp_pump_cpred\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch (demand only)\000event=0x2c05c\000\00000\000\000"
/* offset=310102 */ "pm_non_fma_flop_cmpl\000memory\000Non FMA instruction completed\000event=0x4d056\000\00000\000\000"
/* offset=310179 */ "pm_darq1_4_6_entries\000memory\000Cycles in which 4, 5, or 6 DARQ1 entries (out of 12) are in use\000event=0x3e050\000\00000\000\000"
/* offset=310290 */ "pm_isu1_iss_hold_all\000other\000All ISU rejects\000event=0x3084\000\00000\000\000"
/* offset=310351 */ "pm_snoop_tlbie\000other\000TLBIE snoop\000event=0xf880\000\00000\000\000"
/* offset=310402 */ "pm_tm_tresume\000other\000TM resume instruction completed\000event=0x20a4\000\00000\000\000"
/* offset=310472 */ "pm_srq_empty_cyc\000other\000Cycles in which the SRQ has at least one (out of four) empty slice\000event=0x40008\000\00000\000\000"
/* offset=310581 */ "pm_ierat_reload_4k\000other\000IERAT reloaded (after a miss) for 4K pages\000event=0x20064\000\00000\000\000"
/* offset=310668 */ "pm_l3_p2_lco_rty\000other\000L3 initiated LCO received retry on port 2 (can try 4 times)\000event=0x260b4\000\00000\000\000"
/* offset=310770 */ "pm_disp_held_issq_full\000other\000Dispatch held due to Issue q full. Includes issue queue and branch queue\000event=0x20006\000\00000\000\000"
/* offset=310891 */ "pm_mrk_data_from_l3miss\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\00000\000\000"
/* offset=311048 */ "pm_dpteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e044\000\00000\000\000"
/* offset=311335 */ "pm_br_mpred_taken_cr\000other\000A Conditional Branch that resolved to taken was mispredicted as not taken (due to the BHT Direction Prediction)\000event=0x40b8\000\00000\000\000"
/* offset=311492 */ "pm_dc_dealloc_no_conf\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8ac\000\00000\000\000"
/* offset=311767 */ "pm_ls0_dc_collisions\000other\000Read-write data cache collisions\000event=0xd090\000\00000\000\000"
/* offset=311845 */ "pm_derat_miss_16g_1g\000other\000Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) or 1G (radix mode)\000event=0x4c054\000\00000\000\000"
/* offset=311968 */ "pm_flush_hb_restore_cyc\000other\000Cycles in which no new instructions can be dispatched to the ICT after a flush.  History buffer recovery\000event=0x2084\000\00000\000\000"
/* offset=312121 */ "pm_radix_pwc_miss\000other\000A radix translation attempt missed in the TLB and all levels of page walk cache\000event=0x4f054\000\00000\000\000"
/* offset=312244 */ "pm_l2_dc_inv\000other\000D-cache invalidates sent over the reload bus to the core\000event=0x26882\000\00000\000\000"
/* offset=312339 */ "pm_inst_from_lmem\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\00000\000\000"
/* offset=312501 */ "pm_lsu0_lrq_s0_valid_cyc\000other\000Slot 0 of LRQ valid\000event=0xd8b4\000\00000\000\000"
/* offset=312570 */ "pm_tm_passed\000other\000Number of TM transactions that passed\000event=0x2e052\000\00000\000\000"
/* offset=312646 */ "pm_lsu0_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf088\000\00000\000\000"
/* offset=312839 */ "pm_l3_grp_guess_wrong_low\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was LNS\000event=0x360b2\000\00000\000\000"
/* offset=312971 */ "pm_tm_cam_overflow\000other\000L3 TM CAM is full when a L2 castout of TM_SC line occurs.  Line is pushed to memory\000event=0x168a6\000\00000\000\000"
/* offset=313099 */ "pm_tend_pend_cyc\000other\000TEND latency per thread\000event=0xe8b0\000\00000\000\000"
/* offset=313164 */ "pm_ibuf_full_cyc\000other\000Cycles No room in ibuff\000event=0x4884\000\00000\000\000"
/* offset=313229 */ "pm_lsu2_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd08c\000\00000\000\000"
/* offset=313669 */ "pm_tb_bit_trans\000other\000timebase event\000event=0x300f8\000\00000\000\000"
/* offset=313725 */ "pm_data_from_l2_disp_conflict_ldhitst\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\00000\000\000"
/* offset=313899 */ "pm_ls0_pte_tablewalk_cyc\000other\000Cycles when a tablewalk is pending on this thread on table 0\000event=0xe0bc\000\00000\000\000"
/* offset=314009 */ "pm_isu3_iss_hold_all\000other\000All ISU rejects\000event=0x3884\000\00000\000\000"
/* offset=314070 */ "pm_l3_pf_off_chip_mem\000other\000L3 PF from Off chip memory\000event=0x468a0\000\00000\000\000"
/* offset=314144 */ "pm_l3_p1_lco_data\000other\000LCO sent with data port 1\000event=0x268aa\000\00000\000\000"
/* offset=314213 */ "pm_lsu1_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe894\000\00000\000\000"
/* offset=314273 */ "pm_ic_invalidate\000other\000Ic line invalidated\000event=0x5888\000\00000\000\000"
/* offset=314334 */ "pm_disp_clb_held_tlbie\000other\000Dispatch Hold: Due to TLBIE\000event=0x2890\000\00000\000\000"
/* offset=314409 */ "pm_cmplu_stall_thrd\000other\000Completion Stalled because the thread was blocked\000event=0x1001c\000\00000\000\000"
/* offset=314504 */ "pm_snp_tm_hit_t\000other\000TM snoop that is a store hits line in L3 in T, Tn or Te state (shared modified)\000event=0x368a6\000\00000\000\000"
/* offset=314625 */ "pm_data_tablewalk_cyc\000other\000Data Tablewalk Cycles.  Could be 1 or 2 active tablewalks. Includes data prefetches\000event=0x3001a\000\00000\000\000"
/* offset=314756 */ "pm_ls3_dc_collisions\000other\000Read-write data cache collisions\000event=0xd894\000\00000\000\000"
/* offset=314834 */ "pm_mrk_data_from_l31_eco_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x35158\000\00000\000\000"
/* offset=315009 */ "pm_dc_pref_cons_alloc\000other\000Prefetch stream allocated in the conservative phase by either the hardware prefetch mechanism or software prefetch. The sum of this pair subtracted from the total number of allocs will give the total allocs in normal phase\000event=0xf0b4\000\00000\000\000"
/* offset=315278 */ "pm_lsu3_l1_cam_cancel\000other\000ls3 l1 tm cam cancel\000event=0xf894\000\00000\000\000"
/* offset=315345 */ "pm_flush_disp_tlbie\000other\000Dispatch Flush: TLBIE\000event=0x2888\000\00000\000\000"
/* offset=315411 */ "pm_mrk_data_from_dmem_cyc\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4e11e\000\00000\000\000"
/* offset=315575 */ "pm_mrk_data_from_l2_cyc\000other\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x14156\000\00000\000\000"
/* offset=315695 */ "pm_rd_clearing_sc\000other\000Core TM load hits line in L3 in TM_SC state and causes it to be invalidated\000event=0x468a6\000\00000\000\000"
/* offset=315814 */ "pm_hwsync\000other\000A hwsync instruction was decoded and transferred\000event=0xd0b0\000\00000\000\000"
/* offset=315897 */ "pm_l3_p1_node_pump\000other\000L3 PF sent with nodal scope port 1, counts even retried requests\000event=0x168b0\000\00000\000\000"
/* offset=316006 */ "pm_lsu0_1_lrqf_full_cyc\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd0bc\000\00000\000\000"
/* offset=316258 */ "pm_mrk_data_from_l2_disp_conflict_ldhitst\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x2d148\000\00000\000\000"
/* offset=316436 */ "pm_l3_p3_co_rty\000other\000L3 CO received retry port 3 (memory only), every retry counted\000event=0x468ae\000\00000\000\000"
/* offset=316540 */ "pm_sn_hit\000other\000Any port snooper hit L3.  Up to 4 can happen in a cycle but we only count 1\000event=0x460a8\000\00000\000\000"
/* offset=316651 */ "pm_l3_p0_co_mem\000other\000L3 CO to memory port 0 with or without data\000event=0x360aa\000\00000\000\000"
/* offset=316736 */ "pm_dc_pref_hw_alloc\000other\000Prefetch stream allocated by the hardware prefetch mechanism\000event=0xf0a4\000\00000\000\000"
/* offset=316841 */ "pm_ls2_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0bc\000\00000\000\000"
/* offset=317146 */ "pm_srq_sync_cyc\000other\000A sync is in the S2Q (edge detect to count)\000event=0xd0ac\000\00000\000\000"
/* offset=317230 */ "pm_mrk_inst_from_l3miss\000other\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\00000\000\000"
/* offset=317352 */ "pm_decode_hold_ict_full\000other\000Counts the number of cycles in which the IFU was not able to decode and transmit one or more instructions because all itags were in use.  This means the ICT is full for this thread\000event=0x58a8\000\00000\000\000"
/* offset=317581 */ "pm_l2_ic_inv\000other\000I-cache Invalidates sent over the realod bus to the core\000event=0x26082\000\00000\000\000"
/* offset=317676 */ "pm_lsu_flush_relaunch_miss\000other\000If a load that has already returned data and has to relaunch for any reason then gets a miss (erat, setp, data cache), it will often be flushed at relaunch time because the data might be inconsistent\000event=0xc8ac\000\00000\000\000"
/* offset=317927 */ "pm_l3_ld_hit\000other\000L3 Hits for demand LDs\000event=0x260a4\000\00000\000\000"
/* offset=317988 */ "pm_data_store\000other\000All ops that drain from s2q to L2 containing data\000event=0xf0a0\000\00000\000\000"
/* offset=318076 */ "pm_mrk_data_from_rmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x1d148\000\00000\000\000"
/* offset=318247 */ "pm_l2_loc_guess_correct\000other\000L2 guess local (LNS) and guess was correct (ie data local)\000event=0x16088\000\00000\000\000"
/* offset=318355 */ "pm_l3_hit\000other\000L3 Hits (L2 miss hitting L3, including data/instrn/xlate)\000event=0x160a4\000\00000\000\000"
/* offset=318448 */ "pm_lsu0_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe09c\000\00000\000\000"
/* offset=318507 */ "pm_l3_p1_lco_rty\000other\000L3 initiated LCO received retry on port 1 (can try 4 times)\000event=0x168b4\000\00000\000\000"
/* offset=318609 */ "pm_l3_rd_usage\000other\000Rotating sample of 16 RD actives\000event=0x268ac\000\00000\000\000"
/* offset=318682 */ "pm_mrk_data_from_l3_mepf_cyc\000other\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state due to a marked load\000event=0x1415c\000\00000\000\000"
/* offset=318852 */ "pm_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xe880\000\00000\000\000"
/* offset=318948 */ "pm_disp_clb_held_bal\000other\000Dispatch/CLB Hold: Balance Flush\000event=0x288c\000\00000\000\000"
/* offset=319026 */ "pm_mrk_l1_reload_valid\000other\000Marked demand reload\000event=0x101ea\000\00000\000\000"
/* offset=319095 */ "pm_mrk_ld_miss_l1_cyc\000other\000Marked ld latency\000event=0x1d156\000\00000\000\000"
/* offset=319160 */ "pm_cmplu_stall_dmiss_l3miss\000other\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\00000\000\000"
/* offset=319272 */ "pm_run_cyc_smt4_mode\000other\000Cycles in which this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\00000\000\000"
/* offset=319394 */ "pm_mrk_data_from_off_chip_cache_cyc\000other\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x1d14e\000\00000\000\000"
/* offset=319602 */ "pm_lsu1_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf888\000\00000\000\000"
/* offset=319795 */ "pm_ls2_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc098\000\00000\000\000"
/* offset=320097 */ "pm_darq1_10_12_entries\000other\000Cycles in which 10 or  more DARQ1 entries (out of 12) are in use\000event=0x20058\000\00000\000\000"
/* offset=320210 */ "pm_snp_tm_hit_m\000other\000TM snoop that is a store hits line in L3 in M or Mu state (exclusive modified)\000event=0x360a6\000\00000\000\000"
/* offset=320330 */ "pm_link_stack_invalid_ptr\000other\000It is most often caused by certain types of flush where the pointer is not available. Can result in the data in the link stack becoming unusable\000event=0x5898\000\00000\000\000"
/* offset=320525 */ "pm_l2_chip_pump\000other\000RC requests that were local (aka chip) pump attempts\000event=0x46088\000\00000\000\000"
/* offset=320619 */ "pm_tm_tsuspend\000other\000TM suspend instruction completed\000event=0x28a0\000\00000\000\000"
/* offset=320691 */ "pm_l1_pref\000other\000A data line was written to the L1 due to a hardware or software prefetch\000event=0x20054\000\00000\000\000"
/* offset=320800 */ "pm_tm_ld_conf\000other\000TM Load (fav or non-fav) ran into conflict (failed)\000event=0x2608e\000\00000\000\000"
/* offset=320891 */ "pm_mrk_data_from_l3_disp_conflict\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x1d144\000\00000\000\000"
/* offset=321055 */ "pm_run_inst_cmpl\000other\000Run_Instructions\000event=0x400fa\000\00000\000\000"
/* offset=321114 */ "pm_sync_mrk_l3miss\000other\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\00000\000\000"
/* offset=321214 */ "pm_ls0_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b4\000\00000\000\000"
/* offset=321348 */ "pm_dside_mru_touch\000other\000D-side L2 MRU touch commands sent to the L2\000event=0x26884\000\00000\000\000"
/* offset=321436 */ "pm_mrk_st_cmpl_int\000other\000marked store finished with intervention\000event=0x30134\000\00000\000\000"
/* offset=321520 */ "pm_lsu_flush_sao\000other\000A load-hit-load condition with Strong Address Ordering will have address compare disabled and flush\000event=0xc0b8\000\00000\000\000"
/* offset=321661 */ "pm_eat_force_mispred\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT.  The EAT forces a mispredict in this case since there is no predicated target to validate.  This is a rare case that may occur when the EAT is full and a branch is issued\000event=0x50a8\000\00000\000\000"
/* offset=321963 */ "pm_ls0_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc094\000\00000\000\000"
/* offset=322265 */ "pm_ls3_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8bc\000\00000\000\000"
/* offset=322570 */ "pm_l3_p2_co_rty\000other\000L3 CO received retry port 2 (memory only), every retry counted\000event=0x460ae\000\00000\000\000"
/* offset=322674 */ "pm_btac_good_result\000other\000BTAC predicts a taken branch and the BHT agrees, and the target address is correct\000event=0x58b0\000\00000\000\000"
/* offset=322801 */ "pm_data_from_ll4\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\00000\000\000"
/* offset=322935 */ "pm_tm_st_conf\000other\000TM Store (fav or non-fav) ran into conflict (failed)\000event=0x3608e\000\00000\000\000"
/* offset=323027 */ "pm_non_data_store\000other\000All ops that drain from s2q to L2 and contain no data\000event=0xf8a0\000\00000\000\000"
/* offset=323123 */ "pm_mrk_dpteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f146\000\00000\000\000"
/* offset=323411 */ "pm_br_uncond\000other\000Unconditional Branch Completed. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was covenrted to a Resolve\000event=0x40a0\000\00000\000\000"
/* offset=323665 */ "pm_dc_pref_fuzzy_conf\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8a8\000\00000\000\000"
/* offset=323940 */ "pm_dc_pref_sw_alloc\000other\000Prefetch stream allocated by software prefetching\000event=0xf8a4\000\00000\000\000"
/* offset=324034 */ "pm_lsu2_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a0\000\00000\000\000"
/* offset=324093 */ "pm_ls1_ld_vector_fin\000other\000LS1 finished load vector op\000event=0xc880\000\00000\000\000"
/* offset=324166 */ "pm_tm_outer_tend\000other\000Completion time outer tend\000event=0x2894\000\00000\000\000"
/* offset=324234 */ "pm_xlate_hpt_mode\000other\000LSU reports every cycle the thread is in HPT translation mode (as opposed to radix mode)\000event=0xf098\000\00000\000\000"
/* offset=324365 */ "pm_ld_miss_l1_fin\000other\000Number of load instructions that finished with an L1 miss. Note that even if a load spans multiple slices this event will increment only once per load op\000event=0x2c04e\000\00000\000\000"
/* offset=324562 */ "pm_mrk_lsu_derat_miss\000other\000Marked derat reload (miss) for any page size\000event=0x30162\000\00000\000\000"
/* offset=324654 */ "pm_l3_pf_miss_l3\000other\000L3 PF missed in L3\000event=0x160a0\000\00000\000\000"
/* offset=324715 */ "pm_data_from_rl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\00000\000\000"
/* offset=324923 */ "pm_l3_p1_grp_pump\000other\000L3 PF sent with grp scope port 1, counts even retried requests\000event=0x268b0\000\00000\000\000"
/* offset=325029 */ "pm_cmplu_stall_srq_full\000other\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000event=0x30016\000\00000\000\000"
/* offset=325178 */ "pm_br_pred_ta\000other\000Conditional Branch Completed that had its target address predicted. Only XL-form branches set this event.  This equal the sum of CCACHE, LSTACK, and PCACHE\000event=0x40b4\000\00000\000\000"
/* offset=325372 */ "pm_l2_rty_ld\000other\000RC retries on PB for any load from core (excludes DCBFs)\000event=0x3688a\000\00000\000\000"
/* offset=325467 */ "pm_lsu0_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe08c\000\00000\000\000"
/* offset=325554 */ "pm_ls2_erat_miss_pref\000other\000LS0 Erat miss due to prefetch\000event=0xe088\000\00000\000\000"
/* offset=325630 */ "pm_dc_pref_conf\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Includes forwards and backwards streams\000event=0xf0a8\000\00000\000\000"
/* offset=325870 */ "pm_l2_loc_guess_wrong\000other\000L2 guess local (LNS) and guess was not correct (ie data not on chip)\000event=0x16888\000\00000\000\000"
/* offset=325986 */ "pm_lsu_dtlb_miss_64k\000other\000Data TLB Miss page size 64K\000event=0xc888\000\00000\000\000"
/* offset=326059 */ "pm_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a4\000\00000\000\000"
/* offset=326188 */ "pm_lsu_dtlb_miss_4k\000other\000Data TLB Miss page size 4K\000event=0xc088\000\00000\000\000"
/* offset=326259 */ "pm_data_from_l3_disp_conflict\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\00000\000\000"
/* offset=326419 */ "pm_l3_p1_lco_no_data\000other\000Dataless L3 LCO sent port 1\000event=0x168aa\000\00000\000\000"
/* offset=326493 */ "pm_mrk_data_from_l2_disp_conflict_other_cyc\000other\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x3d140\000\00000\000\000"
/* offset=326656 */ "pm_ls1_launch_held_pref\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc89c\000\00000\000\000"
/* offset=326836 */ "pm_ic_reload_private\000other\000Reloading line was brought in private for a specific thread.  Most lines are brought in shared for all eight threads.  If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4894\000\00000\000\000"
/* offset=327137 */ "pm_tm_ld_caused_fail\000other\000Non-TM Load caused any thread to fail\000event=0x1688e\000\00000\000\000"
/* offset=327221 */ "pm_l2_rcld_disp_fail_other\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflicts with an L2 machines (e.g. Read-Claim/Snoop machine not available)\000event=0x26084\000\00000\000\000"
/* offset=327484 */ "pm_mrk_l1_icache_miss\000other\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\00000\000\000"
/* offset=327575 */ "pm_tm_nested_tbegin\000other\000Completion Tm nested tbegin\000event=0x20a0\000\00000\000\000"
/* offset=327647 */ "pm_l3_p1_co_mem\000other\000L3 CO to memory port 1 with or without data\000event=0x368aa\000\00000\000\000"
/* offset=327732 */ "pm_lsu3_false_lhs\000other\000False LHS match detected\000event=0xc8a4\000\00000\000\000"
/* offset=327799 */ "pm_l3_ld_pref\000other\000L3 load prefetch, sourced from a hardware or software stream, was sent to the nest\000event=0xf0b0\000\00000\000\000"
/* offset=327920 */ "pm_pmc3_saved\000other\000PMC3 Rewind Value saved\000event=0x4d012\000\00000\000\000"
/* offset=327983 */ "pm_ls3_erat_miss_pref\000other\000LS1 Erat miss due to prefetch\000event=0xe888\000\00000\000\000"
/* offset=328059 */ "pm_l3_rd0_busy\000other\000Lifetime, sample of RD machine 0 valid\000event=0x368b4\000\00000\000\000"
/* offset=328138 */ "pm_l2_disp_all_l2miss\000other\000All successful D-side-Ld/St or I-side-instruction-fetch dispatches for this thread that were an L2 miss\000event=0x46080\000\00000\000\000"
/* offset=328289 */ "pm_ls1_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8b8\000\00000\000\000"
/* offset=328594 */ "pm_l1_demand_write\000other\000Instruction Demand sectors written into IL1\000event=0x408c\000\00000\000\000"
/* offset=328681 */ "pm_sn_invl\000other\000Any port snooper detects a store to a line in the Sx state and invalidates the line.  Up to 4 can happen in a cycle but we only count 1\000event=0x368a8\000\00000\000\000"
/* offset=328853 */ "pm_l3_loc_guess_correct\000other\000Prefetch scope predictor selected LNS and was correct\000event=0x160b2\000\00000\000\000"
/* offset=328956 */ "pm_decode_fusion_const_gen\000other\00032-bit constant generation\000event=0x48b4\000\00000\000\000"
/* offset=329034 */ "pm_s2q_full\000other\000Cycles during which the S2Q is full\000event=0xe080\000\00000\000\000"
/* offset=329106 */ "pm_l3_p3_lco_rty\000other\000L3 initiated LCO received retry on port 3 (can try 4 times)\000event=0x268b4\000\00000\000\000"
/* offset=329208 */ "pm_lsu0_lmq_s0_valid\000other\000Slot 0 of LMQ valid\000event=0xd8b8\000\00000\000\000"
/* offset=329273 */ "pm_tm_nested_tend\000other\000Completion time nested tend\000event=0x2098\000\00000\000\000"
/* offset=329343 */ "pm_l3_pf_off_chip_cache\000other\000L3 PF from Off chip cache\000event=0x368a0\000\00000\000\000"
/* offset=329418 */ "pm_taken_br_mpred_cmpl\000other\000Total number of taken branches that were incorrectly predicted as not-taken. This event counts branches completed and does not include speculative instructions\000event=0x20056\000\00000\000\000"
/* offset=329626 */ "pm_l2_sys_pump\000other\000RC requests that were system pump attempts\000event=0x4688a\000\00000\000\000"
/* offset=329709 */ "pm_lsu2_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe090\000\00000\000\000"
/* offset=329796 */ "pm_inst_imc_match_cmpl\000other\000IMC Match Count\000event=0x4001c\000\00000\000\000"
/* offset=329860 */ "pm_br_pred_lstack\000other\000Conditional Branch Completed  that used the Link Stack for Target Prediction\000event=0x40a8\000\00000\000\000"
/* offset=329979 */ "pm_l3_ci_miss\000other\000L3 castins miss (total count)\000event=0x268a2\000\00000\000\000"
/* offset=330048 */ "pm_tm_non_fav_tbegin\000other\000Dispatch time non favored tbegin\000event=0x289c\000\00000\000\000"
/* offset=330126 */ "pm_lsu2_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf08c\000\00000\000\000"
/* offset=330319 */ "pm_l3_pf_on_chip_cache\000other\000L3 PF from On chip cache\000event=0x360a0\000\00000\000\000"
/* offset=330392 */ "pm_mrk_data_from_l2miss_cyc\000other\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x35152\000\00000\000\000"
/* offset=330542 */ "pm_l3_sn_usage\000other\000Rotating sample of 16 snoop valids\000event=0x160ac\000\00000\000\000"
/* offset=330617 */ "pm_rc0_busy\000other\000RC mach 0 Busy. Used by PMU to sample ave RC lifetime (mach0 used as sample point)\000event=0x1608c\000\00000\000\000"
/* offset=330737 */ "pm_l2_ld_disp\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread\000event=0x36082\000\00000\000\000"
/* offset=330856 */ "pm_l3_sw_pref\000other\000L3 load prefetch, sourced from a software prefetch stream, was sent to the nest\000event=0xf8b0\000\00000\000\000"
/* offset=330974 */ "pm_tablewalk_cyc_pref\000other\000tablewalk qualified for pte  prefetches\000event=0xf884\000\00000\000\000"
/* offset=331060 */ "pm_l2_rcld_disp_fail_addr\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflicts with an L2 machines already working on this line (e.g. ld-hit-stq or Read-claim/Castout/Snoop machines)\000event=0x16884\000\00000\000\000"
/* offset=331341 */ "pm_l3_pf_on_chip_mem\000other\000L3 PF from On chip memory\000event=0x460a0\000\00000\000\000"
/* offset=331413 */ "pm_pte_prefetch\000other\000PTE prefetches\000event=0xf084\000\00000\000\000"
/* offset=331468 */ "pm_radix_pwc_l1_pde_from_l2\000other\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L2 data cache\000event=0x2d026\000\00000\000\000"
/* offset=331616 */ "pm_br_mpred_pcache\000other\000Conditional Branch Completed that was Mispredicted due to pattern cache prediction\000event=0x48b0\000\00000\000\000"
/* offset=331742 */ "pm_mrk_data_from_l2\000other\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x2c126\000\00000\000\000"
/* offset=331869 */ "pm_tm_fail_tlbie\000other\000Transaction failed because there was a TLBIE hit in the bloom filter\000event=0xe0ac\000\00000\000\000"
/* offset=331979 */ "pm_l3_p0_lco_data\000other\000LCO sent with data port 0\000event=0x260aa\000\00000\000\000"
/* offset=332048 */ "pm_ic_pref_req\000other\000Instruction prefetch requests\000event=0x4888\000\00000\000\000"
/* offset=332117 */ "pm_ls3_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc898\000\00000\000\000"
/* offset=332419 */ "pm_ic_pref_write\000other\000Instruction prefetch written into IL1\000event=0x488c\000\00000\000\000"
/* offset=332498 */ "pm_xlate_miss\000other\000The LSU requested a line from L2 for translation.  It may be satisfied from any source beyond L2.  Includes speculative instructions. Includes instruction, prefetch and demand\000event=0xf89c\000\00000\000\000"
/* offset=332712 */ "pm_mrk_data_from_l2_no_conflict_cyc\000other\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x14158\000\00000\000\000"
/* offset=332861 */ "pm_mrk_data_from_l31_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x35156\000\00000\000\000"
/* offset=333026 */ "pm_lsu_dtlb_miss_16g_1g\000other\000Data TLB Miss page size 16G (HPT) or 1G (Radix)\000event=0xc88c\000\00000\000\000"
/* offset=333122 */ "pm_tm_rst_sc\000other\000TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x268a6\000\00000\000\000"
/* offset=333237 */ "pm_l3_trans_pf\000other\000L3 Transient prefetch received from L2\000event=0x468a4\000\00000\000\000"
/* offset=333316 */ "pm_ic_pref_cancel_l2\000other\000L2 Squashed a demand or prefetch request\000event=0x4094\000\00000\000\000"
/* offset=333402 */ "pm_br_mpred_lstack\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x48ac\000\00000\000\000"
/* offset=333536 */ "pm_lsu1_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe88c\000\00000\000\000"
/* offset=333623 */ "pm_lsu_flush_wrk_arnd\000other\000LSU workaround flush.  These flushes are setup with programmable scan only latches to perform various actions when the flush macro receives a trigger from the dbg macros. These actions include things like flushing the next op encountered for a particular thread or flushing the next op that is NTC op that is encountered on a particular slice. The kind of flush that the workaround is setup to perform is highly variable\000event=0xc0b4\000\00000\000\000"
/* offset=334090 */ "pm_partial_st_fin\000other\000Any store finished by an LSU slice\000event=0x34054\000\00000\000\000"
/* offset=334168 */ "pm_thrd_prio_6_7_cyc\000other\000Cycles thread running at priority level 6 or 7\000event=0x5880\000\00000\000\000"
/* offset=334260 */ "pm_ic_demand_l2_br_redirect\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x4898\000\00000\000\000"
/* offset=334380 */ "pm_bank_conflict\000other\000Read blocked due to interleave conflict.  The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4880\000\00000\000\000"
/* offset=334556 */ "pm_l3_p0_sys_pump\000other\000L3 PF sent with sys scope port 0, counts even retried requests\000event=0x360b0\000\00000\000\000"
/* offset=334662 */ "pm_ierat_reload_64k\000other\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\00000\000\000"
/* offset=334744 */ "pm_lsu2_3_lrqf_full_cyc\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd8bc\000\00000\000\000"
/* offset=334996 */ "pm_l2_sn_m_rd_done\000other\000Snoop dispatched for a read and was M (true M)\000event=0x46086\000\00000\000\000"
/* offset=335087 */ "pm_mrk_fab_rsp_bkill\000other\000Marked store had to do a bkill\000event=0x40154\000\00000\000\000"
/* offset=335164 */ "pm_lsu2_l1_cam_cancel\000other\000ls2 l1 tm cam cancel\000event=0xf094\000\00000\000\000"
/* offset=335231 */ "pm_cmplu_stall_lrq_full\000other\000Finish stall because the NTF instruction was a load that was held in LSAQ (load-store address queue) because the LRQ (load-reorder queue) was full\000event=0x2d014\000\00000\000\000"
/* offset=335427 */ "pm_l3_co_mepf\000other\000L3 CO of line in Mep state (includes casthrough to memory).  The Mepf state indicates that a line was brought in to satisfy an L3 prefetch request\000event=0x3e05e\000\00000\000\000"
/* offset=335613 */ "pm_l3_lat_ci_hit\000other\000L3 Lateral Castins Hit\000event=0x460a2\000\00000\000\000"
/* offset=335678 */ "pm_mrk_data_from_dl2l3_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d14e\000\00000\000\000"
/* offset=335896 */ "pm_mult_mrk\000other\000mult marked instr\000event=0x3d15e\000\00000\000\000"
/* offset=335951 */ "pm_eat_full_cyc\000other\000Cycles No room in EAT\000event=0x4084\000\00000\000\000"
/* offset=336013 */ "pm_link_stack_wrong_add_pred\000other\000Link stack predicts wrong address, because of link stack design limitation or software violating the coding conventions\000event=0x5098\000\00000\000\000"
/* offset=336186 */ "pm_data_grp_pump_cpred\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\00000\000\000"
/* offset=336317 */ "pm_lsu2_false_lhs\000other\000False LHS match detected\000event=0xc0a4\000\00000\000\000"
/* offset=336384 */ "pm_link_stack_correct\000other\000Link stack predicts right address\000event=0x58a0\000\00000\000\000"
/* offset=336464 */ "pm_l2_sn_sx_i_done\000other\000Snoop dispatched and went from Sx to Ix\000event=0x36886\000\00000\000\000"
/* offset=336548 */ "pm_dpteg_from_off_chip_cache\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04a\000\00000\000\000"
/* offset=336868 */ "pm_mrk_data_from_dl4_cyc\000other\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\00000\000\000"
/* offset=337030 */ "pm_inst_from_l1\000other\000Instruction fetches from L1.  L1 instruction hit\000event=0x4080\000\00000\000\000"
/* offset=337119 */ "pm_lsu3_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe898\000\00000\000\000"
/* offset=337179 */ "pm_l3_co_mem\000other\000L3 CO to memory OR of port 0 and 1 (lossy = may undercount if two cresp come in the same cyc)\000event=0x260a0\000\00000\000\000"
/* offset=337311 */ "pm_l2_castout_mod\000other\000L2 Castouts - Modified (M,Mu,Me)\000event=0x16082\000\00000\000\000"
/* offset=337387 */ "pm_ls0_launch_held_pref\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc09c\000\00000\000\000"
/* offset=337567 */ "pm_lsu_flush_larx_stcx\000other\000A larx is flushed because an older larx has an LMQ reservation for the same thread.  A stcx is flushed because an older stcx is in the LMQ.  The flush happens when the older larx/stcx relaunches\000event=0xc8b8\000\00000\000\000"
/* offset=337809 */ "pm_non_tm_rst_sc\000other\000Non-TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x260a6\000\00000\000\000"
/* offset=337932 */ "pm_l2_rty_st\000other\000RC retries on PB for any store from core (excludes DCBFs)\000event=0x3608a\000\00000\000\000"
/* offset=338028 */ "pm_inst_from_l2_mepf\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\00000\000\000"
/* offset=338231 */ "pm_tm_fav_tbegin\000other\000Dispatch time Favored tbegin\000event=0x209c\000\00000\000\000"
/* offset=338301 */ "pm_ict_noslot_disp_held_issq\000other\000Ict empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000event=0x2d01e\000\00000\000\000"
/* offset=338487 */ "pm_flush_mpred\000other\000Branch mispredict flushes.  Includes target and address misprecition\000event=0x50a4\000\00000\000\000"
/* offset=338595 */ "pm_ipteg_from_ll4\000other\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\00000\000\000"
/* offset=338746 */ "pm_l3_ld_miss\000other\000L3 Misses for demand LDs\000event=0x268a4\000\00000\000\000"
/* offset=338810 */ "pm_l2_grp_guess_correct\000other\000L2 guess grp (GS or NNS) and guess was correct (data intra-group AND ^on-chip)\000event=0x26088\000\00000\000\000"
/* offset=338938 */ "pm_lsu0_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd088\000\00000\000\000"
/* offset=339378 */ "pm_ls1_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b4\000\00000\000\000"
/* offset=339512 */ "pm_rc_usage\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x1688c\000\00000\000\000"
/* offset=339729 */ "pm_radix_pwc_l4_pte_from_l3miss\000other\000A Page Table Entry was reloaded to a level 4 page walk cache from beyond the core's L3 data cache. This is the deepest level of PWC possible for a translation. The source could be local/remote/distant memory or another core's cache\000event=0x3f054\000\00000\000\000"
/* offset=340018 */ "pm_iside_disp_fail_addr\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflict with an L2 machine already working on this line (e.g. ld-hit-stq or RC/CO/SN machines)\000event=0x2608a\000\00000\000\000"
/* offset=340266 */ "pm_tage_correct_taken_cmpl\000other\000The TAGE overrode BHT direction prediction and it was correct.  Counted at completion for taken branches only\000event=0x50b4\000\00000\000\000"
/* offset=340427 */ "pm_disp_clb_held_sb\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x2090\000\00000\000\000"
/* offset=340501 */ "pm_tm_fail_non_tx_conflict\000other\000Non transactional conflict from LSU, gets reported to TEXASR\000event=0xe0b0\000\00000\000\000"
/* offset=340613 */ "pm_mrk_data_from_memory\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\00000\000\000"
/* offset=340788 */ "pm_l3_l2_co_miss\000other\000L2 CO miss\000event=0x368a2\000\00000\000\000"
/* offset=340841 */ "pm_co0_busy\000other\000CO mach 0 Busy. Used by PMU to sample ave CO lifetime (mach0 used as sample point)\000event=0x3608c\000\00000\000\000"
/* offset=340961 */ "pm_mrk_data_from_l3_disp_conflict_cyc\000other\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\00000\000\000"
/* offset=341118 */ "pm_mrk_data_from_l3_cyc\000other\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x35154\000\00000\000\000"
/* offset=341238 */ "pm_mrk_data_from_l31_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x1d140\000\00000\000\000"
/* offset=341405 */ "pm_inst_from_off_chip_cache\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\00000\000\000"
/* offset=341645 */ "pm_tm_fail_self\000other\000TM aborted because a self-induced conflict occurred in Suspended state, due to one of the following: a store to a storage location that was previously accessed transactionally; a dcbf, dcbi, or icbi specify- ing a block that was previously accessed transactionally; a dcbst specifying a block that was previously written transactionally; or a tlbie that specifies a translation that was pre- viously used transactionally\000event=0x28ac\000\00000\000\000"
/* offset=342106 */ "pm_scalar_flop_cmpl\000other\000Scalar flop operation completed\000event=0x45056\000\00000\000\000"
/* offset=342183 */ "pm_l2_ld_miss_128b\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16092\000\00000\000\000"
/* offset=342382 */ "pm_stcx_fin\000other\000Number of stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x2e014\000\00000\000\000"
/* offset=342540 */ "pm_lwsync\000other\000An lwsync instruction was decoded and transferred\000event=0xd8ac\000\00000\000\000"
/* offset=342624 */ "pm_tm_outer_tbegin\000other\000Completion time outer tbegin\000event=0x2094\000\00000\000\000"
/* offset=342696 */ "pm_l3_p0_lco_rty\000other\000L3 initiated LCO received retry on port 0 (can try 4 times)\000event=0x160b4\000\00000\000\000"
/* offset=342798 */ "pm_dside_other_64b_l2memacc\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory that was for hpc_read64, (RC had to fetch other 64B of a line from MC) i.e., number of times RC had to go to memory to get 'missing' 64B\000event=0x36892\000\00000\000\000"
/* offset=343087 */ "pm_tm_fail_footprint_overflow\000other\000TM aborted because the tracking limit for transactional storage accesses was exceeded.. Asynchronous\000event=0x20a8\000\00000\000\000"
/* offset=343242 */ "pm_ict_noslot_disp_held_hb_full\000other\000Ict empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x30018\000\00000\000\000"
/* offset=343442 */ "pm_ls1_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc894\000\00000\000\000"
/* offset=343744 */ "pm_l3_l2_co_hit\000other\000L2 CO hits\000event=0x360a2\000\00000\000\000"
/* offset=343796 */ "pm_dside_l2memacc\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory (excluding hpcread64 accesses), i.e., total memory accesses by RCs\000event=0x36092\000\00000\000\000"
/* offset=344005 */ "pm_mrk_br_2path\000other\000marked branches which are not strongly biased\000event=0x10138\000\00000\000\000"
/* offset=344092 */ "pm_isync\000other\000Isync completion count per thread\000event=0x2884\000\00000\000\000"
/* offset=344159 */ "pm_l2_castout_shr\000other\000L2 Castouts - Shared (Tx,Sx)\000event=0x16882\000\00000\000\000"
/* offset=344231 */ "pm_l2_ld_miss_64b\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B(i.e., M=1)\000event=0x26092\000\00000\000\000"
/* offset=344427 */ "pm_l2_ld_miss\000other\000All successful D-Side Load dispatches that were an L2 miss for this thread\000event=0x26080\000\00000\000\000"
/* offset=344541 */ "pm_mrk_data_from_dmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x3d14c\000\00000\000\000"
/* offset=344712 */ "pm_any_thrd_run_cyc\000other\000Cycles in which at least one thread has the run latch set\000event=0x100fa\000\00000\000\000"
/* offset=344815 */ "pm_mrk_data_from_rmem_cyc\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\00000\000\000"
/* offset=344979 */ "pm_ipteg_from_lmem\000other\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\00000\000\000"
/* offset=345129 */ "pm_islb_miss\000other\000Instruction SLB Miss - Total of all segment sizes\000event=0xd8a8\000\00000\000\000"
/* offset=345216 */ "pm_l3_p1_co_rty\000other\000L3 CO received retry port 1 (memory only), every retry counted\000event=0x368ae\000\00000\000\000"
/* offset=345320 */ "pm_l3_ci_hit\000other\000L3 Castins Hit (total count)\000event=0x260a2\000\00000\000\000"
/* offset=345387 */ "pm_vector_ld_cmpl\000other\000Number of vector load instructions completed\000event=0x44054\000\00000\000\000"
/* offset=345475 */ "pm_cmplu_stall_nested_tbegin\000other\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000event=0x1e05c\000\00000\000\000"
/* offset=345664 */ "pm_ls2_ld_vector_fin\000other\000LS2 finished load vector op\000event=0xc084\000\00000\000\000"
/* offset=345737 */ "pm_st_caused_fail\000other\000Non-TM Store caused any thread to fail\000event=0x1608e\000\00000\000\000"
/* offset=345819 */ "pm_isu0_iss_hold_all\000other\000All ISU rejects\000event=0x3080\000\00000\000\000"
/* offset=345880 */ "pm_sync_mrk_l2miss\000other\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\00000\000\000"
/* offset=345978 */ "pm_l2_st_miss_64b\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B (i.e., M=1)\000event=0x26892\000\00000\000\000"
/* offset=346176 */ "pm_co_usage\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x2688c\000\00000\000\000"
/* offset=346393 */ "pm_br_mpred_taken_ta\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack.  Only XL-form branches that resolved Taken set this event\000event=0x48b8\000\00000\000\000"
/* offset=346620 */ "pm_btac_bad_result\000other\000BTAC thinks branch will be taken but it is either predicted not-taken by the BHT, or the target address is wrong (less common).  In both cases, a redirect will happen\000event=0x50b0\000\00000\000\000"
/* offset=346830 */ "pm_lsu1_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd888\000\00000\000\000"
/* offset=347270 */ "pm_tage_correct\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b4\000\00000\000\000"
/* offset=347437 */ "pm_sn_usage\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3688c\000\00000\000\000"
/* offset=347654 */ "pm_l2_rcst_disp\000other\000All D-side store dispatch attempts for this thread\000event=0x36084\000\00000\000\000"
/* offset=347746 */ "pm_l2_rcst_disp_fail_other\000other\000All D-side store dispatch attempts for this thread that failed due to reason other than address collision\000event=0x46084\000\00000\000\000"
/* offset=347904 */ "pm_dc_pref_strided_conf\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0xf0ac\000\00000\000\000"
/* offset=348119 */ "pm_fma_cmpl\000other\000two flops operation completed (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only\000event=0x45054\000\00000\000\000"
/* offset=348242 */ "pm_thresh_exc_512\000other\000Threshold counter exceeded a value of 512\000event=0x201e8\000\00000\000\000"
/* offset=348327 */ "pm_l2_inst\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread\000event=0x36080\000\00000\000\000"
/* offset=348458 */ "pm_ipteg_from_dl4\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\00000\000\000"
/* offset=348640 */ "pm_ls1_dc_collisions\000other\000Read-write data cache collisions\000event=0xd890\000\00000\000\000"
/* offset=348718 */ "pm_iside_disp\000other\000All I-side-instruction-fetch dispatch attempts for this thread\000event=0x1688a\000\00000\000\000"
/* offset=348820 */ "pm_l3_p1_co_l31\000other\000L3 CO to L3.1 (LCO) port 1 with or without data\000event=0x468aa\000\00000\000\000"
/* offset=348909 */ "pm_disp_held_tbegin\000other\000This outer tbegin transaction cannot be dispatched until the previous tend instruction completes\000event=0x28b0\000\00000\000\000"
/* offset=349050 */ "pm_lsu3_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe8a0\000\00000\000\000"
/* offset=349109 */ "pm_inst_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch (demand only)\000event=0x2c05e\000\00000\000\000"
/* offset=349279 */ "pm_stcx_success_cmpl\000other\000Number of stcx instructions that completed successfully\000event=0xc8bc\000\00000\000\000"
/* offset=349380 */ "pm_lsu2_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe098\000\00000\000\000"
/* offset=349440 */ "pm_ls2_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b8\000\00000\000\000"
/* offset=349574 */ "pm_inst_from_l31_eco_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\00000\000\000"
/* offset=349781 */ "pm_co_disp_fail\000other\000CO dispatch failed due to all CO machines being busy\000event=0x16886\000\00000\000\000"
/* offset=349875 */ "pm_mrk_data_from_l3_no_conflict\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x3d146\000\00000\000\000"
/* offset=350031 */ "pm_l2_st_miss_128b\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16892\000\00000\000\000"
/* offset=350231 */ "pm_iside_l2memacc\000other\000Valid when first beat of data comes in for an I-side fetch where data came from memory\000event=0x26890\000\00000\000\000"
/* offset=350361 */ "pm_ls2_dc_collisions\000other\000Read-write data cache collisions\000event=0xd094\000\00000\000\000"
/* offset=350439 */ "pm_mem_rwitm\000other\000Memory Read With Intent to Modify for this thread\000event=0x3c05e\000\00000\000\000"
/* offset=350527 */ "pm_lsu_stcx\000other\000STCX sent to nest, i.e. total\000event=0xc090\000\00000\000\000"
/* offset=350593 */ "pm_mrk_data_from_l2_no_conflict\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x2c120\000\00000\000\000"
/* offset=350749 */ "pm_l2_rc_st_done\000other\000Read-claim machine did store to line that was in Tx or Sx (Tagged or Shared state)\000event=0x36086\000\00000\000\000"
/* offset=350874 */ "pm_tm_fail_tx_conflict\000other\000Transactional conflict from LSU, gets reported to TEXASR\000event=0xe8ac\000\00000\000\000"
/* offset=350978 */ "pm_decode_fusion_ld_st_disp\000other\00032-bit displacement D-form and 16-bit displacement X-form\000event=0x48a8\000\00000\000\000"
/* offset=351088 */ "pm_mrk_data_from_l2_mepf_cyc\000other\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x3d144\000\00000\000\000"
/* offset=351259 */ "pm_inst_from_l21_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\00000\000\000"
/* offset=351458 */ "pm_br_pred_taken_cr\000other\000Conditional Branch that had its direction predicted. I-form branches do not set this event.  In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\00000\000\000"
/* offset=351741 */ "pm_ipteg_from_l2_no_conflict\000other\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\00000\000\000"
/* offset=351910 */ "pm_rd_forming_sc\000other\000Doesn't occur\000event=0x460a6\000\00000\000\000"
/* offset=351966 */ "pm_ipteg_from_l3_disp_conflict\000other\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\00000\000\000"
/* offset=352143 */ "pm_xlate_radix_mode\000other\000LSU reports every cycle the thread is in radix translation mode (as opposed to HPT mode)\000event=0xf898\000\00000\000\000"
/* offset=352276 */ "pm_mrk_data_from_l3_mepf\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\00000\000\000"
/* offset=352454 */ "pm_l3_p0_node_pump\000other\000L3 PF sent with nodal scope port 0, counts even retried requests\000event=0x160b0\000\00000\000\000"
/* offset=352563 */ "pm_lsu3_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd88c\000\00000\000\000"
/* offset=353003 */ "pm_l2_ld_hit\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread that were L2 hits\000event=0x36882\000\00000\000\000"
/* offset=353139 */ "pm_l3_ci_usage\000other\000Rotating sample of 16 CI or CO actives\000event=0x168ac\000\00000\000\000"
/* offset=353218 */ "pm_mrk_fxu_fin\000other\000fxu marked instr finish\000event=0x20134\000\00000\000\000"
/* offset=353282 */ "pm_tm_cap_overflow\000other\000TM Footprint Capacity Overflow\000event=0x4608e\000\00000\000\000"
/* offset=353357 */ "pm_radix_pwc_l2_pte_from_l3miss\000other\000A Page Table Entry was reloaded to a level 2 page walk cache from beyond the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05c\000\00000\000\000"
/* offset=353677 */ "pm_probe_nop_disp\000other\000ProbeNops dispatched\000event=0x40014\000\00000\000\000"
/* offset=353741 */ "pm_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\00000\000\000"
/* offset=353948 */ "pm_back_br_cmpl\000other\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\00000\000\000"
/* offset=354078 */ "pm_iside_disp_fail_other\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflict with an L2 machine (e.g. no available RC/CO machines)\000event=0x2688a\000\00000\000\000"
/* offset=354313 */ "pm_ntc_all_fin\000other\000Cycles after instruction finished to instruction completed\000event=0x2001a\000\00000\000\000"
/* offset=354412 */ "pm_isq_0_8_entries\000other\000Cycles in which 8 or less Issue Queue entries are in use. This is a shared event, not per thread\000event=0x3005a\000\00000\000\000"
/* offset=354553 */ "pm_mrk_back_br_cmpl\000other\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\00000\000\000"
/* offset=354694 */ "pm_lsu1_l1_cam_cancel\000other\000ls1 l1 tm cam cancel\000event=0xf890\000\00000\000\000"
/* offset=354761 */ "pm_l3_p3_pf_rty\000other\000L3 PF received retry port 3, every retry counted\000event=0x268ae\000\00000\000\000"
/* offset=354851 */ "pm_ls1_erat_miss_pref\000other\000LS1 Erat miss due to prefetch\000event=0xe884\000\00000\000\000"
/* offset=354927 */ "pm_lsu1_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe89c\000\00000\000\000"
/* offset=354986 */ "pm_tm_fail_conf_non_tm\000other\000TM aborted because a conflict occurred with a non-transactional access by another processor\000event=0x28a8\000\00000\000\000"
/* offset=355125 */ "pm_l1pf_l2memacc\000other\000Valid when first beat of data comes in for an L1PF where data came from memory\000event=0x16890\000\00000\000\000"
/* offset=355246 */ "pm_ipteg_from_dmem\000other\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\00000\000\000"
/* offset=355430 */ "pm_lmq_merge\000other\000A demand miss collides with a prefetch for the same line\000event=0x1002e\000\00000\000\000"
/* offset=355525 */ "pm_l3_wi0_busy\000other\000Rotating sample of 8 WI valid (duplicate)\000event=0x160b6\000\00000\000\000"
/* offset=355607 */ "pm_l3_co0_busy\000other\000Lifetime, sample of CO machine 0 valid\000event=0x368ac\000\00000\000\000"
/* offset=355686 */ "pm_dpteg_from_l2_mepf\000other\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e040\000\00000\000\000"
/* offset=355969 */ "pm_mrk_data_from_dl4\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x1d152\000\00000\000\000"
/* offset=356138 */ "pm_iside_mru_touch\000other\000I-side L2 MRU touch sent to L2 for this thread I-side L2 MRU touch commands sent to the L2 for this thread\000event=0x46880\000\00000\000\000"
/* offset=356289 */ "pm_tage_override_wrong\000other\000The TAGE overrode BHT direction prediction but it was incorrect.  Counted at completion for taken branches only\000event=0x50b8\000\00000\000\000"
/* offset=356448 */ "pm_l3_p0_pf_rty\000other\000L3 PF received retry port 0, every retry counted\000event=0x160ae\000\00000\000\000"
/* offset=356538 */ "pm_l3_loc_guess_wrong\000other\000Prefetch scope predictor selected LNS, but was wrong\000event=0x268b2\000\00000\000\000"
/* offset=356638 */ "pm_l2_sys_guess_correct\000other\000L2 guess system (VGS or RNS) and guess was correct (ie data beyond-group)\000event=0x36088\000\00000\000\000"
/* offset=356761 */ "pm_l3_p2_pf_rty\000other\000L3 PF received retry port 2, every retry counted\000event=0x260ae\000\00000\000\000"
/* offset=356851 */ "pm_ptesync\000other\000A ptesync instruction was counted when the instruction is decoded and transmitted\000event=0xd8b0\000\00000\000\000"
/* offset=356968 */ "pm_co_tm_sc_footprint\000other\000L2 did a cleanifdirty CO to the L3 (ie created an SC line in the L3) OR L2 TM_store hit dirty HPC line and L3 indicated SC line formed in L3 on RDR bus\000event=0x26086\000\00000\000\000"
/* offset=357167 */ "pm_cmplu_stall_any_sync\000other\000Cycles in which the NTC sync instruction (isync, lwsync or hwsync) is not allowed to complete\000event=0x1e05a\000\00000\000\000"
/* offset=357310 */ "pm_lsu0_l1_cam_cancel\000other\000ls0 l1 tm cam cancel\000event=0xf090\000\00000\000\000"
/* offset=357377 */ "pm_lsu_flush_ci\000other\000Load was not issued to LSU as a cache inhibited (non-cacheable) load but it was later determined to be cache inhibited\000event=0xc0a8\000\00000\000\000"
/* offset=357536 */ "pm_tm_fail_conf_tm\000other\000TM aborted because a conflict occurred with another transaction\000event=0x20ac\000\00000\000\000"
/* offset=357643 */ "pm_shl_st_dep_created\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x588c\000\00000\000\000"
/* offset=357738 */ "pm_l2_st_hit\000other\000All successful D-side store dispatches for this thread that were L2 hits\000event=0x46882\000\00000\000\000"
/* offset=357849 */ "pm_l3_sn0_busy\000other\000Lifetime, sample of snooper machine 0 valid\000event=0x360ac\000\00000\000\000"
/* offset=357933 */ "pm_bfu_busy\000other\000Cycles in which all 4 Binary Floating Point units are busy. The BFU is running at capacity\000event=0x3005c\000\00000\000\000"
/* offset=358061 */ "pm_br_pred_pcache\000other\000Conditional branch completed that used pattern cache prediction\000event=0x48a0\000\00000\000\000"
/* offset=358167 */ "pm_l2_st_miss\000other\000All successful D-Side Store dispatches that were an L2 miss for this thread\000event=0x26880\000\00000\000\000"
/* offset=358282 */ "pm_dc_pref_xcons_alloc\000other\000Prefetch stream allocated in the Ultra conservative phase by either the hardware prefetch mechanism or software prefetch\000event=0xf8b4\000\00000\000\000"
/* offset=358450 */ "pm_ipteg_from_dl2l3_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\00000\000\000"
/* offset=358679 */ "pm_l3_pf_hit_l3\000other\000L3 PF hit in L3 (abandoned)\000event=0x260a8\000\00000\000\000"
/* offset=358748 */ "pm_l3_pf0_busy\000other\000Lifetime, sample of PF machine 0 valid\000event=0x360b4\000\00000\000\000"
/* offset=358827 */ "pm_lsu_flush_ue\000other\000Correctable ECC error on reload data, reported at critical data forward time\000event=0xc0b0\000\00000\000\000"
/* offset=358944 */ "pm_mrk_ic_miss\000other\000Marked instruction experienced I cache miss\000event=0x4013a\000\00000\000\000"
/* offset=359028 */ "pm_flush_disp_sb\000other\000Dispatch Flush: Scoreboard\000event=0x2088\000\00000\000\000"
/* offset=359096 */ "pm_mrk_data_from_l2miss\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to a marked load\000event=0x401e8\000\00000\000\000"
/* offset=359253 */ "pm_tm_st_caused_fail\000other\000TM Store (fav or non-fav) caused another thread to fail\000event=0x3688e\000\00000\000\000"
/* offset=359355 */ "pm_l3_sys_guess_wrong\000other\000Prefetch scope predictor selected VGS or RNS, but was wrong\000event=0x460b2\000\00000\000\000"
/* offset=359462 */ "pm_tage_override_wrong_spec\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b8\000\00000\000\000"
/* offset=359641 */ "pm_lsu3_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe890\000\00000\000\000"
/* offset=359728 */ "pm_tm_tabort_treclaim\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x2898\000\00000\000\000"
/* offset=359822 */ "pm_l3_co_l31\000other\000L3 CO to L3.1 OR of port 0 and 1 (lossy = may undercount if two cresps come in the same cyc)\000event=0x268a0\000\00000\000\000"
/* offset=359953 */ "pm_vsu_fin\000other\000VSU instruction finished. Up to 4 per cycle\000event=0x2505c\000\00000\000\000"
/* offset=360033 */ "pm_br_pred_ccache\000other\000Conditional Branch Completed that used the Count Cache for Target Prediction\000event=0x40a4\000\00000\000\000"
/* offset=360152 */ "pm_dpteg_from_rl4\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04a\000\00000\000\000"
/* offset=360423 */ "pm_mrk_data_from_dl2l3_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d12e\000\00000\000\000"
/* offset=360634 */ "pm_lsu_flush_lhl_shl\000other\000The instruction was flushed because of a sequential load/store consistency.  If a load or store hits on an older load that has either been snooped (for loads) or has stale data (for stores)\000event=0xc8b4\000\00000\000\000"
/* offset=360869 */ "pm_flush_lsu\000other\000LSU flushes.  Includes all lsu flushes\000event=0x58a4\000\00000\000\000"
/* offset=360945 */ "pm_mrk_data_from_dl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x1d150\000\00000\000\000"
/* offset=361161 */ "pm_lsu1_false_lhs\000other\000False LHS match detected\000event=0xc8a0\000\00000\000\000"
/* offset=361228 */ "pm_thrd_prio_2_3_cyc\000other\000Cycles thread running at priority level 2 or 3\000event=0x48bc\000\00000\000\000"
/* offset=361320 */ "pm_l3_grp_guess_wrong_high\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was VGS or RNS\000event=0x368b2\000\00000\000\000"
/* offset=361460 */ "pm_ls1_pte_tablewalk_cyc\000other\000Cycles when a tablewalk is pending on this thread on table 1\000event=0xe8bc\000\00000\000\000"
/* offset=361570 */ "pm_mrk_fab_rsp_bkill_cyc\000other\000cycles L2 RC took for a bkill\000event=0x1f152\000\00000\000\000"
/* offset=361650 */ "pm_mrk_data_from_l3_no_conflict_cyc\000other\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\00000\000\000"
/* offset=361799 */ "pm_mrk_dpteg_from_rl4\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14a\000\00000\000\000"
/* offset=362081 */ "pm_l2_grp_guess_wrong\000other\000L2 guess grp (GS or NNS) and guess was not correct (ie data on-chip OR beyond-group)\000event=0x26888\000\00000\000\000"
/* offset=362213 */ "pm_lsu_flush_emsh\000other\000An ERAT miss was detected after a set-p hit. Erat tracker indicates fail due to tlbmiss and the instruction gets flushed because the instruction was working on the wrong address\000event=0xc0ac\000\00000\000\000"
/* offset=362433 */ "pm_l3_sys_guess_correct\000other\000Prefetch scope predictor selected VGS or RNS and was correct\000event=0x260b2\000\00000\000\000"
/* offset=362543 */ "pm_mrk_data_from_memory_cyc\000other\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x1d146\000\00000\000\000"
/* offset=362711 */ "pm_lsu0_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe094\000\00000\000\000"
/* offset=362771 */ "pm_l2_group_pump\000other\000RC requests that were on group (aka nodel) pump attempts\000event=0x46888\000\00000\000\000"
/* offset=362870 */ "pm_lsu_dtlb_miss_16m_2m\000other\000Data TLB Miss page size 16M (HPT) or 2M (Radix)\000event=0xc08c\000\00000\000\000"
/* offset=362966 */ "pm_l2_ld\000other\000All successful D-side Load dispatches for this thread (L2 miss + L2 hits)\000event=0x16080\000\00000\000\000"
/* offset=363074 */ "pm_math_flop_cmpl\000other\000Math flop instruction completed\000event=0x4505c\000\00000\000\000"
/* offset=363149 */ "pm_ls0_ld_vector_fin\000other\000LS0 finished load vector op\000event=0xc080\000\00000\000\000"
/* offset=363222 */ "pm_l3_p1_sys_pump\000other\000L3 PF sent with sys scope port 1, counts even retried requests\000event=0x368b0\000\00000\000\000"
/* offset=363328 */ "pm_mrk_dpteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f146\000\00000\000\000"
/* offset=363617 */ "pm_thrd_all_run_cyc\000other\000Cycles in which all the threads have the run latch set\000event=0x2000c\000\00000\000\000"
/* offset=363717 */ "pm_lsu_flush_other\000other\000Other LSU flushes including: Sync (sync ack from L2 caused search of LRQ for oldest snooped load, This will either signal a Precise Flush of the oldest snooped loa or a Flush Next PPC); Data Valid Flush Next (several cases of this, one example is store and reload are lined up such that a store-hit-reload scenario exists and the CDF has already launched and has gotten bad/stale data); Bad Data Valid Flush Next (might be a few cases of this, one example is a larxa (D$ hit) return data and dval but can't allocate to LMQ (LMQ full or other reason). Already gave dval but can't watch it for snoop_hit_larx. Need to take the 'bad dval' back and flush all younger ops)\000event=0xc0bc\000\00000\000\000"
/* offset=364428 */ "pm_ic_miss_icbi\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\00000\000\000"
/* offset=364569 */ "pm_lsu_flush_atomic\000other\000Quad-word loads (lq) are considered atomic because they always span at least 2 slices.  If a snoop or store from another thread changes the data the load is accessing between the 2 or 3 pieces of the lq instruction, the lq will be flushed\000event=0xc8a8\000\00000\000\000"
/* offset=364852 */ "pm_dpteg_from_l2miss\000other\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04e\000\00000\000\000"
/* offset=365114 */ "pm_br_cmpl\000other\000Any Branch instruction completed\000event=0x4d05e\000\00000\000\000"
/* offset=365183 */ "pm_l3_p0_grp_pump\000other\000L3 PF sent with grp scope port 0, counts even retried requests\000event=0x260b0\000\00000\000\000"
/* offset=365289 */ "pm_mrk_vsu_fin\000other\000VSU marked instr finish\000event=0x30132\000\00000\000\000"
/* offset=365353 */ "pm_mrk_data_from_off_chip_cache\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d120\000\00000\000\000"
/* offset=365568 */ "pm_dpteg_from_on_chip_cache\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e048\000\00000\000\000"
/* offset=365864 */ "pm_l2_sn_m_wr_done\000other\000SNP dispatched for a write and was M (true M); for DMA cacheinj this will pulse if rty/push is required (won't pulse if cacheinj is accepted)\000event=0x16086\000\00000\000\000"
/* offset=366050 */ "pm_br_corect_pred_taken_cmpl\000other\000Conditional Branch Completed in which the HW correctly predicted the direction as taken.  Counted at completion time\000event=0x489c\000\00000\000\000"
/* offset=366220 */ "pm_ls0_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0b8\000\00000\000\000"
/* offset=366525 */ "pm_mrk_dfu_fin\000other\000Decimal Unit marked Instruction Finish\000event=0x20132\000\00000\000\000"
/* offset=366604 */ "pm_tm_sc_co\000other\000L3 castout of line that was StoreCopy (original value of speculatively written line) in a Transaction\000event=0x160a6\000\00000\000\000"
/* offset=366743 */ "pm_lsu_flush_lhs\000other\000Effective Address alias flush : no EA match but Real Address match.  If the data has not yet been returned for this load, the instruction will just be rejected, but if it has returned data, it will be flushed\000event=0xc8b0\000\00000\000\000"
/* offset=366993 */ "pm_l2_rcld_disp\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread\000event=0x16084\000\00000\000\000"
/* offset=367110 */ "pm_mrk_st_drain_to_l2disp_cyc\000other\000cycles to drain st from core to L2\000event=0x3f150\000\00000\000\000"
/* offset=367200 */ "pm_l3_miss\000other\000L3 Misses (L2 miss also missing L3, including data/instrn/xlate)\000event=0x168a4\000\00000\000\000"
/* offset=367301 */ "pm_lsu_stcx_fail\000other\000The LSU detects the condition that a stcx instruction failed. No requirement to wait for a response from the nest\000event=0xf080\000\00000\000\000"
/* offset=367456 */ "pm_cmplu_stall_dmiss_lmem\000other\000Completion stall due to cache miss that resolves in local memory\000event=0x30038\000\00000\000\000"
/* offset=367572 */ "pm_mrk_tend_fail\000other\000Nested or not nested tend failed for a marked tend instruction\000event=0x28a4\000\00000\000\000"
/* offset=367676 */ "pm_ld_ref_l1\000other\000All L1 D cache load references counted at finish, gated by reject\000event=0x100fc\000\00000\000\000"
/* offset=367780 */ "pm_lsu0_false_lhs\000other\000False LHS match detected\000event=0xc0a0\000\00000\000\000"
/* offset=367847 */ "pm_sn_miss\000other\000Any port snooper L3 miss or collision.  Up to 4 can happen in a cycle but we only count 1\000event=0x468a8\000\00000\000\000"
/* offset=367973 */ "pm_l2_sys_guess_wrong\000other\000L2 guess system (VGS or RNS) and guess was not correct (ie data ^beyond-group)\000event=0x36888\000\00000\000\000"
/* offset=368099 */ "pm_ee_off_ext_int\000other\000CyclesMSR[EE] is off and external interrupts are active\000event=0x2080\000\00000\000\000"
/* offset=368197 */ "pm_ls3_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b8\000\00000\000\000"
/* offset=368331 */ "pm_tm_fav_caused_fail\000other\000TM Load (fav) caused another thread to fail\000event=0x2688e\000\00000\000\000"
/* offset=368422 */ "pm_sn0_busy\000other\000SN mach 0 Busy. Used by PMU to sample ave SN lifetime (mach0 used as sample point)\000event=0x16090\000\00000\000\000"
/* offset=368542 */ "pm_l3_p0_co_rty\000other\000L3 CO received retry port 0 (memory only), every retry counted\000event=0x360ae\000\00000\000\000"
/* offset=368646 */ "pm_l3_wi_usage\000other\000Lifetime, sample of Write Inject machine 0 valid\000event=0x168a8\000\00000\000\000"
/* offset=368735 */ "pm_l3_lat_ci_miss\000other\000L3 Lateral Castins Miss\000event=0x468a2\000\00000\000\000"
/* offset=368802 */ "pm_l3_p0_co_l31\000other\000L3 CO to L3.1 (LCO) port 0 with or without data\000event=0x460aa\000\00000\000\000"
/* offset=368891 */ "pm_flush_disp\000other\000Dispatch flush\000event=0x2880\000\00000\000\000"
/* offset=368944 */ "pm_l3_p1_pf_rty\000other\000L3 PF received retry port 1, every retry counted\000event=0x168ae\000\00000\000\000"
/* offset=369034 */ "pm_l2_st_disp\000other\000All successful D-side store dispatches for this thread\000event=0x46082\000\00000\000\000"
/* offset=369128 */ "pm_l2_inst_miss\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread that were an L2 miss\000event=0x36880\000\00000\000\000"
/* offset=369285 */ "pm_ls0_erat_miss_pref\000other\000LS0 Erat miss due to prefetch\000event=0xe084\000\00000\000\000"
/* offset=369361 */ "pm_br_pred\000other\000Conditional Branch Executed in which the HW predicted the Direction or Target.  Includes taken and not taken and is counted at execution time\000event=0x409c\000\00000\000\000"
/* offset=369538 */ "pm_l3_co_lco\000other\000Total L3 COs occurred on LCO L3.1 (good cresp, may end up in mem on a retry)\000event=0x360a4\000\00000\000\000"
/* offset=369653 */ "pm_ic_pref_cancel_hit\000other\000Prefetch Canceled due to icache hit\000event=0x4890\000\00000\000\000"
/* offset=369735 */ "pm_rd_hit_pf\000other\000RD machine hit L3 PF machine\000event=0x268a8\000\00000\000\000"
/* offset=369802 */ "pm_l2_st\000other\000All successful D-side store dispatches for this thread (L2 miss + L2 hits)\000event=0x16880\000\00000\000\000"
/* offset=369911 */ "pm_lsu0_srq_s0_valid_cyc\000other\000Slot 0 of SRQ valid\000event=0xd0b4\000\00000\000\000"
/* offset=369980 */ "pm_l3_p0_lco_no_data\000other\000Dataless L3 LCO sent port 0\000event=0x160aa\000\00000\000\000"
/* offset=370054 */ "pm_clb_held\000other\000CLB (control logic block - indicates quadword fetch block) Hold: Any Reason\000event=0x208c\000\00000\000\000"
/* offset=370166 */ "pm_lsu3_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf88c\000\00000\000\000"
/* offset=370359 */ "pm_inst_disp\000other\000# PPC Dispatched\000event=0x200f2\000\00000\000\000"
/* offset=370414 */ "pm_tm_outer_tbegin_disp\000other\000Number of outer tbegin instructions dispatched. The dispatch unit determines whether the tbegin instruction is outer or nested. This is a speculative count, which includes flushed instructions\000event=0x4e05e\000\00000\000\000"
/* offset=370656 */ "pm_cmplu_stall_exec_unit\000other\000Completion stall due to execution units (FXU/VSU/CRU)\000event=0x2d018\000\00000\000\000"
/* offset=370760 */ "pm_lsu_flush_next\000other\000LSU flush next reported at flush time.  Sometimes these also come with an exception\000event=0x20b0\000\00000\000\000"
/* offset=370886 */ "pm_isu2_iss_hold_all\000other\000All ISU rejects\000event=0x3880\000\00000\000\000"
/* offset=370947 */ "pm_ls3_ld_vector_fin\000other\000LS3 finished load vector op\000event=0xc884\000\00000\000\000"
/* offset=371020 */ "pm_l3_co\000other\000L3 castout occurring (does not include casthrough or log writes (cinj/dmaw))\000event=0x360a8\000\00000\000\000"
/* offset=371131 */ "pm_l3_cinj\000other\000L3 castin of cache inject\000event=0x368a4\000\00000\000\000"
/* offset=371193 */ "pm_lsu_ncst\000other\000Asserts when a i=1 store op is sent to the nest. No record of issue pipe (LS0/LS1) is maintained so this is for both pipes. Probably don't need separate LS0 and LS1\000event=0xc890\000\00000\000\000"
/* offset=371394 */ "pm_lsu_lmq_full_cyc\000other\000Counts the number of cycles the LMQ is full\000event=0xd0b8\000\00000\000\000"
/* offset=371482 */ "pm_l3_grp_guess_correct\000other\000Prefetch scope predictor selected GS or NNS and was correct\000event=0x168b2\000\00000\000\000"
/* offset=371591 */ "pm_stop_fetch_pending_cyc\000other\000Fetching is stopped due to an incoming instruction that will result in a flush\000event=0x48a4\000\00000\000\000"
/* offset=371720 */ "pm_l2_rcst_disp_fail_addr\000other\000All D-side store dispatch attempts for this thread that failed due to address collision with RC/CO/SN/SQ\000event=0x36884\000\00000\000\000"
/* offset=371876 */ "pm_l3_pf_usage\000other\000Rotating sample of 32 PF actives\000event=0x260ac\000\00000\000\000"
/* offset=371949 */ "pm_dfu_busy\000pipeline\000Cycles in which all 4 Decimal Floating Point units are busy. The DFU is running at capacity\000event=0x4d04c\000\00000\000\000"
/* offset=372081 */ "pm_ierat_reload\000pipeline\000Number of I-ERAT reloads\000event=0x100f6\000\00000\000\000"
/* offset=372150 */ "pm_mrk_ld_miss_l1\000pipeline\000Marked DL1 Demand Miss counted at exec time. Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x201e2\000\00000\000\000"
/* offset=372370 */ "pm_pmc3_overflow\000pipeline\000Overflow from counter 3\000event=0x40010\000\00000\000\000"
/* offset=372439 */ "pm_cmplu_stall_dflong\000pipeline\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Qualified by multicycle\000event=0x1005a\000\00000\000\000"
/* offset=372750 */ "pm_mrk_data_from_on_chip_cache\000pipeline\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4d140\000\00000\000\000"
/* offset=372944 */ "pm_mrk_dpteg_from_dl4\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14c\000\00000\000\000"
/* offset=373232 */ "pm_dpteg_from_l2_no_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e040\000\00000\000\000"
/* offset=373496 */ "pm_fxu_idle\000pipeline\000Cycles in which FXU0, FXU1, FXU2, and FXU3 are all idle\000event=0x24052\000\00000\000\000"
/* offset=373592 */ "pm_cmplu_stall\000pipeline\000Nothing completed and ICT not empty\000event=0x1e054\000\00000\000\000"
/* offset=373671 */ "pm_inst_cmpl\000pipeline\000Number of PowerPC Instructions that completed\000event=0x2\000\00000\000\000"
/* offset=373754 */ "pm_vsu_dp_fsqrt_fdiv\000pipeline\000vector versions of fdiv,fsqrt\000event=0x3d058\000\00000\000\000"
/* offset=373833 */ "pm_ict_empty_cyc\000pipeline\000Cycles in which the ICT is completely empty. No itags are assigned to any thread\000event=0x20008\000\00000\000\000"
/* offset=373959 */ "pm_mrk_dpteg_from_l21_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f146\000\00000\000\000"
/* offset=374252 */ "pm_mem_read\000pipeline\000Reads from Memory from this thread (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\00000\000\000"
/* offset=374392 */ "pm_data_from_dl4\000pipeline\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\00000\000\000"
/* offset=374560 */ "pm_dpteg_from_l21_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e046\000\00000\000\000"
/* offset=374842 */ "pm_ntc_issue_held_arb\000pipeline\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000event=0x2e016\000\00000\000\000"
/* offset=375054 */ "pm_sync_mrk_fx_divide\000pipeline\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\00000\000\000"
/* offset=375169 */ "pm_derat_miss_4k\000pipeline\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\00000\000\000"
/* offset=375260 */ "pm_mrk_dpteg_from_l3_mepf\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f142\000\00000\000\000"
/* offset=375557 */ "pm_mrk_derat_miss_16g_1g\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) and 1G (radix mode)\000event=0x4c15c\000\00000\000\000"
/* offset=375695 */ "pm_pmc5_overflow\000pipeline\000Overflow from counter 5\000event=0x10024\000\00000\000\000"
/* offset=375764 */ "pm_flop_cmpl\000pipeline\000Floating Point Operation Finished\000event=0x4505e\000\00000\000\000"
/* offset=375839 */ "pm_ierat_reload_16m\000pipeline\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\00000\000\000"
/* offset=375924 */ "pm_ict_noslot_ic_l3miss\000pipeline\000Ict empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000event=0x4e010\000\00000\000\000"
/* offset=376139 */ "pm_ict_noslot_disp_held_sync\000pipeline\000Dispatch held due to a synchronizing instruction at dispatch\000event=0x4d01c\000\00000\000\000"
/* offset=376257 */ "pm_ict_noslot_ic_miss\000pipeline\000Ict empty for this thread due to Icache Miss\000event=0x2d01a\000\00000\000\000"
/* offset=376352 */ "pm_mrk_dpteg_from_off_chip_cache\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14a\000\00000\000\000"
/* offset=376686 */ "pm_ict_noslot_cyc\000pipeline\000Number of cycles the ICT has no itags assigned to this thread\000event=0x100f8\000\00000\000\000"
/* offset=376794 */ "pm_dpteg_from_l3_disp_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e042\000\00000\000\000"
/* offset=377066 */ "pm_mrk_dpteg_from_l2_no_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f140\000\00000\000\000"
/* offset=377341 */ "pm_radix_pwc_l2_pte_from_l2\000pipeline\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L2 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x1f058\000\00000\000\000"
/* offset=377580 */ "pm_mrk_data_from_rl2l3_mod\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\00000\000\000"
/* offset=377797 */ "pm_chip_pump_cpred\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\00000\000\000"
/* offset=377996 */ "pm_ic_miss_cmpl\000pipeline\000Non-speculative icache miss, counted at completion\000event=0x45058\000\00000\000\000"
/* offset=378091 */ "pm_mrk_derat_miss_4k\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x2d150\000\00000\000\000"
/* offset=378193 */ "pm_ict_noslot_br_mpred_icmiss\000pipeline\000Ict empty for this thread due to Icache Miss and branch mispred\000event=0x34058\000\00000\000\000"
/* offset=378315 */ "pm_pmc2_saved\000pipeline\000PMC2 Rewind Value saved\000event=0x10022\000\00000\000\000"
/* offset=378381 */ "pm_hv_cyc\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\00000\000\000"
/* offset=378512 */ "pm_mrk_dpteg_from_l3_no_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f144\000\00000\000\000"
/* offset=378787 */ "pm_dtlb_miss\000pipeline\000Data PTEG reload\000event=0x300fc\000\00000\000\000"
/* offset=378845 */ "pm_data_from_rl2l3_mod\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\00000\000\000"
/* offset=379058 */ "pm_grp_pump_mpred\000pipeline\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\00000\000\000"
/* offset=379275 */ "pm_radix_pwc_l2_pde_from_l3\000pipeline\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L3 data cache\000event=0x3f05a\000\00000\000\000"
/* offset=379426 */ "pm_dpteg_from_rl2l3_shr\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04a\000\00000\000\000"
/* offset=379746 */ "pm_ict_noslot_disp_held_tbegin\000pipeline\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000event=0x10064\000\00000\000\000"
/* offset=379989 */ "pm_dpteg_from_rl2l3_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e046\000\00000\000\000"
/* offset=380311 */ "pm_mrk_dpteg_from_dmem\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14c\000\00000\000\000"
/* offset=380601 */ "pm_dpteg_from_l3_mepf\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e042\000\00000\000\000"
/* offset=380887 */ "pm_cmplu_stall_dfu\000pipeline\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Not qualified by multicycle\000event=0x2d012\000\00000\000\000"
/* offset=381173 */ "pm_derat_miss_16m_2m\000pipeline\000Data ERAT Miss (Data TLB Access) page size 16M (HPT mode) or 2M (Radix mode)\000event=0x3c054\000\00000\000\000"
/* offset=381299 */ "pm_data_from_dmem\000pipeline\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\00000\000\000"
/* offset=381469 */ "pm_pmc4_saved\000pipeline\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\00000\000\000"
/* offset=381555 */ "pm_run_cyc\000pipeline\000Run_cycles\000event=0x200f4\000\00000\000\000"
/* offset=381605 */ "pm_mrk_data_from_l21_mod_cyc\000pipeline\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x3d148\000\00000\000\000"
/* offset=381775 */ "pm_mrk_dpteg_from_rl2l3_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f146\000\00000\000\000"
/* offset=382108 */ "pm_ict_noslot_disp_held\000pipeline\000Cycles in which the NTC instruction is held at dispatch for any reason\000event=0x4e01a\000\00000\000\000"
/* offset=382231 */ "pm_thresh_exc_2048\000pipeline\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\00000\000\000"
/* offset=382321 */ "pm_mrk_data_from_rl2l3_shr\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x35150\000\00000\000\000"
/* offset=382536 */ "pm_ict_noslot_ic_l3\000pipeline\000Ict empty for this thread due to icache misses that were sourced from the local L3\000event=0x3e052\000\00000\000\000"
/* offset=382667 */ "pm_ntc_fin\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000event=0x2405a\000\00000\000\000"
/* offset=382868 */ "pm_pump_mpred\000pipeline\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\00000\000\000"
/* offset=383051 */ "pm_tm_aborts\000pipeline\000Number of TM transactions aborted\000event=0x30056\000\00000\000\000"
/* offset=383126 */ "pm_inst_from_memory\000pipeline\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\00000\000\000"
/* offset=383329 */ "pm_pmc6_overflow\000pipeline\000Overflow from counter 6\000event=0x30024\000\00000\000\000"
/* offset=383398 */ "pm_bru_fin\000pipeline\000Branch Instruction Finished\000event=0x10068\000\00000\000\000"
/* offset=383465 */ "pm_mrk_derat_miss_16m_2m\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16M (hpt mode) or 2M (radix mode)\000event=0x3d154\000\00000\000\000"
/* offset=383602 */ "pm_pmc2_rewind\000pipeline\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\00000\000\000"
/* offset=383689 */ "pm_dummy2_remove_me\000pipeline\000Space holder for LS_PC_RELOAD_RA\000event=0x40064\000\00000\000\000"
/* offset=383770 */ "pm_mrk_dpteg_from_dl2l3_shr\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f148\000\00000\000\000"
/* offset=384105 */ "pm_ict_noslot_br_mpred\000pipeline\000Ict empty for this thread due to branch mispred\000event=0x4d01e\000\00000\000\000"
/* offset=384204 */ "pm_mrk_dpteg_from_on_chip_cache\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f148\000\00000\000\000"
/* offset=384515 */ "pm_dpteg_from_l21_shr\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e046\000\00000\000\000"
/* offset=384795 */ "pm_mrk_dpteg_from_l31_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f144\000\00000\000\000"
/* offset=385088 */ "pm_inst_grp_pump_mpred_rty\000pipeline\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\00000\000\000"
/* offset=385240 */ "pm_dslb_miss\000pipeline\000gate_and(sd_pc_c0_comp_valid AND sd_pc_c0_comp_thread(0:1)=tid,sd_pc_c0_comp_ppc_count(0:3)) + gate_and(sd_pc_c1_comp_valid AND sd_pc_c1_comp_thread(0:1)=tid,sd_pc_c1_comp_ppc_count(0:3))\000event=0xd0a8\000\00000\000\000"
/* offset=385468 */ "pm_mem_co\000pipeline\000Memory castouts from this thread\000event=0x4c058\000\00000\000\000"
/* offset=385539 */ "pm_fxu_fin\000pipeline\000The fixed point unit Unit finished an instruction. Instructions that finish may not necessary complete\000event=0x40004\000\00000\000\000"
/* offset=385681 */ "pm_derat_miss_64k\000pipeline\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\00000\000\000"
/* offset=385774 */ "pm_ic_demand_cyc\000pipeline\000Icache miss demand cycles\000event=0x10018\000\00000\000\000"
/* offset=385845 */ "pm_mrk_data_from_l21_shr\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2d14e\000\00000\000\000"
/* offset=386020 */ "pm_cmplu_stall_dplong\000pipeline\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3405c\000\00000\000\000"
/* offset=386347 */ "pm_2flop_cmpl\000pipeline\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0x4d052\000\00000\000\000"
/* offset=386466 */ "pm_mrk_dpteg_from_l2\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f142\000\00000\000\000"
/* offset=386712 */ "pm_dummy1_remove_me\000pipeline\000Space holder for L2_PC_PM_MK_LDST_SCOPE_PRED_STATUS\000event=0x40062\000\00000\000\000"
/* offset=386812 */ "pm_cmplu_stall_erat_miss\000pipeline\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000event=0x4c012\000\00000\000\000"
/* offset=386959 */ "pm_vsu_non_flop_cmpl\000pipeline\000Non FLOP operation completed\000event=0x4d050\000\00000\000\000"
/* offset=387037 */ "pm_tm_tx_pass_run_cyc\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\00000\000\000"
/* offset=387127 */ "pm_vsu_fsqrt_fdiv\000pipeline\000four flops operation (fdiv,fsqrt) Scalar Instructions only\000event=0x4d04e\000\00000\000\000"
/* offset=387232 */ "pm_mrk_data_from_l2_mepf\000pipeline\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4c120\000\00000\000\000"
/* offset=387413 */ "pm_mrk_dpteg_from_memory\000pipeline\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14c\000\00000\000\000"
/* offset=387707 */ "pm_inst_chip_pump_cpred\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\00000\000\000"
/* offset=387848 */ "pm_fxu_busy\000pipeline\000Cycles in which all 4 FXUs are busy. The FXU is running at capacity\000event=0x2000e\000\00000\000\000"
/* offset=387956 */ "pm_tlb_miss\000pipeline\000TLB Miss (I + D)\000event=0x20066\000\00000\000\000"
/* offset=388013 */ "pm_pump_cpred\000pipeline\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\00000\000\000"
/* offset=388201 */ "pm_mrk_data_from_l31_shr\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\00000\000\000"
/* offset=388376 */ "pm_cmplu_stall_emq_full\000pipeline\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000event=0x30004\000\00000\000\000"
/* offset=388523 */ "pm_mrk_data_from_l21_shr_cyc\000pipeline\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x1d154\000\00000\000\000"
/* offset=388691 */ "pm_br_2path\000pmc\000Branches that are not strongly biased\000event=0x20036\000\00000\000\000"
/* offset=388764 */ "pm_mem_loc_thresh_lsu_high\000pmc\000Local memory above threshold for LSU medium\000event=0x40056\000\00000\000\000"
/* offset=388858 */ "pm_mrk_dcache_reload_intv\000pmc\000Combined Intervention event\000event=0x40118\000\00000\000\000"
/* offset=388935 */ "pm_mrk_dpteg_from_dl2l3_mod\000pmc\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f148\000\00000\000\000"
/* offset=389267 */ "pm_dpteg_from_l3miss\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04e\000\00000\000\000"
/* offset=389527 */ "pm_sys_pump_mpred_rty\000pmc\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\00000\000\000"
/* offset=389739 */ "pm_mrk_dpteg_from_l2miss\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14e\000\00000\000\000"
/* offset=390011 */ "pm_cmplu_stall_bru\000pmc\000Completion stall due to a Branch Unit\000event=0x4d018\000\00000\000\000"
/* offset=390091 */ "pm_4flop_cmpl\000pmc\0004 FLOP instruction completed\000event=0x45052\000\00000\000\000"
/* offset=390157 */ "pm_mrk_data_from_lmem\000pmc\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x3d142\000\00000\000\000"
/* offset=390292 */ "pm_cmplu_stall_crypto\000pmc\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000event=0x4c01e\000\00000\000\000"
/* offset=390444 */ "pm_freq_down\000pmc\000Power Management: Below Threshold B\000event=0x3000c\000\00000\000\000"
/* offset=390516 */ "pm_mrk_data_from_lmem_cyc\000pmc\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\00000\000\000"
/* offset=390644 */ "pm_8flop_cmpl\000pmc\0008 FLOP instruction completed\000event=0x4d054\000\00000\000\000"
/* offset=390710 */ "pm_tablewalk_cyc\000pmc\000Cycles when an instruction tablewalk is active\000event=0x10026\000\00000\000\000"
/* offset=390797 */ "pm_cmplu_stall_dcache_miss\000pmc\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000event=0x2c012\000\00000\000\000"
/* offset=390971 */ "pm_dpteg_from_memory\000pmc\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04c\000\00000\000\000"
/* offset=391249 */ "pm_mrk_dpteg_from_l3_disp_conflict\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f142\000\00000\000\000"
/* offset=391527 */ "pm_mrk_dpteg_from_l3\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f142\000\00000\000\000"
/* offset=391768 */ "pm_tm_trans_run_cyc\000pmc\000run cycles in transactional state\000event=0x10060\000\00000\000\000"
/* offset=391845 */ "pm_dpteg_from_ll4\000pmc\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04c\000\00000\000\000"
/* offset=392086 */ "pm_1flop_cmpl\000pmc\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation completed\000event=0x45050\000\00000\000\000"
/* offset=392216 */ "pm_cyc\000translation\000Processor cycles\000event=0x1e\000\00000\000\000"
/* offset=392268 */ "pm_pmc2_overflow\000translation\000Overflow from counter 2\000event=0x30010\000\00000\000\000"
/* offset=392340 */ "pm_data_from_l21_shr\000translation\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\00000\000\000"
/* offset=392514 */ "pm_dp_qp_flop_cmpl\000translation\000Double-Precion or Quad-Precision instruction completed\000event=0x4d05c\000\00000\000\000"
/* offset=392619 */ "pm_dpteg_from_dmem\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04c\000\00000\000\000"
/* offset=392901 */ "pm_st_fin\000translation\000Store finish count. Includes speculative activity\000event=0x20016\000\00000\000\000"
/* offset=392992 */ "pm_ipteg_from_rl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\00000\000\000"
/* offset=393223 */ "pm_mrk_lsu_fin\000translation\000lsu marked instr PPC finish\000event=0x40132\000\00000\000\000"
/* offset=393297 */ "pm_cmplu_stall_vfxu\000translation\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x3c05c\000\00000\000\000"
/* offset=393490 */ "pm_lsu_fin\000translation\000LSU Finished a PPC instruction (up to 4 per cycle)\000event=0x30066\000\00000\000\000"
/* offset=393583 */ "pm_mrk_ntc_cyc\000translation\000Cycles during which the marked instruction is next to complete (completion is held up because the marked instruction hasn't completed yet)\000event=0x2011c\000\00000\000\000"
/* offset=393768 */ "pm_dpteg_from_dl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e048\000\00000\000\000"
/* offset=394095 */ "pm_cmplu_stall_vfxlong\000translation\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000event=0x2e018\000\00000\000\000"
/* offset=394243 */ "pm_data_from_l2miss_mod\000translation\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\00000\000\000"
/* offset=394406 */ "pm_ipteg_from_on_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\00000\000\000"
/* offset=394616 */ "pm_inst_from_l21_shr\000translation\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\00000\000\000"
/* offset=394819 */ "pm_stcx_fail\000translation\000stcx failed\000event=0x1e058\000\00000\000\000"
/* offset=394875 */ "pm_data_from_l21_mod\000translation\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\00000\000\000"
/* offset=395051 */ "pm_ipteg_from_rl4\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\00000\000\000"
/* offset=395236 */ "pm_lsu_lmq_srq_empty_cyc\000translation\000Cycles in which the LSU is empty for all threads (lmq and srq are completely empty)\000event=0x2003e\000\00000\000\000"
/* offset=395376 */ "pm_thresh_exc_32\000translation\000Threshold counter exceeded a value of 32\000event=0x201e6\000\00000\000\000"
/* offset=395465 */ "pm_cmplu_stall_vdp\000translation\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by vector\000event=0x4405c\000\00000\000\000"
/* offset=395787 */ "pm_pmc1_saved\000translation\000PMC1 Rewind Value saved\000event=0x4d010\000\00000\000\000"
/* offset=395856 */ "pm_inst_from_l3\000translation\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\00000\000\000"
/* offset=396014 */ "pm_data_from_l2miss\000translation\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\00000\000\000"
/* offset=396098 */ "pm_mrk_data_from_rl2l3_mod_cyc\000translation\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d14a\000\00000\000\000"
/* offset=396311 */ "pm_stall_end_ict_empty\000translation\000The number a times the core transitioned from a stall to ICT-empty for this thread\000event=0x10028\000\00000\000\000"
/* offset=396448 */ "pm_ipteg_from_memory\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\00000\000\000"
/* offset=396642 */ "pm_ipteg_from_off_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\00000\000\000"
/* offset=396876 */ "pm_inst_from_l2miss\000translation\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\00000\000\000"
/* offset=397064 */ "pm_inst_from_l3_disp_conflict\000translation\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\00000\000\000"
/* offset=397259 */ "pm_dpteg_from_dl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e048\000\00000\000\000"
/* offset=397588 */ "pm_st_cmpl\000translation\000Stores completed from S2Q (2nd-level store queue)\000event=0x200f0\000\00000\000\000"
/* offset=397680 */ "pm_lsu_reject_lhs\000translation\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\00000\000\000"
/* offset=397771 */ "pm_inst_from_l3_no_conflict\000translation\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\00000\000\000"
/* offset=397958 */ "pm_dpteg_from_dl4\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04c\000\00000\000\000"
/* offset=398238 */ "pm_mrk_probe_nop_cmpl\000translation\000Marked probeNops completed\000event=0x1f15e\000\00000\000\000"
/* offset=398318 */ "pm_mrk_data_from_l31_eco_shr_cyc\000translation\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x1d142\000\00000\000\000"
/* offset=398497 */ "pm_inst_from_l3_mepf\000translation\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\00000\000\000"
/* offset=398706 */ "pm_ipteg_from_rl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\00000\000\000"
/* offset=398939 */ "pm_ipteg_from_rmem\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\00000\000\000"
/* offset=399129 */ "pm_cmplu_stall_vdplong\000translation\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3c05a\000\00000\000\000"
/* offset=399460 */ "pm_cmplu_stall_tlbie\000translation\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000event=0x2e01c\000\00000\000\000"
/* offset=399594 */ "bp_l1_btb_correct\000branch\000L1 BTB Correction\000event=0x8a\000\00000\000\000"
/* offset=399653 */ "bp_l2_btb_correct\000branch\000L2 BTB Correction\000event=0x8b\000\00000\000\000"
/* offset=399712 */ "l3_cache_rd\000cache\000L3 cache access, read\000event=0x40\000\00000\000Attributable Level 3 cache access, read\000"
/* offset=399807 */ "segment_reg_loads.any\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\00000\000\000"
/* offset=399908 */ "dispatch_blocked.any\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\00000\000\000"
/* offset=400040 */ "eist_trans\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\00000\000\000"
/* offset=400165 */ "hisi_sccl,ddrc\000"
/* offset=400180 */ "uncore_hisi_ddrc.flux_wcmd\000uncore\000DDRC write commands\000event=0x2\000\00000\000DDRC write commands\000"
/* offset=400268 */ "uncore_cbox\000"
/* offset=400280 */ "unc_cbo_xsnp_response.miss_eviction\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000event=0x22,umask=0x81\000\00000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000"
/* offset=400511 */ "event-hyphen\000uncore\000UNC_CBO_HYPHEN\000event=0xe0,umask=0x00\000\00000\000UNC_CBO_HYPHEN\000"
/* offset=400587 */ "event-two-hyph\000uncore\000UNC_CBO_TWO_HYPH\000event=0xc0,umask=0x00\000\00000\000UNC_CBO_TWO_HYPH\000"
/* offset=400669 */ "hisi_sccl,l3c\000"
/* offset=400683 */ "uncore_hisi_l3c.rd_hit_cpipe\000uncore\000Total read hits\000event=0x7\000\00000\000Total read hits\000"
/* offset=400765 */ "uncore_imc_free_running\000"
/* offset=400789 */ "uncore_imc_free_running.cache_miss\000uncore\000Total cache misses\000event=0x12\000\00000\000Total cache misses\000"
/* offset=400884 */ "uncore_imc\000"
/* offset=400895 */ "uncore_imc.cache_hits\000uncore\000Total cache hits\000event=0x34\000\00000\000Total cache hits\000"
/* offset=400973 */ "uncore_sys_ddr_pmu\000"
/* offset=400992 */ "sys_ddr_pmu.write_cycles\000uncore\000ddr write-cycles event\000event=0x2b\000v8\00000\000\000"
/* offset=401065 */ "uncore_sys_ccn_pmu\000"
/* offset=401084 */ "sys_ccn_pmu.read_cycles\000uncore\000ccn read-cycles event\000config=0x2c\0000x01\00000\000\000"
/* offset=401158 */ "uncore_sys_cmn_pmu\000"
/* offset=401177 */ "sys_cmn_pmu.hnf_cache_miss\000uncore\000Counts total cache misses in first lookup result (high priority)\000eventid=0x1,type=0x5\000(434|436|43c|43a).*\00000\000\000"
/* offset=401321 */ "RUN_CYCLES_RATE\000General\000PM_RUN_CYC / PM_CYC * 100\000\000Percentage of cycles that are run cycles\000\0001%\000\000\000\00000"
/* offset=401422 */ "CYCLES_PER_INSTRUCTION\000CPI\000PM_CYC / PM_INST_CMPL\000\000Average cycles per completed instruction\000\000\000\000\000\00000"
/* offset=401520 */ "DISPATCH_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_DISP_STALL_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled for any reason\000\000\000\000\000\00000"
/* offset=401686 */ "DISPATCH_STALL_FLUSH_CPI\000CPI\000PM_DISP_STALL_FLUSH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because there was a flush\000\000\000\000\000\00000"
/* offset=401855 */ "DISPATCH_STALL_FETCH_CPI\000CPI\000PM_DISP_STALL_FETCH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because Fetch was being held,  so there was nothing in the pipeline for this thread\000\000\000\000\000\00000"
/* offset=402082 */ "DISPATCH_STALL_TRANSLATION_CPI\000CPI\000PM_DISP_STALL_TRANSLATION / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because the MMU was handling a translation miss\000\000\000\000\000\00000"
/* offset=402285 */ "DISPATCH_STALL_IERAT_ONLY_MISS_CPI\000CPI\000PM_DISP_STALL_IERAT_ONLY_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction ERAT miss\000\000\000\000\000\00000"
/* offset=402492 */ "DISPATCH_STALL_ITLB_MISS_CPI\000CPI\000PM_DISP_STALL_ITLB_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction TLB miss\000\000\000\000\000\00000"
/* offset=402686 */ "DISPATCH_STALL_IC_MISS_CPI\000CPI\000PM_DISP_STALL_IC_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled due to an icache miss\000\000\000\000\000\00000"
/* offset=402855 */ "DISPATCH_STALL_IC_L2_CPI\000CPI\000PM_DISP_STALL_IC_L2 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L2\000\000\000\000\000\00000"
/* offset=403050 */ "DISPATCH_STALL_IC_L3_CPI\000CPI\000PM_DISP_STALL_IC_L3 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L3\000\000\000\000\000\00000"
/* offset=403245 */ "DISPATCH_STALL_IC_L3MISS_CPI\000CPI\000PM_DISP_STALL_IC_L3MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000\000\000\000\000\00000"
/* offset=403466 */ "DISPATCH_STALL_BR_MPRED_ICMISS_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled due to an icache miss after a branch mispredict\000\000\000\000\000\00000"
/* offset=403677 */ "DISPATCH_STALL_BR_MPRED_IC_L2_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_IC_L2 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L2 after suffering a branch mispredict\000\000\000\000\000\00000"
/* offset=403922 */ "DISPATCH_STALL_BR_MPRED_IC_L3_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_IC_L3 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L3 after suffering a branch mispredict\000\000\000\000\000\00000"
/* offset=404167 */ "DISPATCH_STALL_BR_MPRED_IC_L3MISS_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_IC_L3MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from any source beyond the local L3 after suffering a branch mispredict\000\000\000\000\000\00000"
/* offset=404438 */ "DISPATCH_STALL_BR_MPRED_CPI\000CPI\000PM_DISP_STALL_BR_MPRED / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled due to a branch mispredict\000\000\000\000\000\00000"
/* offset=404614 */ "DISPATCH_STALL_HELD_CPI\000CPI\000PM_DISP_STALL_HELD_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any reason\000\000\000\000\000\00000"
/* offset=404794 */ "DISPATCH_STALL_HELD_SYNC_CPI\000CPI\000PM_DISP_STALL_HELD_SYNC_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000\000\000\000\000\00000"
/* offset=405058 */ "DISPATCH_STALL_HELD_SCOREBOARD_CPI\000CPI\000PM_DISP_STALL_HELD_SCOREBOARD_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch while waiting on the scoreboard\000\000\000\000\000\00000"
/* offset=405277 */ "DISPATCH_STALL_HELD_ISSQ_FULL_CPI\000CPI\000PM_DISP_STALL_HELD_ISSQ_FULL_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch due to issue queue full\000\000\000\000\000\00000"
/* offset=405486 */ "DISPATCH_STALL_HELD_RENAME_CPI\000CPI\000PM_DISP_STALL_HELD_RENAME_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the mapper/SRB was full\000\000\000\000\000\00000"
/* offset=405697 */ "DISPATCH_STALL_HELD_STF_MAPPER_CPI\000CPI\000PM_DISP_STALL_HELD_STF_MAPPER_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the STF mapper/SRB was full\000\000\000\000\000\00000"
/* offset=405920 */ "DISPATCH_STALL_HELD_XVFC_MAPPER_CPI\000CPI\000PM_DISP_STALL_HELD_XVFC_MAPPER_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the XVFC mapper/SRB was full\000\000\000\000\000\00000"
/* offset=406146 */ "DISPATCH_STALL_HELD_OTHER_CPI\000CPI\000PM_DISP_STALL_HELD_OTHER_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any other reason\000\000\000\000\000\00000"
/* offset=406344 */ "ISSUE_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_ISSUE_STALL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction has been dispatched but not issued for any reason\000\000\000\000\000\00000"
/* offset=406538 */ "EXECUTION_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_EXEC_STALL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000\00000"
/* offset=406741 */ "NTC_FLUSH_STALL_CPI\000CPI\000PM_EXEC_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction spent executing an NTC instruction that gets flushed some time after dispatch\000\000\000\000\000\00000"
/* offset=406935 */ "FIN_AT_DISP_STALL_CPI\000CPI\000PM_EXEC_STALL_FIN_AT_DISP / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTF instruction finishes at dispatch\000\000\000\000\000\00000"
/* offset=407101 */ "BRU_STALL_CPI\000CPI\000PM_EXEC_STALL_BRU / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing in the branch unit\000\000\000\000\000\00000"
/* offset=407262 */ "SIMPLE_FX_STALL_CPI\000CPI\000PM_EXEC_STALL_SIMPLE_FX / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a simple fixed point instruction that is executing in the LSU\000\000\000\000\000\00000"
/* offset=407468 */ "VSU_STALL_CPI\000CPI\000PM_EXEC_STALL_VSU / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing in the VSU\000\000\000\000\000\00000"
/* offset=407621 */ "TRANSLATION_STALL_CPI\000CPI\000PM_EXEC_STALL_TRANSLATION / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000\00000"
/* offset=407822 */ "DERAT_ONLY_MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_DERAT_ONLY_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a load or store that suffered a translation miss\000\000\000\000\000\00000"
/* offset=408027 */ "DERAT_DTLB_MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_DERAT_DTLB_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is recovering from a TLB miss\000\000\000\000\000\00000"
/* offset=408210 */ "LSU_STALL_CPI\000CPI\000PM_EXEC_STALL_LSU / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing in the LSU\000\000\000\000\000\00000"
/* offset=408363 */ "LOAD_STALL_CPI\000CPI\000PM_EXEC_STALL_LOAD / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a load that is executing in the LSU\000\000\000\000\000\00000"
/* offset=408533 */ "DMISS_L2L3_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3\000\000\000\000\000\00000"
/* offset=408751 */ "DMISS_L2L3_CONFLICT_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, with an RC dispatch conflict\000\000\000\000\000\00000"
/* offset=409017 */ "DMISS_L2L3_NOCONFLICT_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L2L3_NOCONFLICT / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, without an RC dispatch conflict\000\000\000\000\000\00000"
/* offset=409290 */ "DMISS_L3MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\000\000\000\000\00000"
/* offset=409522 */ "DMISS_L21_L31_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a neighbor chiplet's L2 or L3 in the same chip\000\000\000\000\000\00000"
/* offset=409761 */ "DMISS_LMEM_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from L4, local memory or OpenCAPI chip\000\000\000\000\000\00000"
/* offset=409981 */ "DMISS_OFF_CHIP_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_OFF_CHIP / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a remote chip (cache, L4, memory or OpenCAPI) in the same group\000\000\000\000\000\00000"
/* offset=410239 */ "DMISS_OFF_NODE_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_OFF_NODE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a distant chip (cache, L4, memory or OpenCAPI chip)\000\000\000\000\000\00000"
/* offset=410485 */ "TLBIEL_STALL_CPI\000CPI\000PM_EXEC_STALL_TLBIEL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing a TLBIEL instruction\000\000\000\000\000\00000"
/* offset=410654 */ "LOAD_FINISH_STALL_CPI\000CPI\000PM_EXEC_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is finishing a load after its data has been reloaded from a data source beyond the local L1, OR when the LSU is processing an L1-hit, OR when the NTF instruction merged with another load in the LMQ\000\000\000\000\000\00000"
/* offset=410997 */ "STORE_STALL_CPI\000CPI\000PM_EXEC_STALL_STORE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a store that is executing in the LSU\000\000\000\000\000\00000"
/* offset=411170 */ "STORE_PIPE_STALL_CPI\000CPI\000PM_EXEC_STALL_STORE_PIPE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is in the store unit outside of handling store misses or other special store operations\000\000\000\000\000\00000"
/* offset=411401 */ "STORE_MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_STORE_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a store whose cache line was not resident in the L1 and had to wait for allocation of the missing line into the L1\000\000\000\000\000\00000"
/* offset=411662 */ "TLBIE_STALL_CPI\000CPI\000PM_EXEC_STALL_TLBIE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a TLBIE instruction waiting for a response from the L2\000\000\000\000\000\00000"
/* offset=411853 */ "PTESYNC_STALL_CPI\000CPI\000PM_EXEC_STALL_PTESYNC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing a PTESYNC instruction\000\000\000\000\000\00000"
/* offset=412025 */ "COMPLETION_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_CMPL_STALL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction cannot complete because the thread was blocked\000\000\000\000\000\00000"
/* offset=412220 */ "EXCEPTION_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_EXCEPTION / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction cannot complete because it was interrupted by ANY exception\000\000\000\000\000\00000"
/* offset=412432 */ "MEM_ECC_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_MEM_ECC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is stuck at finish waiting for the non-speculative finish of either a STCX instruction waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000\00000"
/* offset=412749 */ "STCX_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_STCX / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a STCX instruction waiting for resolution from the nest\000\000\000\000\000\00000"
/* offset=412950 */ "LWSYNC_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_LWSYNC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a LWSYNC instruction waiting to complete\000\000\000\000\000\00000"
/* offset=413140 */ "HWSYNC_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_HWSYNC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a HWSYNC instruction stuck at finish waiting for a response from the L2\000\000\000\000\000\00000"
/* offset=413361 */ "SPECIAL_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_SPECIAL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction required special handling before completion\000\000\000\000\000\00000"
/* offset=413553 */ "DISPATCH_STALL_FETCH_CPI\000CPI\000PM_DISP_STALL_FETCH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because fetch was being held, so there was nothing in the pipeline for this thread\000\000\000\000\000\00000"
/* offset=413779 */ "DISPATCH_STALL_HELD_HALT_CPI\000CPI\000PM_DISP_STALL_HELD_HALT_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of power management\000\000\000\000\000\00000"
/* offset=413982 */ "FLUSH_RATE\000Others\000PM_FLUSH / PM_RUN_INST_CMPL * 100\000\000Percentage of flushes per completed instruction\000\0001%\000\000\000\00000"
/* offset=414092 */ "BR_MPRED_FLUSH_RATE\000Others\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000\000Percentage of flushes due to a branch mispredict per completed instruction\000\0001%\000\000\000\00000"
/* offset=414244 */ "BRANCH_MISPREDICTION_RATE\000Others\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL\000\000Percentage of branch mispredictions per completed instruction\000\000\000\000\000\00000"
/* offset=414383 */ "L1_LD_MISS_RATIO\000Others\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000\000Percentage of finished loads that missed in the L1\000\0001%\000\000\000\00000"
/* offset=414503 */ "L1_LD_MISS_RATE\000Others\000PM_LD_MISS_L1 / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were loads that missed the L1\000\0001%\000\000\000\00000"
/* offset=414647 */ "L1_ST_MISS_RATE\000Others\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of completed instructions that were stores that missed the L1\000\0001%\000\000\000\00000"
/* offset=414792 */ "DTLB_MISS_RATE\000Others\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions when the DPTEG required for the load/store instruction in execution was missing from the TLB\000\0001%\000\000\000\00000"
/* offset=414992 */ "DISPATCH_PER_INST_CMPL\000General\000PM_INST_DISP / PM_RUN_INST_CMPL\000\000Average number of completed instructions dispatched per instruction completed\000\000\000\000\000\00000"
/* offset=415141 */ "L2_LD_MISS_RATE\000General\000PM_DATA_FROM_L2MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were a demand load that did not hit in the L1 or L2\000\0001%\000\000\000\00000"
/* offset=415314 */ "L1_INST_MISS_RATE\000Instruction_Misses\000PM_L1_ICACHE_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were demand fetches that missed the L1 icache\000\0001%\000\000\000\00000"
/* offset=415492 */ "L2_INST_MISS_RATE\000General\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000Percentage of completed instructions that were demand fetches that missed the L1 and L2 instruction cache\000\0001%\000\000\000\00000"
/* offset=415679 */ "L3_INST_MISS_RATE\000General\000PM_INST_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were demand fetches that reloaded from beyond the L3 icache\000\0001%\000\000\000\00000"
/* offset=415862 */ "IPC\000General\000PM_INST_CMPL / PM_CYC\000\000Average number of completed instructions per cycle\000\000\000\000\000\00000"
/* offset=415955 */ "CYCLES_PER_COMPLETED_INSTRUCTIONS_SET\000General\000PM_CYC / PM_1PLUS_PPC_CMPL\000\000Average number of cycles per completed instruction group\000\000\000\000\000\00000"
/* offset=416093 */ "CYCLES_ATLEAST_ONE_INST_DISPATCHED\000General\000PM_1PLUS_PPC_DISP / PM_RUN_CYC * 100\000\000Percentage of cycles when at least 1 instruction dispatched\000\0001%\000\000\000\00000"
/* offset=416243 */ "LOADS_PER_INST\000General\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000\000Average number of finished loads per completed instruction\000\000\000\000\000\00000"
/* offset=416365 */ "DL1_RELOAD_FROM_L2_RATE\000dL1_Reloads\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from the L2 per completed instruction\000\0001%\000\000\000\00000"
/* offset=416531 */ "DL1_RELOAD_FROM_L2_MISS_RATE\000dL1_Reloads\000PM_DATA_FROM_L2MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of demand loads that reloaded from beyond the L2 per completed instruction\000\0001%\000\000\000\00000"
/* offset=416713 */ "DL1_RELOAD_FROM_RL2L3_MOD_RATE\000dL1_Reloads\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using modified data from another core's L2 or L3 on a remote chip, per completed instruction\000\0001%\000\000\000\00000"
/* offset=416948 */ "DL1_RELOAD_FROM_RL2L3_SHR_RATE\000dL1_Reloads\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using shared data from another core's L2 or L3 on a remote chip, per completed instruction\000\0001%\000\000\000\00000"
/* offset=417181 */ "DL1_RELOAD_FROM_L3_RATE\000dL1_Reloads\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from the L3 per completed instruction\000\0001%\000\000\000\00000"
/* offset=417347 */ "DL1_RELOAD_FROM_L3_MEPF_RATE\000dL1_Reloads\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded with data brought into the L3 by prefetch per completed instruction\000\0001%\000\000\000\00000"
/* offset=417553 */ "DL1_RELOAD_FROM_L3_MISS_RATE\000dL1_Reloads\000PM_DATA_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of demand loads that reloaded from beyond the L3 per completed instruction\000\0001%\000\000\000\00000"
/* offset=417735 */ "DL1_RELOAD_FROM_DL2L3_MOD_RATE\000dL1_Reloads\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using modified data from another core's L2 or L3 on a distant chip, per completed instruction\000\0001%\000\000\000\00000"
/* offset=417971 */ "DL1_RELOAD_FROM_DL2L3_SHR_RATE\000dL1_Reloads\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using shared data from another core's L2 or L3 on a distant chip, per completed instruction\000\0001%\000\000\000\00000"
/* offset=418205 */ "DL1_RELOAD_FROM_LMEM_RATE\000dL1_Reloads\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from local memory per completed instruction\000\0001%\000\000\000\00000"
/* offset=418381 */ "DL1_RELOAD_FROM_RMEM_RATE\000dL1_Reloads\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from remote memory per completed instruction\000\0001%\000\000\000\00000"
/* offset=418558 */ "DL1_RELOAD_FROM_DMEM_RATE\000dL1_Reloads\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from distant memory per completed instruction\000\0001%\000\000\000\00000"
/* offset=418736 */ "MEM_LOCALITY\000Memory\000PM_DATA_FROM_LMEM * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_RMEM + PM_DATA_FROM_DMEM)\000\000Percentage of data reloads from local memory per data reloads from any memory\000\0001%\000\000\000\00000"
/* offset=418930 */ "LD_LMEM_PER_LD_RMEM\000Memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000\000Number of data reloads from local memory per data reloads from remote memory\000\000\000\000\000\00000"
/* offset=419080 */ "LD_LMEM_PER_LD_DMEM\000Memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000\000Number of data reloads from local memory per data reloads from distant memory\000\000\000\000\000\00000"
/* offset=419231 */ "LD_LMEM_PER_LD_MEM\000Memory\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000\000Number of data reloads from local memory per data reloads from distant and remote memory\000\000\000\000\000\00000"
/* offset=419414 */ "ITLB_MISS_RATE\000General\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of ITLB misses per completed run instruction\000\0001%\000\000\000\00000"
/* offset=419541 */ "LD_RMEM_PER_LD_DMEM\000Memory\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000\000Number of data reloads from remote memory per data reloads from distant memory\000\000\000\000\000\00000"
/* offset=419693 */ "DERAT_4K_MISS_RATE\000Translation\000PM_DERAT_MISS_4K / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 4k page size per completed instruction\000\0001%\000\000\000\00000"
/* offset=419847 */ "DERAT_64K_MISS_RATE\000Translation\000PM_DERAT_MISS_64K / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 64k page size per completed instruction\000\0001%\000\000\000\00000"
/* offset=420004 */ "INST_FROM_L2\000Instruction_Stats\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from the L2\000\0001%\000\000\000\00000"
/* offset=420146 */ "INST_FROM_L3\000Instruction_Stats\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from the L3\000\0001%\000\000\000\00000"
/* offset=420288 */ "INST_FROM_LMEM\000Instruction_Stats\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from local memory\000\0001%\000\000\000\00000"
/* offset=420440 */ "INST_FROM_RMEM\000Instruction_Stats\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from remote memory\000\0001%\000\000\000\00000"
/* offset=420593 */ "INST_FROM_DMEM\000Instruction_Stats\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from distant memory\000\0001%\000\000\000\00000"
/* offset=420747 */ "INST_FROM_L2_RATE\000Instruction_Misses\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from the L2 per completed instruction\000\0001%\000\000\000\00000"
/* offset=420902 */ "INST_FROM_L3_RATE\000Instruction_Misses\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from the L3 per completed instruction\000\0001%\000\000\000\00000"
/* offset=421057 */ "INST_FROM_LMEM_RATE\000Instruction_Misses\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from local memory per completed instruction\000\0001%\000\000\000\00000"
/* offset=421222 */ "INST_FROM_RMEM_RATE\000Instruction_Misses\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from remote memory per completed instruction\000\0001%\000\000\000\00000"
/* offset=421388 */ "INST_FROM_DMEM_RATE\000Instruction_Misses\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from distant memory per completed instruction\000\0001%\000\000\000\00000"
/* offset=421555 */ "RUN_CPI\000General\000PM_RUN_CYC / PM_RUN_INST_CMPL\000\000Average number of run cycles per completed instruction\000\000\000\000\000\00000"
/* offset=421664 */ "DERAT_MISS_RATE\000Translation\000PM_DERAT_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses per completed instruction\000\0001%\000\000\000\00000"
/* offset=421794 */ "RUN_IPC\000General\000PM_RUN_INST_CMPL / PM_RUN_CYC\000\000Average number of completed instructions per run cycle\000\000\000\000\000\00000"
/* offset=421903 */ "AVERAGE_COMPLETED_INSTRUCTION_SET_SIZE\000General\000PM_RUN_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Average number of completed instructions per instruction group\000\000\000\000\000\00000"
/* offset=422058 */ "INST_FIN_PER_CMPL\000General\000PM_INST_FIN / PM_RUN_INST_CMPL\000\000Average number of finished instructions per completed instructions\000\000\000\000\000\00000"
/* offset=422190 */ "EXEC_STALL_UNKOWN_CPI\000General\000PM_EXEC_STALL_UNKNOWN / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTF instruction is completing and the finish was overlooked\000\000\000\000\000\00000"
/* offset=422379 */ "TAKEN_BRANCHES\000General\000PM_BR_TAKEN_CMPL / PM_BR_FIN * 100\000\000Percentage of finished branches that were taken\000\0001%\000\000\000\00000"
/* offset=422495 */ "L3_LD_MISS_RATE\000General\000PM_DATA_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were a demand load that did not hit in the L1, L2, or the L3\000\0001%\000\000\000\00000"
/* offset=422677 */ "BRANCHES_PER_INST\000General\000PM_BR_FIN / PM_RUN_INST_CMPL\000\000Average number of finished branches per completed instruction\000\000\000\000\000\00000"
/* offset=422802 */ "LSU_PER_INST\000General\000PM_LSU_FIN / PM_RUN_INST_CMPL\000\000Average number of instructions finished in the LSU per completed instruction\000\000\000\000\000\00000"
/* offset=422938 */ "VSU_PER_INST\000General\000PM_VSU_FIN / PM_RUN_INST_CMPL\000\000Average number of instructions finished in the VSU per completed instruction\000\000\000\000\000\00000"
/* offset=423074 */ "TLBIE_PER_INST\000General\000PM_TLBIE_FIN / PM_RUN_INST_CMPL\000\000Average number of TLBIE instructions finished in the LSU per completed instruction\000\000\000\000\000\00000"
/* offset=423220 */ "STCX_PER_INST\000General\000PM_STCX_FIN / PM_RUN_INST_CMPL\000\000Average number of STCX instructions finshed per completed instruction\000\000\000\000\000\00000"
/* offset=423351 */ "LARX_PER_INST\000General\000PM_LARX_FIN / PM_RUN_INST_CMPL\000\000Average number of LARX instructions finshed per completed instruction\000\000\000\000\000\00000"
/* offset=423482 */ "PTESYNC_PER_INST\000General\000PM_PTESYNC_FIN / PM_RUN_INST_CMPL\000\000Average number of PTESYNC instructions finshed per completed instruction\000\000\000\000\000\00000"
/* offset=423622 */ "FX_PER_INST\000General\000PM_FX_LSU_FIN / PM_RUN_INST_CMPL\000\000Average number of simple fixed-point instructions finshed in the store unit per completed instruction\000\000\000\000\000\00000"
/* offset=423785 */ "DL1_MISS_RELOADS\000General\000PM_LD_DEMAND_MISS_L1 / PM_LD_MISS_L1 * 100\000\000Percentage of demand load misses that reloaded the L1 cache\000\0001%\000\000\000\00000"
/* offset=423923 */ "DL1_RELOAD_FROM_L2\000dL1_Reloads\000PM_DATA_FROM_L2 * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local L2\000\0001%\000\000\000\00000"
/* offset=424074 */ "DL1_RELOAD_FROM_L2_MISS\000dL1_Reloads\000PM_DATA_FROM_L2MISS / PM_LD_DEMAND_MISS_L1 * 100\000\000Percentage of demand load misses that reloaded from beyond the local L2\000\0001%\000\000\000\00000"
/* offset=424241 */ "DL1_RELOAD_FROM_L3\000dL1_Reloads\000PM_DATA_FROM_L3 * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local L3\000\0001%\000\000\000\00000"
/* offset=424392 */ "DL1_RELOAD_FROM_L3_MISS\000dL1_Reloads\000PM_DATA_FROM_L3MISS / PM_LD_DEMAND_MISS_L1 * 100\000\000Percentage of demand load misses that reloaded from beyond the local L3\000\0001%\000\000\000\00000"
/* offset=424559 */ "DL1_RELOAD_FROM_L3_MEPF\000dL1_Reloads\000PM_DATA_FROM_L3_MEPF * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local L3 with modified data\000\0001%\000\000\000\00000"
/* offset=424739 */ "DL1_RELOAD_FROM_L21_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L21_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same regent with modified data\000\0001%\000\000\000\00000"
/* offset=424957 */ "DL1_RELOAD_FROM_L21_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L21_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same regent with shared data\000\0001%\000\000\000\00000"
/* offset=425173 */ "DL1_RELOAD_FROM_L21_NON_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L21_NON_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same chip in a different regent with modified data\000\0001%\000\000\000\00000"
/* offset=425419 */ "DL1_RELOAD_FROM_L21_NON_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L21_NON_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same chip in a different regent with shared data\000\0001%\000\000\000\00000"
/* offset=425663 */ "DL1_RELOAD_FROM_L31_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L31_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same regent with modified data\000\0001%\000\000\000\00000"
/* offset=425881 */ "DL1_RELOAD_FROM_L31_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L31_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same regent with shared data\000\0001%\000\000\000\00000"
/* offset=426097 */ "DL1_RELOAD_FROM_L31_NON_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L31_NON_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same chip in a different regent with modified data\000\0001%\000\000\000\00000"
/* offset=426343 */ "DL1_RELOAD_FROM_L31_NON_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L31_NON_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same chip in a different regent with shared data\000\0001%\000\000\000\00000"
/* offset=426587 */ "DL1_RELOAD_FROM_RL2_MOD\000dL1_Reloads\000PM_DATA_FROM_RL2_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a remote chip with modified data\000\0001%\000\000\000\00000"
/* offset=426789 */ "DL1_RELOAD_FROM_RL2_SHR\000dL1_Reloads\000PM_DATA_FROM_RL2_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a remote chip with shared data\000\0001%\000\000\000\00000"
/* offset=426989 */ "DL1_RELOAD_FROM_RL3_MOD\000dL1_Reloads\000PM_DATA_FROM_RL3_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a remote chip with modified data\000\0001%\000\000\000\00000"
/* offset=427191 */ "DL1_RELOAD_FROM_RL3_SHR\000dL1_Reloads\000PM_DATA_FROM_RL3_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a remote chip with shared data\000\0001%\000\000\000\00000"
/* offset=427391 */ "DL1_RELOAD_FROM_DL2_MOD\000dL1_Reloads\000PM_DATA_FROM_DL2_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a distant chip with modified data\000\0001%\000\000\000\00000"
/* offset=427594 */ "DL1_RELOAD_FROM_DL2_SHR\000dL1_Reloads\000PM_DATA_FROM_DL2_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a distant chip with shared data\000\0001%\000\000\000\00000"
/* offset=427795 */ "DL1_RELOAD_FROM_DL3_MOD\000dL1_Reloads\000PM_DATA_FROM_DL3_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a distant chip with modified data\000\0001%\000\000\000\00000"
/* offset=427998 */ "DL1_RELOAD_FROM_DL3_SHR\000dL1_Reloads\000PM_DATA_FROM_DL3_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a distant chip with shared data\000\0001%\000\000\000\00000"
/* offset=428199 */ "DL1_RELOAD_FROM_LMEM\000dL1_Reloads\000PM_DATA_FROM_LMEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local chip's memory\000\0001%\000\000\000\00000"
/* offset=428365 */ "DL1_RELOAD_FROM_L_OC_CACHE\000dL1_Reloads\000PM_DATA_FROM_L_OC_CACHE * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local chip's OpenCAPI Cache\000\0001%\000\000\000\00000"
/* offset=428551 */ "DL1_RELOAD_FROM_L_OC_MEM\000dL1_Reloads\000PM_DATA_FROM_L_OC_MEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local chip's OpenCAPI memory\000\0001%\000\000\000\00000"
/* offset=428734 */ "DL1_RELOAD_FROM_RMEM\000dL1_Reloads\000PM_DATA_FROM_RMEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a remote chip's memory\000\0001%\000\000\000\00000"
/* offset=428899 */ "DL1_RELOAD_FROM_R_OC_CACHE\000dL1_Reloads\000PM_DATA_FROM_R_OC_CACHE * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a remote chip's OpenCAPI Cache\000\0001%\000\000\000\00000"
/* offset=429084 */ "DL1_RELOAD_FROM_R_OC_MEM\000dL1_Reloads\000PM_DATA_FROM_R_OC_MEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a remote chip's OpenCAPI memory\000\0001%\000\000\000\00000"
/* offset=429266 */ "DL1_RELOAD_FROM_DMEM\000dL1_Reloads\000PM_DATA_FROM_DMEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a distant chip's memory\000\0001%\000\000\000\00000"
/* offset=429432 */ "DL1_RELOAD_FROM_D_OC_CACHE\000dL1_Reloads\000PM_DATA_FROM_D_OC_CACHE * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a distant chip's OpenCAPI Cache\000\0001%\000\000\000\00000"
/* offset=429618 */ "DL1_RELOAD_FROM_D_OC_MEM\000dL1_Reloads\000PM_DATA_FROM_D_OC_MEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a distant chip's OpenCAPI memory\000\0001%\000\000\000\00000"
/* offset=429801 */ "DCACHE_MISS_CPI\000General\000DMISS_L3MISS_STALL_CPI / RUN_CPI * 100\000\000Percentage of cycles stalled due to the NTC instruction waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\0001%\000\000\000\00000"
/* offset=430012 */ "DERAT_2M_MISS_RATE\000Translation\000PM_DERAT_MISS_2M / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 2M page size per completed instruction\000\0001%\000\000\000\00000"
/* offset=430166 */ "DERAT_16M_MISS_RATE\000Translation\000PM_DERAT_MISS_16M / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 16M page size per completed instruction\000\0001%\000\000\000\00000"
/* offset=430323 */ "DERAT_1G_MISS_RATE\000Translation\000PM_DERAT_MISS_1G * 100 / PM_RUN_INST_CMPL\000\000Percentage of DERAT misses with 1G page size per completed run instruction\000\0001%\000\000\000\00000"
/* offset=430481 */ "DERAT_4K_MISS_RATIO\000Translation\000PM_DERAT_MISS_4K / PM_DERAT_MISS\000\000DERAT miss ratio for 4K page size\000\000\000\000\000\00000"
/* offset=430588 */ "DERAT_2M_MISS_RATIO\000Translation\000PM_DERAT_MISS_2M / PM_DERAT_MISS\000\000DERAT miss ratio for 2M page size\000\000\000\000\000\00000"
/* offset=430695 */ "DERAT_16M_MISS_RATIO\000Translation\000PM_DERAT_MISS_16M / PM_DERAT_MISS\000\000DERAT miss ratio for 16M page size\000\000\000\000\000\00000"
/* offset=430805 */ "DERAT_1G_MISS_RATIO\000Translation\000PM_DERAT_MISS_1G / PM_DERAT_MISS\000\000DERAT miss ratio for 1G page size\000\000\000\000\000\00000"
/* offset=430912 */ "DERAT_64K_MISS_RATIO\000Translation\000PM_DERAT_MISS_64K / PM_DERAT_MISS\000\000DERAT miss ratio for 64K page size\000\000\000\000\000\00000"
/* offset=431022 */ "DERAT_MISS_RELOAD\000Translation\000PM_DTLB_MISS / PM_DERAT_MISS * 100\000\000Percentage of DERAT misses that resulted in TLB reloads\000\0001%\000\000\000\00000"
/* offset=431153 */ "INST_FROM_L2_MISS\000Instruction_Misses\000PM_INST_FROM_L2MISS * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from beyond the local L2\000\0001%\000\000\000\00000"
/* offset=431318 */ "INST_FROM_L3_MISS\000Instruction_Misses\000PM_INST_FROM_L3MISS / PM_L1_ICACHE_MISS * 100\000\000Percentage of icache misses that were reloaded from beyond the local L3\000\0001%\000\000\000\00000"
/* offset=431483 */ "INST_FROM_L2_MISS_RATE\000Instruction_Misses\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from beyond the L2 per completed instruction\000\0001%\000\000\000\00000"
/* offset=431654 */ "INST_FROM_L3_MISS_RATE\000Instruction_Misses\000PM_INST_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of icache reloads from the beyond the L3 per completed instruction\000\0001%\000\000\000\00000"
/* offset=431829 */ "VEC_GROUP_PUMP_RETRY_RATIO_P01\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=431958 */ "VEC_GROUP_PUMP_RETRY_RATIO_P23\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=432087 */ "LOCAL_NODE_PUMP_RETRY_RATIO_P01\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010"
/* offset=432213 */ "LOCAL_NODE_PUMP_RETRY_RATIO_P23\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010"
/* offset=432339 */ "GROUP_PUMP_RETRY_RATIO_P01\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010"
/* offset=432464 */ "GROUP_PUMP_RETRY_RATIO_P23\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010"
/* offset=432589 */ "TOTAL_GROUP_PUMPS_P01\000\000hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=432690 */ "TOTAL_GROUP_PUMPS_P23\000\000hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=432791 */ "TOTAL_GROUP_PUMPS_RETRIES_P01\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=432904 */ "TOTAL_GROUP_PUMPS_RETRIES_P23\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=433017 */ "REMOTE_NODE_PUMPS_RETRIES_RATIO_P01\000\000hv_24x7@PM_PB_RTY_RNS_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=433153 */ "REMOTE_NODE_PUMPS_RETRIES_RATIO_P23\000\000hv_24x7@PM_PB_RTY_RNS_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=433289 */ "TOTAL_VECTOR_GROUP_PUMPS_P01\000\000hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=433394 */ "TOTAL_VECTOR_GROUP_PUMPS_P23\000\000hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=433499 */ "TOTAL_LOCAL_NODE_PUMPS_P01\000\000hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=433603 */ "TOTAL_LOCAL_NODE_PUMPS_P23\000\000hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=433707 */ "TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P01\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=433824 */ "TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P23\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=433941 */ "TOTAL_LOCAL_NODE_PUMPS_RETRIES_P01\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=434057 */ "TOTAL_LOCAL_NODE_PUMPS_RETRIES_P23\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=434173 */ "TOTAL_REMOTE_NODE_PUMPS_P01\000\000hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=434278 */ "TOTAL_REMOTE_NODE_PUMPS_P23\000\000hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=434383 */ "TOTAL_NEAR_NODE_PUMPS_P01\000\000hv_24x7@PM_PB_NNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=434486 */ "TOTAL_NEAR_NODE_PUMPS_P23\000\000hv_24x7@PM_PB_NNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010"
/* offset=434589 */ "TOTAL_INT_PB_BW\000\000hv_24x7@PM_PB_INT_DATA_XFER\\,chip\\=?@\000\000\000\0002.09MB\000\000\000\00010"
/* offset=434659 */ "XLINK0_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=434914 */ "XLINK1_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=435169 */ "XLINK2_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=435424 */ "XLINK3_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=435679 */ "XLINK4_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=435934 */ "XLINK5_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=436189 */ "XLINK6_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=436444 */ "XLINK7_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=436699 */ "XLINK0_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=436945 */ "XLINK1_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=437191 */ "XLINK2_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=437437 */ "XLINK3_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=437683 */ "XLINK4_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=437929 */ "XLINK5_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=438175 */ "XLINK6_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=438421 */ "XLINK7_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=438667 */ "ALINK0_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=438922 */ "ALINK1_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=439177 */ "ALINK2_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=439432 */ "ALINK3_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=439687 */ "ALINK4_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=439942 */ "ALINK5_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=440197 */ "ALINK6_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=440452 */ "ALINK7_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010"
/* offset=440707 */ "ALINK0_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=440953 */ "ALINK1_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=441199 */ "ALINK2_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=441445 */ "ALINK3_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=441691 */ "ALINK4_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=441937 */ "ALINK5_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=442183 */ "ALINK6_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=442429 */ "ALINK7_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010"
/* offset=442675 */ "TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI1\000\000hv_24x7@PM_PCI1_32B_INOUT\\,chip\\=?@\000\000\000\0003.28e-2MB\000\000\000\00010"
/* offset=442776 */ "TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI0\000\000hv_24x7@PM_PCI0_32B_INOUT\\,chip\\=?@\000\000\000\0003.28e-2MB\000\000\000\00010"
/* offset=442877 */ "TOTAL_MCS_READ_BW_MC0_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010"
/* offset=442981 */ "TOTAL_MCS_READ_BW_MC1_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010"
/* offset=443085 */ "TOTAL_MCS_READ_BW_MC2_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010"
/* offset=443189 */ "TOTAL_MCS_READ_BW_MC3_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010"
/* offset=443293 */ "TOTAL_MCS_WRITE_BW_MC0_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010"
/* offset=443396 */ "TOTAL_MCS_WRITE_BW_MC1_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010"
/* offset=443499 */ "TOTAL_MCS_WRITE_BW_MC2_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010"
/* offset=443602 */ "TOTAL_MCS_WRITE_BW_MC3_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010"
/* offset=443705 */ "Memory_RD_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010"
/* offset=443981 */ "Memory_WR_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010"
/* offset=444252 */ "PowerBUS_Frequency\000\000hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0002.56e-7GHz\000\000\000\00010"
/* offset=444320 */ "bc_8_branch_ratio_percent\000branch_prediction\000PM_BR_BC_8_CONV / PM_BRU_FIN * 100\000\000% of finished branches that were treated as BC+8\000\000\000\000\000\00000"
/* offset=444456 */ "bc_8_not_converted_branch_ratio_percent\000branch_prediction\000PM_BR_BC_8 / PM_BRU_FIN * 100\000\000% of finished branches that were pairable but not treated as BC+8\000\000\000\000\000\00000"
/* offset=444618 */ "br_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CMPL / (PM_BR_PRED_BR0 + PM_BR_PRED_BR1) * 100\000\000Percent of mispredicted branches out of all predicted (correctly and incorrectly) branches that completed\000\000\000\000\000\00000"
/* offset=444834 */ "branch_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL * 100\000\000% of Branch miss predictions per instruction\000\000\000\000\000\00000"
/* offset=444978 */ "ccache_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_CCACHE / PM_RUN_INST_CMPL * 100\000\000Count cache branch misprediction per instruction\000\000\000\000\000\00000"
/* offset=445128 */ "ccache_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CCACHE / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1) * 100\000\000Percent of count catch mispredictions out of all completed branches that required count cache predictionn\000\000\000\000\000\00000"
/* offset=445364 */ "cr_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_CR / PM_RUN_INST_CMPL * 100\000\000CR MisPredictions per Instruction\000\000\000\000\000\00000"
/* offset=445491 */ "lstack_mispredict_rate_percent\000branch_prediction\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / PM_RUN_INST_CMPL * 100\000\000Link stack branch misprediction\000\000\000\000\000\00000"
/* offset=445643 */ "lstack_misprediction_percent\000branch_prediction\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / (PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000\000Percent of link stack mispredictions out of all completed branches that required link stack prediction\000\000\000\000\000\00000"
/* offset=445895 */ "ta_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_TA / PM_RUN_INST_CMPL * 100\000\000TA MisPredictions per Instruction\000\000\000\000\000\00000"
/* offset=446022 */ "ta_misprediction_percent\000branch_prediction\000PM_BR_MPRED_TA / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1 + PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000\000Percent of target address mispredictions out of all completed branches that required address prediction\000\000\000\000\000\00000"
/* offset=446296 */ "taken_branches_percent\000branch_prediction\000PM_BR_TAKEN_CMPL * 100 / PM_BR_CMPL\000\000Percent of branches completed that were taken\000\000\000\000\000\00000"
/* offset=446427 */ "any_pump_mpred_percent\000bus_stats\000PM_PUMP_MPRED * 100 / (PM_PUMP_CPRED + PM_PUMP_MPRED)\000\000Percent of chip+group+sys pumps that were incorrectly predicted\000\000\000\000\000\00000"
/* offset=446586 */ "chip_pump_cpred_percent\000bus_stats\000PM_CHIP_PUMP_CPRED * 100 / PM_L2_CHIP_PUMP\000\000Percent of chip pumps that were correctly predicted as chip pumps the first time\000\000\000\000\000\00000"
/* offset=446752 */ "group_pump_cpred_percent\000bus_stats\000PM_GRP_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000\000Percent of group pumps that were correctly predicted as group pumps the first time\000\000\000\000\000\00000"
/* offset=446921 */ "sys_pump_cpred_percent\000bus_stats\000PM_SYS_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000\000Percent of system pumps that were correctly predicted as group pumps the first time\000\000\000\000\000\00000"
/* offset=447089 */ "bru_cru_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_BRU_CRU / PM_RUN_INST_CMPL\000\000Cycles stalled due to CRU or BRU operations\000\000\000\000\000\00000"
/* offset=447215 */ "bru_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000\000Cycles stalled due to ISU Branch Operations\000\000\000\000\000\00000"
/* offset=447333 */ "completion_cpi\000cpi_breakdown\000PM_GRP_CMPL / PM_RUN_INST_CMPL\000\000Cycles in which a Group Completed\000\000\000\000\000\00000"
/* offset=447435 */ "coq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_COQ_FULL / PM_RUN_INST_CMPL\000\000Cycles stalled by CO queue full\000\000\000\000\000\00000"
/* offset=447551 */ "cru_stall_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_BRU_CRU - PM_CMPLU_STALL_BRU) / PM_RUN_INST_CMPL\000\000Cycles stalled due to CRU Operations\000\000\000\000\000\00000"
/* offset=447689 */ "flush_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FLUSH / PM_RUN_INST_CMPL\000\000Cycles stalled by flushes\000\000\000\000\000\00000"
/* offset=447793 */ "fxu_multi_cyc_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000\000Cycles stalled by FXU Multi-Cycle Instructions\000\000\000\000\000\00000"
/* offset=447921 */ "fxu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000\000Cycles stalled by FXU\000\000\000\000\000\00000"
/* offset=448017 */ "fxu_stall_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000\000Other cycles stalled by FXU\000\000\000\000\000\00000"
/* offset=448168 */ "gct_empty_br_mpred_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000\000Cycles GCT empty due to Branch Mispredicts\000\000\000\000\000\00000"
/* offset=448298 */ "gct_empty_br_mpred_ic_miss_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000\000Cycles GCT empty due to Branch Mispredicts and Icache Misses\000\000\000\000\000\00000"
/* offset=448461 */ "gct_empty_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL\000\000GCT empty cycles\000\000\000\000\000\00000"
/* offset=448551 */ "gct_empty_disp_held_cpi\000cpi_breakdown\000(PM_GCT_NOSLOT_DISP_HELD_MAP + PM_GCT_NOSLOT_DISP_HELD_SRQ + PM_GCT_NOSLOT_DISP_HELD_ISSQ + PM_GCT_NOSLOT_DISP_HELD_OTHER) / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held\000\000\000\000\000\00000"
/* offset=448780 */ "gct_empty_disp_held_issq_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to issue queue\000\000\000\000\000\00000"
/* offset=448939 */ "gct_empty_disp_held_map_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_MAP / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to maps\000\000\000\000\000\00000"
/* offset=449089 */ "gct_empty_disp_held_other_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_OTHER / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to syncs and other effects\000\000\000\000\000\00000"
/* offset=449262 */ "gct_empty_disp_held_srq_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_SRQ / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to SRQ\000\000\000\000\000\00000"
/* offset=449411 */ "gct_empty_ic_miss_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by GCT empty due to Icache misses\000\000\000\000\000\00000"
/* offset=449545 */ "gct_empty_ic_miss_l2l3_cpi\000cpi_breakdown\000(PM_GCT_NOSLOT_IC_MISS - PM_GCT_NOSLOT_IC_L3MISS) / PM_RUN_INST_CMPL\000\000Cycles stalled by GCT empty due to Icache misses that resolve in the local L2 or L3\000\000\000\000\000\00000"
/* offset=449747 */ "gct_empty_ic_miss_l3miss_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by GCT empty due to Icache misses that resolve off-chip\000\000\000\000\000\00000"
/* offset=449912 */ "gct_empty_other_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL - (PM_GCT_NOSLOT_DISP_HELD_MAP / PM_RUN_INST_CMPL + PM_GCT_NOSLOT_DISP_HELD_SRQ / PM_RUN_INST_CMPL + PM_GCT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL + PM_GCT_NOSLOT_DISP_HELD_OTHER / PM_RUN_INST_CMPL)\000\000Other GCT empty cycles\000\000\000\000\000\00000"
/* offset=450353 */ "hwsync_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_HWSYNC / PM_RUN_INST_CMPL\000\000Cycles stalled by heavyweight syncs\000\000\000\000\000\00000"
/* offset=450469 */ "lsu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU\000\000\000\000\000\00000"
/* offset=450565 */ "lsu_stall_dcache_miss_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses\000\000\000\000\000\00000"
/* offset=450692 */ "lsu_stall_dcache_miss_distant_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_DMISS_L3MISS - PM_CMPLU_STALL_DMISS_LMEM - PM_CMPLU_STALL_DMISS_L21_L31 - PM_CMPLU_STALL_DMISS_REMOTE) / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in distant interventions and memory\000\000\000\000\000\00000"
/* offset=450969 */ "lsu_stall_dcache_miss_l21l31_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in remote or distant caches\000\000\000\000\000\00000"
/* offset=451147 */ "lsu_stall_dcache_miss_l2l3_conflict_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was a conflict\000\000\000\000\000\00000"
/* offset=451360 */ "lsu_stall_dcache_miss_l2l3_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3\000\000\000\000\000\00000"
/* offset=451527 */ "lsu_stall_dcache_miss_l2l3_noconflict_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_DMISS_L2L3 - PM_CMPLU_STALL_DMISS_L2L3_CONFLICT) / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was no conflict\000\000\000\000\000\00000"
/* offset=451773 */ "lsu_stall_dcache_miss_l3miss_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in other core's caches or memory\000\000\000\000\000\00000"
/* offset=451955 */ "lsu_stall_dcache_miss_lmem_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in local memory or local L4\000\000\000\000\000\00000"
/* offset=452128 */ "lsu_stall_dcache_miss_remote_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in remote interventions and memory\000\000\000\000\000\00000"
/* offset=452312 */ "lsu_stall_erat_miss_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by ERAT Translation rejects\000\000\000\000\000\00000"
/* offset=452445 */ "lsu_stall_ld_fin_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU load finishes\000\000\000\000\000\00000"
/* offset=452570 */ "lsu_stall_lhs_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJECT_LHS / PM_RUN_INST_CMPL\000\000Cycles stalled by LHS rejects\000\000\000\000\000\00000"
/* offset=452685 */ "lsu_stall_lmq_full_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJ_LMQ_FULL / PM_RUN_INST_CMPL\000\000Cycles stalled by LMQ Full rejects\000\000\000\000\000\00000"
/* offset=452812 */ "lsu_stall_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL - PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL - PM_CMPLU_STALL_STORE / PM_RUN_INST_CMPL - PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL - PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000\000Cycles stalled by Other LSU Operations\000\000\000\000\000\00000"
/* offset=453155 */ "lsu_stall_reject_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU Rejects\000\000\000\000\000\00000"
/* offset=453269 */ "lsu_stall_reject_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL - PM_CMPLU_STALL_REJECT_LHS / PM_RUN_INST_CMPL - PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL - PM_CMPLU_STALL_REJ_LMQ_FULL / PM_RUN_INST_CMPL\000\000Cycles stalled by Other LSU Rejects\000\000\000\000\000\00000"
/* offset=453537 */ "lsu_stall_st_fwd_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU store forwarding\000\000\000\000\000\00000"
/* offset=453660 */ "lsu_stall_store_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU Stores\000\000\000\000\000\00000"
/* offset=453771 */ "lwsync_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LWSYNC / PM_RUN_INST_CMPL\000\000Cycles stalled by lightweight syncs\000\000\000\000\000\00000"
/* offset=453887 */ "mem_ecc_delay_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_MEM_ECC_DELAY / PM_RUN_INST_CMPL\000\000\000\000\000\000\000\00000"
/* offset=453982 */ "no_ntf_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NO_NTF / PM_RUN_INST_CMPL\000\000Cycles stalled by nops (nothing next to finish)\000\000\000\000\000\00000"
/* offset=454110 */ "ntcg_all_fin_cpi\000cpi_breakdown\000PM_NTCG_ALL_FIN / PM_RUN_INST_CMPL\000\000\000\000\000\000\000\00000"
/* offset=454185 */ "ntcg_flush_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NTCG_FLUSH / PM_RUN_INST_CMPL\000\000\000\000\000\000\000\00000"
/* offset=454268 */ "other_block_stall_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_THRD - PM_CMPLU_STALL_LWSYNC - PM_CMPLU_STALL_HWSYNC - PM_CMPLU_STALL_MEM_ECC_DELAY - PM_CMPLU_STALL_FLUSH - PM_CMPLU_STALL_COQ_FULL) / PM_RUN_INST_CMPL\000\000Other thread block stall cycles\000\000\000\000\000\00000"
/* offset=454513 */ "other_cpi\000cpi_breakdown\000PM_RUN_CYC / PM_RUN_INST_CMPL - PM_CMPLU_STALL / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL - PM_NTCG_ALL_FIN / PM_RUN_INST_CMPL - PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL - PM_GRP_CMPL / PM_RUN_INST_CMPL\000\000Cycles unaccounted for\000\000\000\000\000\00000"
/* offset=454784 */ "other_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL / PM_RUN_INST_CMPL - PM_CMPLU_STALL_BRU_CRU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_VSU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_NTCG_FLUSH / PM_RUN_INST_CMPL - PM_CMPLU_STALL_NO_NTF / PM_RUN_INST_CMPL\000\000Stall cycles unaccounted for\000\000\000\000\000\00000"
/* offset=455139 */ "run_cpi\000cpi_breakdown\000PM_RUN_CYC / PM_RUN_INST_CMPL\000\000Run cycles per run instruction\000\000\000\000\000\00000"
/* offset=455230 */ "stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000\000Completion Stall Cycles\000\000\000\000\000\00000"
/* offset=455320 */ "thread_block_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000\000Cycles a thread was blocked\000\000\000\000\000\00000"
/* offset=455432 */ "vsu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VSU / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU\000\000\000\000\000\00000"
/* offset=455528 */ "vsu_stall_other_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_VSU - PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_SCALAR) / PM_RUN_INST_CMPL\000\000Cycles stalled by other VSU Operations\000\000\000\000\000\00000"
/* offset=455697 */ "vsu_stall_scalar_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SCALAR / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Scalar Operations\000\000\000\000\000\00000"
/* offset=455821 */ "vsu_stall_scalar_long_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SCALAR_LONG / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Scalar Long Operations\000\000\000\000\000\00000"
/* offset=455960 */ "vsu_stall_scalar_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SCALAR / PM_RUN_INST_CMPL - PM_CMPLU_STALL_SCALAR_LONG / PM_RUN_INST_CMPL\000\000Cycles stalled by Other VSU Scalar Operations\000\000\000\000\000\00000"
/* offset=456144 */ "vsu_stall_vector_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VECTOR / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Vector Operations\000\000\000\000\000\00000"
/* offset=456268 */ "vsu_stall_vector_long_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VECTOR_LONG / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Vector Long Operations\000\000\000\000\000\00000"
/* offset=456407 */ "vsu_stall_vector_other_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_VECTOR_LONG) / PM_RUN_INST_CMPL\000\000Cycles stalled by other VSU Vector Operations\000\000\000\000\000\00000"
/* offset=456574 */ "dl1_reload_from_dl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000\00000"
/* offset=456757 */ "dl1_reload_from_dl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000\00000"
/* offset=456938 */ "dl1_reload_from_dl4_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000\00000"
/* offset=457092 */ "dl1_reload_from_dmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant Memory per Inst\000\000\000\000\000\00000"
/* offset=457252 */ "dl1_reload_from_l21_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000\00000"
/* offset=457426 */ "dl1_reload_from_l21_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000\00000"
/* offset=457600 */ "dl1_reload_from_l2_lhs_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 load hits per instruction where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000\00000"
/* offset=457830 */ "dl1_reload_from_l2_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L2 per Inst\000\000\000\000\000\00000"
/* offset=457983 */ "dl1_reload_from_l2_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 load hits per instruction where the L2 did not experience a conflict\000\000\000\000\000\00000"
/* offset=458203 */ "dl1_reload_from_l2_other_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 load hits per instruction where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000\00000"
/* offset=458456 */ "dl1_reload_from_l2_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L2 per Inst\000\000\000\000\000\00000"
/* offset=458600 */ "dl1_reload_from_l31_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3 M state, other core per Inst\000\000\000\000\000\00000"
/* offset=458782 */ "dl1_reload_from_l31_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3 S tate, other core per Inst\000\000\000\000\000\00000"
/* offset=458963 */ "dl1_reload_from_l3_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_RUN_INST_CMPL\000\000Percentage of L3 load hits per instruction where the load collided with a pending prefetch\000\000\000\000\000\00000"
/* offset=459187 */ "dl1_reload_from_l3_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L3 per Inst\000\000\000\000\000\00000"
/* offset=459340 */ "dl1_reload_from_l3_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000\000Percentage of L3 load hits per instruction where the L3 did not experience a conflict\000\000\000\000\000\00000"
/* offset=459560 */ "dl1_reload_from_l3_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from L3 per Inst\000\000\000\000\000\00000"
/* offset=459704 */ "dl1_reload_from_ll4_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000\00000"
/* offset=459856 */ "dl1_reload_from_lmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Local Memory per Inst\000\000\000\000\000\00000"
/* offset=460014 */ "dl1_reload_from_rl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000"
/* offset=460192 */ "dl1_reload_from_rl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000"
/* offset=460370 */ "dl1_reload_from_rl4_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000\00000"
/* offset=460527 */ "dl1_reload_from_rmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000\00000"
/* offset=460686 */ "l1_ld_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_LD_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L1 demand load misses per run instruction\000\000\000\000\000\00000"
/* offset=460842 */ "dl1_miss_reloads_percent\000dl1_reloads_percent_per_ref\000PM_L1_DCACHE_RELOAD_VALID * 100 / PM_LD_MISS_L1\000\000% of DL1 misses that result in a cache reload\000\000\000\000\000\00000"
/* offset=460997 */ "dl1_reload_from_dl2l3_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000"
/* offset=461178 */ "dl1_reload_from_dl2l3_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000"
/* offset=461357 */ "dl1_reload_from_dl4_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000\00000"
/* offset=461509 */ "dl1_reload_from_dmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant Memory\000\000\000\000\000\00000"
/* offset=461667 */ "dl1_reload_from_l21_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L21_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L2, other core\000\000\000\000\000\00000"
/* offset=461835 */ "dl1_reload_from_l21_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L21_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L2, other core\000\000\000\000\000\00000"
/* offset=462003 */ "dl1_reload_from_l2_lhs_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L2 with a Load-Hit-Store conflict\000\000\000\000\000\00000"
/* offset=462207 */ "dl1_reload_from_l2_no_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L2 with no conflicts\000\000\000\000\000\00000"
/* offset=462396 */ "dl1_reload_from_l2_other_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L2 with some conflict other than Load-Hit-Store\000\000\000\000\000\00000"
/* offset=462623 */ "dl1_reload_from_l2_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from L2\000\000\000\000\000\00000"
/* offset=462761 */ "dl1_reload_from_l31_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L31_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L3, other core\000\000\000\000\000\00000"
/* offset=462929 */ "dl1_reload_from_l31_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L31_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L3, other core\000\000\000\000\000\00000"
/* offset=463097 */ "dl1_reload_from_l3_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L3 where the load collided with a pending prefetch\000\000\000\000\000\00000"
/* offset=463315 */ "dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000\000Percentage of L3 load hits per instruction where the line was brought into the L3 by a prefetch operation\000\000\000\000\000\00000"
/* offset=463540 */ "dl1_reload_from_l3_no_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L3 without conflicts\000\000\000\000\000\00000"
/* offset=463729 */ "dl1_reload_from_l3_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from L3\000\000\000\000\000\00000"
/* offset=463867 */ "dl1_reload_from_ll4_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000\00000"
/* offset=464017 */ "dl1_reload_from_lmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_LMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Local Memory\000\000\000\000\000\00000"
/* offset=464173 */ "dl1_reload_from_rl2l3_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000"
/* offset=464353 */ "dl1_reload_from_rl2l3_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000"
/* offset=464531 */ "dl1_reload_from_rl4_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000\00000"
/* offset=464682 */ "dl1_reload_from_rmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote Memory\000\000\000\000\000\00000"
/* offset=464839 */ "dcache_miss_cpi_percent\000estimated_dcache_miss_cpi\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL / (PM_RUN_CYC / PM_RUN_INST_CMPL) * 100\000\000dL1 miss portion of CPI\000\000\000\000\000\00000"
/* offset=465007 */ "dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=465323 */ "dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=465639 */ "dl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL4 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=465918 */ "dmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DMEM / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=466206 */ "l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=466503 */ "l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=466800 */ "l2_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L2 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=467067 */ "l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=467364 */ "l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=467661 */ "l3_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L3 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000\00000"
/* offset=467929 */ "ll4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_LL4 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of Local L4 miss rates with measured LL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=468206 */ "lmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_LMEM / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=468492 */ "rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=468807 */ "rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=469118 */ "rl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL4 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=469396 */ "rmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RMEM / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=469683 */ "br_mpred_flush_rate_percent\000general\000PM_FLUSH_BR_MPRED / PM_RUN_INST_CMPL * 100\000\000Branch Mispredict flushes per instruction\000\000\000\000\000\00000"
/* offset=469812 */ "cpi\000general\000PM_CYC / PM_INST_CMPL\000\000Cycles per instruction\000\000\000\000\000\00000"
/* offset=469877 */ "cyc_grp_completed_percent\000general\000PM_GRP_CMPL / PM_CYC * 100\000\000Percentage Cycles a group completed\000\000\000\000\000\00000"
/* offset=469982 */ "cyc_grp_dispatched_percent\000general\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000\000Percentage Cycles a group dispatched\000\000\000\000\000\00000"
/* offset=470095 */ "cyc_per_group\000general\000PM_CYC / PM_1PLUS_PPC_CMPL\000\000Cycles per group\000\000\000\000\000\00000"
/* offset=470169 */ "disp_flush_rate_percent\000general\000PM_FLUSH_DISP / PM_RUN_INST_CMPL * 100\000\000GCT empty cycles\000\000\000\000\000\00000"
/* offset=470265 */ "dtlb_miss_rate_percent\000general\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000\000% DTLB miss rate per inst\000\000\000\000\000\00000"
/* offset=470368 */ "flush_rate_percent\000general\000PM_FLUSH * 100 / PM_RUN_INST_CMPL\000\000Flush rate (%)\000\000\000\000\000\00000"
/* offset=470452 */ "gct_util_11to14_slots_percent\000general\000PM_GCT_UTIL_11_14_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (11 to 14) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000"
/* offset=470652 */ "gct_util_15to17_slots_percent\000general\000PM_GCT_UTIL_15_17_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (15 to 17) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000"
/* offset=470852 */ "gct_util_18plus_slots_percent\000general\000PM_GCT_UTIL_18_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization 18+ as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000"
/* offset=471042 */ "gct_util_1to2_slots_percent\000general\000PM_GCT_UTIL_1_2_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (1 to 2) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000"
/* offset=471236 */ "gct_util_3to6_slots_percent\000general\000PM_GCT_UTIL_3_6_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (3 to 6) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000"
/* offset=471430 */ "gct_util_7to10_slots_percent\000general\000PM_GCT_UTIL_7_10_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (7 to 10) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000"
/* offset=471627 */ "group_size\000general\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Avg. group size\000\000\000\000\000\00000"
/* offset=471703 */ "inst_per_group\000general\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Instructions per group\000\000\000\000\000\00000"
/* offset=471790 */ "ipc\000general\000PM_INST_CMPL / PM_CYC\000\000Instructions per cycles\000\000\000\000\000\00000"
/* offset=471856 */ "itlb_miss_rate_percent\000general\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000\000% ITLB miss rate per inst\000\000\000\000\000\00000"
/* offset=471959 */ "l1_ld_miss_ratio_percent\000general\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000\000Percentage of L1 load misses per L1 load ref\000\000\000\000\000\00000"
/* offset=472080 */ "l1_st_miss_rate_percent\000general\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L1 store misses per run instruction\000\000\000\000\000\00000"
/* offset=472209 */ "l1_st_miss_ratio_percent\000general\000PM_ST_MISS_L1 / PM_ST_FIN * 100\000\000Percentage of L1 store misses per L1 store ref\000\000\000\000\000\00000"
/* offset=472329 */ "l2_inst_miss_rate_percent\000general\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000\00000"
/* offset=472462 */ "l2_ld_miss_rate_percent\000general\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 dmand  Load Miss Rate (per run instruction)(%)\000\000\000\000\000\00000"
/* offset=472597 */ "l2_pteg_miss_rate_percent\000general\000PM_DPTEG_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000\00000"
/* offset=472728 */ "l2_st_miss_rate_percent\000general\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 store misses per run instruction\000\000\000\000\000\00000"
/* offset=472857 */ "l3_inst_miss_rate_percent\000general\000PM_INST_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000\00000"
/* offset=472990 */ "l3_ld_miss_rate_percent\000general\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 demand Load Miss Rate (per run instruction)(%)\000\000\000\000\000\00000"
/* offset=473125 */ "l3_pteg_miss_rate_percent\000general\000PM_DPTEG_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000\00000"
/* offset=473256 */ "run_cycles_percent\000general\000PM_RUN_CYC / PM_CYC * 100\000\000Run cycles per cycle\000\000\000\000\000\00000"
/* offset=473338 */ "smt2_cycles_percent\000general\000PM_RUN_CYC_SMT2_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in SMT2 Mode\000\000\000\000\000\00000"
/* offset=473454 */ "smt4_cycles_percent\000general\000PM_RUN_CYC_SMT4_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in SMT4 Mode\000\000\000\000\000\00000"
/* offset=473570 */ "smt8_cycles_percent\000general\000PM_RUN_CYC_SMT8_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in SMT8 Mode\000\000\000\000\000\00000"
/* offset=473686 */ "smt_benefit\000general\000PM_CMPLU_STALL_OTHER_CMPL / PM_RUN_CYC\000\000IPC of all instructions completed by the core while this thread was stalled\000\000\000\000\000\00000"
/* offset=473829 */ "speculation\000general\000PM_INST_DISP / PM_INST_CMPL\000\000Instruction dispatch-to-completion ratio\000\000\000\000\000\00000"
/* offset=473926 */ "st_cycles_percent\000general\000PM_RUN_CYC_ST_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in Single Thread Mode\000\000\000\000\000\00000"
/* offset=474047 */ "inst_from_dl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000\00000"
/* offset=474234 */ "inst_from_dl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000\00000"
/* offset=474419 */ "inst_from_dl4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L4 per Inst\000\000\000\000\000\00000"
/* offset=474577 */ "inst_from_dmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant Memory per Inst\000\000\000\000\000\00000"
/* offset=474741 */ "inst_from_l21_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000\00000"
/* offset=474919 */ "inst_from_l21_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000\00000"
/* offset=475097 */ "inst_from_l2_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from L2 per Inst\000\000\000\000\000\00000"
/* offset=475245 */ "inst_from_l31_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L3, other core per Inst\000\000\000\000\000\00000"
/* offset=475423 */ "inst_from_l31_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L3 other core per Inst\000\000\000\000\000\00000"
/* offset=475600 */ "inst_from_l3_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from L3 per Inst\000\000\000\000\000\00000"
/* offset=475748 */ "inst_from_ll4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Local L4 per Inst\000\000\000\000\000\00000"
/* offset=475904 */ "inst_from_lmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Local Memory per Inst\000\000\000\000\000\00000"
/* offset=476066 */ "inst_from_rl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L2 or L3 (Modified) per Inst\000\000\000\000\000\00000"
/* offset=476252 */ "inst_from_rl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L2 or L3 (Shared) per Inst\000\000\000\000\000\00000"
/* offset=476436 */ "inst_from_rl4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L4 per Inst\000\000\000\000\000\00000"
/* offset=476593 */ "inst_from_rmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote Memory per Inst\000\000\000\000\000\00000"
/* offset=476756 */ "l1_inst_miss_rate_percent\000instruction_misses_percent_per_inst\000PM_L1_ICACHE_MISS * 100 / PM_RUN_INST_CMPL\000\000Instruction Cache Miss Rate (Per run Instruction)(%)\000\000\000\000\000\00000"
/* offset=476922 */ "branches_per_inst\000instruction_mix\000PM_BRU_FIN / PM_RUN_INST_CMPL\000\000% Branches per instruction\000\000\000\000\000\00000"
/* offset=477021 */ "fixed_per_inst\000instruction_mix\000(PM_FXU0_FIN + PM_FXU1_FIN) / PM_RUN_INST_CMPL\000\000Total Fixed point operations\000\000\000\000\000\00000"
/* offset=477136 */ "fxu0_balance\000instruction_mix\000PM_FXU0_FIN / (PM_FXU0_FIN + PM_FXU1_FIN)\000\000FXU0 balance\000\000\000\000\000\00000"
/* offset=477228 */ "fxu0_fin\000instruction_mix\000PM_FXU0_FIN / PM_RUN_CYC\000\000Fraction of cycles that FXU0 is in use\000\000\000\000\000\00000"
/* offset=477325 */ "fxu0_only_busy\000instruction_mix\000PM_FXU0_BUSY_FXU1_IDLE / PM_CYC\000\000FXU0 only Busy\000\000\000\000\000\00000"
/* offset=477411 */ "fxu1_fin\000instruction_mix\000PM_FXU1_FIN / PM_RUN_CYC\000\000Fraction of cycles that FXU1 is in use\000\000\000\000\000\00000"
/* offset=477508 */ "fxu1_only_busy\000instruction_mix\000PM_FXU1_BUSY_FXU0_IDLE / PM_CYC\000\000FXU1 only Busy\000\000\000\000\000\00000"
/* offset=477594 */ "fxu_both_busy\000instruction_mix\000PM_FXU_BUSY / PM_CYC\000\000Both FXU Busy\000\000\000\000\000\00000"
/* offset=477667 */ "fxu_both_idle\000instruction_mix\000PM_FXU_IDLE / PM_CYC\000\000Both FXU Idle\000\000\000\000\000\00000"
/* offset=477740 */ "loads_per_inst\000instruction_mix\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000\000PCT instruction loads\000\000\000\000\000\00000"
/* offset=477833 */ "stores_per_inst\000instruction_mix\000PM_ST_FIN / PM_RUN_INST_CMPL\000\000PCT instruction stores\000\000\000\000\000\00000"
/* offset=477925 */ "icache_miss_reload\000instruction_stats_percent_per_ref\000(PM_L1_ICACHE_MISS - PM_IC_PREF_WRITE) / PM_L1_ICACHE_MISS\000\000Icache Fetchs per Icache Miss\000\000\000\000\000\00000"
/* offset=478075 */ "icache_pref_percent\000instruction_stats_percent_per_ref\000PM_IC_PREF_WRITE * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads due to prefetch\000\000\000\000\000\00000"
/* offset=478216 */ "inst_from_dl2l3_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000"
/* offset=478388 */ "inst_from_dl2l3_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000"
/* offset=478558 */ "inst_from_dl4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L4\000\000\000\000\000\00000"
/* offset=478701 */ "inst_from_dmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant Memory\000\000\000\000\000\00000"
/* offset=478850 */ "inst_from_l21_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L21_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L2, other core\000\000\000\000\000\00000"
/* offset=479013 */ "inst_from_l21_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L21_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L2, other core\000\000\000\000\000\00000"
/* offset=479176 */ "inst_from_l2_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from L2\000\000\000\000\000\00000"
/* offset=479309 */ "inst_from_l31_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L31_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L3, other core\000\000\000\000\000\00000"
/* offset=479472 */ "inst_from_l31_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L31_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L3, other core\000\000\000\000\000\00000"
/* offset=479635 */ "inst_from_l3_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from L3\000\000\000\000\000\00000"
/* offset=479768 */ "inst_from_ll4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_LL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Local L4\000\000\000\000\000\00000"
/* offset=479909 */ "inst_from_lmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Local Memory\000\000\000\000\000\00000"
/* offset=480056 */ "inst_from_rl2l3_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000"
/* offset=480227 */ "inst_from_rl2l3_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000"
/* offset=480396 */ "inst_from_rl4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L4\000\000\000\000\000\00000"
/* offset=480538 */ "inst_from_rmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote Memory\000\000\000\000\000\00000"
/* offset=480686 */ "avg_stores_gathered\000l2_stats\000PM_ST_CMPL / (PM_L2_ST / 2)\000\000Average number of stores that gather in the store buffer before being sent to an L2 RC machine\000\000\000\000\000\00000"
/* offset=480846 */ "l2_st_miss_ratio_percent\000l2_stats\000PM_L2_ST_MISS / PM_L2_ST * 100\000\000L2  Store misses  as a % of total L2  Store dispatches (per thread)\000\000\000\000\000\00000"
/* offset=480987 */ "l2_store_miss_ratio_percent\000l2_stats\000PM_L2_ST_MISS / (PM_L2_ST / 2)\000\000Percentage of L2 store misses per drained store.  A drained store may contain multiple individual stores if they target the same line\000\000\000\000\000\00000"
/* offset=481197 */ "average_dl1miss_latency\000latency\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000\000average L1 miss latency using marked events\000\000\000\000\000\00000"
/* offset=481323 */ "average_il1_miss_latency\000latency\000PM_IC_DEMAND_CYC / PM_IC_DEMAND_REQ\000\000Average icache miss latency\000\000\000\000\000\00000"
/* offset=481428 */ "average_sync_cyc\000latency\000PM_LSU_SRQ_SYNC_CYC / PM_LSU_SRQ_SYNC\000\000average service time for SYNC\000\000\000\000\000\00000"
/* offset=481529 */ "avg_lmq_life_time\000latency\000PM_LSU_LMQ_S0_VALID / PM_LSU_LMQ_S0_ALLOC\000\000Cycles LMQ slot0 was active on an average\000\000\000\000\000\00000"
/* offset=481647 */ "avg_lrq_life_time_even\000latency\000PM_LSU_LRQ_S0_VALID / PM_LSU_LRQ_S0_ALLOC\000\000Average number of cycles LRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000\00000"
/* offset=481823 */ "avg_lrq_life_time_odd\000latency\000PM_LSU_LRQ_S43_VALID / PM_LSU_LRQ_S43_ALLOC\000\000Average number of cycles LRQ stays active for one load.  Slot 43 is valid ONLY FOR ODD THREADS\000\000\000\000\000\00000"
/* offset=482000 */ "avg_srq_life_time_even\000latency\000PM_LSU_SRQ_S0_VALID / PM_LSU_SRQ_S0_ALLOC\000\000Average number of cycles SRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000\00000"
/* offset=482176 */ "avg_srq_life_time_odd\000latency\000PM_LSU_SRQ_S39_VALID / PM_LSU_SRQ_S39_ALLOC\000\000Average number of cycles SRQ stays active for one load.  Slot 39 is valid ONLY FOR ODD THREADS\000\000\000\000\000\00000"
/* offset=482353 */ "bkill_latency\000latency\000PM_MRK_FAB_RSP_BKILL_CYC / PM_MRK_FAB_RSP_BKILL\000\000Marked background kill latency, measured in L2\000\000\000\000\000\00000"
/* offset=482478 */ "dclaim_latency\000latency\000PM_MRK_FAB_RSP_DCLAIM_CYC / PM_MRK_FAB_RSP_DCLAIM\000\000Marked dclaim latency, measured in L2\000\000\000\000\000\00000"
/* offset=482597 */ "dl2l3_mod_latency\000latency\000PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000"
/* offset=482723 */ "dl2l3_shr_latency\000latency\000PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR\000\000Marked L2L3 distant Load latency\000\000\000\000\000\00000"
/* offset=482850 */ "dl4_latency\000latency\000PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4\000\000Distant L4 average load latency\000\000\000\000\000\00000"
/* offset=482958 */ "dmem_latency\000latency\000PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM\000\000Marked Dmem Load latency\000\000\000\000\000\00000"
/* offset=483062 */ "exposed_dl1miss_latency\000latency\000PM_MRK_LD_MISS_EXPOSED_CYC / PM_MRK_LD_MISS_EXPOSED\000\000estimated exposed miss latency for dL1 misses, ie load miss when we were NTC\000\000\000\000\000\00000"
/* offset=483231 */ "l21_mod_latency\000latency\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000\000Average load latency for all marked demand loads that came from L2.1 in the M state\000\000\000\000\000\00000"
/* offset=483403 */ "l21_shr_latency\000latency\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000\000Average load latency for all marked demand loads that came from L2.1 in the S state\000\000\000\000\000\00000"
/* offset=483575 */ "l2_disp_conflict_ldhitst_latency\000latency\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST\000\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time due to load-hit-store\000\000\000\000\000\00000"
/* offset=483859 */ "l2_disp_conflict_other_latency\000latency\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER\000\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time NOT due load-hit-store\000\000\000\000\000\00000"
/* offset=484138 */ "l2_latency\000latency\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that came from the L2\000\000\000\000\000\00000"
/* offset=484282 */ "l2_mepf_latency\000latency\000PM_MRK_DATA_FROM_L2_MEPF_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that were satisfied by lines prefetched into the L3.  This information is forwarded from the L3\000\000\000\000\000\00000"
/* offset=484510 */ "l2_no_conflict_latency\000latency\000PM_MRK_DATA_FROM_L2_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that came from the L2 and suffered no conflicts\000\000\000\000\000\00000"
/* offset=484704 */ "l2miss_latency\000latency\000PM_MRK_DATA_FROM_L2MISS_CYC / PM_MRK_DATA_FROM_L2MISS\000\000Average load latency for all marked demand loads that came from the L3 and beyond\000\000\000\000\000\00000"
/* offset=484871 */ "l31_mod_latency\000latency\000PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD\000\000Marked L31 Load latency\000\000\000\000\000\00000"
/* offset=484983 */ "l31_shr_latency\000latency\000PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR\000\000Marked L31 Load latency\000\000\000\000\000\00000"
/* offset=485095 */ "l3_latency\000latency\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000\000Average load latency for all marked demand loads that came from the L3\000\000\000\000\000\00000"
/* offset=485239 */ "l3_no_conflict_latency\000latency\000PM_MRK_DATA_FROM_L3_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that came from the L3 and suffered no conflicts\000\000\000\000\000\00000"
/* offset=485433 */ "l3miss_latency\000latency\000PM_MRK_DATA_FROM_L3MISS_CYC / PM_MRK_DATA_FROM_L3MISS\000\000Average load latency for all marked demand loads that come from beyond the L3\000\000\000\000\000\00000"
/* offset=485596 */ "l3pref_latency\000latency\000PM_MRK_DATA_FROM_L3_MEPF_CYC / PM_MRK_DATA_FROM_L3_MEPF\000\000Average latency for marked reloads that hit in the L3 on the MEPF state.  i.e. lines that were prefetched into the L3\000\000\000\000\000\00000"
/* offset=485801 */ "ll4_latency\000latency\000PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4\000\000Local L4 average load latency\000\000\000\000\000\00000"
/* offset=485907 */ "lmem_latency\000latency\000PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM\000\000Marked Lmem Load latency\000\000\000\000\000\00000"
/* offset=486011 */ "off_chip_cache_latency\000latency\000PM_MRK_DATA_FROM_OFF_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_OFF_CHIP_CACHE\000\000Latency for marked reloads that hit in the L2 or L3 of any other core on a different chip\000\000\000\000\000\00000"
/* offset=486210 */ "on_chip_cache_latency\000latency\000PM_MRK_DATA_FROM_ON_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_ON_CHIP_CACHE\000\000Latency for marked reloads that hit in the L2 or L3 of any other core on the same chip\000\000\000\000\000\00000"
/* offset=486403 */ "rl2l3_mod_latency\000latency\000PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000"
/* offset=486529 */ "rl2l3_shr_latency\000latency\000PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000"
/* offset=486655 */ "rl4_latency\000latency\000PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4\000\000Remote L4 average load latency\000\000\000\000\000\00000"
/* offset=486762 */ "rmem_latency\000latency\000PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM\000\000Marked Rmem Load latency\000\000\000\000\000\00000"
/* offset=486866 */ "erat_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_ERAT_MISS * 100 / PM_RUN_INST_CMPL\000\000ERAT miss reject ratio\000\000\000\000\000\00000"
/* offset=486983 */ "erat_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT_ERAT_MISS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000\000ERAT miss reject ratio\000\000\000\000\000\00000"
/* offset=487113 */ "lhs_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_LHS * 100 / PM_RUN_INST_CMPL\000\000LHS reject ratio\000\000\000\000\000\00000"
/* offset=487217 */ "lhs_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT_LHS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000\000LHS reject ratio\000\000\000\000\000\00000"
/* offset=487334 */ "lmq_full_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000\000LMQ full reject ratio\000\000\000\000\000\00000"
/* offset=487453 */ "lmq_full_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_LD_REF_L1\000\000ERAT miss reject ratio\000\000\000\000\000\00000"
/* offset=487570 */ "lsu_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT * 100 / PM_RUN_INST_CMPL\000\000LSU reject ratio\000\000\000\000\000\00000"
/* offset=487670 */ "lsu_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000\000LSU reject ratio\000\000\000\000\000\00000"
/* offset=487783 */ "ld_ll4_per_ld_dmem\000memory\000PM_DATA_FROM_LL4 / PM_DATA_FROM_DL4\000\000Ratio of reloads from local L4 to distant L4\000\000\000\000\000\00000"
/* offset=487898 */ "ld_ll4_per_ld_mem\000memory\000PM_DATA_FROM_LL4 / (PM_DATA_FROM_DL4 + PM_DATA_FROM_RL4)\000\000Ratio of reloads from local L4 to remote+distant L4\000\000\000\000\000\00000"
/* offset=488040 */ "ld_ll4_per_ld_rl4\000memory\000PM_DATA_FROM_LL4 / PM_DATA_FROM_RL4\000\000Ratio of reloads from local L4 to remote L4\000\000\000\000\000\00000"
/* offset=488153 */ "ld_lmem_per_ld_dmem\000memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000\000Number of loads from local memory per loads from distant memory\000\000\000\000\000\00000"
/* offset=488290 */ "ld_lmem_per_ld_mem\000memory\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000\000Number of loads from local memory per loads from remote and distant memory\000\000\000\000\000\00000"
/* offset=488459 */ "ld_lmem_per_ld_rmem\000memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000\000Number of loads from local memory per loads from remote memory\000\000\000\000\000\00000"
/* offset=488595 */ "ld_rmem_per_ld_dmem\000memory\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000\000Number of loads from remote memory per loads from distant memory\000\000\000\000\000\00000"
/* offset=488733 */ "mem_locality_percent\000memory\000(PM_DATA_FROM_LL4 + PM_DATA_FROM_LMEM) * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4 + PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4 + PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4)\000\000Memory locality\000\000\000\000\000\00000"
/* offset=488949 */ "derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000\000DERAT Miss Rate (per run  instruction)(%)\000\000\000\000\000\00000"
/* offset=489096 */ "pteg_from_dl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L2 or L3 (Modified) per inst\000\000\000\000\000\00000"
/* offset=489277 */ "pteg_from_dl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L2 or L3 (Shared) per inst\000\000\000\000\000\00000"
/* offset=489456 */ "pteg_from_dl4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L4 per inst\000\000\000\000\000\00000"
/* offset=489608 */ "pteg_from_dmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant Memory per inst\000\000\000\000\000\00000"
/* offset=489766 */ "pteg_from_l21_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000\00000"
/* offset=489938 */ "pteg_from_l21_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000\00000"
/* offset=490110 */ "pteg_from_l2_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from L2 per inst\000\000\000\000\000\00000"
/* offset=490252 */ "pteg_from_l31_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000\00000"
/* offset=490424 */ "pteg_from_l31_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000\00000"
/* offset=490596 */ "pteg_from_l3_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from L3 per inst\000\000\000\000\000\00000"
/* offset=490738 */ "pteg_from_ll4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Local L4 per inst\000\000\000\000\000\00000"
/* offset=490888 */ "pteg_from_lmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Local Memory per inst\000\000\000\000\000\00000"
/* offset=491044 */ "pteg_from_rl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L2 or L3 (Modified) per inst\000\000\000\000\000\00000"
/* offset=491224 */ "pteg_from_rl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L2 or L3 (Shared) per inst\000\000\000\000\000\00000"
/* offset=491402 */ "pteg_from_rl4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L4 per inst\000\000\000\000\000\00000"
/* offset=491553 */ "pteg_from_rmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote Memory per inst\000\000\000\000\000\00000"
/* offset=491710 */ "derat_miss_reload_percent\000pteg_reloads_percent_per_ref\000PM_DTLB_MISS * 100 / PM_LSU_DERAT_MISS\000\000% of DERAT misses that result in an ERAT reload\000\000\000\000\000\00000"
/* offset=491860 */ "pteg_from_dl2l3_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000"
/* offset=492022 */ "pteg_from_dl2l3_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000"
/* offset=492182 */ "pteg_from_dl4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L4\000\000\000\000\000\00000"
/* offset=492315 */ "pteg_from_dmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant Memory\000\000\000\000\000\00000"
/* offset=492454 */ "pteg_from_l21_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L21_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L2, other core\000\000\000\000\000\00000"
/* offset=492607 */ "pteg_from_l21_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L21_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L2, other core\000\000\000\000\000\00000"
/* offset=492760 */ "pteg_from_l2_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L2 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from L2\000\000\000\000\000\00000"
/* offset=492883 */ "pteg_from_l31_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L31_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L3, other core\000\000\000\000\000\00000"
/* offset=493036 */ "pteg_from_l31_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L31_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L3, other core\000\000\000\000\000\00000"
/* offset=493189 */ "pteg_from_l3_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L3 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from L3\000\000\000\000\000\00000"
/* offset=493312 */ "pteg_from_ll4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_LL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Local L4\000\000\000\000\000\00000"
/* offset=493443 */ "pteg_from_lmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_LMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Local Memory\000\000\000\000\000\00000"
/* offset=493580 */ "pteg_from_rl2l3_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000"
/* offset=493741 */ "pteg_from_rl2l3_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000"
/* offset=493900 */ "pteg_from_rl4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L4\000\000\000\000\000\00000"
/* offset=494032 */ "pteg_from_rmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote Memory\000\000\000\000\000\00000"
/* offset=494170 */ "derat_16g_miss_rate_percent\000translation\000100 * PM_DERAT_MISS_16G / PM_RUN_INST_CMPL\000\000% DERAT miss ratio for 16G page per inst\000\000\000\000\000\00000"
/* offset=494302 */ "derat_16g_miss_ratio\000translation\000PM_DERAT_MISS_16G / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 16G page\000\000\000\000\000\00000"
/* offset=494411 */ "derat_16m_miss_rate_percent\000translation\000PM_DERAT_MISS_16M * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss rate for 16M page per inst\000\000\000\000\000\00000"
/* offset=494542 */ "derat_16m_miss_ratio\000translation\000PM_DERAT_MISS_16M / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 16M page\000\000\000\000\000\00000"
/* offset=494651 */ "derat_4k_miss_rate_percent\000translation\000PM_DERAT_MISS_4K * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss rate for 4K page per inst\000\000\000\000\000\00000"
/* offset=494779 */ "derat_4k_miss_ratio\000translation\000PM_DERAT_MISS_4K / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 4K page\000\000\000\000\000\00000"
/* offset=494885 */ "derat_64k_miss_rate_percent\000translation\000PM_DERAT_MISS_64K * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss ratio for 64K page per inst\000\000\000\000\000\00000"
/* offset=495017 */ "derat_64k_miss_ratio\000translation\000PM_DERAT_MISS_64K / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 64K page\000\000\000\000\000\00000"
/* offset=495126 */ "dslb_miss_rate_percent\000translation\000PM_DSLB_MISS * 100 / PM_RUN_INST_CMPL\000\000% DSLB_Miss_Rate per inst\000\000\000\000\000\00000"
/* offset=495233 */ "islb_miss_rate_percent\000translation\000PM_ISLB_MISS * 100 / PM_RUN_INST_CMPL\000\000% ISLB miss rate per inst\000\000\000\000\000\00000"
/* offset=495340 */ "any_centaur_ld_hit_ratio\000\000PM_DATA_FROM_MEMORY / PM_LD_REF_L1\000\000Fraction of hits on any Centaur (local, remote, or distant) on either L4 or DRAM per L1 load ref\000\000\000\000\000\00000"
/* offset=495506 */ "base_completion_cpi\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000\000Base Completion Cycles\000\000\000\000\000\00000"
/* offset=495595 */ "bkill_ratio_percent\000\000PM_MRK_FAB_RSP_BKILL_CYC / PM_MRK_FAB_RSP_BKILL\000\000Marked background kill latency, measured in L2\000\000\000\000\000\00000"
/* offset=495719 */ "custom_secs\000\000PM_RUN_CYC\000\000cycles\000\000\000\000\000\00000"
/* offset=495758 */ "distant_centaur_ld_hit_ratio\000\000(PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4) / PM_LD_REF_L1\000\000Fraction of hits on a distant chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000\00000"
/* offset=495924 */ "dl1_reload_from_l2_miss_percent\000\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads that came from the L3 and beyond\000\000\000\000\000\00000"
/* offset=496069 */ "dl1_reload_from_l31_rate_percent\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000"
/* offset=496236 */ "dl1_reload_from_l3_mepf_percent\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L3 where the lines were brought into the L3 by a prefetch operation\000\000\000\000\000\00000"
/* offset=496431 */ "dl1_reload_from_l3_miss_percent\000\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from beyond the local L3\000\000\000\000\000\00000"
/* offset=496568 */ "dl2l3_mod_ld_hit_ratio\000\000PM_DATA_FROM_DL2L3_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000\00000"
/* offset=496752 */ "dl2l3_shr_ld_hit_ratio\000\000PM_DATA_FROM_DL2L3_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000\00000"
/* offset=496924 */ "dl4_ld_hit_ratio\000\000PM_DATA_FROM_DL4 / PM_LD_REF_L1\000\000Fraction of hits on a distant Centaur's cache per L1 load ref\000\000\000\000\000\00000"
/* offset=497044 */ "dmem_ld_hit_ratio\000\000PM_DATA_FROM_DMEM / PM_LD_REF_L1\000\000Fraction of hits on a distant Centaur's DRAM per L1 load ref\000\000\000\000\000\00000"
/* offset=497165 */ "dpteg_from_l2_rate_percent\000\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Rate of DERAT reloads from L2\000\000\000\000\000\00000"
/* offset=497273 */ "dpteg_from_l3_rate_percent\000\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Rate of DERAT reloads from L3\000\000\000\000\000\00000"
/* offset=497381 */ "expansion_overhead_cpi\000\000PM_GRP_CMPL / PM_RUN_INST_CMPL - PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000\000Overhead of expansion cycles\000\000\000\000\000\00000"
/* offset=497512 */ "fixed_in_lsu_per_inst\000\000PM_LSU_FX_FIN / PM_RUN_INST_CMPL\000\000Total Fixed point operations executded in the Load/Store Unit following a load/store operation\000\000\000\000\000\00000"
/* offset=497671 */ "gct_empty_percent\000\000PM_GCT_NOSLOT_CYC / PM_RUN_CYC * 100\000\000GCT empty cycles\000\000\000\000\000\00000"
/* offset=497752 */ "ipteg_from_l2_rate_percent\000\000PM_IPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from L2\000\000\000\000\000\00000"
/* offset=497860 */ "ipteg_from_l3_rate_percent\000\000PM_IPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from L3\000\000\000\000\000\00000"
/* offset=497968 */ "ipteg_from_ll4_rate_percent\000\000PM_IPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from local memory\000\000\000\000\000\00000"
/* offset=498088 */ "ipteg_from_lmem_rate_percent\000\000PM_IPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from local memory\000\000\000\000\000\00000"
/* offset=498210 */ "l1_ld_hit_ratio\000\000(PM_LD_REF_L1 - PM_LD_MISS_L1) / PM_LD_REF_L1\000\000Fraction of L1 hits per load ref\000\000\000\000\000\00000"
/* offset=498314 */ "l1_ld_miss_ratio\000\000PM_LD_MISS_L1 / PM_LD_REF_L1\000\000Fraction of L1 load misses per L1 load ref\000\000\000\000\000\00000"
/* offset=498412 */ "l2_1_ld_hit_ratio\000\000(PM_DATA_FROM_L21_MOD + PM_DATA_FROM_L21_SHR) / PM_LD_REF_L1\000\000Fraction of hits on another core's L2 on the same chip per L1 load ref\000\000\000\000\000\00000"
/* offset=498571 */ "l2_1_mod_ld_hit_ratio\000\000PM_DATA_FROM_L21_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000\00000"
/* offset=498746 */ "l2_1_shr_ld_hit_ratio\000\000PM_DATA_FROM_L21_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000\00000"
/* offset=498909 */ "l2_co_usage\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000\000Average number of Castout machines used.  1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000\00000"
/* offset=499048 */ "l2_ld_hit_ratio\000\000PM_DATA_FROM_L2 / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref\000\000\000\000\000\00000"
/* offset=499145 */ "l2_ld_miss_ratio\000\000PM_DATA_FROM_L2MISS / PM_LD_REF_L1\000\000Fraction of L2 load misses per L1 load ref\000\000\000\000\000\00000"
/* offset=499249 */ "l2_lhs_ld_hit_ratio\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000\00000"
/* offset=499423 */ "l2_no_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L2_NO_CONFLICT / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref where the L2 did not experience a conflict\000\000\000\000\000\00000"
/* offset=499587 */ "l2_other_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000\00000"
/* offset=499784 */ "l2_rc_usage\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000\000Average number of Read/Claim machines used.  1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000\00000"
/* offset=499926 */ "l2_sn_usage\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000\000Average number of Snoop machines used.  1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000\00000"
/* offset=500061 */ "l31_latency\000\000(PM_MRK_DATA_FROM_L31_SHR_CYC + PM_MRK_DATA_FROM_L31_MOD_CYC) / (PM_MRK_DATA_FROM_L31_SHR + PM_MRK_DATA_FROM_L31_MOD)\000\000Marked L31 Load latency\000\000\000\000\000\00000"
/* offset=500224 */ "l3_1_ld_hit_ratio\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) / PM_LD_REF_L1\000\000Fraction of hits on another core's L3 on the same chip per L1 load ref\000\000\000\000\000\00000"
/* offset=500383 */ "l3_1_mod_ld_hit_ratio\000\000PM_DATA_FROM_L31_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000\00000"
/* offset=500558 */ "l3_1_shr_ld_hit_ratio\000\000PM_DATA_FROM_L31_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000\00000"
/* offset=500721 */ "l3_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L3_DISP_CONFLICT / PM_LD_REF_L1\000\000Fraction of L3 load hits per load ref where the demand load collided with a pending prefetch\000\000\000\000\000\00000"
/* offset=500893 */ "l3_ld_hit_ratio\000\000PM_DATA_FROM_L3 / PM_LD_REF_L1\000\000Fraction of L3 load hits per L1 load ref\000\000\000\000\000\00000"
/* offset=500990 */ "l3_ld_miss_ratio\000\000PM_DATA_FROM_L3MISS / PM_LD_REF_L1\000\000Fraction of L3 load misses per L1 load ref\000\000\000\000\000\00000"
/* offset=501094 */ "l3_no_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L3_NO_CONFLICT / PM_LD_REF_L1\000\000Fraction of L3 load hits per load ref where the L3 did not experience a conflict\000\000\000\000\000\00000"
/* offset=501255 */ "l3other_ld_hit_ratio\000\000(PM_DATA_FROM_L3 - PM_DATA_FROM_L3_MEPF) / PM_LD_REF_L1\000\000Fraction of L3 hits on lines that were not in the MEPF state per L1 load ref\000\000\000\000\000\00000"
/* offset=501418 */ "l3pref_ld_hit_ratio\000\000PM_DATA_FROM_L3_MEPF / PM_LD_REF_L1\000\000Fraction of L3 hits on lines that were recently prefetched into the L3 (MEPF state) per L1 load ref\000\000\000\000\000\00000"
/* offset=501583 */ "ll4_ld_hit_ratio\000\000PM_DATA_FROM_LL4 / PM_LD_REF_L1\000\000Fraction of hits on a local Centaur's cache per L1 load ref\000\000\000\000\000\00000"
/* offset=501701 */ "lmem_ld_hit_ratio\000\000PM_DATA_FROM_LMEM / PM_LD_REF_L1\000\000Fraction of hits on a local Centaur's DRAM per L1 load ref\000\000\000\000\000\00000"
/* offset=501820 */ "local_centaur_ld_hit_ratio\000\000(PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4) / PM_LD_REF_L1\000\000Fraction of hits on a local Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000\00000"
/* offset=501975 */ "lsu_stall_avg_cyc_per_l1hit_stfw\000\000(PM_CMPLU_STALL_LSU - PM_CMPLU_STALL_REJECT - PM_CMPLU_STALL_DCACHE_MISS - PM_CMPLU_STALL_STORE) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000\000Cycles stalled by Other LSU Operations\000\000\000\000\000\00000"
/* offset=502186 */ "off_chip_cache_ld_hit_ratio\000\000PM_DATA_FROM_OFF_CHIP_CACHE / PM_LD_REF_L1\000\000Fraction of hits on another core's L2 or L3 on a different chip (remote or distant) per L1 load ref\000\000\000\000\000\00000"
/* offset=502366 */ "on_chip_cache_ld_hit_ratio\000\000PM_DATA_FROM_ON_CHIP_CACHE / PM_LD_REF_L1\000\000Fraction of hits on another core's L2 or L3 on the same chip per L1 load ref\000\000\000\000\000\00000"
/* offset=502521 */ "remote_centaur_ld_hit_ratio\000\000(PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4) / PM_LD_REF_L1\000\000Fraction of hits on a remote chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000\00000"
/* offset=502685 */ "resource_na_reject_rate_percent\000\000PM_ISU_REJECT_RES_NA * 100 / PM_RUN_INST_CMPL\000\000Percent of all FXU/VSU instructions that got rejected because of unavailable resources or facilities\000\000\000\000\000\00000"
/* offset=502873 */ "rl2l3_mod_ld_hit_ratio\000\000PM_DATA_FROM_RL2L3_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000\00000"
/* offset=503056 */ "rl2l3_shr_ld_hit_ratio\000\000PM_DATA_FROM_RL2L3_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000\00000"
/* offset=503227 */ "rl4_ld_hit_ratio\000\000PM_DATA_FROM_RL4 / PM_LD_REF_L1\000\000Fraction of hits on a remote Centaur's cache per L1 load ref\000\000\000\000\000\00000"
/* offset=503346 */ "rmem_ld_hit_ratio\000\000PM_DATA_FROM_RMEM / PM_LD_REF_L1\000\000Fraction of hits on a remote Centaur's DRAM per L1 load ref\000\000\000\000\000\00000"
/* offset=503466 */ "sar_bypass_reject_rate_percent\000\000PM_ISU_REJECT_SAR_BYPASS * 100 / PM_RUN_INST_CMPL\000\000Percent of all FXU/VSU instructions that got rejected due to SAR Bypass\000\000\000\000\000\00000"
/* offset=503628 */ "source_na_reject_rate_percent\000\000PM_ISU_REJECT_SRC_NA * 100 / PM_RUN_INST_CMPL\000\000Percent of all FXU/VSU instructions that got rejected because of unavailable sources\000\000\000\000\000\00000"
/* offset=503798 */ "store_forward_rate_percent\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / PM_RUN_INST_CMPL\000\000Store forward rate\000\000\000\000\000\00000"
/* offset=503918 */ "store_forward_ratio_percent\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000\000Store forward rate\000\000\000\000\000\00000"
/* offset=504053 */ "store_latency\000\000(PM_MRK_ST_L2DISP_TO_CMPL_CYC + PM_MRK_ST_DRAIN_TO_L2DISP_CYC) / PM_MRK_ST_NEST\000\000Marked store latency, from core completion to L2 RC machine completion\000\000\000\000\000\00000"
/* offset=504227 */ "sync_stall_cpi\000\000(PM_CMPLU_STALL_LWSYNC + PM_CMPLU_STALL_HWSYNC) / PM_RUN_INST_CMPL\000\000Cycles stalled by any sync\000\000\000\000\000\00000"
/* offset=504345 */ "wasted_l3_prefetch_percent\000\000PM_L3_CO_MEPF / 2 / PM_L3_PREF_ALL * 100\000\000Percentage of lines that were prefetched into the L3 and evicted before they were consumed\000\000\000\000\000\00000"
/* offset=504513 */ "br_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CMPL / PM_BR_PRED * 100\000\000\000\000\000\000\000\00000"
/* offset=504601 */ "ccache_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CCACHE / PM_BR_PRED_CCACHE * 100\000\000Count cache branch misprediction\000\000\000\000\000\00000"
/* offset=504734 */ "lstack_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_LSTACK / PM_RUN_INST_CMPL * 100\000\000Link stack branch misprediction\000\000\000\000\000\00000"
/* offset=504867 */ "lstack_misprediction_percent\000branch_prediction\000PM_BR_MPRED_LSTACK / PM_BR_PRED_LSTACK * 100\000\000Link stack branch misprediction\000\000\000\000\000\00000"
/* offset=504999 */ "taken_branches_percent\000branch_prediction\000PM_BR_TAKEN_CMPL * 100 / PM_BRU_FIN\000\000% Branches Taken\000\000\000\000\000\00000"
/* offset=505101 */ "bru_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000\000Completion stall due to a Branch Unit\000\000\000\000\000\00000"
/* offset=505213 */ "crypto_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_CRYPTO / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000\000\000\000\000\00000"
/* offset=505400 */ "dcache_miss_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000\000\000\000\000\00000"
/* offset=505614 */ "dflong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DFLONG / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000\00000"
/* offset=505839 */ "dfu_other_stall_cpi\000cpi_breakdown\000dfu_stall_cpi - dflong_stall_cpi\000\000Stalls due to short latency decimal floating ops\000\000\000\000\000\00000"
/* offset=505963 */ "dfu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DFU / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000\00000"
/* offset=506156 */ "dmiss_distant_stall_cpi\000cpi_breakdown\000dmiss_non_local_stall_cpi - dmiss_remote_stall_cpi\000\000Completion stall by Dcache miss which resolved off node memory/cache\000\000\000\000\000\00000"
/* offset=506322 */ "dmiss_l21_l31_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000\000\000\000\000\00000"
/* offset=506496 */ "dmiss_l2l3_conflict_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000\000\000\000\000\00000"
/* offset=506683 */ "dmiss_l2l3_noconflict_stall_cpi\000cpi_breakdown\000dmiss_l2l3_stall_cpi - dmiss_l2l3_conflict_stall_cpi\000\000Completion stall due to cache miss that resolves in the L2 or L3 without conflict\000\000\000\000\000\00000"
/* offset=506872 */ "dmiss_l2l3_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000\000Completion stall by Dcache miss which resolved in L2/L3\000\000\000\000\000\00000"
/* offset=507016 */ "dmiss_l3miss_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000\000Completion stall due to cache miss resolving missed the L3\000\000\000\000\000\00000"
/* offset=507167 */ "dmiss_lmem_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000\000Completion stall due to cache miss that resolves in local memory\000\000\000\000\000\00000"
/* offset=507320 */ "dmiss_non_local_stall_cpi\000cpi_breakdown\000dmiss_l3miss_stall_cpi - dmiss_l21_l31_stall_cpi - dmiss_lmem_stall_cpi\000\000Completion stall by Dcache miss which resolved outside of local memory\000\000\000\000\000\00000"
/* offset=507511 */ "dmiss_remote_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000\000\000\000\000\00000"
/* offset=507685 */ "dp_other_stall_cpi\000cpi_breakdown\000dp_stall_cpi - dplong_stall_cpi\000\000Stalls due to short latency double precision ops\000\000\000\000\000\00000"
/* offset=507807 */ "dp_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DP / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000\00000"
/* offset=508104 */ "dplong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DPLONG / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000\00000"
/* offset=508421 */ "eieio_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EIEIO / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000\000\000\000\000\00000"
/* offset=508581 */ "emq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EMQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000\000\000\000\000\00000"
/* offset=508760 */ "emq_stall_cpi\000cpi_breakdown\000erat_miss_stall_cpi + emq_full_stall_cpi\000\000\000\000\000\000\000\00000"
/* offset=508838 */ "erat_miss_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000\000\000\000\000\00000"
/* offset=509018 */ "exception_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EXCEPTION / PM_RUN_INST_CMPL\000\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000\000\000\000\000\00000"
/* offset=509273 */ "exec_unit_other_stall_cpi\000cpi_breakdown\000exec_unit_stall_cpi - scalar_stall_cpi - vector_stall_cpi\000\000Completion stall due to execution units for other reasons\000\000\000\000\000\00000"
/* offset=509437 */ "exec_unit_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EXEC_UNIT / PM_RUN_INST_CMPL\000\000Completion stall due to execution units (FXU/VSU/CRU)\000\000\000\000\000\00000"
/* offset=509577 */ "flush_any_thread_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FLUSH_ANY_THREAD / PM_RUN_INST_CMPL\000\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000\000\000\000\000\00000"
/* offset=509828 */ "fxlong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000\000\000\000\000\00000"
/* offset=510002 */ "fxu_other_stall_cpi\000cpi_breakdown\000fxu_stall_cpi - fxlong_stall_cpi\000\000Stalls due to short latency integer ops\000\000\000\000\000\00000"
/* offset=510117 */ "fxu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000\00000"
/* offset=510339 */ "ict_noslot_br_mpred_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to branch mispred\000\000\000\000\000\00000"
/* offset=510500 */ "ict_noslot_br_mpred_icmiss_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to Icache Miss and branch mispred\000\000\000\000\000\00000"
/* offset=510691 */ "ict_noslot_cyc_other_cpi\000cpi_breakdown\000nothing_dispatched_cpi - ict_noslot_ic_miss_cpi - ict_noslot_br_mpred_icmiss_cpi - ict_noslot_br_mpred_cpi - ict_noslot_disp_held_cpi\000\000Instruction Completion Table other stalls\000\000\000\000\000\00000"
/* offset=510914 */ "ict_noslot_disp_held_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD / PM_RUN_INST_CMPL\000\000Cycles in which the NTC instruciton is held at dispatch for any reason\000\000\000\000\000\00000"
/* offset=511075 */ "ict_noslot_disp_held_hb_full_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_HB_FULL / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF\000\000\000\000\000\00000"
/* offset=511323 */ "ict_noslot_disp_held_issq_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000\000\000\000\000\00000"
/* offset=511580 */ "ict_noslot_disp_held_other_cpi\000cpi_breakdown\000ict_noslot_disp_held_cpi - ict_noslot_disp_held_hb_full_cpi - ict_noslot_disp_held_sync_cpi - ict_noslot_disp_held_tbegin_cpi - ict_noslot_disp_held_issq_cpi\000\000ICT_NOSLOT_DISP_HELD_OTHER_CPI\000\000\000\000\000\00000"
/* offset=511822 */ "ict_noslot_disp_held_sync_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_SYNC / PM_RUN_INST_CMPL\000\000Dispatch held due to a synchronizing instruction at dispatch\000\000\000\000\000\00000"
/* offset=511983 */ "ict_noslot_disp_held_tbegin_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_TBEGIN / PM_RUN_INST_CMPL\000\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000\000\000\000\000\00000"
/* offset=512271 */ "ict_noslot_ic_l2_cpi\000cpi_breakdown\000ict_noslot_ic_miss_cpi - ict_noslot_ic_l3_cpi - ict_noslot_ic_l3miss_cpi\000\000ICT_NOSLOT_IC_L2_CPI\000\000\000\000\000\00000"
/* offset=512408 */ "ict_noslot_ic_l3_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_IC_L3 / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to icache misses that were sourced from the local L3\000\000\000\000\000\00000"
/* offset=512598 */ "ict_noslot_ic_l3miss_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000\000\000\000\000\00000"
/* offset=512876 */ "ict_noslot_ic_miss_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to Icache Miss\000\000\000\000\000\00000"
/* offset=513032 */ "issue_hold_cpi\000cpi_breakdown\000ntc_issue_held_darq_full_cpi + ntc_issue_held_arb_cpi + ntc_issue_held_other_cpi\000\000\000\000\000\000\000\00000"
/* offset=513151 */ "larx_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LARX / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000\000\000\000\000\00000"
/* offset=513303 */ "lhs_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LHS / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000\000\000\000\000\00000"
/* offset=513490 */ "lmq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LMQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000\000\000\000\000\00000"
/* offset=513724 */ "load_finish_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000\000\000\000\000\00000"
/* offset=513956 */ "lrq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LRQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that was held in LSAQ because the LRQ was full\000\000\000\000\000\00000"
/* offset=514139 */ "lrq_other_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LRQ_OTHER / PM_RUN_INST_CMPL\000\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000\000\000\000\000\00000"
/* offset=514378 */ "lrq_stall_cpi\000cpi_breakdown\000lmq_full_stall_cpi + st_fwd_stall_cpi + lhs_stall_cpi + lsu_mfspr_stall_cpi + larx_stall_cpi + lrq_other_stall_cpi\000\000\000\000\000\000\000\00000"
/* offset=514530 */ "lsaq_arb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSAQ_ARB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000\000\000\000\000\00000"
/* offset=514812 */ "lsaq_stall_cpi\000cpi_breakdown\000lrq_full_stall_cpi + srq_full_stall_cpi + lsaq_arb_stall_cpi\000\000\000\000\000\000\000\00000"
/* offset=514911 */ "lsu_fin_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU_FIN / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000\000\000\000\000\00000"
/* offset=515155 */ "lsu_flush_next_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU_FLUSH_NEXT / PM_RUN_INST_CMPL\000\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000\000\000\000\000\00000"
/* offset=515449 */ "lsu_mfspr_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU_MFSPR / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000\000\000\000\000\00000"
/* offset=515677 */ "lsu_other_stall_cpi\000cpi_breakdown\000lsu_stall_cpi - lsu_fin_stall_cpi - store_finish_stall_cpi - srq_stall_cpi - load_finish_stall_cpi + lsu_stall_dcache_miss_cpi - lrq_stall_cpi + emq_stall_cpi - lsaq_stall_cpi\000\000Completion LSU stall for other reasons\000\000\000\000\000\00000"
/* offset=515934 */ "lsu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000\000Completion stall by LSU instruction\000\000\000\000\000\00000"
/* offset=516044 */ "mtfpscr_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_MTFPSCR / PM_RUN_INST_CMPL\000\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000\000\000\000\000\00000"
/* offset=516232 */ "nested_tbegin_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NESTED_TBEGIN / PM_RUN_INST_CMPL\000\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000\000\000\000\000\00000"
/* offset=516461 */ "nested_tend_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NESTED_TEND / PM_RUN_INST_CMPL\000\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000\000\000\000\000\00000"
/* offset=516701 */ "nothing_dispatched_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_CYC / PM_RUN_INST_CMPL\000\000Number of cycles the Instruction Completion Table has no itags assigned to this thread\000\000\000\000\000\00000"
/* offset=516870 */ "ntc_disp_fin_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NTC_DISP_FIN / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was one that must finish at dispatch\000\000\000\000\000\00000"
/* offset=517040 */ "ntc_fin_cpi\000cpi_breakdown\000PM_NTC_FIN / PM_RUN_INST_CMPL\000\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000\000\000\000\000\00000"
/* offset=517266 */ "ntc_flush_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000\000Completion stall due to ntc flush\000\000\000\000\000\00000"
/* offset=517386 */ "ntc_issue_held_arb_cpi\000cpi_breakdown\000PM_NTC_ISSUE_HELD_ARB / PM_RUN_INST_CMPL\000\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000\000\000\000\000\00000"
/* offset=517634 */ "ntc_issue_held_darq_full_cpi\000cpi_breakdown\000PM_NTC_ISSUE_HELD_DARQ_FULL / PM_RUN_INST_CMPL\000\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000\000\000\000\000\00000"
/* offset=517824 */ "ntc_issue_held_other_cpi\000cpi_breakdown\000PM_NTC_ISSUE_HELD_OTHER / PM_RUN_INST_CMPL\000\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000\000\000\000\000\00000"
/* offset=518096 */ "other_cpi\000cpi_breakdown\000run_cpi - completion_cpi - thread_block_stall_cpi - stall_cpi - nothing_dispatched_cpi\000\000Cycles unaccounted for\000\000\000\000\000\00000"
/* offset=518238 */ "other_stall_cpi\000cpi_breakdown\000stall_cpi - ntc_disp_fin_stall_cpi - ntc_flush_stall_cpi - lsu_stall_cpi - exec_unit_stall_cpi - bru_stall_cpi\000\000Completion stall for other reasons\000\000\000\000\000\00000"
/* offset=518422 */ "paste_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_PASTE / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a paste waiting for response from L2\000\000\000\000\000\00000"
/* offset=518582 */ "pm_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_PM / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish\000\000\000\000\000\00000"
/* offset=518758 */ "run_cyc_cpi\000cpi_breakdown\000PM_RUN_CYC / PM_RUN_INST_CMPL\000\000Run_cycles\000\000\000\000\000\00000"
/* offset=518833 */ "scalar_stall_cpi\000cpi_breakdown\000fxu_stall_cpi + dp_stall_cpi + dfu_stall_cpi + pm_stall_cpi + crypto_stall_cpi\000\000\000\000\000\000\000\00000"
/* offset=518952 */ "slb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SLB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000\000\000\000\000\00000"
/* offset=519103 */ "spec_finish_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SPEC_FINISH / PM_RUN_INST_CMPL\000\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000\00000"
/* offset=519350 */ "srq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SRQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000\000\000\000\000\00000"
/* offset=519534 */ "srq_stall_cpi\000cpi_breakdown\000store_data_stall_cpi + eieio_stall_cpi + stcx_stall_cpi + slb_stall_cpi + tend_stall_cpi + paste_stall_cpi + tlbie_stall_cpi + store_pipe_arb_stall_cpi + store_fin_arb_stall_cpi\000\000\000\000\000\000\000\00000"
/* offset=519749 */ "st_fwd_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000\000Completion stall due to store forward\000\000\000\000\000\00000"
/* offset=519867 */ "stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000\000Nothing completed and Instruction Completion Table not empty\000\000\000\000\000\00000"
/* offset=519994 */ "stcx_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STCX / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000\000\000\000\000\00000"
/* offset=520151 */ "store_data_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_DATA / PM_RUN_INST_CMPL\000\000Finish stall because the next to finish instruction was a store waiting on data\000\000\000\000\000\00000"
/* offset=520319 */ "store_fin_arb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_FIN_ARB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000\000\000\000\000\00000"
/* offset=520619 */ "store_finish_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_FINISH / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000\000\000\000\000\00000"
/* offset=520845 */ "store_pipe_arb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_PIPE_ARB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000\000\000\000\000\00000"
/* offset=521146 */ "tend_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_TEND / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000\000\000\000\000\00000"
/* offset=521312 */ "thread_block_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000\000Completion Stalled because the thread was blocked\000\000\000\000\000\00000"
/* offset=521446 */ "tlbie_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_TLBIE / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000\000\000\000\000\00000"
/* offset=521606 */ "vdp_other_stall_cpi\000cpi_breakdown\000vdp_stall_cpi - vdplong_stall_cpi\000\000Vector stalls due to small latency double precision ops\000\000\000\000\000\00000"
/* offset=521738 */ "vdp_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VDP / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish\000\000\000\000\000\00000"
/* offset=521946 */ "vdplong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VDPLONG / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000\00000"
/* offset=522265 */ "vector_stall_cpi\000cpi_breakdown\000vfxu_stall_cpi + vdp_stall_cpi\000\000\000\000\000\000\000\00000"
/* offset=522336 */ "vfxlong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VFXLONG / PM_RUN_INST_CMPL\000\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000\000\000\000\000\00000"
/* offset=522512 */ "vfxu_other_stall_cpi\000cpi_breakdown\000vfxu_stall_cpi - vfxlong_stall_cpi\000\000Vector stalls due to small latency integer ops\000\000\000\000\000\00000"
/* offset=522637 */ "vfxu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VFXU / PM_RUN_INST_CMPL\000\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000\00000"
/* offset=522855 */ "dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads that came from the L3 and were brought into the L3 by a prefetch, per instruction completed\000\000\000\000\000\00000"
/* offset=523084 */ "dl1_reload_from_l2_miss_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from sources beyond the local L2\000\000\000\000\000\00000"
/* offset=523256 */ "dl1_reload_from_l3_mepf_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads that came from L3 and were brought into the L3 by a prefetch\000\000\000\000\000\00000"
/* offset=523457 */ "dl1_reload_from_l3_miss_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from sources beyond the local L3\000\000\000\000\000\00000"
/* offset=523629 */ "dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_MOD * PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=523903 */ "dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_SHR * PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=524177 */ "dl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL4 * PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=524414 */ "dmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DMEM * PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=524660 */ "l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_MOD * PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=524915 */ "l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_SHR * PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=525170 */ "l2_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L2 * PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=525395 */ "l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_MOD * PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=525650 */ "l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_SHR * PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=525905 */ "l3_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L3 * PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000\00000"
/* offset=526131 */ "lmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_LMEM * PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=526375 */ "rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_MOD * PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=526648 */ "rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_SHR * PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=526917 */ "rl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL4 * PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=527153 */ "rmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RMEM * PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000"
/* offset=527398 */ "br_mpred_flush_rate_percent\000general\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000\000Branch Mispredict flushes per instruction\000\000\000\000\000\00000"
/* offset=527524 */ "l2_ld_miss_rate_percent\000general\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 dmand Load Miss Rate (per run instruction)(%)\000\000\000\000\000\00000"
/* offset=527658 */ "l2_dem_ld_disp_percent\000l2_stats\000PM_L1_DCACHE_RELOAD_VALID / (PM_L2_LD / 2) * 100\000\000Demand load misses as a % of L2 LD dispatches (per thread)\000\000\000\000\000\00000"
/* offset=527806 */ "l2_st_miss_ratio_percent\000l2_stats\000PM_L2_ST_MISS / PM_L2_ST * 100\000\000L2 Store misses as a % of total L2 Store dispatches (per thread)\000\000\000\000\000\00000"
/* offset=527944 */ "l2_st_wr_util\000l2_stats\000PM_L2_ST_DISP / 2 * 4 / PM_RUN_CYC * 100\000\000L2 stores that require a cache write (4 pclks per disp attempt) % of pclks\000\000\000\000\000\00000"
/* offset=528091 */ "estimated_dl1miss_latency\000latency\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000\000average L1 miss latency using marked events\000\000\000\000\000\00000"
/* offset=528219 */ "l21_mod_latency\000latency\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000\000Marked L21 Load latency\000\000\000\000\000\00000"
/* offset=528331 */ "l21_shr_latency\000latency\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000\000Marked L21 Load latency\000\000\000\000\000\00000"
/* offset=528443 */ "l2_latency\000latency\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000\000Marked L2 Load latency\000\000\000\000\000\00000"
/* offset=528539 */ "l3_latency\000latency\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000\000Marked L3 Load latency\000\000\000\000\000\00000"
/* offset=528635 */ "lmq_full_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000\000ERAT miss reject ratio\000\000\000\000\000\00000"
/* offset=528755 */ "l4_locality\000memory\000PM_DATA_FROM_LL4 * 100 / (PM_DATA_FROM_LL4 + PM_DATA_FROM_RL4 + PM_DATA_FROM_DL4)\000\000L4 locality(%)\000\000\000\000\000\00000"
/* offset=528879 */ "mem_locality_percent\000memory\000PM_DATA_FROM_LMEM * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_RMEM + PM_DATA_FROM_DMEM)\000\000Memory locality\000\000\000\000\000\00000"
/* offset=529017 */ "l1_prefetch_rate_percent\000prefetch\000PM_L1_PREF / PM_RUN_INST_CMPL * 100\000\000L1 Prefetches issued by the prefetch machine per instruction (per thread)\000\000\000\000\000\00000"
/* offset=529169 */ "derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000\000DERAT Miss Rate (per run instruction)(%)\000\000\000\000\000\00000"
/* offset=529315 */ "derat_miss_ratio\000translation\000PM_LSU_DERAT_MISS / PM_LSU_DERAT_MISS\000\000DERAT miss ratio\000\000\000\000\000\00000"
/* offset=529407 */ "any_sync_stall_cpi\000\000PM_CMPLU_STALL_ANY_SYNC / PM_RUN_INST_CMPL\000\000ANY_SYNC_STALL_CPI\000\000\000\000\000\00000"
/* offset=529497 */ "average_completed_instruction_set_size\000\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Avg. more than 1 instructions completed\000\000\000\000\000\00000"
/* offset=529618 */ "branches_per_inst\000\000PM_BRU_FIN / PM_RUN_INST_CMPL\000\000% Branches per instruction\000\000\000\000\000\00000"
/* offset=529702 */ "completion_cpi\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000\000Cycles in which at least one instruction completes in this thread\000\000\000\000\000\00000"
/* offset=529829 */ "cycles_atleast_one_inst_dispatched_percent\000\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000\000Percentage Cycles at least one instruction dispatched\000\000\000\000\000\00000"
/* offset=529968 */ "cycles_per_completed_instructions_set\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000\000Cycles per instruction group\000\000\000\000\000\00000"
/* offset=530071 */ "dl1_reload_from_dl4_percent\000\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000\00000"
/* offset=530196 */ "dl1_reload_from_dl4_rate_percent\000\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000\00000"
/* offset=530322 */ "dl1_reload_from_l31_rate_percent\000\000dl1_reload_from_l31_mod_rate_percent + dl1_reload_from_l31_shr_rate_percent\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000"
/* offset=530494 */ "dl1_reload_from_ll4_percent\000\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000\00000"
/* offset=530617 */ "dl1_reload_from_ll4_rate_percent\000\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000\00000"
/* offset=530741 */ "dl1_reload_from_rl4_percent\000\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000\00000"
/* offset=530865 */ "dl1_reload_from_rl4_rate_percent\000\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000\00000"
/* offset=530994 */ "finish_to_cmpl_cpi\000\000PM_NTC_ALL_FIN / PM_RUN_INST_CMPL\000\000Cycles in which the oldest instruction is finished and ready to complete for waiting to get through the completion pipe\000\000\000\000\000\00000"
/* offset=531176 */ "fixed_per_inst\000\000PM_FXU_FIN / PM_RUN_INST_CMPL\000\000Total Fixed point operations\000\000\000\000\000\00000"
/* offset=531259 */ "fxu_all_busy\000\000PM_FXU_BUSY / PM_CYC\000\000All FXU Busy\000\000\000\000\000\00000"
/* offset=531315 */ "fxu_all_idle\000\000PM_FXU_IDLE / PM_CYC\000\000All FXU Idle\000\000\000\000\000\00000"
/* offset=531371 */ "l2_co_usage\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000\000Average number of Castout machines used. 1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000\00000"
/* offset=531509 */ "l2_instr_commands_percent\000\000PM_ISIDE_DISP * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000\000Percent of instruction reads out of all L2 commands\000\000\000\000\000\00000"
/* offset=531656 */ "l2_ld_commands_percent\000\000PM_L2_LD * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000\000Percent of loads out of all L2 commands\000\000\000\000\000\00000"
/* offset=531783 */ "l2_rc_st_disp_fail_rate_percent\000\000100 * (PM_L2_RCST_DISP_FAIL_ADDR + PM_L2_RCST_DISP_FAIL_OTHER) / 2 / PM_RUN_INST_CMPL\000\000Rate of L2 store dispatches that failed per core\000\000\000\000\000\00000"
/* offset=531959 */ "l2_rc_usage\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000\000Average number of Read/Claim machines used. 1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000\00000"
/* offset=532100 */ "l2_sn_usage\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000\000Average number of Snoop machines used. 1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000\00000"
/* offset=532234 */ "l2_st_commands_percent\000\000PM_L2_ST * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000\000Percent of stores out of all L2 commands\000\000\000\000\000\00000"
/* offset=532362 */ "l2_st_disp_fail_rate_percent\000\000100 * (PM_L2_RCST_DISP_FAIL_ADDR + PM_L2_RCST_DISP_FAIL_OTHER) / 2 / PM_RUN_INST_CMPL\000\000Rate of L2 store dispatches that failed per core\000\000\000\000\000\00000"
/* offset=532535 */ "l2_st_disp_rate_percent\000\000100 * PM_L2_RCST_DISP / 2 / PM_RUN_INST_CMPL\000\000Rate of L2 dispatches per core\000\000\000\000\000\00000"
/* offset=532644 */ "loads_per_inst\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000\000PCT instruction loads\000\000\000\000\000\00000"
/* offset=532722 */ "lsu_stall_dcache_miss_cpi\000\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses\000\000\000\000\000\00000"
/* offset=532836 */ "other_thread_cmpl_stall\000\000thread_block_stall_cpi - exception_stall_cpi - any_sync_stall_cpi - sync_pmu_int_stall_cpi - spec_finish_stall_cpi - flush_any_thread_stall_cpi - lsu_flush_next_stall_cpi - nested_tbegin_stall_cpi - nested_tend_stall_cpi - mtfpscr_stall_cpi\000\000Completion stall because a different thread was using the completion pipe\000\000\000\000\000\00000"
/* offset=533184 */ "stores_per_inst\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000\000PCT instruction stores\000\000\000\000\000\00000"
/* offset=533261 */ "sync_pmu_int_stall_cpi\000\000PM_CMPLU_STALL_SYNC_PMU_INT / PM_RUN_INST_CMPL\000\000ANY_SYNC_STALL_CPI\000\000\000\000\000\00000"
/* offset=533359 */ "Memory_RD_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS01_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_RD_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT23\\,chip\\=?@\000\000\000\0001.6e-2MB\000\000\000\00010"
/* offset=533598 */ "Memory_WR_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS01_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_WR_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT23\\,chip\\=?@\000\000\000\0001.6e-2MB\000\000\000\00010"
/* offset=533837 */ "PowerBUS_Frequency\000\000hv_24x7@PM_PB_CYC\\,chip\\=?@\000\000\000\0002.5e-7GHz\000\000\000\00010"
/* offset=533903 */ "CPM_CS_32MHZ_CYC\000\000hv_24x7@CPM_CS_32MHZ_CYC\\,domain\\=3\\,core\\=?@\000\000\000\0001MHz\000\000\000\00020"
/* offset=533980 */ "mcs01-read\000memory-bandwidth\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000"
/* offset=534117 */ "mcs23-read\000memory-bandwidth\000nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000"
/* offset=534254 */ "mcs01-write\000memory-bandwidth\000nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000"
/* offset=534392 */ "mcs23-write\000memory-bandwidth\000nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000"
/* offset=534530 */ "powerbus_freq\000\000nest_powerbus0_imc@PM_PB_CYC@\000\000\000\0001e-9GHz\000\000\000\00000"
/* offset=534591 */ "Memory-bandwidth-MCS\000memory-bandwidth\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000"
/* offset=535020 */ "CPI\000\0001 / IPC\000\000\000\000\000\000\000\00000"
/* offset=535042 */ "IPC\000group1\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000\000\00000"
/* offset=535105 */ "Frontend_Bound_SMT\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000\000\00000"
/* offset=535271 */ "dcache_miss_cpi\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000"
/* offset=535335 */ "icache_miss_cycles\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000"
/* offset=535402 */ "cache_miss_cycles\000group1\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000\000\00000"
/* offset=535473 */ "DCache_L2_All_Hits\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000\000\00000"
/* offset=535567 */ "DCache_L2_All_Miss\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000\000\00000"
/* offset=535701 */ "DCache_L2_All\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000\000\00000"
/* offset=535765 */ "DCache_L2_Hits\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000\000\00000"
/* offset=535833 */ "DCache_L2_Misses\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000\000\00000"
/* offset=535903 */ "M1\000\000ipc + M2\000\000\000\000\000\000\000\00000"
/* offset=535925 */ "M2\000\000ipc + M1\000\000\000\000\000\000\000\00000"
/* offset=535947 */ "M3\000\0001 / M3\000\000\000\000\000\000\000\00000"
/* offset=535967 */ "L1D_Cache_Fill_BW\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000\000\00000"
;

static const struct compact_pmu_event pmu_events__power10_default_core[] = {
{ 77878 }, /* pm_1flop_cmpl\000floating_point\000One floating point instruction completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45050\000\00000\000\000 */
{ 80006 }, /* pm_1plus_ppc_cmpl\000frontend\000Cycles in which at least one instruction is completed by this thread\000event=0x100f2\000\00000\000\000 */
{ 114229 }, /* pm_1plus_ppc_disp\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\00000\000\000 */
{ 78652 }, /* pm_2flop_cmpl\000floating_point\000Double Precision vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg completed\000event=0x4d052\000\00000\000\000 */
{ 78031 }, /* pm_4flop_cmpl\000floating_point\000Four floating point instruction completed (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg)\000event=0x45052\000\00000\000\000 */
{ 78801 }, /* pm_8flop_cmpl\000floating_point\000Four Double Precision vector instruction completed\000event=0x4d054\000\00000\000\000 */
{ 97232 }, /* pm_adjunct_cyc\000others\000Cycles in which the thread is in Adjunct state. MSR[S HV PR] bits = 011\000event=0x10066\000\00000\000\000 */
{ 97572 }, /* pm_adjunct_inst_cmpl\000others\000PowerPC instruction completed while the thread was in Adjunct state\000event=0x2e010\000\00000\000\000 */
{ 99205 }, /* pm_br_cmpl\000others\000A branch completed. All branches are included\000event=0x4d05e\000\00000\000\000 */
{ 102494 }, /* pm_br_fin\000pipeline\000A branch instruction finished. Includes predicted/mispredicted/unconditional\000event=0x10068\000\00000\000\000 */
{ 156 }, /* pm_br_mpred_cmpl\000cache\000A mispredicted branch completed. Includes direction and target\000event=0x400f6\000\00000\000\000 */
{ 80613 }, /* pm_br_taken_cmpl\000frontend\000Branch Taken instruction completed\000event=0x200fa\000\00000\000\000 */
{ 111495 }, /* pm_cmpl_stall\000pipeline\000Cycles in which the oldest instruction in the pipeline cannot complete because the thread was blocked for any reason\000event=0x4c018\000\00000\000\000 */
{ 108748 }, /* pm_cmpl_stall_exception\000pipeline\000Cycles in which the oldest instruction in the pipeline was not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\00000\000\000 */
{ 112371 }, /* pm_cmpl_stall_hwsync\000pipeline\000Cycles in which the oldest instruction in the pipeline was a hwsync waiting for response from L2 before completing\000event=0x4d01a\000\00000\000\000 */
{ 102155 }, /* pm_cmpl_stall_lwsync\000pipeline\000Cycles in which the oldest instruction in the pipeline was a lwsync waiting to complete\000event=0x1e05a\000\00000\000\000 */
{ 108107 }, /* pm_cmpl_stall_mem_ecc\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for the non-speculative finish of either a STCX waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\00000\000\000 */
{ 103498 }, /* pm_cmpl_stall_special\000pipeline\000Cycles in which the oldest instruction in the pipeline required special handling before completing\000event=0x2c014\000\00000\000\000 */
{ 105083 }, /* pm_cmpl_stall_stcx\000pipeline\000Cycles in which the oldest instruction in the pipeline was a stcx waiting for resolution from the nest before completing\000event=0x2d01c\000\00000\000\000 */
{ 114781 }, /* pm_cyc\000pmc\000Processor cycles\000event=0x100f0\000\00000\000\000 */
{ 36078 }, /* pm_data_from_any_memory\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss\000event=0x95840000000c040\000\00000\000\000 */
{ 36427 }, /* pm_data_from_any_memory_all\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload\000event=0x95840000020c040\000\00000\000\000 */
{ 33796 }, /* pm_data_from_d_oc_any\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss\000event=0xf8140000000c040\000\00000\000\000 */
{ 34169 }, /* pm_data_from_d_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xf8140000020c040\000\00000\000\000 */
{ 32915 }, /* pm_data_from_d_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss\000event=0xf8040000000c040\000\00000\000\000 */
{ 33080 }, /* pm_data_from_d_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss or prefetch reload\000event=0xf8040000020c040\000\00000\000\000 */
{ 33268 }, /* pm_data_from_d_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss\000event=0xfc040000000c040\000\00000\000\000 */
{ 33432 }, /* pm_data_from_d_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss or prefetch reload\000event=0xfc040000020c040\000\00000\000\000 */
{ 28403 }, /* pm_data_from_dl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss\000event=0xe0140000000c040\000\00000\000\000 */
{ 28758 }, /* pm_data_from_dl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe0140000020c040\000\00000\000\000 */
{ 27798 }, /* pm_data_from_dl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss\000event=0xe4040000000c040\000\00000\000\000 */
{ 28005 }, /* pm_data_from_dl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe4040000020c040\000\00000\000\000 */
{ 27323 }, /* pm_data_from_dl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss\000event=0xe0040000000c040\000\00000\000\000 */
{ 27549 }, /* pm_data_from_dl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe0040000020c040\000\00000\000\000 */
{ 31687 }, /* pm_data_from_dl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe0340000000c040\000\00000\000\000 */
{ 32058 }, /* pm_data_from_dl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe0340000020c040\000\00000\000\000 */
{ 31058 }, /* pm_data_from_dl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe4240000000c040\000\00000\000\000 */
{ 31273 }, /* pm_data_from_dl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe4240000020c040\000\00000\000\000 */
{ 30567 }, /* pm_data_from_dl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe0240000000c040\000\00000\000\000 */
{ 30801 }, /* pm_data_from_dl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe0240000020c040\000\00000\000\000 */
{ 30025 }, /* pm_data_from_dl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss\000event=0xe8140000000c040\000\00000\000\000 */
{ 30380 }, /* pm_data_from_dl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe8140000020c040\000\00000\000\000 */
{ 29420 }, /* pm_data_from_dl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss\000event=0xec040000000c040\000\00000\000\000 */
{ 29627 }, /* pm_data_from_dl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xec040000020c040\000\00000\000\000 */
{ 28945 }, /* pm_data_from_dl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss\000event=0xe8040000000c040\000\00000\000\000 */
{ 29171 }, /* pm_data_from_dl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe8040000020c040\000\00000\000\000 */
{ 32409 }, /* pm_data_from_dmem\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss\000event=0xf4040000000c040\000\00000\000\000 */
{ 32740 }, /* pm_data_from_dmem_all\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload\000event=0xf4040000020c040\000\00000\000\000 */
{ 1505 }, /* pm_data_from_l1miss\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss\000event=0x3f40000000c040\000\00000\000\000 */
{ 1860 }, /* pm_data_from_l1miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload\000event=0x3f40000020c040\000\00000\000\000 */
{ 858 }, /* pm_data_from_l2\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss\000event=0x340000000c040\000\00000\000\000 */
{ 13797 }, /* pm_data_from_l21_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa0140000000c040\000\00000\000\000 */
{ 14212 }, /* pm_data_from_l21_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0140000020c040\000\00000\000\000 */
{ 13102 }, /* pm_data_from_l21_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa4040000000c040\000\00000\000\000 */
{ 13339 }, /* pm_data_from_l21_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa4040000020c040\000\00000\000\000 */
{ 12567 }, /* pm_data_from_l21_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa0040000000c040\000\00000\000\000 */
{ 12823 }, /* pm_data_from_l21_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0040000020c040\000\00000\000\000 */
{ 8288 }, /* pm_data_from_l21_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x80140000000c040\000\00000\000\000 */
{ 8689 }, /* pm_data_from_l21_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80140000020c040\000\00000\000\000 */
{ 7614 }, /* pm_data_from_l21_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x84040000000c040\000\00000\000\000 */
{ 7844 }, /* pm_data_from_l21_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x84040000020c040\000\00000\000\000 */
{ 7093 }, /* pm_data_from_l21_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x80040000000c040\000\00000\000\000 */
{ 7342 }, /* pm_data_from_l21_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80040000020c040\000\00000\000\000 */
{ 1171 }, /* pm_data_from_l2_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss or prefetch reload\000event=0x340000020c040\000\00000\000\000 */
{ 2927 }, /* pm_data_from_l2_ldhitst_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss\000event=0x8040000000c040\000\00000\000\000 */
{ 3143 }, /* pm_data_from_l2_ldhitst_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss or prefetch reload\000event=0x8040000020c040\000\00000\000\000 */
{ 2496 }, /* pm_data_from_l2_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss\000event=0x4040000000c040\000\00000\000\000 */
{ 2700 }, /* pm_data_from_l2_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss or prefetch reload\000event=0x4040000020c040\000\00000\000\000 */
{ 2047 }, /* pm_data_from_l2_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss\000event=0x40000000c040\000\00000\000\000 */
{ 2260 }, /* pm_data_from_l2_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss or prefetch reload\000event=0x40000020c040\000\00000\000\000 */
{ 3382 }, /* pm_data_from_l2_other_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss\000event=0xc040000000c040\000\00000\000\000 */
{ 3604 }, /* pm_data_from_l2_other_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss or prefetch reload\000event=0xc040000020c040\000\00000\000\000 */
{ 261 }, /* pm_data_from_l2miss\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss\000event=0x200fe\000\00000\000\000 */
{ 4374 }, /* pm_data_from_l2miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload\000event=0x3c0000020c040\000\00000\000\000 */
{ 4016 }, /* pm_data_from_l2miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss\000event=0x3c0000000c040\000\00000\000\000 */
{ 4709 }, /* pm_data_from_l3\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss\000event=0x10340000000c040\000\00000\000\000 */
{ 15659 }, /* pm_data_from_l31_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xa8140000000c040\000\00000\000\000 */
{ 16074 }, /* pm_data_from_l31_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa8140000020c040\000\00000\000\000 */
{ 14964 }, /* pm_data_from_l31_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xac040000000c040\000\00000\000\000 */
{ 15201 }, /* pm_data_from_l31_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xac040000020c040\000\00000\000\000 */
{ 14429 }, /* pm_data_from_l31_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xa8040000000c040\000\00000\000\000 */
{ 14685 }, /* pm_data_from_l31_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa8040000020c040\000\00000\000\000 */
{ 10094 }, /* pm_data_from_l31_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x88140000000c040\000\00000\000\000 */
{ 10495 }, /* pm_data_from_l31_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x88140000020c040\000\00000\000\000 */
{ 9420 }, /* pm_data_from_l31_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x8c040000000c040\000\00000\000\000 */
{ 9650 }, /* pm_data_from_l31_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x8c040000020c040\000\00000\000\000 */
{ 8899 }, /* pm_data_from_l31_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x88040000000c040\000\00000\000\000 */
{ 9148 }, /* pm_data_from_l31_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x88040000020c040\000\00000\000\000 */
{ 5026 }, /* pm_data_from_l3_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload\000event=0x10340000020c040\000\00000\000\000 */
{ 6082 }, /* pm_data_from_l3_conflict\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss\000event=0x1c040000000c040\000\00000\000\000 */
{ 6236 }, /* pm_data_from_l3_conflict_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload\000event=0x1c040000020c040\000\00000\000\000 */
{ 5649 }, /* pm_data_from_l3_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss\000event=0x14040000000c040\000\00000\000\000 */
{ 5854 }, /* pm_data_from_l3_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss or prefetch reload\000event=0x14040000020c040\000\00000\000\000 */
{ 5194 }, /* pm_data_from_l3_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss\000event=0x10040000000c040\000\00000\000\000 */
{ 5410 }, /* pm_data_from_l3_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss or prefetch reload\000event=0x10040000020c040\000\00000\000\000 */
{ 416 }, /* pm_data_from_l3miss\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x300fe\000\00000\000\000 */
{ 6916 }, /* pm_data_from_l3miss_all\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload\000event=0x7c0000020c040\000\00000\000\000 */
{ 6576 }, /* pm_data_from_l3miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x7c0000000c040\000\00000\000\000 */
{ 19748 }, /* pm_data_from_l_oc_any\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss\000event=0x98140000000c040\000\00000\000\000 */
{ 20121 }, /* pm_data_from_l_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0x98140000020c040\000\00000\000\000 */
{ 18867 }, /* pm_data_from_l_oc_cache\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss\000event=0x98040000000c040\000\00000\000\000 */
{ 19032 }, /* pm_data_from_l_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss or prefetch reload\000event=0x98040000020c040\000\00000\000\000 */
{ 19220 }, /* pm_data_from_l_oc_mem\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss\000event=0x9c040000000c040\000\00000\000\000 */
{ 19384 }, /* pm_data_from_l_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss or prefetch reload\000event=0x9c040000020c040\000\00000\000\000 */
{ 18364 }, /* pm_data_from_lmem\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss\000event=0x94040000000c040\000\00000\000\000 */
{ 18693 }, /* pm_data_from_lmem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss or prefetch reload\000event=0x94040000020c040\000\00000\000\000 */
{ 562 }, /* pm_data_from_memory\000datasource\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss\000event=0x400fe\000\00000\000\000 */
{ 17556 }, /* pm_data_from_non_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa0340000000c040\000\00000\000\000 */
{ 17985 }, /* pm_data_from_non_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0340000020c040\000\00000\000\000 */
{ 16840 }, /* pm_data_from_non_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa4240000000c040\000\00000\000\000 */
{ 17084 }, /* pm_data_from_non_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa4240000020c040\000\00000\000\000 */
{ 16291 }, /* pm_data_from_non_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa0240000000c040\000\00000\000\000 */
{ 16554 }, /* pm_data_from_non_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0240000020c040\000\00000\000\000 */
{ 35317 }, /* pm_data_from_offchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss\000event=0xc0b40000000c040\000\00000\000\000 */
{ 35708 }, /* pm_data_from_offchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload\000event=0xc0b40000020c040\000\00000\000\000 */
{ 34547 }, /* pm_data_from_onchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss\000event=0x80b40000000c040\000\00000\000\000 */
{ 34930 }, /* pm_data_from_onchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload\000event=0x80b40000020c040\000\00000\000\000 */
{ 26757 }, /* pm_data_from_r_oc_any\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss\000event=0xd8140000000c040\000\00000\000\000 */
{ 27128 }, /* pm_data_from_r_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xd8140000020c040\000\00000\000\000 */
{ 25881 }, /* pm_data_from_r_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss\000event=0xd8040000000c040\000\00000\000\000 */
{ 26045 }, /* pm_data_from_r_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss or prefetch reload\000event=0xd8040000020c040\000\00000\000\000 */
{ 26232 }, /* pm_data_from_r_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss\000event=0xdc040000000c040\000\00000\000\000 */
{ 26395 }, /* pm_data_from_r_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss or prefetch reload\000event=0xdc040000020c040\000\00000\000\000 */
{ 11935 }, /* pm_data_from_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x80340000000c040\000\00000\000\000 */
{ 12350 }, /* pm_data_from_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80340000020c040\000\00000\000\000 */
{ 11240 }, /* pm_data_from_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x84240000000c040\000\00000\000\000 */
{ 11477 }, /* pm_data_from_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x84240000020c040\000\00000\000\000 */
{ 10705 }, /* pm_data_from_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x80240000000c040\000\00000\000\000 */
{ 10961 }, /* pm_data_from_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80240000020c040\000\00000\000\000 */
{ 21392 }, /* pm_data_from_rl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss\000event=0xc0140000000c040\000\00000\000\000 */
{ 21745 }, /* pm_data_from_rl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc0140000020c040\000\00000\000\000 */
{ 20790 }, /* pm_data_from_rl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss\000event=0xc4040000000c040\000\00000\000\000 */
{ 20996 }, /* pm_data_from_rl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc4040000020c040\000\00000\000\000 */
{ 20317 }, /* pm_data_from_rl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss\000event=0xc0040000000c040\000\00000\000\000 */
{ 20542 }, /* pm_data_from_rl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc0040000020c040\000\00000\000\000 */
{ 24660 }, /* pm_data_from_rl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc0340000000c040\000\00000\000\000 */
{ 25029 }, /* pm_data_from_rl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc0340000020c040\000\00000\000\000 */
{ 24034 }, /* pm_data_from_rl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc4240000000c040\000\00000\000\000 */
{ 24248 }, /* pm_data_from_rl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc4240000020c040\000\00000\000\000 */
{ 23545 }, /* pm_data_from_rl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc0240000000c040\000\00000\000\000 */
{ 23778 }, /* pm_data_from_rl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc0240000020c040\000\00000\000\000 */
{ 23006 }, /* pm_data_from_rl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss\000event=0xc8140000000c040\000\00000\000\000 */
{ 23359 }, /* pm_data_from_rl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc8140000020c040\000\00000\000\000 */
{ 22404 }, /* pm_data_from_rl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss\000event=0xcc040000000c040\000\00000\000\000 */
{ 22610 }, /* pm_data_from_rl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xcc040000020c040\000\00000\000\000 */
{ 21931 }, /* pm_data_from_rl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss\000event=0xc8040000000c040\000\00000\000\000 */
{ 22156 }, /* pm_data_from_rl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc8040000020c040\000\00000\000\000 */
{ 25378 }, /* pm_data_from_rmem\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss\000event=0xd4040000000c040\000\00000\000\000 */
{ 25707 }, /* pm_data_from_rmem_all\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload\000event=0xd4040000020c040\000\00000\000\000 */
{ 94453 }, /* pm_derat_miss\000memory\000DERAT Reloaded to satisfy a DERAT miss. All page sizes are counted by this event. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x200f6\000\00000\000\000 */
{ 95139 }, /* pm_derat_miss_16m\000memory\000Data ERAT Miss (Data TLB Access) page size 16M. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c054\000\00000\000\000 */
{ 94197 }, /* pm_derat_miss_1g\000memory\000Data ERAT Miss (Data TLB Access) page size 1G. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c05a\000\00000\000\000 */
{ 101079 }, /* pm_derat_miss_2m\000pipeline\000Data ERAT Miss (Data TLB Access) page size 2M. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05a\000\00000\000\000 */
{ 92200 }, /* pm_derat_miss_4k\000memory\000Data ERAT Miss (Data TLB Access) page size 4K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c056\000\00000\000\000 */
{ 93754 }, /* pm_derat_miss_64k\000memory\000Data ERAT Miss (Data TLB Access) page size 64K. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c054\000\00000\000\000 */
{ 94714 }, /* pm_derat_miss_pref\000memory\000DERAT miss (TLB access) while servicing a data prefetch\000event=0x34044\000\00000\000\000 */
{ 102292 }, /* pm_disp_held_cyc\000pipeline\000Cycles dispatch is held\000event=0x1f058\000\00000\000\000 */
{ 106501 }, /* pm_disp_held_other_cyc\000pipeline\000Cycles dispatch is held for any other reason\000event=0x20066\000\00000\000\000 */
{ 114064 }, /* pm_disp_held_rename_cyc\000pipeline\000Cycles dispatch is held because the mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR and XVFC\000event=0x40062\000\00000\000\000 */
{ 113907 }, /* pm_disp_held_scoreboard_cyc\000pipeline\000Cycles dispatch is held while waiting on the Scoreboard. This event combines VSCR and FPSCR together\000event=0x40060\000\00000\000\000 */
{ 106597 }, /* pm_disp_held_stf_mapper_cyc\000pipeline\000Cycles dispatch is held because the STF mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR\000event=0x2006a\000\00000\000\000 */
{ 97071 }, /* pm_disp_held_sync_cyc\000others\000Cycles dispatch is held because of a synchronizing instruction that requires the ICT to be empty before dispatch\000event=0x1f05a\000\00000\000\000 */
{ 110402 }, /* pm_disp_held_xvfc_mapper_cyc\000pipeline\000Cycles dispatch is held because the XVFC mapper/SRB was full\000event=0x30060\000\00000\000\000 */
{ 96954 }, /* pm_disp_ss0_2_instr_cyc\000others\000Cycles in which Superslice 0 dispatches either 1 or 2 instructions\000event=0x1f056\000\00000\000\000 */
{ 98413 }, /* pm_disp_ss0_4_instr_cyc\000others\000Cycles in which Superslice 0 dispatches either 3 or 4 instructions\000event=0x3f054\000\00000\000\000 */
{ 98530 }, /* pm_disp_ss0_8_instr_cyc\000others\000Cycles in which Superslice 0 dispatches either 5, 6, 7 or 8 instructions\000event=0x3f056\000\00000\000\000 */
{ 97826 }, /* pm_disp_ss1_2_instr_cyc\000others\000Cycles in which Superslice 1 dispatches either 1 or 2 instructions\000event=0x2f054\000\00000\000\000 */
{ 97943 }, /* pm_disp_ss1_4_instr_cyc\000others\000Cycles in which Superslice 1 dispatches either 3 or 4 instructions\000event=0x2f056\000\00000\000\000 */
{ 112801 }, /* pm_disp_stall_br_mpred\000pipeline\000Cycles when dispatch was stalled for this thread due to a mispredicted branch\000event=0x4d01e\000\00000\000\000 */
{ 100414 }, /* pm_disp_stall_br_mpred_ic_l2\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L2 after suffering a branch mispredict\000event=0x1003a\000\00000\000\000 */
{ 104153 }, /* pm_disp_stall_br_mpred_ic_l3\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L3 after suffering a branch mispredict\000event=0x2c01e\000\00000\000\000 */
{ 110923 }, /* pm_disp_stall_br_mpred_ic_l3miss\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from sources beyond the local L3 after suffering a mispredicted branch\000event=0x4c010\000\00000\000\000 */
{ 109890 }, /* pm_disp_stall_br_mpred_icmiss\000pipeline\000Cycles when dispatch was stalled after a mispredicted branch resulted in an instruction cache miss\000event=0x34058\000\00000\000\000 */
{ 102732 }, /* pm_disp_stall_cyc\000pipeline\000Cycles the ICT has no itags assigned to this thread (no instructions were dispatched during these cycles)\000event=0x100f8\000\00000\000\000 */
{ 105251 }, /* pm_disp_stall_fetch\000pipeline\000Cycles when dispatch was stalled for this thread because Fetch was being held\000event=0x2e018\000\00000\000\000 */
{ 106761 }, /* pm_disp_stall_flush\000pipeline\000Cycles when dispatch was stalled because of a flush that happened to an instruction(s) that was not yet next-to-complete (NTC). PM_EXEC_STALL_NTC_FLUSH only includes instructions that were flushed after becoming NTC\000event=0x30004\000\00000\000\000 */
{ 113357 }, /* pm_disp_stall_held_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch for any reason\000event=0x4e01a\000\00000\000\000 */
{ 101337 }, /* pm_disp_stall_held_halt_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because of power management\000event=0x1d05e\000\00000\000\000 */
{ 103016 }, /* pm_disp_stall_held_issq_full_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch due to Issue queue full. Includes issue queue and branch queue\000event=0x20006\000\00000\000\000 */
{ 99549 }, /* pm_disp_stall_held_other_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch for any other reason\000event=0x10006\000\00000\000\000 */
{ 110047 }, /* pm_disp_stall_held_rename_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because the mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR and XVFC\000event=0x3d05c\000\00000\000\000 */
{ 107576 }, /* pm_disp_stall_held_scoreboard_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch while waiting on the Scoreboard. This event combines VSCR and FPSCR together\000event=0x30018\000\00000\000\000 */
{ 101496 }, /* pm_disp_stall_held_stf_mapper_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because the STF mapper/SRB was full. Includes GPR (count, link, tar), VSR, VMR, FPR\000event=0x1e050\000\00000\000\000 */
{ 113581 }, /* pm_disp_stall_held_sync_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000event=0x4003c\000\00000\000\000 */
{ 105377 }, /* pm_disp_stall_held_xvfc_mapper_cyc\000pipeline\000Cycles in which the next-to-complete (NTC) instruction is held at dispatch because the XVFC mapper/SRB was full\000event=0x2e01a\000\00000\000\000 */
{ 102361 }, /* pm_disp_stall_ic_l2\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L2\000event=0x10064\000\00000\000\000 */
{ 110269 }, /* pm_disp_stall_ic_l3\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from the local L3\000event=0x3e052\000\00000\000\000 */
{ 112930 }, /* pm_disp_stall_ic_l3miss\000pipeline\000Cycles when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000event=0x4e010\000\00000\000\000 */
{ 104951 }, /* pm_disp_stall_ic_miss\000pipeline\000Cycles when dispatch was stalled for this thread due to an instruction cache miss\000event=0x2d01a\000\00000\000\000 */
{ 103647 }, /* pm_disp_stall_ierat_only_miss\000pipeline\000Cycles when dispatch was stalled while waiting to resolve an instruction ERAT miss\000event=0x2c016\000\00000\000\000 */
{ 80693 }, /* pm_disp_stall_itlb_miss\000frontend\000Cycles when dispatch was stalled while waiting to resolve an instruction TLB miss\000event=0x3000a\000\00000\000\000 */
{ 100263 }, /* pm_disp_stall_translation\000pipeline\000Cycles when dispatch was stalled for this thread because the MMU was handling a translation miss\000event=0x10038\000\00000\000\000 */
{ 79170 }, /* pm_dpp_flop_cmpl\000floating_point\000Double-Precision or Quad-Precision instruction completed\000event=0x4d05c\000\00000\000\000 */
{ 79748 }, /* pm_dtlb_hit\000frontend\000The PTE required by the instruction was resident in the TLB (data TLB access). When MMCR1[16]=0 this event counts only demand hits. When MMCR1[16]=1 this event includes demand and prefetch. Applies to both HPT and RPT\000event=0x1f054\000\00000\000\000 */
{ 82329 }, /* pm_dtlb_hit_1g\000frontend\000Data TLB hit (DERAT reload) page size 1G. Implies radix translation. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4e054\000\00000\000\000 */
{ 79278 }, /* pm_dtlb_hit_2m\000frontend\000Data TLB hit (DERAT reload) page size 2M. Implies radix translation. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1d054\000\00000\000\000 */
{ 81258 }, /* pm_dtlb_hit_64k\000frontend\000Data TLB hit (DERAT reload) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c05a\000\00000\000\000 */
{ 95722 }, /* pm_dtlb_miss\000memory\000The DPTEG required for the load/store instruction in execution was missing from the TLB. This event only counts for demand misses\000event=0x300fc\000\00000\000\000 */
{ 92429 }, /* pm_dtlb_miss_16g\000memory\000Data TLB reload (after a miss) page size 16G. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c058\000\00000\000\000 */
{ 96279 }, /* pm_dtlb_miss_16m\000memory\000Data TLB reload (after a miss) page size 16M. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c056\000\00000\000\000 */
{ 96493 }, /* pm_dtlb_miss_1g\000memory\000Data TLB reload (after a miss) page size 1G. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c05a\000\00000\000\000 */
{ 92643 }, /* pm_dtlb_miss_2m\000memory\000Data TLB reload (after a miss) page size 2M. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1c05c\000\00000\000\000 */
{ 93985 }, /* pm_dtlb_miss_4k\000memory\000Data TLB reload (after a miss) page size 4K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2c056\000\00000\000\000 */
{ 95370 }, /* pm_dtlb_miss_64k\000memory\000Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3c056\000\00000\000\000 */
{ 107025 }, /* pm_exec_stall\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting to finish in one of the execution units (BRU, LSU, VSU). Only cycles between issue and finish are counted in this category\000event=0x30008\000\00000\000\000 */
{ 112237 }, /* pm_exec_stall_bru\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the Branch unit\000event=0x4d018\000\00000\000\000 */
{ 107417 }, /* pm_exec_stall_derat_dtlb_miss\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss and waited for it resolve\000event=0x30016\000\00000\000\000 */
{ 111122 }, /* pm_exec_stall_derat_only_miss\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered an ERAT miss and waited for it resolve\000event=0x4c012\000\00000\000\000 */
{ 101717 }, /* pm_exec_stall_dmiss_l21_l31\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from another core's L2 or L3 on the same chip\000event=0x1e054\000\00000\000\000 */
{ 100592 }, /* pm_exec_stall_dmiss_l2l3\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from either the local L2 or local L3\000event=0x1003c\000\00000\000\000 */
{ 111283 }, /* pm_exec_stall_dmiss_l2l3_conflict\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, with a dispatch conflict\000event=0x4c016\000\00000\000\000 */
{ 109202 }, /* pm_exec_stall_dmiss_l2l3_noconflict\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local L2 or local L3, without a dispatch conflict\000event=0x34054\000\00000\000\000 */
{ 103788 }, /* pm_exec_stall_dmiss_l3miss\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a source beyond the local L2 or local L3\000event=0x2c018\000\00000\000\000 */
{ 108531 }, /* pm_exec_stall_dmiss_lmem\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from the local memory, local OpenCAPI cache, or local OpenCAPI memory\000event=0x30038\000\00000\000\000 */
{ 103983 }, /* pm_exec_stall_dmiss_off_chip\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a remote chip\000event=0x2c01c\000\00000\000\000 */
{ 111654 }, /* pm_exec_stall_dmiss_off_node\000pipeline\000Cycles in which the oldest instruction in the pipeline was waiting for a load miss to resolve from a distant chip\000event=0x4c01a\000\00000\000\000 */
{ 100776 }, /* pm_exec_stall_fin_at_disp\000pipeline\000Cycles in which the oldest instruction in the pipeline finished at dispatch and did not require execution in the LSU, BRU or VSU\000event=0x10058\000\00000\000\000 */
{ 111915 }, /* pm_exec_stall_load\000pipeline\000Cycles in which the oldest instruction in the pipeline was a load instruction executing in the Load Store Unit\000event=0x4d014\000\00000\000\000 */
{ 109419 }, /* pm_exec_stall_load_finish\000pipeline\000Cycles in which the oldest instruction in the pipeline was finishing a load after its data was reloaded from a data source beyond the local L1; cycles in which the LSU was processing an L1-hit; cycles in which the next-to-finish (NTF) instruction merged with another load in the LMQ; cycles in which the NTF instruction is waiting for a data reload for a load miss, but the data comes back with a non-NTF instruction\000event=0x34056\000\00000\000\000 */
{ 103305 }, /* pm_exec_stall_lsu\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the Load Store Unit. This does not include simple fixed point instructions\000event=0x2c010\000\00000\000\000 */
{ 105712 }, /* pm_exec_stall_ntc_flush\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in any unit before it was flushed. Note that if the flush of the oldest instruction happens after finish, the cycles from dispatch to issue will be included in PM_DISP_STALL and the cycles from issue to finish will be included in PM_EXEC_STALL and its corresponding children. This event will also count cycles when the previous next-to-finish (NTF) instruction is still completing and the new NTF instruction is stalled at dispatch\000event=0x2e01e\000\00000\000\000 */
{ 112073 }, /* pm_exec_stall_ptesync\000pipeline\000Cycles in which the oldest instruction in the pipeline was a PTESYNC instruction executing in the Load Store Unit\000event=0x4d016\000\00000\000\000 */
{ 108354 }, /* pm_exec_stall_simple_fx\000pipeline\000Cycles in which the oldest instruction in the pipeline was a simple fixed point instruction executing in the Load Store Unit\000event=0x30036\000\00000\000\000 */
{ 107257 }, /* pm_exec_stall_store\000pipeline\000Cycles in which the oldest instruction in the pipeline was a store instruction executing in the Load Store Unit\000event=0x30014\000\00000\000\000 */
{ 107880 }, /* pm_exec_stall_store_miss\000pipeline\000Cycles in which the oldest instruction in the pipeline was a store whose cache line was not resident in the L1 and was waiting for allocation of the missing line into the L1\000event=0x30026\000\00000\000\000 */
{ 101913 }, /* pm_exec_stall_store_pipe\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the store unit. This does not include cycles spent handling store misses, PTESYNC instructions or TLBIE instructions\000event=0x1e056\000\00000\000\000 */
{ 105552 }, /* pm_exec_stall_tlbie\000pipeline\000Cycles in which the oldest instruction in the pipeline was a TLBIE instruction executing in the Load Store Unit\000event=0x2e01c\000\00000\000\000 */
{ 112535 }, /* pm_exec_stall_tlbiel\000pipeline\000Cycles in which the oldest instruction in the pipeline was a TLBIEL instruction executing in the Load Store Unit. TLBIEL instructions have lower overhead than TLBIE instructions because they don't get set to the nest\000event=0x4d01c\000\00000\000\000 */
{ 99378 }, /* pm_exec_stall_translation\000pipeline\000Cycles in which the oldest instruction in the pipeline suffered a TLB miss or ERAT miss and waited for it to resolve\000event=0x10004\000\00000\000\000 */
{ 113085 }, /* pm_exec_stall_unknown\000pipeline\000Cycles in which the oldest instruction in the pipeline completed without an ntf_type pulse. The ntf_pulse was missed by the ISU because the next-to-finish (NTF) instruction finishes and completions came too close together\000event=0x4e012\000\00000\000\000 */
{ 104800 }, /* pm_exec_stall_vsu\000pipeline\000Cycles in which the oldest instruction in the pipeline was executing in the VSU (includes FXU, VSU, CRU)\000event=0x2d018\000\00000\000\000 */
{ 77673 }, /* pm_flop_cmpl\000floating_point\000Floating Point Operations Completed. Includes any type. It counts once for each 1, 2, 4 or 8 flop instruction. Use PM_1|2|4|8_FLOP_CMPL events to count flops\000event=0x100f4\000\00000\000\000 */
{ 114312 }, /* pm_flush\000pipeline\000Flush (any type)\000event=0x400f8\000\00000\000\000 */
{ 80827 }, /* pm_flush_completion\000frontend\000The instruction that was next to complete (oldest in the pipeline) did not complete because it suffered a flush\000event=0x30012\000\00000\000\000 */
{ 100959 }, /* pm_flush_mpred\000pipeline\000A flush occurred due to a mispredicted branch. Includes target and direction\000event=0x1005a\000\00000\000\000 */
{ 78185 }, /* pm_fma_cmpl\000floating_point\000Two floating point instruction completed (FMA class of instructions: fmadd, fnmadd, fmsub, fnmsub). Scalar instructions only\000event=0x45054\000\00000\000\000 */
{ 102609 }, /* pm_fx_lsu_fin\000pipeline\000Simple fixed point instruction issued to the store unit. Measured at finish time\000event=0x1006a\000\00000\000\000 */
{ 110614 }, /* pm_fxu_issue\000pipeline\000A fixed point instruction was issued to the VSU\000event=0x40004\000\00000\000\000 */
{ 115723 }, /* pm_hypervisor_cyc\000pmc\000Cycles when the thread is in Hypervisor state. MSR[S HV PR]=010\000event=0x2000a\000\00000\000\000 */
{ 117594 }, /* pm_hypervisor_inst_cmpl\000pmc\000PowerPC instruction completed while the thread was in hypervisor state\000event=0x4d022\000\00000\000\000 */
{ 100037 }, /* pm_ic_demand_cyc\000pipeline\000Cycles in which an instruction reload is pending to satisfy a demand miss\000event=0x10018\000\00000\000\000 */
{ 113801 }, /* pm_ic_miss_cmpl\000pipeline\000Non-speculative instruction cache miss, counted at completion\000event=0x45058\000\00000\000\000 */
{ 80121 }, /* pm_ierat_miss\000frontend\000IERAT Reloaded to satisfy an IERAT miss. All page sizes are counted by this event. This event only counts instruction demand access\000event=0x100f6\000\00000\000\000 */
{ 114366 }, /* pm_inst_cmpl\000pmc\000PowerPC instruction completed\000event=0x100fe\000\00000\000\000 */
{ 98060 }, /* pm_inst_disp\000others\000PowerPC instruction dispatched\000event=0x200f2\000\00000\000\000 */
{ 118048 }, /* pm_inst_fin\000pmc\000Instruction finished\000event=0x40030\000\00000\000\000 */
{ 35913 }, /* pm_inst_from_any_memory\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss\000event=0x95900000000c040\000\00000\000\000 */
{ 36239 }, /* pm_inst_from_any_memory_all\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload\000event=0x95900000010c040\000\00000\000\000 */
{ 33619 }, /* pm_inst_from_d_oc_any\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss\000event=0xf8100000000c040\000\00000\000\000 */
{ 33969 }, /* pm_inst_from_d_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xf8100000010c040\000\00000\000\000 */
{ 28235 }, /* pm_inst_from_dl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss\000event=0xe0100000000c040\000\00000\000\000 */
{ 28567 }, /* pm_inst_from_dl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload\000event=0xe0100000010c040\000\00000\000\000 */
{ 31511 }, /* pm_inst_from_dl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss\000event=0xe0300000000c040\000\00000\000\000 */
{ 31859 }, /* pm_inst_from_dl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe0300000010c040\000\00000\000\000 */
{ 29857 }, /* pm_inst_from_dl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss\000event=0xe8100000000c040\000\00000\000\000 */
{ 30189 }, /* pm_inst_from_dl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload\000event=0xe8100000010c040\000\00000\000\000 */
{ 32253 }, /* pm_inst_from_dmem\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss\000event=0xf4100000000c040\000\00000\000\000 */
{ 32561 }, /* pm_inst_from_dmem_all\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload\000event=0xf4100000010c040\000\00000\000\000 */
{ 1337 }, /* pm_inst_from_l1miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss\000event=0x3f00000000c040\000\00000\000\000 */
{ 1669 }, /* pm_inst_from_l1miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload\000event=0x3f00000010c040\000\00000\000\000 */
{ 711 }, /* pm_inst_from_l2\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss\000event=0x300000000c040\000\00000\000\000 */
{ 13599 }, /* pm_inst_from_l21_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss\000event=0xa0100000000c040\000\00000\000\000 */
{ 13991 }, /* pm_inst_from_l21_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0100000010c040\000\00000\000\000 */
{ 8097 }, /* pm_inst_from_l21_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss\000event=0x80100000000c040\000\00000\000\000 */
{ 8475 }, /* pm_inst_from_l21_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80100000010c040\000\00000\000\000 */
{ 1001 }, /* pm_inst_from_l2_all\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss or prefetch reload\000event=0x300000010c040\000\00000\000\000 */
{ 3849 }, /* pm_inst_from_l2miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss\000event=0x380000000c040\000\00000\000\000 */
{ 4184 }, /* pm_inst_from_l2miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload\000event=0x380000010c040\000\00000\000\000 */
{ 4560 }, /* pm_inst_from_l3\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss\000event=0x10300000000c040\000\00000\000\000 */
{ 15461 }, /* pm_inst_from_l31_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss\000event=0xa8100000000c040\000\00000\000\000 */
{ 15853 }, /* pm_inst_from_l31_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa8100000010c040\000\00000\000\000 */
{ 9903 }, /* pm_inst_from_l31_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss\000event=0x88100000000c040\000\00000\000\000 */
{ 10281 }, /* pm_inst_from_l31_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x88100000010c040\000\00000\000\000 */
{ 4854 }, /* pm_inst_from_l3_all\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss or prefetch reload\000event=0x10300000010c040\000\00000\000\000 */
{ 81856 }, /* pm_inst_from_l3miss\000frontend\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x300fa\000\00000\000\000 */
{ 6735 }, /* pm_inst_from_l3miss_all\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload\000event=0x780000010c040\000\00000\000\000 */
{ 6413 }, /* pm_inst_from_l3miss_dsrc\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss\000event=0x780000000c040\000\00000\000\000 */
{ 19571 }, /* pm_inst_from_l_oc_any\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss\000event=0x98100000000c040\000\00000\000\000 */
{ 19921 }, /* pm_inst_from_l_oc_any_all\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0x98100000010c040\000\00000\000\000 */
{ 18209 }, /* pm_inst_from_lmem\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss\000event=0x94100000000c040\000\00000\000\000 */
{ 18515 }, /* pm_inst_from_lmem_all\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss or prefetch reload\000event=0x94100000010c040\000\00000\000\000 */
{ 17351 }, /* pm_inst_from_non_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss\000event=0xa0300000000c040\000\00000\000\000 */
{ 17757 }, /* pm_inst_from_non_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload\000event=0xa0300000010c040\000\00000\000\000 */
{ 35131 }, /* pm_inst_from_offchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss\000event=0xc0b00000000c040\000\00000\000\000 */
{ 35499 }, /* pm_inst_from_offchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload\000event=0xc0b00000010c040\000\00000\000\000 */
{ 34365 }, /* pm_inst_from_onchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss\000event=0x80b00000000c040\000\00000\000\000 */
{ 34725 }, /* pm_inst_from_onchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload\000event=0x80b00000010c040\000\00000\000\000 */
{ 26581 }, /* pm_inst_from_r_oc_any\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss\000event=0xd8100000000c040\000\00000\000\000 */
{ 26929 }, /* pm_inst_from_r_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload\000event=0xd8100000010c040\000\00000\000\000 */
{ 11737 }, /* pm_inst_from_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss\000event=0x80300000000c040\000\00000\000\000 */
{ 12129 }, /* pm_inst_from_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload\000event=0x80300000010c040\000\00000\000\000 */
{ 21225 }, /* pm_inst_from_rl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss\000event=0xc0100000000c040\000\00000\000\000 */
{ 21555 }, /* pm_inst_from_rl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload\000event=0xc0100000010c040\000\00000\000\000 */
{ 24485 }, /* pm_inst_from_rl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss\000event=0xc0300000000c040\000\00000\000\000 */
{ 24831 }, /* pm_inst_from_rl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc0300000010c040\000\00000\000\000 */
{ 22839 }, /* pm_inst_from_rl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss\000event=0xc8100000000c040\000\00000\000\000 */
{ 23169 }, /* pm_inst_from_rl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload\000event=0xc8100000010c040\000\00000\000\000 */
{ 25223 }, /* pm_inst_from_rmem\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss\000event=0xd4100000000c040\000\00000\000\000 */
{ 25529 }, /* pm_inst_from_rmem_all\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload\000event=0xd4100000010c040\000\00000\000\000 */
{ 80295 }, /* pm_iops_disp\000frontend\000Internal Operations dispatched. PM_IOPS_DISP / PM_INST_DISP will show the average number of internal operations per PowerPC instruction\000event=0x24050\000\00000\000\000 */
{ 80472 }, /* pm_issue_cancel\000frontend\000An instruction issued and the issue was later cancelled. Only one cancel per PowerPC instruction\000event=0x2405e\000\00000\000\000 */
{ 82004 }, /* pm_issue_kill\000frontend\000Cycles in which an instruction or group of instructions were cancelled after being issued. This event increments once per occurrence, regardless of how many instructions are included in the issue group\000event=0x40006\000\00000\000\000 */
{ 102884 }, /* pm_issue_stall\000pipeline\000Cycles in which the oldest instruction in the pipeline was dispatched but not issued yet\000event=0x20004\000\00000\000\000 */
{ 92994 }, /* pm_itlb_hit\000memory\000The PTE required to translate the instruction address was resident in the TLB (instruction TLB access/IERAT reload). Applies to both HPT and RPT. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x2001a\000\00000\000\000 */
{ 80987 }, /* pm_itlb_hit_1g\000frontend\000Instruction TLB hit (IERAT reload) page size 1G, which implies Radix Page Table translation is in use. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x3f046\000\00000\000\000 */
{ 79529 }, /* pm_itlb_hit_64k\000frontend\000Instruction TLB hit (IERAT reload) page size 64K. When MMCR1[17]=0 this event counts only for demand misses. When MMCR1[17]=1 this event includes demand misses and prefetches\000event=0x1d058\000\00000\000\000 */
{ 82566 }, /* pm_itlb_miss\000frontend\000Instruction TLB reload (after a miss), all page sizes. Includes only demand misses\000event=0x400fc\000\00000\000\000 */
{ 98130 }, /* pm_l1_icache_miss\000others\000Demand instruction cache miss\000event=0x200fd\000\00000\000\000 */
{ 98951 }, /* pm_l1_icache_reloaded_all\000others\000Counts all instruction cache reloads includes demand, prefetch, prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\00000\000\000 */
{ 98653 }, /* pm_l1_icache_reloaded_pref\000others\000Counts all instruction cache prefetch reloads (includes demand turned into prefetch)\000event=0x30068\000\00000\000\000 */
{ 95584 }, /* pm_larx_fin\000memory\000Load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x3c058\000\00000\000\000 */
{ 95891 }, /* pm_ld_cmpl\000memory\000Load instruction completed\000event=0x4003e\000\00000\000\000 */
{ 98791 }, /* pm_ld_demand_miss_l1\000others\000The L1 cache was reloaded with a line that fulfills a demand miss request. Counted at reload time, before finish\000event=0x300f6\000\00000\000\000 */
{ 99288 }, /* pm_ld_demand_miss_l1_fin\000others\000Load missed L1, counted at finish time\000event=0x400f0\000\00000\000\000 */
{ 96869 }, /* pm_ld_hit_l1\000others\000Load finished without experiencing an L1 miss\000event=0x1505e\000\00000\000\000 */
{ 92891 }, /* pm_ld_l3miss_pend_cyc\000memory\000Cycles in which an L3 miss was pending for this thread\000event=0x10062\000\00000\000\000 */
{ 81470 }, /* pm_ld_miss_l1\000frontend\000Load missed L1, counted at finish time. LMQ merges are not included in this count. i.e. if a load instruction misses on an address that is already allocated on the LMQ, this event will not increment for that load). Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x3e054\000\00000\000\000 */
{ 96741 }, /* pm_ld_prefetch_cache_line_miss\000others\000The L1 cache was reloaded with a line that fulfills a prefetch request\000event=0x1002c\000\00000\000\000 */
{ 97345 }, /* pm_ld_ref_l1\000others\000All L1 D cache load references counted at finish, gated by reject. In P9 and earlier this event counted only cacheable loads but in P10 both cacheable and non-cacheable loads are included\000event=0x100fc\000\00000\000\000 */
{ 110520 }, /* pm_lsu_fin\000pipeline\000LSU Finished an internal operation (up to 4 per cycle)\000event=0x30066\000\00000\000\000 */
{ 99702 }, /* pm_lsu_ld0_fin\000pipeline\000LSU Finished an internal operation in LD0 port\000event=0x1000c\000\00000\000\000 */
{ 103215 }, /* pm_lsu_ld1_fin\000pipeline\000LSU Finished an internal operation in LD1 port\000event=0x2000e\000\00000\000\000 */
{ 99857 }, /* pm_lsu_st0_fin\000pipeline\000LSU Finished an internal operation in ST0 port\000event=0x10012\000\00000\000\000 */
{ 104331 }, /* pm_lsu_st1_fin\000pipeline\000LSU Finished an internal operation in ST1 port\000event=0x2d010\000\00000\000\000 */
{ 107790 }, /* pm_lsu_st2_fin\000pipeline\000LSU Finished an internal operation in ST2 port\000event=0x3001a\000\00000\000\000 */
{ 111825 }, /* pm_lsu_st3_fin\000pipeline\000LSU Finished an internal operation in ST3 port\000event=0x4c01e\000\00000\000\000 */
{ 99947 }, /* pm_lsu_st4_fin\000pipeline\000LSU Finished an internal operation in ST4 port\000event=0x10014\000\00000\000\000 */
{ 98204 }, /* pm_lsu_st5_fin\000others\000LSU Finished an internal operation in ST2 port\000event=0x3f04a\000\00000\000\000 */
{ 78558 }, /* pm_math_flop_cmpl\000floating_point\000Math floating point instruction completed\000event=0x4505c\000\00000\000\000 */
{ 99792 }, /* pm_mma_issued\000pipeline\000MMA instruction issued\000event=0x1000e\000\00000\000\000 */
{ 86527 }, /* pm_mrk_br_cmpl\000marked\000A marked branch completed. All branches are included\000event=0x2415c\000\00000\000\000 */
{ 89044 }, /* pm_mrk_br_mpred_cmpl\000marked\000Marked Branch Mispredicted. Includes direction and target\000event=0x301e4\000\00000\000\000 */
{ 84316 }, /* pm_mrk_br_taken_cmpl\000marked\000Marked Branch Taken instruction completed\000event=0x101e2\000\00000\000\000 */
{ 85430 }, /* pm_mrk_bru_fin\000marked\000Marked Branch instruction finished\000event=0x2013a\000\00000\000\000 */
{ 77053 }, /* pm_mrk_data_from_any_memory\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss for a marked instruction\000event=0x95840000000c142\000\00000\000\000 */
{ 77460 }, /* pm_mrk_data_from_any_memory_all\000datasource\000The processor's L1 data cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0x95840000020c142\000\00000\000\000 */
{ 74423 }, /* pm_mrk_data_from_d_oc_any\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xf8140000000c142\000\00000\000\000 */
{ 74854 }, /* pm_mrk_data_from_d_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xf8140000020c142\000\00000\000\000 */
{ 73397 }, /* pm_mrk_data_from_d_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss for a marked instruction\000event=0xf8040000000c142\000\00000\000\000 */
{ 73591 }, /* pm_mrk_data_from_d_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI cache due to a demand miss or prefetch reload for a marked instruction\000event=0xf8040000020c142\000\00000\000\000 */
{ 73808 }, /* pm_mrk_data_from_d_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss for a marked instruction\000event=0xfc040000000c142\000\00000\000\000 */
{ 74001 }, /* pm_mrk_data_from_d_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a distant chip's OpenCAPI memory due to a demand miss or prefetch reload for a marked instruction\000event=0xfc040000020c142\000\00000\000\000 */
{ 68218 }, /* pm_mrk_data_from_dl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe0140000000c142\000\00000\000\000 */
{ 68631 }, /* pm_mrk_data_from_dl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0140000020c142\000\00000\000\000 */
{ 67526 }, /* pm_mrk_data_from_dl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe4040000000c142\000\00000\000\000 */
{ 67762 }, /* pm_mrk_data_from_dl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe4040000020c142\000\00000\000\000 */
{ 66993 }, /* pm_mrk_data_from_dl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe0040000000c142\000\00000\000\000 */
{ 67248 }, /* pm_mrk_data_from_dl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0040000020c142\000\00000\000\000 */
{ 71966 }, /* pm_mrk_data_from_dl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe0340000000c142\000\00000\000\000 */
{ 72395 }, /* pm_mrk_data_from_dl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0340000020c142\000\00000\000\000 */
{ 71250 }, /* pm_mrk_data_from_dl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe4240000000c142\000\00000\000\000 */
{ 71494 }, /* pm_mrk_data_from_dl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe4240000020c142\000\00000\000\000 */
{ 70701 }, /* pm_mrk_data_from_dl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe0240000000c142\000\00000\000\000 */
{ 70964 }, /* pm_mrk_data_from_dl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0240000020c142\000\00000\000\000 */
{ 70072 }, /* pm_mrk_data_from_dl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe8140000000c142\000\00000\000\000 */
{ 70485 }, /* pm_mrk_data_from_dl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe8140000020c142\000\00000\000\000 */
{ 69380 }, /* pm_mrk_data_from_dl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xec040000000c142\000\00000\000\000 */
{ 69616 }, /* pm_mrk_data_from_dl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xec040000020c142\000\00000\000\000 */
{ 68847 }, /* pm_mrk_data_from_dl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe8040000000c142\000\00000\000\000 */
{ 69102 }, /* pm_mrk_data_from_dl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe8040000020c142\000\00000\000\000 */
{ 72804 }, /* pm_mrk_data_from_dmem\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss for a marked instruction\000event=0xf4040000000c142\000\00000\000\000 */
{ 73193 }, /* pm_mrk_data_from_dmem_all\000datasource\000The processor's L1 data cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xf4040000020c142\000\00000\000\000 */
{ 37550 }, /* pm_mrk_data_from_l1miss\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss for a marked instruction\000event=0x3f40000000c142\000\00000\000\000 */
{ 37963 }, /* pm_mrk_data_from_l1miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload for a marked instruction\000event=0x3f40000020c142\000\00000\000\000 */
{ 36787 }, /* pm_mrk_data_from_l2\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss for a marked instruction\000event=0x340000000c142\000\00000\000\000 */
{ 51524 }, /* pm_mrk_data_from_l21_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0140000000c142\000\00000\000\000 */
{ 51997 }, /* pm_mrk_data_from_l21_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0140000020c142\000\00000\000\000 */
{ 50742 }, /* pm_mrk_data_from_l21_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa4040000000c142\000\00000\000\000 */
{ 51008 }, /* pm_mrk_data_from_l21_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa4040000020c142\000\00000\000\000 */
{ 50149 }, /* pm_mrk_data_from_l21_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0040000000c142\000\00000\000\000 */
{ 50434 }, /* pm_mrk_data_from_l21_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0040000020c142\000\00000\000\000 */
{ 45319 }, /* pm_mrk_data_from_l21_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80140000000c142\000\00000\000\000 */
{ 45778 }, /* pm_mrk_data_from_l21_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80140000020c142\000\00000\000\000 */
{ 44558 }, /* pm_mrk_data_from_l21_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x84040000000c142\000\00000\000\000 */
{ 44817 }, /* pm_mrk_data_from_l21_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x84040000020c142\000\00000\000\000 */
{ 43979 }, /* pm_mrk_data_from_l21_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80040000000c142\000\00000\000\000 */
{ 44257 }, /* pm_mrk_data_from_l21_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80040000020c142\000\00000\000\000 */
{ 37158 }, /* pm_mrk_data_from_l2_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x340000020c142\000\00000\000\000 */
{ 39175 }, /* pm_mrk_data_from_l2_ldhitst_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss for a marked instruction\000event=0x8040000000c142\000\00000\000\000 */
{ 39420 }, /* pm_mrk_data_from_l2_ldhitst_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict on ld-hit-store from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x8040000020c142\000\00000\000\000 */
{ 38686 }, /* pm_mrk_data_from_l2_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss for a marked instruction\000event=0x4040000000c142\000\00000\000\000 */
{ 38919 }, /* pm_mrk_data_from_l2_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x4040000020c142\000\00000\000\000 */
{ 38179 }, /* pm_mrk_data_from_l2_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss for a marked instruction\000event=0x40000000c142\000\00000\000\000 */
{ 38421 }, /* pm_mrk_data_from_l2_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x40000020c142\000\00000\000\000 */
{ 39688 }, /* pm_mrk_data_from_l2_other_conflict\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss for a marked instruction\000event=0xc040000000c142\000\00000\000\000 */
{ 39939 }, /* pm_mrk_data_from_l2_other_conflict_all\000datasource\000The processor's L1 data cache was reloaded with data that had a dispatch conflict other than ld-hit-store from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0xc040000020c142\000\00000\000\000 */
{ 91697 }, /* pm_mrk_data_from_l2miss\000marked\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss for a marked instruction\000event=0x401e8\000\00000\000\000 */
{ 40825 }, /* pm_mrk_data_from_l2miss_all\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x3c0000020c142\000\00000\000\000 */
{ 40409 }, /* pm_mrk_data_from_l2miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from a source beyond the local core's L2 due to a demand miss for a marked instruction\000event=0x3c0000000c142\000\00000\000\000 */
{ 41218 }, /* pm_mrk_data_from_l3\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss for a marked instruction\000event=0x10340000000c142\000\00000\000\000 */
{ 53618 }, /* pm_mrk_data_from_l31_non_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa8140000000c142\000\00000\000\000 */
{ 54091 }, /* pm_mrk_data_from_l31_non_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa8140000020c142\000\00000\000\000 */
{ 52836 }, /* pm_mrk_data_from_l31_non_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xac040000000c142\000\00000\000\000 */
{ 53102 }, /* pm_mrk_data_from_l31_non_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xac040000020c142\000\00000\000\000 */
{ 52243 }, /* pm_mrk_data_from_l31_non_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa8040000000c142\000\00000\000\000 */
{ 52528 }, /* pm_mrk_data_from_l31_non_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa8040000020c142\000\00000\000\000 */
{ 47357 }, /* pm_mrk_data_from_l31_regent\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x88140000000c142\000\00000\000\000 */
{ 47816 }, /* pm_mrk_data_from_l31_regent_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x88140000020c142\000\00000\000\000 */
{ 46596 }, /* pm_mrk_data_from_l31_regent_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x8c040000000c142\000\00000\000\000 */
{ 46855 }, /* pm_mrk_data_from_l31_regent_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x8c040000020c142\000\00000\000\000 */
{ 46017 }, /* pm_mrk_data_from_l31_regent_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x88040000000c142\000\00000\000\000 */
{ 46295 }, /* pm_mrk_data_from_l31_regent_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x88040000020c142\000\00000\000\000 */
{ 41593 }, /* pm_mrk_data_from_l3_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x10340000020c142\000\00000\000\000 */
{ 42794 }, /* pm_mrk_data_from_l3_conflict\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss for a marked instruction\000event=0x1c040000000c142\000\00000\000\000 */
{ 42977 }, /* pm_mrk_data_from_l3_conflict_all\000datasource\000The processor's L1 data cache was reloaded from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x1c040000020c142\000\00000\000\000 */
{ 42303 }, /* pm_mrk_data_from_l3_mepf\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss for a marked instruction\000event=0x14040000000c142\000\00000\000\000 */
{ 42537 }, /* pm_mrk_data_from_l3_mepf_all\000datasource\000The processor's L1 data cache was reloaded with data in the MEPF state without dispatch conflicts from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x14040000020c142\000\00000\000\000 */
{ 41790 }, /* pm_mrk_data_from_l3_no_conflict\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss for a marked instruction\000event=0x10040000000c142\000\00000\000\000 */
{ 42035 }, /* pm_mrk_data_from_l3_no_conflict_all\000datasource\000The processor's L1 data cache was reloaded without dispatch conflicts with data NOT in the MEPF state from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x10040000020c142\000\00000\000\000 */
{ 87144 }, /* pm_mrk_data_from_l3miss\000marked\000The processor's data cache was reloaded from a source other than the local core's L1, L2, or L3 due to a demand miss for a marked load\000event=0x201e4\000\00000\000\000 */
{ 43773 }, /* pm_mrk_data_from_l3miss_all\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x7c0000020c142\000\00000\000\000 */
{ 43375 }, /* pm_mrk_data_from_l3miss_dsrc\000datasource\000The processor's L1 data cache was reloaded from beyond the local core's L3 due to a demand miss for a marked instruction\000event=0x7c0000000c142\000\00000\000\000 */
{ 58287 }, /* pm_mrk_data_from_l_oc_any\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0x98140000000c142\000\00000\000\000 */
{ 58718 }, /* pm_mrk_data_from_l_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0x98140000020c142\000\00000\000\000 */
{ 57261 }, /* pm_mrk_data_from_l_oc_cache\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss for a marked instruction\000event=0x98040000000c142\000\00000\000\000 */
{ 57455 }, /* pm_mrk_data_from_l_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI cache due to a demand miss or prefetch reload for a marked instruction\000event=0x98040000020c142\000\00000\000\000 */
{ 57672 }, /* pm_mrk_data_from_l_oc_mem\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss for a marked instruction\000event=0x9c040000000c142\000\00000\000\000 */
{ 57865 }, /* pm_mrk_data_from_l_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's OpenCAPI memory due to a demand miss or prefetch reload for a marked instruction\000event=0x9c040000020c142\000\00000\000\000 */
{ 56671 }, /* pm_mrk_data_from_lmem\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss for a marked instruction\000event=0x94040000000c142\000\00000\000\000 */
{ 57058 }, /* pm_mrk_data_from_lmem_all\000datasource\000The processor's L1 data cache was reloaded from the local chip's memory due to a demand miss or prefetch reload for a marked instruction\000event=0x94040000020c142\000\00000\000\000 */
{ 86881 }, /* pm_mrk_data_from_memory\000marked\000The processor's data cache was reloaded from local, remote, or distant memory due to a demand miss for a marked load\000event=0x201e0\000\00000\000\000 */
{ 55747 }, /* pm_mrk_data_from_non_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0340000000c142\000\00000\000\000 */
{ 56234 }, /* pm_mrk_data_from_non_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0340000020c142\000\00000\000\000 */
{ 54944 }, /* pm_mrk_data_from_non_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa4240000000c142\000\00000\000\000 */
{ 55217 }, /* pm_mrk_data_from_non_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa4240000020c142\000\00000\000\000 */
{ 54337 }, /* pm_mrk_data_from_non_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0240000000c142\000\00000\000\000 */
{ 54629 }, /* pm_mrk_data_from_non_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0240000020c142\000\00000\000\000 */
{ 76176 }, /* pm_mrk_data_from_offchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss for a marked instruction\000event=0xc0b40000000c142\000\00000\000\000 */
{ 76625 }, /* pm_mrk_data_from_offchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0b40000020c142\000\00000\000\000 */
{ 75290 }, /* pm_mrk_data_from_onchip_cache\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss for a marked instruction\000event=0x80b40000000c142\000\00000\000\000 */
{ 75731 }, /* pm_mrk_data_from_onchip_cache_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload for a marked instruction\000event=0x80b40000020c142\000\00000\000\000 */
{ 66340 }, /* pm_mrk_data_from_r_oc_any\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xd8140000000c142\000\00000\000\000 */
{ 66769 }, /* pm_mrk_data_from_r_oc_any_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xd8140000020c142\000\00000\000\000 */
{ 65319 }, /* pm_mrk_data_from_r_oc_cache\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss for a marked instruction\000event=0xd8040000000c142\000\00000\000\000 */
{ 65512 }, /* pm_mrk_data_from_r_oc_cache_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI cache due to a demand miss or prefetch reload for a marked instruction\000event=0xd8040000020c142\000\00000\000\000 */
{ 65728 }, /* pm_mrk_data_from_r_oc_mem\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss for a marked instruction\000event=0xdc040000000c142\000\00000\000\000 */
{ 65920 }, /* pm_mrk_data_from_r_oc_mem_all\000datasource\000The processor's L1 data cache was reloaded from a remote chip's OpenCAPI memory due to a demand miss or prefetch reload for a marked instruction\000event=0xdc040000020c142\000\00000\000\000 */
{ 49430 }, /* pm_mrk_data_from_regent_l2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80340000000c142\000\00000\000\000 */
{ 49903 }, /* pm_mrk_data_from_regent_l2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80340000020c142\000\00000\000\000 */
{ 48648 }, /* pm_mrk_data_from_regent_l2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x84240000000c142\000\00000\000\000 */
{ 48914 }, /* pm_mrk_data_from_regent_l2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x84240000020c142\000\00000\000\000 */
{ 48055 }, /* pm_mrk_data_from_regent_l2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80240000000c142\000\00000\000\000 */
{ 48340 }, /* pm_mrk_data_from_regent_l2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80240000020c142\000\00000\000\000 */
{ 60163 }, /* pm_mrk_data_from_rl2\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc0140000000c142\000\00000\000\000 */
{ 60574 }, /* pm_mrk_data_from_rl2_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0140000020c142\000\00000\000\000 */
{ 59474 }, /* pm_mrk_data_from_rl2_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc4040000000c142\000\00000\000\000 */
{ 59709 }, /* pm_mrk_data_from_rl2_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc4040000020c142\000\00000\000\000 */
{ 58943 }, /* pm_mrk_data_from_rl2_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc0040000000c142\000\00000\000\000 */
{ 59197 }, /* pm_mrk_data_from_rl2_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0040000020c142\000\00000\000\000 */
{ 63895 }, /* pm_mrk_data_from_rl2l3\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc0340000000c142\000\00000\000\000 */
{ 64322 }, /* pm_mrk_data_from_rl2l3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0340000020c142\000\00000\000\000 */
{ 63182 }, /* pm_mrk_data_from_rl2l3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc4240000000c142\000\00000\000\000 */
{ 63425 }, /* pm_mrk_data_from_rl2l3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc4240000020c142\000\00000\000\000 */
{ 62635 }, /* pm_mrk_data_from_rl2l3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc0240000000c142\000\00000\000\000 */
{ 62897 }, /* pm_mrk_data_from_rl2l3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0240000020c142\000\00000\000\000 */
{ 62009 }, /* pm_mrk_data_from_rl3\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc8140000000c142\000\00000\000\000 */
{ 62420 }, /* pm_mrk_data_from_rl3_all\000datasource\000The processor's L1 data cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc8140000020c142\000\00000\000\000 */
{ 61320 }, /* pm_mrk_data_from_rl3_mod\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xcc040000000c142\000\00000\000\000 */
{ 61555 }, /* pm_mrk_data_from_rl3_mod_all\000datasource\000The processor's L1 data cache was reloaded with a line in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xcc040000020c142\000\00000\000\000 */
{ 60789 }, /* pm_mrk_data_from_rl3_shr\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc8040000000c142\000\00000\000\000 */
{ 61043 }, /* pm_mrk_data_from_rl3_shr_all\000datasource\000The processor's L1 data cache was reloaded with a valid line that was not in the M (exclusive) state from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc8040000020c142\000\00000\000\000 */
{ 64729 }, /* pm_mrk_data_from_rmem\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss for a marked instruction\000event=0xd4040000000c142\000\00000\000\000 */
{ 65116 }, /* pm_mrk_data_from_rmem_all\000datasource\000The processor's L1 data cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xd4040000020c142\000\00000\000\000 */
{ 89149 }, /* pm_mrk_derat_miss\000marked\000Marked Erat Miss (Data TLB Access) All page sizes. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x301e6\000\00000\000\000 */
{ 90448 }, /* pm_mrk_derat_miss_1g\000marked\000Data ERAT Miss (Data TLB Access) page size 1G for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c15c\000\00000\000\000 */
{ 91012 }, /* pm_mrk_derat_miss_2m\000marked\000Data ERAT Miss (Data TLB Access) page size 2M for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x40164\000\00000\000\000 */
{ 86621 }, /* pm_mrk_derat_miss_64k\000marked\000Data ERAT Miss (Data TLB Access) page size 64K for a marked instruction. When MMCR1[16]=0 this event counts only DERAT reloads for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x2d154\000\00000\000\000 */
{ 84934 }, /* pm_mrk_dfu_issue\000marked\000The marked instruction was a decimal floating point operation issued to the VSU. Measured at issue time\000event=0x20132\000\00000\000\000 */
{ 91342 }, /* pm_mrk_dtlb_miss\000marked\000The DPTEG required for the marked load/store instruction in execution was missing from the TLB. This event only counts for demand misses\000event=0x401e4\000\00000\000\000 */
{ 83860 }, /* pm_mrk_dtlb_miss_1g\000marked\000Marked Data TLB reload (after a miss) page size 1G. Implies radix translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x1d15c\000\00000\000\000 */
{ 87440 }, /* pm_mrk_dtlb_miss_2m\000marked\000Marked Data TLB reload (after a miss) page size 2M, which implies Radix Page Table translation was used. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x3012e\000\00000\000\000 */
{ 90706 }, /* pm_mrk_dtlb_miss_64k\000marked\000Marked Data TLB reload (after a miss) page size 64K. When MMCR1[16]=0 this event counts only for demand misses. When MMCR1[16]=1 this event includes demand misses and prefetches\000event=0x4c15e\000\00000\000\000 */
{ 85506 }, /* pm_mrk_fx_lsu_fin\000marked\000The marked instruction was simple fixed point that was issued to the store unit. Measured at finish time\000event=0x2013c\000\00000\000\000 */
{ 85081 }, /* pm_mrk_fxu_issue\000marked\000The marked instruction was a fixed point operation issued to the VSU. Measured at issue time\000event=0x20134\000\00000\000\000 */
{ 86326 }, /* pm_mrk_inst\000marked\000An instruction was marked. Includes both Random Instruction Sampling (RIS) at decode time and Random Event Sampling (RES) at the time the configured event happens\000event=0x24158\000\00000\000\000 */
{ 91270 }, /* pm_mrk_inst_cmpl\000marked\000Marked instruction completed\000event=0x401e0\000\00000\000\000 */
{ 84807 }, /* pm_mrk_inst_decoded\000marked\000An instruction was marked at decode time. Random Instruction Sampling (RIS) only\000event=0x20130\000\00000\000\000 */
{ 84209 }, /* pm_mrk_inst_disp\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\00000\000\000 */
{ 90931 }, /* pm_mrk_inst_flushed\000marked\000The marked instruction was flushed\000event=0x4e15e\000\00000\000\000 */
{ 76859 }, /* pm_mrk_inst_from_any_memory\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss for a marked instruction\000event=0x95900000000c142\000\00000\000\000 */
{ 77243 }, /* pm_mrk_inst_from_any_memory_all\000datasource\000The processor's instruction cache was reloaded from any chip's memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0x95900000010c142\000\00000\000\000 */
{ 74217 }, /* pm_mrk_inst_from_d_oc_any\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xf8100000000c142\000\00000\000\000 */
{ 74625 }, /* pm_mrk_inst_from_d_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a distant chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xf8100000010c142\000\00000\000\000 */
{ 68021 }, /* pm_mrk_inst_from_dl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss for a marked instruction\000event=0xe0100000000c142\000\00000\000\000 */
{ 68411 }, /* pm_mrk_inst_from_dl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0100000010c142\000\00000\000\000 */
{ 71761 }, /* pm_mrk_inst_from_dl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe0300000000c142\000\00000\000\000 */
{ 72167 }, /* pm_mrk_inst_from_dl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe0300000010c142\000\00000\000\000 */
{ 69875 }, /* pm_mrk_inst_from_dl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss for a marked instruction\000event=0xe8100000000c142\000\00000\000\000 */
{ 70265 }, /* pm_mrk_inst_from_dl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a distant chip due to a demand miss or prefetch reload for a marked instruction\000event=0xe8100000010c142\000\00000\000\000 */
{ 72619 }, /* pm_mrk_inst_from_dmem\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss for a marked instruction\000event=0xf4100000000c142\000\00000\000\000 */
{ 72985 }, /* pm_mrk_inst_from_dmem_all\000datasource\000The processor's instruction cache was reloaded from distant memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xf4100000010c142\000\00000\000\000 */
{ 37353 }, /* pm_mrk_inst_from_l1miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss for a marked instruction\000event=0x3f00000000c142\000\00000\000\000 */
{ 37743 }, /* pm_mrk_inst_from_l1miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L1 due to a demand miss or prefetch reload for a marked instruction\000event=0x3f00000010c142\000\00000\000\000 */
{ 36611 }, /* pm_mrk_inst_from_l2\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss for a marked instruction\000event=0x300000000c142\000\00000\000\000 */
{ 51297 }, /* pm_mrk_inst_from_l21_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0100000000c142\000\00000\000\000 */
{ 51747 }, /* pm_mrk_inst_from_l21_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0100000010c142\000\00000\000\000 */
{ 45099 }, /* pm_mrk_inst_from_l21_regent\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80100000000c142\000\00000\000\000 */
{ 45535 }, /* pm_mrk_inst_from_l21_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80100000010c142\000\00000\000\000 */
{ 36959 }, /* pm_mrk_inst_from_l2_all\000datasource\000The processor's instruction cache was reloaded from the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x300000010c142\000\00000\000\000 */
{ 40213 }, /* pm_mrk_inst_from_l2miss\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss for a marked instruction\000event=0x380000000c142\000\00000\000\000 */
{ 40606 }, /* pm_mrk_inst_from_l2miss_all\000datasource\000The processor's instruction cache was reloaded from a source beyond the local core's L2 due to a demand miss or prefetch reload for a marked instruction\000event=0x380000010c142\000\00000\000\000 */
{ 41040 }, /* pm_mrk_inst_from_l3\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss for a marked instruction\000event=0x10300000000c142\000\00000\000\000 */
{ 53391 }, /* pm_mrk_inst_from_l31_non_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa8100000000c142\000\00000\000\000 */
{ 53841 }, /* pm_mrk_inst_from_l31_non_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa8100000010c142\000\00000\000\000 */
{ 47137 }, /* pm_mrk_inst_from_l31_regent\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x88100000000c142\000\00000\000\000 */
{ 47573 }, /* pm_mrk_inst_from_l31_regent_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x88100000010c142\000\00000\000\000 */
{ 41392 }, /* pm_mrk_inst_from_l3_all\000datasource\000The processor's instruction cache was reloaded from the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x10300000010c142\000\00000\000\000 */
{ 91522 }, /* pm_mrk_inst_from_l3miss\000marked\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss for a marked instruction\000event=0x401e6\000\00000\000\000 */
{ 43563 }, /* pm_mrk_inst_from_l3miss_all\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss or prefetch reload for a marked instruction\000event=0x780000010c142\000\00000\000\000 */
{ 43183 }, /* pm_mrk_inst_from_l3miss_dsrc\000datasource\000The processor's instruction cache was reloaded from beyond the local core's L3 due to a demand miss for a marked instruction\000event=0x780000000c142\000\00000\000\000 */
{ 58081 }, /* pm_mrk_inst_from_l_oc_any\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0x98100000000c142\000\00000\000\000 */
{ 58489 }, /* pm_mrk_inst_from_l_oc_any_all\000datasource\000The processor's instruction cache was reloaded from the local chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0x98100000010c142\000\00000\000\000 */
{ 56487 }, /* pm_mrk_inst_from_lmem\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss for a marked instruction\000event=0x94100000000c142\000\00000\000\000 */
{ 56851 }, /* pm_mrk_inst_from_lmem_all\000datasource\000The processor's instruction cache was reloaded from the local chip's memory due to a demand miss or prefetch reload for a marked instruction\000event=0x94100000010c142\000\00000\000\000 */
{ 55513 }, /* pm_mrk_inst_from_non_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss for a marked instruction\000event=0xa0300000000c142\000\00000\000\000 */
{ 55977 }, /* pm_mrk_inst_from_non_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in a different regent due to a demand miss or prefetch reload for a marked instruction\000event=0xa0300000010c142\000\00000\000\000 */
{ 75961 }, /* pm_mrk_inst_from_offchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss for a marked instruction\000event=0xc0b00000000c142\000\00000\000\000 */
{ 76387 }, /* pm_mrk_inst_from_offchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a different chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0b00000010c142\000\00000\000\000 */
{ 75079 }, /* pm_mrk_inst_from_onchip_cache\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss for a marked instruction\000event=0x80b00000000c142\000\00000\000\000 */
{ 75497 }, /* pm_mrk_inst_from_onchip_cache_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from the same chip due to a demand miss or prefetch reload for a marked instruction\000event=0x80b00000010c142\000\00000\000\000 */
{ 66135 }, /* pm_mrk_inst_from_r_oc_any\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss for a marked instruction\000event=0xd8100000000c142\000\00000\000\000 */
{ 66541 }, /* pm_mrk_inst_from_r_oc_any_all\000datasource\000The processor's instruction cache was reloaded from a remote chip's OpenCAPI cache or memory due to a demand miss or prefetch reload for a marked instruction\000event=0xd8100000010c142\000\00000\000\000 */
{ 49203 }, /* pm_mrk_inst_from_regent_l2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss for a marked instruction\000event=0x80300000000c142\000\00000\000\000 */
{ 49653 }, /* pm_mrk_inst_from_regent_l2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 on the same chip in the same regent due to a demand miss or prefetch reload for a marked instruction\000event=0x80300000010c142\000\00000\000\000 */
{ 59967 }, /* pm_mrk_inst_from_rl2\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss for a marked instruction\000event=0xc0100000000c142\000\00000\000\000 */
{ 60355 }, /* pm_mrk_inst_from_rl2_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0100000010c142\000\00000\000\000 */
{ 63691 }, /* pm_mrk_inst_from_rl2l3\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc0300000000c142\000\00000\000\000 */
{ 64095 }, /* pm_mrk_inst_from_rl2l3_all\000datasource\000The processor's instruction cache was reloaded from another core's L2 or L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc0300000010c142\000\00000\000\000 */
{ 61813 }, /* pm_mrk_inst_from_rl3\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss for a marked instruction\000event=0xc8100000000c142\000\00000\000\000 */
{ 62201 }, /* pm_mrk_inst_from_rl3_all\000datasource\000The processor's instruction cache was reloaded from another core's L3 from a remote chip due to a demand miss or prefetch reload for a marked instruction\000event=0xc8100000010c142\000\00000\000\000 */
{ 64545 }, /* pm_mrk_inst_from_rmem\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss for a marked instruction\000event=0xd4100000000c142\000\00000\000\000 */
{ 64909 }, /* pm_mrk_inst_from_rmem_all\000datasource\000The processor's instruction cache was reloaded from remote memory (MC slow) due to a demand miss or prefetch reload for a marked instruction\000event=0xd4100000010c142\000\00000\000\000 */
{ 82972 }, /* pm_mrk_inst_issued\000marked\000Marked instruction issued. Note that stores always get issued twice, the address gets issued to the LSU and the data gets issued to the VSU. Also, issues can sometimes get killed/cancelled and cause multiple sequential issues for the same instruction\000event=0x10132\000\00000\000\000 */
{ 118104 }, /* pm_mrk_inst_timeo\000pmc\000Marked instruction finish timeout (instruction was lost)\000event=0x40134\000\00000\000\000 */
{ 88777 }, /* pm_mrk_issue_dependent_load\000marked\000The marked instruction was dependent on a load. It is eligible for issue kill\000event=0x30162\000\00000\000\000 */
{ 84405 }, /* pm_mrk_l1_icache_miss\000marked\000Marked instruction suffered an instruction cache miss\000event=0x101e4\000\00000\000\000 */
{ 84507 }, /* pm_mrk_l1_reload_valid\000marked\000Marked demand reload\000event=0x101ea\000\00000\000\000 */
{ 84577 }, /* pm_mrk_l2_rc_disp\000marked\000Marked instruction RC dispatched in L2\000event=0x20114\000\00000\000\000 */
{ 87329 }, /* pm_mrk_l2_rc_done\000marked\000L2 RC machine completed the transaction for the marked instruction\000event=0x3012a\000\00000\000\000 */
{ 89500 }, /* pm_mrk_larx_fin\000marked\000Marked load and reserve instruction (LARX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x40116\000\00000\000\000 */
{ 87847 }, /* pm_mrk_ld_cmpl\000marked\000Marked load instruction completed\000event=0x34146\000\00000\000\000 */
{ 87048 }, /* pm_mrk_ld_miss_l1\000marked\000Marked demand data load miss counted at finish time\000event=0x201e2\000\00000\000\000 */
{ 89649 }, /* pm_mrk_lsu_fin\000marked\000LSU marked instruction finish\000event=0x40132\000\00000\000\000 */
{ 84660 }, /* pm_mrk_ntf_cyc\000marked\000Cycles in which the marked instruction is the oldest in the pipeline (next-to-finish or next-to-complete)\000event=0x2011c\000\00000\000\000 */
{ 88909 }, /* pm_mrk_st_cmpl\000marked\000Marked store completed and sent to nest. Note that this count excludes cache-inhibited stores\000event=0x301e2\000\00000\000\000 */
{ 83268 }, /* pm_mrk_st_done_l2\000marked\000Marked store completed in L2\000event=0x10134\000\00000\000\000 */
{ 88666 }, /* pm_mrk_st_drain_cyc\000marked\000Cycles in which the marked store drained from the core to the L2\000event=0x3f150\000\00000\000\000 */
{ 88592 }, /* pm_mrk_st_fin\000marked\000Marked store instruction finished\000event=0x3e15a\000\00000\000\000 */
{ 84119 }, /* pm_mrk_st_l2_cyc\000marked\000Cycles from L2 RC dispatch to L2 RC completion\000event=0x1f150\000\00000\000\000 */
{ 85217 }, /* pm_mrk_st_nest\000marked\000A store has been sampled/marked and is at the point of execution where it has completed in the core and can no longer be flushed. At this point the store is sent to the L2\000event=0x20138\000\00000\000\000 */
{ 115278 }, /* pm_mrk_start_probe_nop_cmpl\000pmc\000Marked Start probe nop (AND R0,R0,R0) completed\000event=0x1f15e\000\00000\000\000 */
{ 117235 }, /* pm_mrk_start_probe_nop_disp\000pmc\000Marked Start probe nop dispatched. Instruction AND R0,R0,R0\000event=0x40114\000\00000\000\000 */
{ 89720 }, /* pm_mrk_stcx_core_cyc\000marked\000Cycles spent in the core portion of a marked STCX instruction. It starts counting when the instruction is decoded and stops counting when it drains into the L2\000event=0x44146\000\00000\000\000 */
{ 88443 }, /* pm_mrk_stcx_fail\000marked\000Marked conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x3e158\000\00000\000\000 */
{ 86176 }, /* pm_mrk_stcx_fin\000marked\000Marked conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x24156\000\00000\000\000 */
{ 89383 }, /* pm_mrk_tlbie_fin\000marked\000Marked TLBIE instruction finished. Includes TLBIE and TLBIEL instructions\000event=0x4010e\000\00000\000\000 */
{ 87716 }, /* pm_mrk_vsu_fin\000marked\000VSU marked instruction finished. Excludes simple FX instructions issued to the Store Unit\000event=0x30132\000\00000\000\000 */
{ 83708 }, /* pm_mrk_xfer_from_src_cyc_pmc1\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[0:12]\000event=0x1c144\000\00000\000\000 */
{ 86023 }, /* pm_mrk_xfer_from_src_cyc_pmc2\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[15:27]\000event=0x2c144\000\00000\000\000 */
{ 88290 }, /* pm_mrk_xfer_from_src_cyc_pmc3\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[30:42]\000event=0x3c144\000\00000\000\000 */
{ 90295 }, /* pm_mrk_xfer_from_src_cyc_pmc4\000marked\000Cycles taken for a marked demand miss to reload a line from the source specified in MMCR3[45:57]\000event=0x4c144\000\00000\000\000 */
{ 83341 }, /* pm_mrk_xfer_from_src_pmc1\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c142\000\00000\000\000 */
{ 85655 }, /* pm_mrk_xfer_from_src_pmc2\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c142\000\00000\000\000 */
{ 87922 }, /* pm_mrk_xfer_from_src_pmc3\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c142\000\00000\000\000 */
{ 89927 }, /* pm_mrk_xfer_from_src_pmc4\000marked\000For a marked data transfer instruction, the processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c142\000\00000\000\000 */
{ 78900 }, /* pm_non_fma_flop_cmpl\000floating_point\000Non FMA instruction completed\000event=0x4d056\000\00000\000\000 */
{ 79083 }, /* pm_non_math_flop_cmpl\000floating_point\000Non Math instruction completed\000event=0x4d05a\000\00000\000\000 */
{ 110703 }, /* pm_ntc_all_fin\000pipeline\000Cycles in which both instructions in the ICT entry pair show as finished. These are the cycles between finish and completion for the oldest pair of instructions in the pipeline\000event=0x40008\000\00000\000\000 */
{ 106265 }, /* pm_ntc_fin\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. Note that instructions can finish out of order, therefore not all the instructions that finish have a Next-to-complete status\000event=0x2405a\000\00000\000\000 */
{ 100156 }, /* pm_ntc_flush\000pipeline\000The instruction was flushed after becoming next-to-complete (NTC)\000event=0x10028\000\00000\000\000 */
{ 115929 }, /* pm_pmc1_overflow\000pmc\000The event selected for PMC1 caused the event counter to overflow\000event=0x20010\000\00000\000\000 */
{ 117922 }, /* pm_pmc1_rewind\000pmc\000The speculative event selected for PMC1 rewinds and the counter for PMC1 is not charged\000event=0x4d02c\000\00000\000\000 */
{ 117346 }, /* pm_pmc1_saved\000pmc\000The conditions for the speculative event selected for PMC1 are met and PMC1 is charged\000event=0x4d010\000\00000\000\000 */
{ 116388 }, /* pm_pmc2_overflow\000pmc\000The event selected for PMC2 caused the event counter to overflow\000event=0x30010\000\00000\000\000 */
{ 116493 }, /* pm_pmc2_rewind\000pmc\000The speculative event selected for PMC2 rewinds and the counter for PMC2 is not charged\000event=0x30020\000\00000\000\000 */
{ 114954 }, /* pm_pmc2_saved\000pmc\000The conditions for the speculative event selected for PMC2 are met and PMC2 is charged\000event=0x10022\000\00000\000\000 */
{ 115183 }, /* pm_pmc3_held_cyc\000pmc\000Cycles when the speculative counter for PMC3 is frozen\000event=0x1002a\000\00000\000\000 */
{ 117130 }, /* pm_pmc3_overflow\000pmc\000The event selected for PMC3 caused the event counter to overflow\000event=0x40010\000\00000\000\000 */
{ 114432 }, /* pm_pmc3_rewind\000pmc\000The speculative event selected for PMC3 rewinds and the counter for PMC3 is not charged\000event=0x1000a\000\00000\000\000 */
{ 117470 }, /* pm_pmc3_saved\000pmc\000The conditions for the speculative event selected for PMC3 are met and PMC3 is charged\000event=0x4d012\000\00000\000\000 */
{ 114558 }, /* pm_pmc4_overflow\000pmc\000The event selected for PMC4 caused the event counter to overflow\000event=0x10010\000\00000\000\000 */
{ 114828 }, /* pm_pmc4_rewind\000pmc\000The speculative event selected for PMC4 rewinds and the counter for PMC4 is not charged\000event=0x10020\000\00000\000\000 */
{ 116619 }, /* pm_pmc4_saved\000pmc\000The conditions for the speculative event selected for PMC4 are met and PMC4 is charged\000event=0x30022\000\00000\000\000 */
{ 115078 }, /* pm_pmc5_overflow\000pmc\000The event selected for PMC5 caused the event counter to overflow\000event=0x10024\000\00000\000\000 */
{ 116743 }, /* pm_pmc6_overflow\000pmc\000The event selected for PMC6 caused the event counter to overflow\000event=0x30024\000\00000\000\000 */
{ 117817 }, /* pm_privileged_cyc\000pmc\000Cycles when the thread is in Privileged state. MSR[S HV PR]=x00\000event=0x4d028\000\00000\000\000 */
{ 98292 }, /* pm_privileged_inst_cmpl\000others\000PowerPC instruction completed while the thread was in Privileged state\000event=0x3405a\000\00000\000\000 */
{ 93303 }, /* pm_ptesync_fin\000memory\000Ptesync instruction finished in the store unit. Only one ptesync can finish at a time\000event=0x2003e\000\00000\000\000 */
{ 116314 }, /* pm_run_cyc\000pmc\000Processor cycles gated by the run latch\000event=0x200f4\000\00000\000\000 */
{ 116848 }, /* pm_run_cyc_smt2_mode\000pmc\000Cycles when this thread's run latch is set and the core is in SMT2 mode\000event=0x3006c\000\00000\000\000 */
{ 116034 }, /* pm_run_cyc_smt4_mode\000pmc\000Cycles when this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\00000\000\000 */
{ 115377 }, /* pm_run_cyc_st_mode\000pmc\000Cycles when the run latch is set and the core is in ST mode\000event=0x1006c\000\00000\000\000 */
{ 118285 }, /* pm_run_inst_cmpl\000pmc\000PowerPC instruction completed while the run latch is set\000event=0x500fa\000\00000\000\000 */
{ 13 }, /* pm_run_inst_cmpl_conc\000cache\000PowerPC instruction completed by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\00000\000\000 */
{ 115828 }, /* pm_run_latch_all_threads_cyc\000pmc\000Cycles when the run latch is set for all threads\000event=0x2000c\000\00000\000\000 */
{ 115618 }, /* pm_run_latch_any_thread_cyc\000pmc\000Cycles when at least one thread has the run latch set\000event=0x100fa\000\00000\000\000 */
{ 78356 }, /* pm_scalar_flop_cmpl\000floating_point\000Scalar floating point instruction completed\000event=0x45056\000\00000\000\000 */
{ 78454 }, /* pm_sp_flop_cmpl\000floating_point\000Single Precision floating point instruction completed\000event=0x4505a\000\00000\000\000 */
{ 118452 }, /* pm_st_cmpl\000translation\000Stores completed from S2Q (2nd-level store queue). This event includes regular stores, stcx and cache inhibited stores. The following operations are excluded (pteupdate, snoop tlbie complete, store atomics, miso, load atomic payloads, tlbie, tlbsync, slbieg, isync, msgsnd, slbiag, cpabort, copy, tcheck, tend, stsync, dcbst, icbi, dcbf, hwsync, lwsync, ptesync, eieio, msgsync)\000event=0x200f0\000\00000\000\000 */
{ 118382 }, /* pm_st_fwd\000translation\000Store forwards that finished\000event=0x20018\000\00000\000\000 */
{ 118873 }, /* pm_st_miss_l1\000translation\000Store Missed L1\000event=0x300f0\000\00000\000\000 */
{ 82690 }, /* pm_stcx_fail_fin\000locks\000Conditional store instruction (STCX) failed. LARX and STCX are instructions used to acquire a lock\000event=0x1e058\000\00000\000\000 */
{ 97687 }, /* pm_stcx_fin\000others\000Conditional store instruction (STCX) finished. LARX and STCX are instructions used to acquire a lock\000event=0x2e014\000\00000\000\000 */
{ 82831 }, /* pm_stcx_pass_fin\000locks\000Conditional store instruction (STCX) passed. LARX and STCX are instructions used to acquire a lock\000event=0x4e050\000\00000\000\000 */
{ 117045 }, /* pm_thresh_exc_1024\000pmc\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\00000\000\000 */
{ 118202 }, /* pm_thresh_exc_128\000pmc\000Threshold counter exceeded a value of 128\000event=0x401ea\000\00000\000\000 */
{ 115479 }, /* pm_thresh_exc_256\000pmc\000Threshold counter exceeded a count of 256\000event=0x101e8\000\00000\000\000 */
{ 116150 }, /* pm_thresh_exc_32\000pmc\000Threshold counter exceeded a value of 32\000event=0x201e6\000\00000\000\000 */
{ 116231 }, /* pm_thresh_exc_512\000pmc\000Threshold counter exceeded a value of 512\000event=0x201e8\000\00000\000\000 */
{ 116964 }, /* pm_thresh_exc_64\000pmc\000Threshold counter exceeded a value of 64\000event=0x301e8\000\00000\000\000 */
{ 115562 }, /* pm_thresh_met\000pmc\000Threshold exceeded\000event=0x101ec\000\00000\000\000 */
{ 109068 }, /* pm_tlbie_fin\000pipeline\000TLBIE instruction finished in the LSU. Two TLBIEs can finish each cycle. All will be counted\000event=0x30058\000\00000\000\000 */
{ 117712 }, /* pm_ultravisor_cyc\000pmc\000Cycles when the thread is in Ultravisor state. MSR[S HV PR]=110\000event=0x4d026\000\00000\000\000 */
{ 114663 }, /* pm_ultravisor_inst_cmpl\000pmc\000PowerPC instruction completed while the thread was in ultravisor state\000event=0x1001c\000\00000\000\000 */
{ 78985 }, /* pm_vector_flop_cmpl\000floating_point\000Vector floating point instruction completed\000event=0x4d058\000\00000\000\000 */
{ 99127 }, /* pm_vector_ld_cmpl\000others\000Vector load instruction completed\000event=0x44054\000\00000\000\000 */
{ 82248 }, /* pm_vector_st_cmpl\000frontend\000Vector store instruction completed\000event=0x44056\000\00000\000\000 */
{ 104421 }, /* pm_vsu0_issue\000pipeline\000VSU instruction issued to VSU pipe 0\000event=0x10016\000\00000\000\000 */
{ 104500 }, /* pm_vsu1_issue\000pipeline\000VSU instruction issued to VSU pipe 1\000event=0x2d012\000\00000\000\000 */
{ 108989 }, /* pm_vsu2_issue\000pipeline\000VSU instruction issued to VSU pipe 2\000event=0x3f044\000\00000\000\000 */
{ 113498 }, /* pm_vsu3_issue\000pipeline\000VSU instruction was issued to VSU pipe 3\000event=0x4d020\000\00000\000\000 */
{ 104736 }, /* pm_vsu_fin\000pipeline\000VSU instruction finished\000event=0x4001c\000\00000\000\000 */
{ 104579 }, /* pm_vsu_issue\000pipeline\000At least one VSU instruction was issued to one of the VSU pipes. Up to 4 per cycle. Includes fixed point operations\000event=0x2505c\000\00000\000\000 */
{ 91877 }, /* pm_xfer_from_src_pmc1\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[0:12]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x1c040\000\00000\000\000 */
{ 93430 }, /* pm_xfer_from_src_pmc2\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[15:27]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x2c040\000\00000\000\000 */
{ 94815 }, /* pm_xfer_from_src_pmc3\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[30:42]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x3c040\000\00000\000\000 */
{ 95955 }, /* pm_xfer_from_src_pmc4\000memory\000The processor's L1 data cache was reloaded from the source specified in MMCR3[45:57]. If MMCR1[16|17] is 0 (default), this count includes only lines that were reloaded to satisfy a demand miss. If MMCR1[16|17] is 1, this count includes both demand misses and prefetch reloads\000event=0x4c040\000\00000\000\000 */

};

const struct pmu_table_entry pmu_events__power10[] = {
{
     .entries = pmu_events__power10_default_core,
     .num_entries = ARRAY_SIZE(pmu_events__power10_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__power10_default_core[] = {
{ 440707 }, /* ALINK0_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 438667 }, /* ALINK0_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 440953 }, /* ALINK1_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 438922 }, /* ALINK1_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 441199 }, /* ALINK2_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 439177 }, /* ALINK2_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 441445 }, /* ALINK3_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 439432 }, /* ALINK3_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 441691 }, /* ALINK4_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 439687 }, /* ALINK4_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 441937 }, /* ALINK5_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 439942 }, /* ALINK5_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 442183 }, /* ALINK6_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 440197 }, /* ALINK6_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 442429 }, /* ALINK7_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_ALINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 440452 }, /* ALINK7_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_ALINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_ALINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_ALINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 432339 }, /* GROUP_PUMP_RETRY_RATIO_P01\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010 */
{ 432464 }, /* GROUP_PUMP_RETRY_RATIO_P23\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010 */
{ 432087 }, /* LOCAL_NODE_PUMP_RETRY_RATIO_P01\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010 */
{ 432213 }, /* LOCAL_NODE_PUMP_RETRY_RATIO_P23\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ * 100\000\000\000\0001%\000\000\000\00010 */
{ 443705 }, /* Memory_RD_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010 */
{ 443981 }, /* Memory_WR_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@ + hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010 */
{ 444252 }, /* PowerBUS_Frequency\000\000hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0002.56e-7GHz\000\000\000\00010 */
{ 433017 }, /* REMOTE_NODE_PUMPS_RETRIES_RATIO_P01\000\000hv_24x7@PM_PB_RTY_RNS_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 433153 }, /* REMOTE_NODE_PUMPS_RETRIES_RATIO_P23\000\000hv_24x7@PM_PB_RTY_RNS_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 442776 }, /* TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI0\000\000hv_24x7@PM_PCI0_32B_INOUT\\,chip\\=?@\000\000\000\0003.28e-2MB\000\000\000\00010 */
{ 442675 }, /* TOTAL_DATA_BANDWIDTH_TRANSFERRED_OVER_PB_PCI1\000\000hv_24x7@PM_PCI1_32B_INOUT\\,chip\\=?@\000\000\000\0003.28e-2MB\000\000\000\00010 */
{ 432589 }, /* TOTAL_GROUP_PUMPS_P01\000\000hv_24x7@PM_PB_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 432690 }, /* TOTAL_GROUP_PUMPS_P23\000\000hv_24x7@PM_PB_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 432791 }, /* TOTAL_GROUP_PUMPS_RETRIES_P01\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 432904 }, /* TOTAL_GROUP_PUMPS_RETRIES_P23\000\000hv_24x7@PM_PB_RTY_GROUP_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 434589 }, /* TOTAL_INT_PB_BW\000\000hv_24x7@PM_PB_INT_DATA_XFER\\,chip\\=?@\000\000\000\0002.09MB\000\000\000\00010 */
{ 433499 }, /* TOTAL_LOCAL_NODE_PUMPS_P01\000\000hv_24x7@PM_PB_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 433603 }, /* TOTAL_LOCAL_NODE_PUMPS_P23\000\000hv_24x7@PM_PB_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 433941 }, /* TOTAL_LOCAL_NODE_PUMPS_RETRIES_P01\000\000hv_24x7@PM_PB_RTY_LNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 434057 }, /* TOTAL_LOCAL_NODE_PUMPS_RETRIES_P23\000\000hv_24x7@PM_PB_RTY_LNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 442877 }, /* TOTAL_MCS_READ_BW_MC0_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010 */
{ 442981 }, /* TOTAL_MCS_READ_BW_MC1_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010 */
{ 443085 }, /* TOTAL_MCS_READ_BW_MC2_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010 */
{ 443189 }, /* TOTAL_MCS_READ_BW_MC3_CHAN01\000\000hv_24x7@PM_MCS_128B_RD_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0005.24e-1MB\000\000\000\00010 */
{ 443293 }, /* TOTAL_MCS_WRITE_BW_MC0_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC0_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010 */
{ 443396 }, /* TOTAL_MCS_WRITE_BW_MC1_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC1_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010 */
{ 443499 }, /* TOTAL_MCS_WRITE_BW_MC2_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC2_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010 */
{ 443602 }, /* TOTAL_MCS_WRITE_BW_MC3_CHAN01\000\000hv_24x7@PM_MCS_64B_WR_DATA_BLOCKS_MC3_CHAN01\\,chip\\=?@\000\000\000\0002.6e-1MB\000\000\000\00010 */
{ 434383 }, /* TOTAL_NEAR_NODE_PUMPS_P01\000\000hv_24x7@PM_PB_NNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 434486 }, /* TOTAL_NEAR_NODE_PUMPS_P23\000\000hv_24x7@PM_PB_NNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 434173 }, /* TOTAL_REMOTE_NODE_PUMPS_P01\000\000hv_24x7@PM_PB_RNS_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 434278 }, /* TOTAL_REMOTE_NODE_PUMPS_P23\000\000hv_24x7@PM_PB_RNS_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 433289 }, /* TOTAL_VECTOR_GROUP_PUMPS_P01\000\000hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 433394 }, /* TOTAL_VECTOR_GROUP_PUMPS_P23\000\000hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 433707 }, /* TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P01\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 433824 }, /* TOTAL_VECTOR_GROUP_PUMPS_RETRIES_P23\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / hv_24x7@PM_PAU_CYC\\,chip\\=?@\000\000\000\0004\000\000\000\00010 */
{ 431829 }, /* VEC_GROUP_PUMP_RETRY_RATIO_P01\000\000hv_24x7@PM_PB_RTY_VG_PUMP01\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP01\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 431958 }, /* VEC_GROUP_PUMP_RETRY_RATIO_P23\000\000hv_24x7@PM_PB_RTY_VG_PUMP23\\,chip\\=?@ / (1 + hv_24x7@PM_PB_VG_PUMP23\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 436699 }, /* XLINK0_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK0_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 434659 }, /* XLINK0_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK0_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK0_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK0_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 436945 }, /* XLINK1_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK1_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 434914 }, /* XLINK1_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK1_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK1_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK1_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 437191 }, /* XLINK2_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK2_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 435169 }, /* XLINK2_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK2_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK2_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK2_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 437437 }, /* XLINK3_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK3_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 435424 }, /* XLINK3_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK3_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK3_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK3_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 437683 }, /* XLINK4_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK4_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 435679 }, /* XLINK4_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK4_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK4_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK4_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 437929 }, /* XLINK5_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK5_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 435934 }, /* XLINK5_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK5_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK5_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK5_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 438175 }, /* XLINK6_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK6_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 436189 }, /* XLINK6_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK6_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK6_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK6_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 438421 }, /* XLINK7_OUT_DATA_UTILIZATION\000\000(hv_24x7@PM_XLINK7_OUT_ODD_DATA\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_DATA\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001.063%\000\000\000\00010 */
{ 436444 }, /* XLINK7_OUT_TOTAL_UTILIZATION\000\000(hv_24x7@PM_XLINK7_OUT_ODD_TOTAL_UTIL\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_TOTAL_UTIL\\,chip\\=?@) / (1 + hv_24x7@PM_XLINK7_OUT_ODD_AVLBL_CYCLES\\,chip\\=?@ + hv_24x7@PM_XLINK7_OUT_EVEN_AVLBL_CYCLES\\,chip\\=?@) * 100\000\000\000\0001%\000\000\000\00010 */
{ 421903 }, /* AVERAGE_COMPLETED_INSTRUCTION_SET_SIZE\000General\000PM_RUN_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Average number of completed instructions per instruction group\000\000\000\000\000\00000 */
{ 422677 }, /* BRANCHES_PER_INST\000General\000PM_BR_FIN / PM_RUN_INST_CMPL\000\000Average number of finished branches per completed instruction\000\000\000\000\000\00000 */
{ 414244 }, /* BRANCH_MISPREDICTION_RATE\000Others\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL\000\000Percentage of branch mispredictions per completed instruction\000\000\000\000\000\00000 */
{ 407101 }, /* BRU_STALL_CPI\000CPI\000PM_EXEC_STALL_BRU / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing in the branch unit\000\000\000\000\000\00000 */
{ 414092 }, /* BR_MPRED_FLUSH_RATE\000Others\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000\000Percentage of flushes due to a branch mispredict per completed instruction\000\0001%\000\000\000\00000 */
{ 412025 }, /* COMPLETION_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_CMPL_STALL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction cannot complete because the thread was blocked\000\000\000\000\000\00000 */
{ 416093 }, /* CYCLES_ATLEAST_ONE_INST_DISPATCHED\000General\000PM_1PLUS_PPC_DISP / PM_RUN_CYC * 100\000\000Percentage of cycles when at least 1 instruction dispatched\000\0001%\000\000\000\00000 */
{ 415955 }, /* CYCLES_PER_COMPLETED_INSTRUCTIONS_SET\000General\000PM_CYC / PM_1PLUS_PPC_CMPL\000\000Average number of cycles per completed instruction group\000\000\000\000\000\00000 */
{ 401422 }, /* CYCLES_PER_INSTRUCTION\000CPI\000PM_CYC / PM_INST_CMPL\000\000Average cycles per completed instruction\000\000\000\000\000\00000 */
{ 429801 }, /* DCACHE_MISS_CPI\000General\000DMISS_L3MISS_STALL_CPI / RUN_CPI * 100\000\000Percentage of cycles stalled due to the NTC instruction waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\0001%\000\000\000\00000 */
{ 430166 }, /* DERAT_16M_MISS_RATE\000Translation\000PM_DERAT_MISS_16M / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 16M page size per completed instruction\000\0001%\000\000\000\00000 */
{ 430695 }, /* DERAT_16M_MISS_RATIO\000Translation\000PM_DERAT_MISS_16M / PM_DERAT_MISS\000\000DERAT miss ratio for 16M page size\000\000\000\000\000\00000 */
{ 430323 }, /* DERAT_1G_MISS_RATE\000Translation\000PM_DERAT_MISS_1G * 100 / PM_RUN_INST_CMPL\000\000Percentage of DERAT misses with 1G page size per completed run instruction\000\0001%\000\000\000\00000 */
{ 430805 }, /* DERAT_1G_MISS_RATIO\000Translation\000PM_DERAT_MISS_1G / PM_DERAT_MISS\000\000DERAT miss ratio for 1G page size\000\000\000\000\000\00000 */
{ 430012 }, /* DERAT_2M_MISS_RATE\000Translation\000PM_DERAT_MISS_2M / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 2M page size per completed instruction\000\0001%\000\000\000\00000 */
{ 430588 }, /* DERAT_2M_MISS_RATIO\000Translation\000PM_DERAT_MISS_2M / PM_DERAT_MISS\000\000DERAT miss ratio for 2M page size\000\000\000\000\000\00000 */
{ 419693 }, /* DERAT_4K_MISS_RATE\000Translation\000PM_DERAT_MISS_4K / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 4k page size per completed instruction\000\0001%\000\000\000\00000 */
{ 430481 }, /* DERAT_4K_MISS_RATIO\000Translation\000PM_DERAT_MISS_4K / PM_DERAT_MISS\000\000DERAT miss ratio for 4K page size\000\000\000\000\000\00000 */
{ 419847 }, /* DERAT_64K_MISS_RATE\000Translation\000PM_DERAT_MISS_64K / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses with 64k page size per completed instruction\000\0001%\000\000\000\00000 */
{ 430912 }, /* DERAT_64K_MISS_RATIO\000Translation\000PM_DERAT_MISS_64K / PM_DERAT_MISS\000\000DERAT miss ratio for 64K page size\000\000\000\000\000\00000 */
{ 408027 }, /* DERAT_DTLB_MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_DERAT_DTLB_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is recovering from a TLB miss\000\000\000\000\000\00000 */
{ 421664 }, /* DERAT_MISS_RATE\000Translation\000PM_DERAT_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of DERAT misses per completed instruction\000\0001%\000\000\000\00000 */
{ 431022 }, /* DERAT_MISS_RELOAD\000Translation\000PM_DTLB_MISS / PM_DERAT_MISS * 100\000\000Percentage of DERAT misses that resulted in TLB reloads\000\0001%\000\000\000\00000 */
{ 407822 }, /* DERAT_ONLY_MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_DERAT_ONLY_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a load or store that suffered a translation miss\000\000\000\000\000\00000 */
{ 414992 }, /* DISPATCH_PER_INST_CMPL\000General\000PM_INST_DISP / PM_RUN_INST_CMPL\000\000Average number of completed instructions dispatched per instruction completed\000\000\000\000\000\00000 */
{ 404438 }, /* DISPATCH_STALL_BR_MPRED_CPI\000CPI\000PM_DISP_STALL_BR_MPRED / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled due to a branch mispredict\000\000\000\000\000\00000 */
{ 403466 }, /* DISPATCH_STALL_BR_MPRED_ICMISS_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled due to an icache miss after a branch mispredict\000\000\000\000\000\00000 */
{ 403677 }, /* DISPATCH_STALL_BR_MPRED_IC_L2_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_IC_L2 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L2 after suffering a branch mispredict\000\000\000\000\000\00000 */
{ 404167 }, /* DISPATCH_STALL_BR_MPRED_IC_L3MISS_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_IC_L3MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from any source beyond the local L3 after suffering a branch mispredict\000\000\000\000\000\00000 */
{ 403922 }, /* DISPATCH_STALL_BR_MPRED_IC_L3_CPI\000CPI\000PM_DISP_STALL_BR_MPRED_IC_L3 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while instruction was fetched from the local L3 after suffering a branch mispredict\000\000\000\000\000\00000 */
{ 401520 }, /* DISPATCH_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_DISP_STALL_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled for any reason\000\000\000\000\000\00000 */
{ 401855 }, /* DISPATCH_STALL_FETCH_CPI\000CPI\000PM_DISP_STALL_FETCH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because Fetch was being held,  so there was nothing in the pipeline for this thread\000\000\000\000\000\00000 */
{ 413553 }, /* DISPATCH_STALL_FETCH_CPI\000CPI\000PM_DISP_STALL_FETCH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because fetch was being held, so there was nothing in the pipeline for this thread\000\000\000\000\000\00000 */
{ 401686 }, /* DISPATCH_STALL_FLUSH_CPI\000CPI\000PM_DISP_STALL_FLUSH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because there was a flush\000\000\000\000\000\00000 */
{ 404614 }, /* DISPATCH_STALL_HELD_CPI\000CPI\000PM_DISP_STALL_HELD_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any reason\000\000\000\000\000\00000 */
{ 413779 }, /* DISPATCH_STALL_HELD_HALT_CPI\000CPI\000PM_DISP_STALL_HELD_HALT_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of power management\000\000\000\000\000\00000 */
{ 405277 }, /* DISPATCH_STALL_HELD_ISSQ_FULL_CPI\000CPI\000PM_DISP_STALL_HELD_ISSQ_FULL_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch due to issue queue full\000\000\000\000\000\00000 */
{ 406146 }, /* DISPATCH_STALL_HELD_OTHER_CPI\000CPI\000PM_DISP_STALL_HELD_OTHER_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch for any other reason\000\000\000\000\000\00000 */
{ 405486 }, /* DISPATCH_STALL_HELD_RENAME_CPI\000CPI\000PM_DISP_STALL_HELD_RENAME_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the mapper/SRB was full\000\000\000\000\000\00000 */
{ 405058 }, /* DISPATCH_STALL_HELD_SCOREBOARD_CPI\000CPI\000PM_DISP_STALL_HELD_SCOREBOARD_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch while waiting on the scoreboard\000\000\000\000\000\00000 */
{ 405697 }, /* DISPATCH_STALL_HELD_STF_MAPPER_CPI\000CPI\000PM_DISP_STALL_HELD_STF_MAPPER_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the STF mapper/SRB was full\000\000\000\000\000\00000 */
{ 404794 }, /* DISPATCH_STALL_HELD_SYNC_CPI\000CPI\000PM_DISP_STALL_HELD_SYNC_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because of a synchronizing instruction that requires the ICT to be empty before dispatch\000\000\000\000\000\00000 */
{ 405920 }, /* DISPATCH_STALL_HELD_XVFC_MAPPER_CPI\000CPI\000PM_DISP_STALL_HELD_XVFC_MAPPER_CYC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction was held at dispatch because the XVFC mapper/SRB was full\000\000\000\000\000\00000 */
{ 402855 }, /* DISPATCH_STALL_IC_L2_CPI\000CPI\000PM_DISP_STALL_IC_L2 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L2\000\000\000\000\000\00000 */
{ 403245 }, /* DISPATCH_STALL_IC_L3MISS_CPI\000CPI\000PM_DISP_STALL_IC_L3MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from any source beyond the local L3\000\000\000\000\000\00000 */
{ 403050 }, /* DISPATCH_STALL_IC_L3_CPI\000CPI\000PM_DISP_STALL_IC_L3 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled while the instruction was fetched from the local L3\000\000\000\000\000\00000 */
{ 402686 }, /* DISPATCH_STALL_IC_MISS_CPI\000CPI\000PM_DISP_STALL_IC_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled due to an icache miss\000\000\000\000\000\00000 */
{ 402285 }, /* DISPATCH_STALL_IERAT_ONLY_MISS_CPI\000CPI\000PM_DISP_STALL_IERAT_ONLY_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction ERAT miss\000\000\000\000\000\00000 */
{ 402492 }, /* DISPATCH_STALL_ITLB_MISS_CPI\000CPI\000PM_DISP_STALL_ITLB_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled waiting to resolve an instruction TLB miss\000\000\000\000\000\00000 */
{ 402082 }, /* DISPATCH_STALL_TRANSLATION_CPI\000CPI\000PM_DISP_STALL_TRANSLATION / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when dispatch was stalled because the MMU was handling a translation miss\000\000\000\000\000\00000 */
{ 423785 }, /* DL1_MISS_RELOADS\000General\000PM_LD_DEMAND_MISS_L1 / PM_LD_MISS_L1 * 100\000\000Percentage of demand load misses that reloaded the L1 cache\000\0001%\000\000\000\00000 */
{ 417735 }, /* DL1_RELOAD_FROM_DL2L3_MOD_RATE\000dL1_Reloads\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using modified data from another core's L2 or L3 on a distant chip, per completed instruction\000\0001%\000\000\000\00000 */
{ 417971 }, /* DL1_RELOAD_FROM_DL2L3_SHR_RATE\000dL1_Reloads\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using shared data from another core's L2 or L3 on a distant chip, per completed instruction\000\0001%\000\000\000\00000 */
{ 427391 }, /* DL1_RELOAD_FROM_DL2_MOD\000dL1_Reloads\000PM_DATA_FROM_DL2_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a distant chip with modified data\000\0001%\000\000\000\00000 */
{ 427594 }, /* DL1_RELOAD_FROM_DL2_SHR\000dL1_Reloads\000PM_DATA_FROM_DL2_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a distant chip with shared data\000\0001%\000\000\000\00000 */
{ 427795 }, /* DL1_RELOAD_FROM_DL3_MOD\000dL1_Reloads\000PM_DATA_FROM_DL3_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a distant chip with modified data\000\0001%\000\000\000\00000 */
{ 427998 }, /* DL1_RELOAD_FROM_DL3_SHR\000dL1_Reloads\000PM_DATA_FROM_DL3_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a distant chip with shared data\000\0001%\000\000\000\00000 */
{ 429266 }, /* DL1_RELOAD_FROM_DMEM\000dL1_Reloads\000PM_DATA_FROM_DMEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a distant chip's memory\000\0001%\000\000\000\00000 */
{ 418558 }, /* DL1_RELOAD_FROM_DMEM_RATE\000dL1_Reloads\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from distant memory per completed instruction\000\0001%\000\000\000\00000 */
{ 429432 }, /* DL1_RELOAD_FROM_D_OC_CACHE\000dL1_Reloads\000PM_DATA_FROM_D_OC_CACHE * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a distant chip's OpenCAPI Cache\000\0001%\000\000\000\00000 */
{ 429618 }, /* DL1_RELOAD_FROM_D_OC_MEM\000dL1_Reloads\000PM_DATA_FROM_D_OC_MEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a distant chip's OpenCAPI memory\000\0001%\000\000\000\00000 */
{ 423923 }, /* DL1_RELOAD_FROM_L2\000dL1_Reloads\000PM_DATA_FROM_L2 * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local L2\000\0001%\000\000\000\00000 */
{ 425173 }, /* DL1_RELOAD_FROM_L21_NON_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L21_NON_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same chip in a different regent with modified data\000\0001%\000\000\000\00000 */
{ 425419 }, /* DL1_RELOAD_FROM_L21_NON_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L21_NON_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same chip in a different regent with shared data\000\0001%\000\000\000\00000 */
{ 424739 }, /* DL1_RELOAD_FROM_L21_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L21_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same regent with modified data\000\0001%\000\000\000\00000 */
{ 424957 }, /* DL1_RELOAD_FROM_L21_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L21_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on the same regent with shared data\000\0001%\000\000\000\00000 */
{ 424074 }, /* DL1_RELOAD_FROM_L2_MISS\000dL1_Reloads\000PM_DATA_FROM_L2MISS / PM_LD_DEMAND_MISS_L1 * 100\000\000Percentage of demand load misses that reloaded from beyond the local L2\000\0001%\000\000\000\00000 */
{ 416531 }, /* DL1_RELOAD_FROM_L2_MISS_RATE\000dL1_Reloads\000PM_DATA_FROM_L2MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of demand loads that reloaded from beyond the L2 per completed instruction\000\0001%\000\000\000\00000 */
{ 416365 }, /* DL1_RELOAD_FROM_L2_RATE\000dL1_Reloads\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from the L2 per completed instruction\000\0001%\000\000\000\00000 */
{ 424241 }, /* DL1_RELOAD_FROM_L3\000dL1_Reloads\000PM_DATA_FROM_L3 * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local L3\000\0001%\000\000\000\00000 */
{ 426097 }, /* DL1_RELOAD_FROM_L31_NON_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L31_NON_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same chip in a different regent with modified data\000\0001%\000\000\000\00000 */
{ 426343 }, /* DL1_RELOAD_FROM_L31_NON_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L31_NON_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same chip in a different regent with shared data\000\0001%\000\000\000\00000 */
{ 425663 }, /* DL1_RELOAD_FROM_L31_REGENT_MOD\000dL1_Reloads\000PM_DATA_FROM_L31_REGENT_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same regent with modified data\000\0001%\000\000\000\00000 */
{ 425881 }, /* DL1_RELOAD_FROM_L31_REGENT_SHR\000dL1_Reloads\000PM_DATA_FROM_L31_REGENT_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on the same regent with shared data\000\0001%\000\000\000\00000 */
{ 424559 }, /* DL1_RELOAD_FROM_L3_MEPF\000dL1_Reloads\000PM_DATA_FROM_L3_MEPF * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local L3 with modified data\000\0001%\000\000\000\00000 */
{ 417347 }, /* DL1_RELOAD_FROM_L3_MEPF_RATE\000dL1_Reloads\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded with data brought into the L3 by prefetch per completed instruction\000\0001%\000\000\000\00000 */
{ 424392 }, /* DL1_RELOAD_FROM_L3_MISS\000dL1_Reloads\000PM_DATA_FROM_L3MISS / PM_LD_DEMAND_MISS_L1 * 100\000\000Percentage of demand load misses that reloaded from beyond the local L3\000\0001%\000\000\000\00000 */
{ 417553 }, /* DL1_RELOAD_FROM_L3_MISS_RATE\000dL1_Reloads\000PM_DATA_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of demand loads that reloaded from beyond the L3 per completed instruction\000\0001%\000\000\000\00000 */
{ 417181 }, /* DL1_RELOAD_FROM_L3_RATE\000dL1_Reloads\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from the L3 per completed instruction\000\0001%\000\000\000\00000 */
{ 428199 }, /* DL1_RELOAD_FROM_LMEM\000dL1_Reloads\000PM_DATA_FROM_LMEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local chip's memory\000\0001%\000\000\000\00000 */
{ 418205 }, /* DL1_RELOAD_FROM_LMEM_RATE\000dL1_Reloads\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from local memory per completed instruction\000\0001%\000\000\000\00000 */
{ 428365 }, /* DL1_RELOAD_FROM_L_OC_CACHE\000dL1_Reloads\000PM_DATA_FROM_L_OC_CACHE * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local chip's OpenCAPI Cache\000\0001%\000\000\000\00000 */
{ 428551 }, /* DL1_RELOAD_FROM_L_OC_MEM\000dL1_Reloads\000PM_DATA_FROM_L_OC_MEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from the local chip's OpenCAPI memory\000\0001%\000\000\000\00000 */
{ 416713 }, /* DL1_RELOAD_FROM_RL2L3_MOD_RATE\000dL1_Reloads\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using modified data from another core's L2 or L3 on a remote chip, per completed instruction\000\0001%\000\000\000\00000 */
{ 416948 }, /* DL1_RELOAD_FROM_RL2L3_SHR_RATE\000dL1_Reloads\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded using shared data from another core's L2 or L3 on a remote chip, per completed instruction\000\0001%\000\000\000\00000 */
{ 426587 }, /* DL1_RELOAD_FROM_RL2_MOD\000dL1_Reloads\000PM_DATA_FROM_RL2_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a remote chip with modified data\000\0001%\000\000\000\00000 */
{ 426789 }, /* DL1_RELOAD_FROM_RL2_SHR\000dL1_Reloads\000PM_DATA_FROM_RL2_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L2 on a remote chip with shared data\000\0001%\000\000\000\00000 */
{ 426989 }, /* DL1_RELOAD_FROM_RL3_MOD\000dL1_Reloads\000PM_DATA_FROM_RL3_MOD * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a remote chip with modified data\000\0001%\000\000\000\00000 */
{ 427191 }, /* DL1_RELOAD_FROM_RL3_SHR\000dL1_Reloads\000PM_DATA_FROM_RL3_SHR * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from another core's L3 on a remote chip with shared data\000\0001%\000\000\000\00000 */
{ 428734 }, /* DL1_RELOAD_FROM_RMEM\000dL1_Reloads\000PM_DATA_FROM_RMEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a remote chip's memory\000\0001%\000\000\000\00000 */
{ 418381 }, /* DL1_RELOAD_FROM_RMEM_RATE\000dL1_Reloads\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of demand loads that reloaded from remote memory per completed instruction\000\0001%\000\000\000\00000 */
{ 428899 }, /* DL1_RELOAD_FROM_R_OC_CACHE\000dL1_Reloads\000PM_DATA_FROM_R_OC_CACHE * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a remote chip's OpenCAPI Cache\000\0001%\000\000\000\00000 */
{ 429084 }, /* DL1_RELOAD_FROM_R_OC_MEM\000dL1_Reloads\000PM_DATA_FROM_R_OC_MEM * 100 / PM_LD_DEMAND_MISS_L1\000\000Percentage of demand load misses that reloaded from a remote chip's OpenCAPI memory\000\0001%\000\000\000\00000 */
{ 409522 }, /* DMISS_L21_L31_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a neighbor chiplet's L2 or L3 in the same chip\000\000\000\000\000\00000 */
{ 408751 }, /* DMISS_L2L3_CONFLICT_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, with an RC dispatch conflict\000\000\000\000\000\00000 */
{ 409017 }, /* DMISS_L2L3_NOCONFLICT_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L2L3_NOCONFLICT / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3, without an RC dispatch conflict\000\000\000\000\000\00000 */
{ 408533 }, /* DMISS_L2L3_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from either the local L2 or local L3\000\000\000\000\000\00000 */
{ 409290 }, /* DMISS_L3MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a source beyond the local L2 and local L3\000\000\000\000\000\00000 */
{ 409761 }, /* DMISS_LMEM_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from L4, local memory or OpenCAPI chip\000\000\000\000\000\00000 */
{ 409981 }, /* DMISS_OFF_CHIP_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_OFF_CHIP / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a remote chip (cache, L4, memory or OpenCAPI) in the same group\000\000\000\000\000\00000 */
{ 410239 }, /* DMISS_OFF_NODE_STALL_CPI\000CPI\000PM_EXEC_STALL_DMISS_OFF_NODE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting for a load miss to resolve from a distant chip (cache, L4, memory or OpenCAPI chip)\000\000\000\000\000\00000 */
{ 414792 }, /* DTLB_MISS_RATE\000Others\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions when the DPTEG required for the load/store instruction in execution was missing from the TLB\000\0001%\000\000\000\00000 */
{ 412220 }, /* EXCEPTION_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_EXCEPTION / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction cannot complete because it was interrupted by ANY exception\000\000\000\000\000\00000 */
{ 406538 }, /* EXECUTION_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_EXEC_STALL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000\00000 */
{ 422190 }, /* EXEC_STALL_UNKOWN_CPI\000General\000PM_EXEC_STALL_UNKNOWN / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTF instruction is completing and the finish was overlooked\000\000\000\000\000\00000 */
{ 406935 }, /* FIN_AT_DISP_STALL_CPI\000CPI\000PM_EXEC_STALL_FIN_AT_DISP / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTF instruction finishes at dispatch\000\000\000\000\000\00000 */
{ 413982 }, /* FLUSH_RATE\000Others\000PM_FLUSH / PM_RUN_INST_CMPL * 100\000\000Percentage of flushes per completed instruction\000\0001%\000\000\000\00000 */
{ 423622 }, /* FX_PER_INST\000General\000PM_FX_LSU_FIN / PM_RUN_INST_CMPL\000\000Average number of simple fixed-point instructions finshed in the store unit per completed instruction\000\000\000\000\000\00000 */
{ 413140 }, /* HWSYNC_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_HWSYNC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a HWSYNC instruction stuck at finish waiting for a response from the L2\000\000\000\000\000\00000 */
{ 422058 }, /* INST_FIN_PER_CMPL\000General\000PM_INST_FIN / PM_RUN_INST_CMPL\000\000Average number of finished instructions per completed instructions\000\000\000\000\000\00000 */
{ 420593 }, /* INST_FROM_DMEM\000Instruction_Stats\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from distant memory\000\0001%\000\000\000\00000 */
{ 421388 }, /* INST_FROM_DMEM_RATE\000Instruction_Misses\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from distant memory per completed instruction\000\0001%\000\000\000\00000 */
{ 420004 }, /* INST_FROM_L2\000Instruction_Stats\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from the L2\000\0001%\000\000\000\00000 */
{ 431153 }, /* INST_FROM_L2_MISS\000Instruction_Misses\000PM_INST_FROM_L2MISS * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from beyond the local L2\000\0001%\000\000\000\00000 */
{ 431483 }, /* INST_FROM_L2_MISS_RATE\000Instruction_Misses\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from beyond the L2 per completed instruction\000\0001%\000\000\000\00000 */
{ 420747 }, /* INST_FROM_L2_RATE\000Instruction_Misses\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from the L2 per completed instruction\000\0001%\000\000\000\00000 */
{ 420146 }, /* INST_FROM_L3\000Instruction_Stats\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from the L3\000\0001%\000\000\000\00000 */
{ 431318 }, /* INST_FROM_L3_MISS\000Instruction_Misses\000PM_INST_FROM_L3MISS / PM_L1_ICACHE_MISS * 100\000\000Percentage of icache misses that were reloaded from beyond the local L3\000\0001%\000\000\000\00000 */
{ 431654 }, /* INST_FROM_L3_MISS_RATE\000Instruction_Misses\000PM_INST_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of icache reloads from the beyond the L3 per completed instruction\000\0001%\000\000\000\00000 */
{ 420902 }, /* INST_FROM_L3_RATE\000Instruction_Misses\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from the L3 per completed instruction\000\0001%\000\000\000\00000 */
{ 420288 }, /* INST_FROM_LMEM\000Instruction_Stats\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from local memory\000\0001%\000\000\000\00000 */
{ 421057 }, /* INST_FROM_LMEM_RATE\000Instruction_Misses\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from local memory per completed instruction\000\0001%\000\000\000\00000 */
{ 420440 }, /* INST_FROM_RMEM\000Instruction_Stats\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000\000Percentage of ICache misses that were reloaded from remote memory\000\0001%\000\000\000\00000 */
{ 421222 }, /* INST_FROM_RMEM_RATE\000Instruction_Misses\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000Percentage of ICache reloads from remote memory per completed instruction\000\0001%\000\000\000\00000 */
{ 415862 }, /* IPC\000General\000PM_INST_CMPL / PM_CYC\000\000Average number of completed instructions per cycle\000\000\000\000\000\00000 */
{ 406344 }, /* ISSUE_STALL_CPI\000CPI;CPI_STALL_RATIO\000PM_ISSUE_STALL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction has been dispatched but not issued for any reason\000\000\000\000\000\00000 */
{ 419414 }, /* ITLB_MISS_RATE\000General\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of ITLB misses per completed run instruction\000\0001%\000\000\000\00000 */
{ 415314 }, /* L1_INST_MISS_RATE\000Instruction_Misses\000PM_L1_ICACHE_MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were demand fetches that missed the L1 icache\000\0001%\000\000\000\00000 */
{ 414503 }, /* L1_LD_MISS_RATE\000Others\000PM_LD_MISS_L1 / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were loads that missed the L1\000\0001%\000\000\000\00000 */
{ 414383 }, /* L1_LD_MISS_RATIO\000Others\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000\000Percentage of finished loads that missed in the L1\000\0001%\000\000\000\00000 */
{ 414647 }, /* L1_ST_MISS_RATE\000Others\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of completed instructions that were stores that missed the L1\000\0001%\000\000\000\00000 */
{ 415492 }, /* L2_INST_MISS_RATE\000General\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000Percentage of completed instructions that were demand fetches that missed the L1 and L2 instruction cache\000\0001%\000\000\000\00000 */
{ 415141 }, /* L2_LD_MISS_RATE\000General\000PM_DATA_FROM_L2MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were a demand load that did not hit in the L1 or L2\000\0001%\000\000\000\00000 */
{ 415679 }, /* L3_INST_MISS_RATE\000General\000PM_INST_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were demand fetches that reloaded from beyond the L3 icache\000\0001%\000\000\000\00000 */
{ 422495 }, /* L3_LD_MISS_RATE\000General\000PM_DATA_FROM_L3MISS / PM_RUN_INST_CMPL * 100\000\000Percentage of completed instructions that were a demand load that did not hit in the L1, L2, or the L3\000\0001%\000\000\000\00000 */
{ 423351 }, /* LARX_PER_INST\000General\000PM_LARX_FIN / PM_RUN_INST_CMPL\000\000Average number of LARX instructions finshed per completed instruction\000\000\000\000\000\00000 */
{ 419080 }, /* LD_LMEM_PER_LD_DMEM\000Memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000\000Number of data reloads from local memory per data reloads from distant memory\000\000\000\000\000\00000 */
{ 419231 }, /* LD_LMEM_PER_LD_MEM\000Memory\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000\000Number of data reloads from local memory per data reloads from distant and remote memory\000\000\000\000\000\00000 */
{ 418930 }, /* LD_LMEM_PER_LD_RMEM\000Memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000\000Number of data reloads from local memory per data reloads from remote memory\000\000\000\000\000\00000 */
{ 419541 }, /* LD_RMEM_PER_LD_DMEM\000Memory\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000\000Number of data reloads from remote memory per data reloads from distant memory\000\000\000\000\000\00000 */
{ 416243 }, /* LOADS_PER_INST\000General\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000\000Average number of finished loads per completed instruction\000\000\000\000\000\00000 */
{ 410654 }, /* LOAD_FINISH_STALL_CPI\000CPI\000PM_EXEC_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is finishing a load after its data has been reloaded from a data source beyond the local L1, OR when the LSU is processing an L1-hit, OR when the NTF instruction merged with another load in the LMQ\000\000\000\000\000\00000 */
{ 408363 }, /* LOAD_STALL_CPI\000CPI\000PM_EXEC_STALL_LOAD / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a load that is executing in the LSU\000\000\000\000\000\00000 */
{ 422802 }, /* LSU_PER_INST\000General\000PM_LSU_FIN / PM_RUN_INST_CMPL\000\000Average number of instructions finished in the LSU per completed instruction\000\000\000\000\000\00000 */
{ 408210 }, /* LSU_STALL_CPI\000CPI\000PM_EXEC_STALL_LSU / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing in the LSU\000\000\000\000\000\00000 */
{ 412950 }, /* LWSYNC_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_LWSYNC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a LWSYNC instruction waiting to complete\000\000\000\000\000\00000 */
{ 412432 }, /* MEM_ECC_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_MEM_ECC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is stuck at finish waiting for the non-speculative finish of either a STCX instruction waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000\00000 */
{ 418736 }, /* MEM_LOCALITY\000Memory\000PM_DATA_FROM_LMEM * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_RMEM + PM_DATA_FROM_DMEM)\000\000Percentage of data reloads from local memory per data reloads from any memory\000\0001%\000\000\000\00000 */
{ 406741 }, /* NTC_FLUSH_STALL_CPI\000CPI\000PM_EXEC_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction spent executing an NTC instruction that gets flushed some time after dispatch\000\000\000\000\000\00000 */
{ 423482 }, /* PTESYNC_PER_INST\000General\000PM_PTESYNC_FIN / PM_RUN_INST_CMPL\000\000Average number of PTESYNC instructions finshed per completed instruction\000\000\000\000\000\00000 */
{ 411853 }, /* PTESYNC_STALL_CPI\000CPI\000PM_EXEC_STALL_PTESYNC / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing a PTESYNC instruction\000\000\000\000\000\00000 */
{ 421555 }, /* RUN_CPI\000General\000PM_RUN_CYC / PM_RUN_INST_CMPL\000\000Average number of run cycles per completed instruction\000\000\000\000\000\00000 */
{ 401321 }, /* RUN_CYCLES_RATE\000General\000PM_RUN_CYC / PM_CYC * 100\000\000Percentage of cycles that are run cycles\000\0001%\000\000\000\00000 */
{ 421794 }, /* RUN_IPC\000General\000PM_RUN_INST_CMPL / PM_RUN_CYC\000\000Average number of completed instructions per run cycle\000\000\000\000\000\00000 */
{ 407262 }, /* SIMPLE_FX_STALL_CPI\000CPI\000PM_EXEC_STALL_SIMPLE_FX / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a simple fixed point instruction that is executing in the LSU\000\000\000\000\000\00000 */
{ 413361 }, /* SPECIAL_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_SPECIAL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction required special handling before completion\000\000\000\000\000\00000 */
{ 412749 }, /* STCX_COMPLETION_STALL_CPI\000CPI\000PM_CMPL_STALL_STCX / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a STCX instruction waiting for resolution from the nest\000\000\000\000\000\00000 */
{ 423220 }, /* STCX_PER_INST\000General\000PM_STCX_FIN / PM_RUN_INST_CMPL\000\000Average number of STCX instructions finshed per completed instruction\000\000\000\000\000\00000 */
{ 411401 }, /* STORE_MISS_STALL_CPI\000CPI\000PM_EXEC_STALL_STORE_MISS / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a store whose cache line was not resident in the L1 and had to wait for allocation of the missing line into the L1\000\000\000\000\000\00000 */
{ 411170 }, /* STORE_PIPE_STALL_CPI\000CPI\000PM_EXEC_STALL_STORE_PIPE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is in the store unit outside of handling store misses or other special store operations\000\000\000\000\000\00000 */
{ 410997 }, /* STORE_STALL_CPI\000CPI\000PM_EXEC_STALL_STORE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a store that is executing in the LSU\000\000\000\000\000\00000 */
{ 422379 }, /* TAKEN_BRANCHES\000General\000PM_BR_TAKEN_CMPL / PM_BR_FIN * 100\000\000Percentage of finished branches that were taken\000\0001%\000\000\000\00000 */
{ 410485 }, /* TLBIEL_STALL_CPI\000CPI\000PM_EXEC_STALL_TLBIEL / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing a TLBIEL instruction\000\000\000\000\000\00000 */
{ 423074 }, /* TLBIE_PER_INST\000General\000PM_TLBIE_FIN / PM_RUN_INST_CMPL\000\000Average number of TLBIE instructions finished in the LSU per completed instruction\000\000\000\000\000\00000 */
{ 411662 }, /* TLBIE_STALL_CPI\000CPI\000PM_EXEC_STALL_TLBIE / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is a TLBIE instruction waiting for a response from the L2\000\000\000\000\000\00000 */
{ 407621 }, /* TRANSLATION_STALL_CPI\000CPI\000PM_EXEC_STALL_TRANSLATION / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is waiting to be finished in one of the execution units\000\000\000\000\000\00000 */
{ 422938 }, /* VSU_PER_INST\000General\000PM_VSU_FIN / PM_RUN_INST_CMPL\000\000Average number of instructions finished in the VSU per completed instruction\000\000\000\000\000\00000 */
{ 407468 }, /* VSU_STALL_CPI\000CPI\000PM_EXEC_STALL_VSU / PM_RUN_INST_CMPL\000\000Average cycles per completed instruction when the NTC instruction is executing in the VSU\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__power10[] = {
{
     .entries = pmu_metrics__power10_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__power10_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__power8_default_core[] = {
{ 171951 }, /* pm_1lpar_cyc\000other\000Number of cycles in single lpar mode. All threads in the core are assigned to the same lpar\000event=0x1f05e\000\00000\000\000 */
{ 262954 }, /* pm_1plus_ppc_cmpl\000pipeline\0001 or more ppc insts finished\000event=0x100f2\000\00000\0001 or more ppc insts finished (completed)\000 */
{ 263069 }, /* pm_1plus_ppc_disp\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\00000\000Cycles at least one Instr Dispatched. Could be a group with only microcode. Issue HW016521\000 */
{ 172081 }, /* pm_2lpar_cyc\000other\000Cycles in 2-lpar mode. Threads 0-3 belong to Lpar0 and threads 4-7 belong to Lpar1\000event=0x2006e\000\00000\000Number of cycles in 2 lpar mode\000 */
{ 172233 }, /* pm_4lpar_cyc\000other\000Number of cycles in 4 LPAR mode. Threads 0-1 belong to lpar0, threads 2-3 belong to lpar1, threads 4-5 belong to lpar2, and threads 6-7 belong to lpar3\000event=0x4e05e\000\00000\000\000 */
{ 172423 }, /* pm_all_chip_pump_cpred\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000 */
{ 172790 }, /* pm_all_grp_pump_cpred\000other\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x520050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 173161 }, /* pm_all_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x620052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 173620 }, /* pm_all_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 174057 }, /* pm_all_pump_cpred\000other\000Pump prediction correct. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x610054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 174381 }, /* pm_all_pump_mpred\000other\000Pump misprediction. Counts across all types of pumps for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 174695 }, /* pm_all_sys_pump_cpred\000other\000Initial and Final Pump Scope was system pump for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 175033 }, /* pm_all_sys_pump_mpred\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x630052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 175574 }, /* pm_all_sys_pump_mpred_rty\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types (demand load,data prefetch,inst prefetch,inst fetch,xlate)\000event=0x640050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 263242 }, /* pm_any_thrd_run_cyc\000pipeline\000One of threads in run_cycles\000event=0x100fa\000\00000\000Any thread in run_cycles (was one thread in run_cycles)\000 */
{ 126788 }, /* pm_back_br_cmpl\000frontend\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\00000\000\000 */
{ 175972 }, /* pm_bank_conflict\000other\000Read blocked due to interleave conflict. The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4082\000\00000\000\000 */
{ 126988 }, /* pm_br_2path\000frontend\000two path branch\000event=0x20036\000\00000\000\000 */
{ 176147 }, /* pm_br_bc_8\000other\000Pairable BC+8 branch that has not been converted to a Resolve Finished in the BRU pipeline\000event=0x5086\000\00000\000\000 */
{ 176273 }, /* pm_br_bc_8_conv\000other\000Pairable BC+8 branch that was converted to a Resolve Finished in the BRU pipeline\000event=0x5084\000\00000\000\000 */
{ 127044 }, /* pm_br_cmpl\000frontend\000Branch Instruction completed\000event=0x40060\000\00000\000\000 */
{ 176395 }, /* pm_br_mpred_ccache\000other\000Conditional Branch Completed that was Mispredicted due to the Count Cache Target Prediction\000event=0x40ac\000\00000\000\000 */
{ 127112 }, /* pm_br_mpred_cmpl\000frontend\000Number of Branch Mispredicts\000event=0x400f6\000\00000\000\000 */
{ 176530 }, /* pm_br_mpred_cr\000other\000Conditional Branch Completed that was Mispredicted due to the BHT Direction Prediction (taken/not taken)\000event=0x40b8\000\00000\000\000 */
{ 176674 }, /* pm_br_mpred_lstack\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x40ae\000\00000\000\000 */
{ 176808 }, /* pm_br_mpred_ta\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack. Only XL-form branches that resolved Taken set this event\000event=0x40ba\000\00000\000\000 */
{ 177028 }, /* pm_br_mrk_2path\000other\000marked two path branch\000event=0x10138\000\00000\000\000 */
{ 177092 }, /* pm_br_pred_br0\000other\000Conditional Branch Completed on BR0 (1st branch in group) in which the HW predicted the Direction or Target\000event=0x409c\000\00000\000\000 */
{ 177239 }, /* pm_br_pred_br1\000other\000Conditional Branch Completed on BR1 (2nd branch in group) in which the HW predicted the Direction or Target. Note: BR1 can only be used in Single Thread Mode. In all of the SMT modes, only one branch can complete, thus BR1 is unused\000event=0x409e\000\00000\000\000 */
{ 177511 }, /* pm_br_pred_br_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) OR if_pc_br0_br_pred(1)\000event=0x489c\000\00000\000IFU\000 */
{ 177691 }, /* pm_br_pred_ccache_br0\000other\000Conditional Branch Completed on BR0 that used the Count Cache for Target Prediction\000event=0x40a4\000\00000\000\000 */
{ 177821 }, /* pm_br_pred_ccache_br1\000other\000Conditional Branch Completed on BR1 that used the Count Cache for Target Prediction\000event=0x40a6\000\00000\000\000 */
{ 177951 }, /* pm_br_pred_ccache_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND if_pc_br0_pred_type\000event=0x48a4\000\00000\000IFU\000 */
{ 178135 }, /* pm_br_pred_cr_br0\000other\000Conditional Branch Completed on BR0 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\00000\000\000 */
{ 178432 }, /* pm_br_pred_cr_br1\000other\000Conditional Branch Completed on BR1 that had its direction predicted. I-form branches do not set this event. In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b2\000\00000\000\000 */
{ 178729 }, /* pm_br_pred_cr_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(1)='1'\000event=0x48b0\000\00000\000IFU\000 */
{ 178889 }, /* pm_br_pred_lstack_br0\000other\000Conditional Branch Completed on BR0 that used the Link Stack for Target Prediction\000event=0x40a8\000\00000\000\000 */
{ 179018 }, /* pm_br_pred_lstack_br1\000other\000Conditional Branch Completed on BR1 that used the Link Stack for Target Prediction\000event=0x40aa\000\00000\000\000 */
{ 179147 }, /* pm_br_pred_lstack_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0) AND (not if_pc_br0_pred_type)\000event=0x48a8\000\00000\000IFU\000 */
{ 179337 }, /* pm_br_pred_ta_br0\000other\000Conditional Branch Completed on BR0 that had its target address predicted. Only XL-form branches set this event\000event=0x40b4\000\00000\000\000 */
{ 179491 }, /* pm_br_pred_ta_br1\000other\000Conditional Branch Completed on BR1 that had its target address predicted. Only XL-form branches set this event\000event=0x40b6\000\00000\000\000 */
{ 179645 }, /* pm_br_pred_ta_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred(0)='1'\000event=0x48b4\000\00000\000IFU\000 */
{ 127186 }, /* pm_br_taken_cmpl\000frontend\000New event for Branch Taken\000event=0x200fa\000\00000\000\000 */
{ 179805 }, /* pm_br_uncond_br0\000other\000Unconditional Branch Completed on BR0. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a0\000\00000\000\000 */
{ 180069 }, /* pm_br_uncond_br1\000other\000Unconditional Branch Completed on BR1. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was coverted to a Resolve\000event=0x40a2\000\00000\000\000 */
{ 180333 }, /* pm_br_uncond_cmpl\000other\000Completion Time Event. This event can also be calculated from the direct bus as follows: if_pc_br0_br_pred=00 AND if_pc_br0_completed\000event=0x48a0\000\00000\000IFU\000 */
{ 126921 }, /* pm_bru_fin\000frontend\000Branch Instruction Finished\000event=0x10068\000\00000\000\000 */
{ 180512 }, /* pm_castout_issued\000other\000Castouts issued\000event=0x3094\000\00000\000\000 */
{ 180570 }, /* pm_castout_issued_gpr\000other\000Castouts issued GPR\000event=0x3096\000\00000\000\000 */
{ 162972 }, /* pm_chip_pump_cpred\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for all data types ( demand load,data,inst prefetch,inst fetch,xlate (I or d)\000 */
{ 180636 }, /* pm_clb_held\000other\000CLB Hold: Any Reason\000event=0x2090\000\00000\000\000 */
{ 263374 }, /* pm_cmplu_stall\000pipeline\000Completion stall\000event=0x4000a\000\00000\000\000 */
{ 263434 }, /* pm_cmplu_stall_bru\000pipeline\000Completion stall due to a Branch Unit\000event=0x4d018\000\00000\000\000 */
{ 180693 }, /* pm_cmplu_stall_bru_cru\000other\000Completion stall due to IFU\000event=0x2d018\000\00000\000\000 */
{ 180769 }, /* pm_cmplu_stall_coq_full\000other\000Completion stall due to CO q full\000event=0x30026\000\00000\000\000 */
{ 263519 }, /* pm_cmplu_stall_dcache_miss\000pipeline\000Completion stall by Dcache miss\000event=0x2c012\000\00000\000\000 */
{ 263606 }, /* pm_cmplu_stall_dmiss_l21_l31\000pipeline\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000event=0x2c018\000\00000\000\000 */
{ 263743 }, /* pm_cmplu_stall_dmiss_l2l3\000pipeline\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x2c016\000\00000\000\000 */
{ 263853 }, /* pm_cmplu_stall_dmiss_l2l3_conflict\000pipeline\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\00000\000Completion stall due to cache miss resolving in core's L2/L3 with a conflict\000 */
{ 264073 }, /* pm_cmplu_stall_dmiss_l3miss\000pipeline\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\00000\000\000 */
{ 264188 }, /* pm_cmplu_stall_dmiss_lmem\000pipeline\000Completion stall due to cache miss that resolves in local memory\000event=0x4c018\000\00000\000Completion stall due to cache miss resolving in core's Local Memory\000 */
{ 264374 }, /* pm_cmplu_stall_dmiss_remote\000pipeline\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\00000\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000 */
{ 264591 }, /* pm_cmplu_stall_erat_miss\000pipeline\000Completion stall due to LSU reject ERAT miss\000event=0x4c012\000\00000\000\000 */
{ 180852 }, /* pm_cmplu_stall_flush\000other\000completion stall due to flush by own thread\000event=0x30038\000\00000\000\000 */
{ 264689 }, /* pm_cmplu_stall_fxlong\000pipeline\000Completion stall due to a long latency fixed point instruction\000event=0x4d016\000\00000\000\000 */
{ 264802 }, /* pm_cmplu_stall_fxu\000pipeline\000Completion stall due to FXU\000event=0x2d016\000\00000\000\000 */
{ 264877 }, /* pm_cmplu_stall_hwsync\000pipeline\000completion stall due to hwsync\000event=0x30036\000\00000\000\000 */
{ 264958 }, /* pm_cmplu_stall_load_finish\000pipeline\000Completion stall due to a Load finish\000event=0x4d014\000\00000\000\000 */
{ 265051 }, /* pm_cmplu_stall_lsu\000pipeline\000Completion stall by LSU instruction\000event=0x2c010\000\00000\000\000 */
{ 265134 }, /* pm_cmplu_stall_lwsync\000pipeline\000completion stall due to isync/lwsync\000event=0x10036\000\00000\000\000 */
{ 180942 }, /* pm_cmplu_stall_mem_ecc_delay\000other\000Completion stall due to mem ECC delay\000event=0x30028\000\00000\000\000 */
{ 181034 }, /* pm_cmplu_stall_no_ntf\000other\000Completion stall due to nop\000event=0x2e01c\000\00000\000\000 */
{ 181109 }, /* pm_cmplu_stall_ntcg_flush\000other\000Completion stall due to ntcg flush\000event=0x2e01e\000\00000\000Completion stall due to reject (load hit store)\000 */
{ 265221 }, /* pm_cmplu_stall_other_cmpl\000pipeline\000Instructions core completed while this tread was stalled\000event=0x30006\000\00000\000Instructions core completed while this thread was stalled\000 */
{ 181423 }, /* pm_cmplu_stall_rej_lmq_full\000other\000Completion stall due to LSU reject LMQ full\000event=0x4c014\000\00000\000\000 */
{ 181242 }, /* pm_cmplu_stall_reject\000other\000Completion stall due to LSU reject\000event=0x4c010\000\00000\000\000 */
{ 181324 }, /* pm_cmplu_stall_reject_lhs\000other\000Completion stall due to reject (load hit store)\000event=0x2c01a\000\00000\000\000 */
{ 181520 }, /* pm_cmplu_stall_scalar\000other\000Completion stall due to VSU scalar instruction\000event=0x4d010\000\00000\000\000 */
{ 181614 }, /* pm_cmplu_stall_scalar_long\000other\000Completion stall due to VSU scalar long latency instruction\000event=0x2d010\000\00000\000\000 */
{ 265389 }, /* pm_cmplu_stall_st_fwd\000pipeline\000Completion stall due to store forward\000event=0x4c01c\000\00000\000\000 */
{ 181726 }, /* pm_cmplu_stall_store\000other\000Completion stall by stores this includes store agen finishes in pipe LS0/LS1 and store data finishes in LS2/LS3\000event=0x2c014\000\00000\000\000 */
{ 265477 }, /* pm_cmplu_stall_thrd\000pipeline\000Completion Stalled due to thread conflict. Group ready to complete but it was another thread's turn\000event=0x1001c\000\00000\000Completion stall due to thread conflict\000 */
{ 181884 }, /* pm_cmplu_stall_vector\000other\000Completion stall due to VSU vector instruction\000event=0x2d014\000\00000\000\000 */
{ 181978 }, /* pm_cmplu_stall_vector_long\000other\000Completion stall due to VSU vector long instruction\000event=0x4d012\000\00000\000\000 */
{ 182082 }, /* pm_cmplu_stall_vsu\000other\000Completion stall due to VSU instruction\000event=0x2d012\000\00000\000\000 */
{ 182166 }, /* pm_co0_alloc\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16083\000\00000\0000.0\000 */
{ 182289 }, /* pm_co0_busy\000other\000CO mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16082\000\00000\000\000 */
{ 182408 }, /* pm_co_usage\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3608a\000\00000\000\000 */
{ 182627 }, /* pm_cru_fin\000other\000IFU Finished a (non-branch) instruction\000event=0x40066\000\00000\000\000 */
{ 265664 }, /* pm_cyc\000pipeline\000Cycles\000event=0x1e\000\00000\000\000 */
{ 182703 }, /* pm_data_all_chip_pump_cpred\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for either demand loads or data prefetch\000event=0x61c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000 */
{ 182978 }, /* pm_data_all_from_dl2l3_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x64c048\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 183446 }, /* pm_data_all_from_dl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either demand loads or data prefetch\000event=0x63c048\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 183910 }, /* pm_data_all_from_dl4\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either demand loads or data prefetch\000event=0x63c04c\000\00000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 184286 }, /* pm_data_all_from_dmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either demand loads or data prefetch\000event=0x64c04c\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 184665 }, /* pm_data_all_from_l2\000other\000The processor's data cache was reloaded from local core's L2 due to either demand loads or data prefetch\000event=0x61c042\000\00000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 184958 }, /* pm_data_all_from_l21_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x64c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 185340 }, /* pm_data_all_from_l21_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either demand loads or data prefetch\000event=0x63c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 186071 }, /* pm_data_all_from_l2_disp_conflict_ldhitst\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either demand loads or data prefetch\000event=0x63c040\000\00000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 186444 }, /* pm_data_all_from_l2_disp_conflict_other\000other\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either demand loads or data prefetch\000event=0x64c040\000\00000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 186803 }, /* pm_data_all_from_l2_mepf\000other\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either demand loads or data prefetch\000event=0x62c040\000\00000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 187191 }, /* pm_data_all_from_l2_no_conflict\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to either demand loads or data prefetch\000event=0x61c040\000\00000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 185718 }, /* pm_data_all_from_l2miss_mod\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to either demand loads or data prefetch\000event=0x61c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 187530 }, /* pm_data_all_from_l3\000other\000The processor's data cache was reloaded from local core's L3 due to either demand loads or data prefetch\000event=0x64c042\000\00000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 187823 }, /* pm_data_all_from_l31_eco_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x64c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 188217 }, /* pm_data_all_from_l31_eco_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either demand loads or data prefetch\000event=0x63c044\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 188607 }, /* pm_data_all_from_l31_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x62c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 188989 }, /* pm_data_all_from_l31_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either demand loads or data prefetch\000event=0x61c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 189720 }, /* pm_data_all_from_l3_disp_conflict\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either demand loads or data prefetch\000event=0x63c042\000\00000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 190073 }, /* pm_data_all_from_l3_mepf\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either demand loads or data prefetch\000event=0x62c042\000\00000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 190461 }, /* pm_data_all_from_l3_no_conflict\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to either demand loads or data prefetch\000event=0x61c044\000\00000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 189367 }, /* pm_data_all_from_l3miss_mod\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to either demand loads or data prefetch\000event=0x64c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 190800 }, /* pm_data_all_from_ll4\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to either demand loads or data prefetch\000event=0x61c04c\000\00000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 191114 }, /* pm_data_all_from_lmem\000other\000The processor's data cache was reloaded from the local chip's Memory due to either demand loads or data prefetch\000event=0x62c048\000\00000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 191425 }, /* pm_data_all_from_memory\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either demand loads or data prefetch\000event=0x62c04c\000\00000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 191810 }, /* pm_data_all_from_off_chip_cache\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either demand loads or data prefetch\000event=0x64c04a\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 192267 }, /* pm_data_all_from_on_chip_cache\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either demand loads or data prefetch\000event=0x61c048\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 192677 }, /* pm_data_all_from_rl2l3_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x62c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 193137 }, /* pm_data_all_from_rl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either demand loads or data prefetch\000event=0x61c04a\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 193593 }, /* pm_data_all_from_rl4\000other\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x62c04a\000\00000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 193963 }, /* pm_data_all_from_rmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either demand loads or data prefetch\000event=0x63c04a\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 194342 }, /* pm_data_all_grp_pump_cpred\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for either demand loads or data prefetch\000event=0x62c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000 */
{ 194597 }, /* pm_data_all_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for either demand loads or data prefetch\000event=0x62c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 195024 }, /* pm_data_all_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for either demand loads or data prefetch\000event=0x61c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000 */
{ 195359 }, /* pm_data_all_pump_cpred\000other\000Pump prediction correct. Counts across all types of pumps for either demand loads or data prefetch\000event=0x61c054\000\00000\000Pump prediction correct. Counts across all types of pumps for a demand load\000 */
{ 195582 }, /* pm_data_all_pump_mpred\000other\000Pump misprediction. Counts across all types of pumps for either demand loads or data prefetch\000event=0x64c052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000 */
{ 195794 }, /* pm_data_all_sys_pump_cpred\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for either demand loads or data prefetch\000event=0x63c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000 */
{ 196051 }, /* pm_data_all_sys_pump_mpred\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for either demand loads or data prefetch\000event=0x63c052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 196560 }, /* pm_data_all_sys_pump_mpred_rty\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for either demand loads or data prefetch\000event=0x64c050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000 */
{ 163345 }, /* pm_data_chip_pump_cpred\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for a demand load\000 */
{ 118934 }, /* pm_data_from_dl2l3_mod\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 119374 }, /* pm_data_from_dl2l3_shr\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 119810 }, /* pm_data_from_dl4\000cache\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\00000\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 163593 }, /* pm_data_from_dmem\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 120158 }, /* pm_data_from_l2\000cache\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\00000\000The processor's data cache was reloaded from local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 196856 }, /* pm_data_from_l21_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 197210 }, /* pm_data_from_l21_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 120826 }, /* pm_data_from_l2_disp_conflict_ldhitst\000cache\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\00000\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 121171 }, /* pm_data_from_l2_disp_conflict_other\000cache\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\00000\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 121502 }, /* pm_data_from_l2_mepf\000cache\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\00000\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 121862 }, /* pm_data_from_l2_no_conflict\000cache\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\00000\000The processor's data cache was reloaded from local core's L2 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 120423 }, /* pm_data_from_l2miss\000cache\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\00000\000\000 */
{ 120501 }, /* pm_data_from_l2miss_mod\000cache\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L2 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 122173 }, /* pm_data_from_l3\000cache\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\00000\000The processor's data cache was reloaded from local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 197560 }, /* pm_data_from_l31_eco_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 197926 }, /* pm_data_from_l31_eco_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 198288 }, /* pm_data_from_l31_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\00000\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 198642 }, /* pm_data_from_l31_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\00000\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 122856 }, /* pm_data_from_l3_disp_conflict\000cache\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\00000\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 123181 }, /* pm_data_from_l3_mepf\000cache\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\00000\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 123541 }, /* pm_data_from_l3_no_conflict\000cache\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\00000\000The processor's data cache was reloaded from local core's L3 without conflict due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 122438 }, /* pm_data_from_l3miss\000cache\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\00000\000\000 */
{ 122531 }, /* pm_data_from_l3miss_mod\000cache\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\00000\000The processor's data cache was reloaded from a location other than the local core's L3 due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 123852 }, /* pm_data_from_ll4\000cache\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\00000\000The processor's data cache was reloaded from the local chip's L4 cache due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 163945 }, /* pm_data_from_lmem\000memory\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\00000\000The processor's data cache was reloaded from the local chip's Memory due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 198992 }, /* pm_data_from_mem\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\00000\000Data cache reload from memory (including L4)\000 */
{ 164229 }, /* pm_data_from_memory\000memory\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x2c04c\000\00000\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 124138 }, /* pm_data_from_off_chip_cache\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 124567 }, /* pm_data_from_on_chip_cache\000cache\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\00000\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 124949 }, /* pm_data_from_rl2l3_mod\000cache\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\00000\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 125381 }, /* pm_data_from_rl2l3_shr\000cache\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\00000\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 164587 }, /* pm_data_from_rl4\000memory\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\00000\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 164930 }, /* pm_data_from_rmem\000memory\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\00000\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either only demand loads or demand loads plus prefetches if MMCR1[16] is 1\000 */
{ 165282 }, /* pm_data_grp_pump_cpred\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for a demand load\000 */
{ 165510 }, /* pm_data_grp_pump_mpred\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 165910 }, /* pm_data_grp_pump_mpred_rty\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor a demand load\000 */
{ 166218 }, /* pm_data_pump_cpred\000memory\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\00000\000\000 */
{ 166339 }, /* pm_data_pump_mpred\000memory\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor a demand load\000 */
{ 166524 }, /* pm_data_sys_pump_cpred\000memory\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for a demand load\000 */
{ 166754 }, /* pm_data_sys_pump_mpred\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 167236 }, /* pm_data_sys_pump_mpred_rty\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for a demand load\000 */
{ 125809 }, /* pm_data_tablewalk_cyc\000cache\000Tablwalk Cycles (could be 1 or 2 active)\000event=0x3001a\000\00000\000Data Tablewalk Active\000 */
{ 199204 }, /* pm_dc_collisions\000other\000DATA Cache collisions\000event=0xe0bc\000\00000\000DATA Cache collisions42\000 */
{ 199290 }, /* pm_dc_pref_stream_alloc\000other\000Stream marked valid. The stream could have been allocated through the hardware prefetch mechanism or through software. This is combined ls0 and ls1\000event=0x1e050\000\00000\000\000 */
{ 199487 }, /* pm_dc_pref_stream_conf\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Combine up + down\000event=0x2e050\000\00000\000\000 */
{ 199713 }, /* pm_dc_pref_stream_fuzzy_conf\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0x4e050\000\00000\000\000 */
{ 199996 }, /* pm_dc_pref_stream_strided_conf\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0x3e050\000\00000\000\000 */
{ 270116 }, /* pm_derat_miss_16g\000translation\000Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4c054\000\00000\000\000 */
{ 270212 }, /* pm_derat_miss_16m\000translation\000Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3c054\000\00000\000\000 */
{ 270308 }, /* pm_derat_miss_4k\000translation\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\00000\000\000 */
{ 270402 }, /* pm_derat_miss_64k\000translation\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\00000\000\000 */
{ 200219 }, /* pm_dfu\000other\000Finish DFU (all finish)\000event=0xb0ba\000\00000\000\000 */
{ 200274 }, /* pm_dfu_dcffix\000other\000Convert from fixed opcode finish (dcffix,dcffixq)\000event=0xb0be\000\00000\000\000 */
{ 200362 }, /* pm_dfu_denbcd\000other\000BCD->DPD opcode finish (denbcd, denbcdq)\000event=0xb0bc\000\00000\000\000 */
{ 200441 }, /* pm_dfu_mc\000other\000Finish DFU multicycle\000event=0xb0b8\000\00000\000\000 */
{ 200497 }, /* pm_disp_clb_held_bal\000other\000Dispatch/CLB Hold: Balance\000event=0x2092\000\00000\000\000 */
{ 200569 }, /* pm_disp_clb_held_res\000other\000Dispatch/CLB Hold: Resource\000event=0x2094\000\00000\000\000 */
{ 200642 }, /* pm_disp_clb_held_sb\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x20a8\000\00000\000\000 */
{ 200716 }, /* pm_disp_clb_held_sync\000other\000Dispatch/CLB Hold: Sync type instruction\000event=0x2098\000\00000\000\000 */
{ 200803 }, /* pm_disp_clb_held_tlbie\000other\000Dispatch Hold: Due to TLBIE\000event=0x2096\000\00000\000\000 */
{ 265703 }, /* pm_disp_held\000pipeline\000Dispatch Held\000event=0x10006\000\00000\000\000 */
{ 200878 }, /* pm_disp_held_iq_full\000other\000Dispatch held due to Issue q full\000event=0x20006\000\00000\000\000 */
{ 200958 }, /* pm_disp_held_map_full\000other\000Dispatch for this thread was held because the Mappers were full\000event=0x1002a\000\00000\000Dispatch held due to Mapper full\000 */
{ 201101 }, /* pm_disp_held_srq_full\000other\000Dispatch held due SRQ no room\000event=0x30018\000\00000\000\000 */
{ 265758 }, /* pm_disp_held_sync_hold\000pipeline\000Dispatch held due to SYNC hold\000event=0x4003c\000\00000\000\000 */
{ 201178 }, /* pm_disp_hold_gct_full\000other\000Dispatch Hold Due to no space in the GCT\000event=0x30a6\000\00000\000\000 */
{ 201265 }, /* pm_disp_wt\000other\000Dispatched Starved\000event=0x30008\000\00000\000Dispatched Starved (not held, nothing to dispatch)\000 */
{ 270498 }, /* pm_dpteg_from_dl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x4e048\000\00000\000\000 */
{ 270728 }, /* pm_dpteg_from_dl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request\000event=0x3e048\000\00000\000\000 */
{ 167505 }, /* pm_dpteg_from_dl4\000memory\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request\000event=0x3e04c\000\00000\000\000 */
{ 167681 }, /* pm_dpteg_from_dmem\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request\000event=0x4e04c\000\00000\000\000 */
{ 270956 }, /* pm_dpteg_from_l2\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request\000event=0x1e042\000\00000\000\000 */
{ 201370 }, /* pm_dpteg_from_l21_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request\000event=0x4e046\000\00000\000\000 */
{ 201550 }, /* pm_dpteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request\000event=0x3e046\000\00000\000\000 */
{ 201728 }, /* pm_dpteg_from_l2_disp_conflict_ldhitst\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a data side request\000event=0x3e040\000\00000\000\000 */
{ 201912 }, /* pm_dpteg_from_l2_disp_conflict_other\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a data side request\000event=0x4e040\000\00000\000\000 */
{ 271264 }, /* pm_dpteg_from_l2_mepf\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request\000event=0x2e040\000\00000\000\000 */
{ 271454 }, /* pm_dpteg_from_l2_no_conflict\000translation\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request\000event=0x1e040\000\00000\000\000 */
{ 271095 }, /* pm_dpteg_from_l2miss\000translation\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request\000event=0x1e04e\000\00000\000\000 */
{ 271622 }, /* pm_dpteg_from_l3\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request\000event=0x4e042\000\00000\000\000 */
{ 202088 }, /* pm_dpteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request\000event=0x4e044\000\00000\000\000 */
{ 202276 }, /* pm_dpteg_from_l31_eco_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request\000event=0x3e044\000\00000\000\000 */
{ 202462 }, /* pm_dpteg_from_l31_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request\000event=0x2e044\000\00000\000\000 */
{ 202642 }, /* pm_dpteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request\000event=0x1e046\000\00000\000\000 */
{ 271761 }, /* pm_dpteg_from_l3_disp_conflict\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request\000event=0x3e042\000\00000\000\000 */
{ 271937 }, /* pm_dpteg_from_l3_mepf\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request\000event=0x2e042\000\00000\000\000 */
{ 272127 }, /* pm_dpteg_from_l3_no_conflict\000translation\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request\000event=0x1e044\000\00000\000\000 */
{ 125918 }, /* pm_dpteg_from_l3miss\000cache\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request\000event=0x4e04e\000\00000\000\000 */
{ 272295 }, /* pm_dpteg_from_ll4\000translation\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request\000event=0x1e04c\000\00000\000\000 */
{ 272445 }, /* pm_dpteg_from_lmem\000translation\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request\000event=0x2e048\000\00000\000\000 */
{ 272594 }, /* pm_dpteg_from_memory\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request\000event=0x2e04c\000\00000\000\000 */
{ 272781 }, /* pm_dpteg_from_off_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request\000event=0x4e04a\000\00000\000\000 */
{ 273008 }, /* pm_dpteg_from_on_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request\000event=0x1e048\000\00000\000\000 */
{ 273211 }, /* pm_dpteg_from_rl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x2e046\000\00000\000\000 */
{ 273437 }, /* pm_dpteg_from_rl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request\000event=0x1e04a\000\00000\000\000 */
{ 273661 }, /* pm_dpteg_from_rl4\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request\000event=0x2e04a\000\00000\000\000 */
{ 167859 }, /* pm_dpteg_from_rmem\000memory\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request\000event=0x3e04a\000\00000\000\000 */
{ 126081 }, /* pm_dslb_miss\000cache\000Data SLB Miss - Total of all segment sizes\000event=0xd094\000\00000\000Data SLB Miss - Total of all segment sizesData SLB misses\000 */
{ 273839 }, /* pm_dtlb_miss\000translation\000Data PTEG reload\000event=0x300fc\000\00000\000Data PTEG Reloaded (DTLB Miss)\000 */
{ 273930 }, /* pm_dtlb_miss_16g\000translation\000Data TLB Miss page size 16G\000event=0x1c058\000\00000\000\000 */
{ 274006 }, /* pm_dtlb_miss_16m\000translation\000Data TLB Miss page size 16M\000event=0x4c056\000\00000\000\000 */
{ 274082 }, /* pm_dtlb_miss_4k\000translation\000Data TLB Miss page size 4k\000event=0x2c056\000\00000\000\000 */
{ 274156 }, /* pm_dtlb_miss_64k\000translation\000Data TLB Miss page size 64K\000event=0x3c056\000\00000\000\000 */
{ 202820 }, /* pm_eat_force_mispred\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT. The EAT forces a mispredict in this case since there is no predicated target to validate. This is a rare case that may occur when the EAT is full and a branch is issue\000event=0x50a8\000\00000\000\000 */
{ 203119 }, /* pm_eat_full_cyc\000other\000Cycles No room in EAT\000event=0x4084\000\00000\000Cycles No room in EATSet on bank conflict and case where no ibuffers available\000 */
{ 203259 }, /* pm_ee_off_ext_int\000other\000Ee off and external interrupt\000event=0x2080\000\00000\000\000 */
{ 265840 }, /* pm_ext_int\000pipeline\000external interrupt\000event=0x200f8\000\00000\000\000 */
{ 203331 }, /* pm_fav_tbegin\000other\000Dispatch time Favored tbegin\000event=0x20b4\000\00000\000\000 */
{ 203398 }, /* pm_flop\000other\000Floating Point Operation Finished\000event=0x100f4\000\00000\000Floating Point Operations Finished\000 */
{ 203499 }, /* pm_flop_sum_scalar\000other\000flops summary scalar instructions\000event=0xa0ae\000\00000\000\000 */
{ 203576 }, /* pm_flop_sum_vec\000other\000flops summary vector instructions\000event=0xa0ac\000\00000\000\000 */
{ 114312 }, /* pm_flush\000pipeline\000Flush (any type)\000event=0x400f8\000\00000\000\000 */
{ 203650 }, /* pm_flush_br_mpred\000other\000Flush caused by branch mispredict\000event=0x2084\000\00000\000\000 */
{ 265898 }, /* pm_flush_completion\000pipeline\000Completion Flush\000event=0x30012\000\00000\000\000 */
{ 203726 }, /* pm_flush_disp\000other\000Dispatch flush\000event=0x2082\000\00000\000\000 */
{ 203779 }, /* pm_flush_disp_sb\000other\000Dispatch Flush: Scoreboard\000event=0x208c\000\00000\000\000 */
{ 203847 }, /* pm_flush_disp_sync\000other\000Dispatch Flush: Sync\000event=0x2088\000\00000\000\000 */
{ 203911 }, /* pm_flush_disp_tlbie\000other\000Dispatch Flush: TLBIE\000event=0x208a\000\00000\000\000 */
{ 203977 }, /* pm_flush_lsu\000other\000Flush initiated by LSU\000event=0x208e\000\00000\000\000 */
{ 204037 }, /* pm_flush_partial\000other\000Partial flush\000event=0x2086\000\00000\000\000 */
{ 204092 }, /* pm_fpu0_fconv\000other\000Convert instruction executed\000event=0xa0b0\000\00000\000\000 */
{ 204159 }, /* pm_fpu0_fest\000other\000Estimate instruction executed\000event=0xa0b8\000\00000\000\000 */
{ 204226 }, /* pm_fpu0_frsp\000other\000Round to single precision instruction executed\000event=0xa0b4\000\00000\000\000 */
{ 204310 }, /* pm_fpu1_fconv\000other\000Convert instruction executed\000event=0xa0b2\000\00000\000\000 */
{ 204377 }, /* pm_fpu1_fest\000other\000Estimate instruction executed\000event=0xa0ba\000\00000\000\000 */
{ 204444 }, /* pm_fpu1_frsp\000other\000Round to single precision instruction executed\000event=0xa0b6\000\00000\000\000 */
{ 265963 }, /* pm_freq_down\000pipeline\000Power Management: Below Threshold B\000event=0x3000c\000\00000\000Frequency is being slewed down due to Power Management\000 */
{ 266094 }, /* pm_freq_up\000pipeline\000Power Management: Above Threshold A\000event=0x4000c\000\00000\000Frequency is being slewed up due to Power Management\000 */
{ 204528 }, /* pm_fusion_toc_grp0_1\000other\000One pair of instructions fused with TOC in Group0\000event=0x50b0\000\00000\000\000 */
{ 204623 }, /* pm_fusion_toc_grp0_2\000other\000Two pairs of instructions fused with TOCin Group0\000event=0x50ae\000\00000\000\000 */
{ 204718 }, /* pm_fusion_toc_grp0_3\000other\000Three pairs of instructions fused with TOC in Group0\000event=0x50ac\000\00000\000\000 */
{ 204816 }, /* pm_fusion_toc_grp1_1\000other\000One pair of instructions fused with TOX in Group1\000event=0x50b2\000\00000\000\000 */
{ 204911 }, /* pm_fusion_vsx_grp0_1\000other\000One pair of instructions fused with VSX in Group0\000event=0x50b8\000\00000\000\000 */
{ 205006 }, /* pm_fusion_vsx_grp0_2\000other\000Two pairs of instructions fused with VSX in Group0\000event=0x50b6\000\00000\000\000 */
{ 205102 }, /* pm_fusion_vsx_grp0_3\000other\000Three pairs of instructions fused with VSX in Group0\000event=0x50b4\000\00000\000\000 */
{ 205200 }, /* pm_fusion_vsx_grp1_1\000other\000One pair of instructions fused with VSX in Group1\000event=0x50ba\000\00000\000\000 */
{ 205295 }, /* pm_fxu0_busy_fxu1_idle\000other\000fxu0 busy and fxu1 idle\000event=0x3000e\000\00000\000\000 */
{ 205367 }, /* pm_fxu0_fin\000other\000The fixed point unit Unit 0 finished an instruction. Instructions that finish may not necessary complete\000event=0x10004\000\00000\000FXU0 Finished\000 */
{ 205522 }, /* pm_fxu1_busy_fxu0_idle\000other\000fxu0 idle and fxu1 busy\000event=0x4000e\000\00000\000\000 */
{ 205594 }, /* pm_fxu1_fin\000other\000FXU1 Finished\000event=0x40004\000\00000\000\000 */
{ 126648 }, /* pm_fxu_busy\000floating point\000fxu0 busy and fxu1 busy\000event=0x2000e\000\00000\000\000 */
{ 126718 }, /* pm_fxu_idle\000floating point\000fxu0 idle and fxu1 idle\000event=0x1000e\000\00000\000\000 */
{ 205645 }, /* pm_gct_empty_cyc\000other\000No itags assigned either thread (GCT Empty)\000event=0x20008\000\00000\000\000 */
{ 205731 }, /* pm_gct_merge\000other\000Group dispatched on a merged GCT empty. GCT entries can be merged only within the same thread\000event=0x30a4\000\00000\000\000 */
{ 205862 }, /* pm_gct_noslot_br_mpred\000other\000Gct empty for this thread due to branch mispred\000event=0x4d01e\000\00000\000\000 */
{ 205958 }, /* pm_gct_noslot_br_mpred_icmiss\000other\000Gct empty for this thread due to Icache Miss and branch mispred\000event=0x4d01a\000\00000\000\000 */
{ 206077 }, /* pm_gct_noslot_cyc\000other\000No itags assigned\000event=0x100f8\000\00000\000Pipeline empty (No itags assigned , no GCT slots used)\000 */
{ 206192 }, /* pm_gct_noslot_disp_held_issq\000other\000Gct empty for this thread due to dispatch hold on this thread due to Issue q full\000event=0x2d01e\000\00000\000\000 */
{ 206328 }, /* pm_gct_noslot_disp_held_map\000other\000Gct empty for this thread due to dispatch hold on this thread due to Mapper full\000event=0x4d01c\000\00000\000\000 */
{ 206462 }, /* pm_gct_noslot_disp_held_other\000other\000Gct empty for this thread due to dispatch hold on this thread due to sync\000event=0x2e010\000\00000\000\000 */
{ 206591 }, /* pm_gct_noslot_disp_held_srq\000other\000Gct empty for this thread due to dispatch hold on this thread due to SRQ full\000event=0x2d01c\000\00000\000\000 */
{ 206722 }, /* pm_gct_noslot_ic_l3miss\000other\000Gct empty for this thread due to icache l3 miss\000event=0x4e010\000\00000\000\000 */
{ 206819 }, /* pm_gct_noslot_ic_miss\000other\000Gct empty for this thread due to Icache Miss\000event=0x2d01a\000\00000\000\000 */
{ 206911 }, /* pm_gct_util_11_14_entries\000other\000GCT Utilization 11-14 entries\000event=0x20a2\000\00000\000\000 */
{ 206991 }, /* pm_gct_util_15_17_entries\000other\000GCT Utilization 15-17 entries\000event=0x20a4\000\00000\000\000 */
{ 207071 }, /* pm_gct_util_18_entries\000other\000GCT Utilization 18+ entries\000event=0x20a6\000\00000\000\000 */
{ 207146 }, /* pm_gct_util_1_2_entries\000other\000GCT Utilization 1-2 entries\000event=0x209c\000\00000\000\000 */
{ 207222 }, /* pm_gct_util_3_6_entries\000other\000GCT Utilization 3-6 entries\000event=0x209e\000\00000\000\000 */
{ 207298 }, /* pm_gct_util_7_10_entries\000other\000GCT Utilization 7-10 entries\000event=0x20a0\000\00000\000\000 */
{ 207376 }, /* pm_grp_br_mpred_nonspec\000other\000Group experienced non-speculative branch redirect\000event=0x1000a\000\00000\000Group experienced Non-speculative br mispredicct\000 */
{ 207523 }, /* pm_grp_cmpl\000other\000group completed\000event=0x30004\000\00000\000\000 */
{ 207576 }, /* pm_grp_disp\000other\000group dispatch\000event=0x3000a\000\00000\000dispatch_success (Group Dispatched)\000 */
{ 207663 }, /* pm_grp_ic_miss_nonspec\000other\000Group experienced non-speculative I cache miss\000event=0x1000c\000\00000\000Group experi enced Non-specu lative I cache miss\000 */
{ 207806 }, /* pm_grp_mrk\000other\000Instruction Marked\000event=0x10130\000\00000\000Instruction marked in idu\000 */
{ 207886 }, /* pm_grp_non_full_group\000other\000GROUPs where we did not have 6 non branch instructions in the group(ST mode), in SMT mode 3 non branches\000event=0x509c\000\00000\000\000 */
{ 168037 }, /* pm_grp_pump_cpred\000memory\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\00000\000\000 */
{ 168248 }, /* pm_grp_pump_mpred\000memory\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 168713 }, /* pm_grp_pump_mpred_rty\000memory\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 208037 }, /* pm_grp_term_2nd_branch\000other\000There were enough instructions in the Ibuffer, but 2nd branch ends group\000event=0x50a4\000\00000\000\000 */
{ 208157 }, /* pm_grp_term_fpu_after_br\000other\000There were enough instructions in the Ibuffer, but FPU OP IN same group after a branch terminates a group, cant do partial flushes\000event=0x50a6\000\00000\000\000 */
{ 208337 }, /* pm_grp_term_noinst\000other\000Do not fill every slot in the group, Not enough instructions in the Ibuffer. This includes cases where the group started with enough instructions, but some got knocked out by a cache miss or branch redirect (which would also empty the Ibuffer)\000event=0x509e\000\00000\000\000 */
{ 208624 }, /* pm_grp_term_other\000other\000There were enough instructions in the Ibuffer, but the group terminated early for some other reason, most likely due to a First or Last\000event=0x50a0\000\00000\000\000 */
{ 208802 }, /* pm_grp_term_slot_limit\000other\000There were enough instructions in the Ibuffer, but 3 src RA/RB/RC , 2 way crack caused a group termination\000event=0x50a2\000\00000\000\000 */
{ 266221 }, /* pm_hv_cyc\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\00000\000cycles in hypervisor mode\000 */
{ 208956 }, /* pm_ibuf_full_cyc\000other\000Cycles No room in ibuff\000event=0x4086\000\00000\000Cycles No room in ibufffully qualified transfer (if5 valid)\000 */
{ 127258 }, /* pm_ic_demand_cyc\000frontend\000Cycles when a demand ifetch was pending\000event=0x10018\000\00000\000Demand ifetch pending\000 */
{ 209080 }, /* pm_ic_demand_l2_bht_redirect\000other\000L2 I cache demand request due to BHT redirect, branch redirect ( 2 bubbles 3 cycles)\000event=0x4098\000\00000\000\000 */
{ 209218 }, /* pm_ic_demand_l2_br_redirect\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x409a\000\00000\000\000 */
{ 209338 }, /* pm_ic_demand_req\000other\000Demand Instruction fetch request\000event=0x4088\000\00000\000\000 */
{ 209412 }, /* pm_ic_invalidate\000other\000Ic line invalidated\000event=0x508a\000\00000\000\000 */
{ 209473 }, /* pm_ic_pref_cancel_hit\000other\000Prefetch Canceled due to icache hit\000event=0x4092\000\00000\000\000 */
{ 209555 }, /* pm_ic_pref_cancel_l2\000other\000L2 Squashed request\000event=0x4094\000\00000\000\000 */
{ 209620 }, /* pm_ic_pref_cancel_page\000other\000Prefetch Canceled due to page boundary\000event=0x4090\000\00000\000\000 */
{ 209706 }, /* pm_ic_pref_req\000other\000Instruction prefetch requests\000event=0x408a\000\00000\000\000 */
{ 209775 }, /* pm_ic_pref_write\000other\000Instruction prefetch written into IL1\000event=0x408e\000\00000\000\000 */
{ 209854 }, /* pm_ic_reload_private\000other\000Reloading line was brought in private for a specific thread. Most lines are brought in shared for all eight thrreads. If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4096\000\00000\000\000 */
{ 127364 }, /* pm_ierat_reload\000frontend\000Number of I-ERAT reloads\000event=0x100f6\000\00000\000IERAT Reloaded (Miss)\000 */
{ 127454 }, /* pm_ierat_reload_16m\000frontend\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\00000\000\000 */
{ 127539 }, /* pm_ierat_reload_4k\000frontend\000IERAT Miss (Not implemented as DI on POWER6)\000event=0x20064\000\00000\000IERAT Reloaded (Miss) for a 4k page\000 */
{ 127666 }, /* pm_ierat_reload_64k\000frontend\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\00000\000\000 */
{ 266377 }, /* pm_ifetch_throttle\000pipeline\000Cycles in which Instruction fetch throttle was active\000event=0x3405e\000\00000\000Cycles instruction fecth was throttled in IFU\000 */
{ 210154 }, /* pm_ifu_l2_touch\000other\000L2 touch to update MRU on a line\000event=0x5088\000\00000\000\000 */
{ 210227 }, /* pm_inst_all_chip_pump_cpred\000other\000Initial and Final Pump Scope was chip pump (prediction=correct) for instruction fetches and prefetches\000event=0x514050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000 */
{ 210507 }, /* pm_inst_all_from_dl2l3_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x544048\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 210993 }, /* pm_inst_all_from_dl2l3_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to instruction fetches and prefetches\000event=0x534048\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 211475 }, /* pm_inst_all_from_dl4\000other\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to instruction fetches and prefetches\000event=0x53404c\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 211869 }, /* pm_inst_all_from_dmem\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to instruction fetches and prefetches\000event=0x54404c\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 212266 }, /* pm_inst_all_from_l2\000other\000The processor's Instruction cache was reloaded from local core's L2 due to instruction fetches and prefetches\000event=0x514042\000\00000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 212577 }, /* pm_inst_all_from_l21_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x544046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 212977 }, /* pm_inst_all_from_l21_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to instruction fetches and prefetches\000event=0x534046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 213740 }, /* pm_inst_all_from_l2_disp_conflict_ldhitst\000other\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to instruction fetches and prefetches\000event=0x534040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 214131 }, /* pm_inst_all_from_l2_disp_conflict_other\000other\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to instruction fetches and prefetches\000event=0x544040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 214508 }, /* pm_inst_all_from_l2_mepf\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to instruction fetches and prefetches\000event=0x524040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 214916 }, /* pm_inst_all_from_l2_no_conflict\000other\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to instruction fetches and prefetches\000event=0x514040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 213373 }, /* pm_inst_all_from_l2miss\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to instruction fetches and prefetches\000event=0x51404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 215273 }, /* pm_inst_all_from_l3\000other\000The processor's Instruction cache was reloaded from local core's L3 due to instruction fetches and prefetches\000event=0x544042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 215584 }, /* pm_inst_all_from_l31_eco_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x544044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 215996 }, /* pm_inst_all_from_l31_eco_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to instruction fetches and prefetches\000event=0x534044\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 216404 }, /* pm_inst_all_from_l31_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x524044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 216804 }, /* pm_inst_all_from_l31_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to instruction fetches and prefetches\000event=0x514046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 217556 }, /* pm_inst_all_from_l3_disp_conflict\000other\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to instruction fetches and prefetches\000event=0x534042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 217927 }, /* pm_inst_all_from_l3_mepf\000other\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to instruction fetches and prefetches\000event=0x524042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 218335 }, /* pm_inst_all_from_l3_no_conflict\000other\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to instruction fetches and prefetches\000event=0x514044\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 217200 }, /* pm_inst_all_from_l3miss_mod\000other\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x54404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 218692 }, /* pm_inst_all_from_ll4\000other\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to instruction fetches and prefetches\000event=0x51404c\000\00000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 219024 }, /* pm_inst_all_from_lmem\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to instruction fetches and prefetches\000event=0x524048\000\00000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 219353 }, /* pm_inst_all_from_memory\000other\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to instruction fetches and prefetches\000event=0x52404c\000\00000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 219756 }, /* pm_inst_all_from_off_chip_cache\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to instruction fetches and prefetches\000event=0x54404a\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 220231 }, /* pm_inst_all_from_on_chip_cache\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to instruction fetches and prefetches\000event=0x514048\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 220659 }, /* pm_inst_all_from_rl2l3_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x524046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 221137 }, /* pm_inst_all_from_rl2l3_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to instruction fetches and prefetches\000event=0x51404a\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 221611 }, /* pm_inst_all_from_rl4\000other\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x52404a\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 221999 }, /* pm_inst_all_from_rmem\000other\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to instruction fetches and prefetches\000event=0x53404a\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 222396 }, /* pm_inst_all_grp_pump_cpred\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for instruction fetches and prefetches\000event=0x524050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000 */
{ 222656 }, /* pm_inst_all_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for instruction fetches and prefetches\000event=0x524052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 223081 }, /* pm_inst_all_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for instruction fetches and prefetches\000event=0x514052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000 */
{ 223421 }, /* pm_inst_all_pump_cpred\000other\000Pump prediction correct. Counts across all types of pumps for instruction fetches and prefetches\000event=0x514054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000 */
{ 223648 }, /* pm_inst_all_pump_mpred\000other\000Pump misprediction. Counts across all types of pumps for instruction fetches and prefetches\000event=0x544052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000 */
{ 223865 }, /* pm_inst_all_sys_pump_cpred\000other\000Initial and Final Pump Scope was system pump (prediction=correct) for instruction fetches and prefetches\000event=0x534050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000 */
{ 224127 }, /* pm_inst_all_sys_pump_mpred\000other\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for instruction fetches and prefetches\000event=0x534052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 224634 }, /* pm_inst_all_sys_pump_mpred_rty\000other\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for instruction fetches and prefetches\000event=0x544050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000 */
{ 127751 }, /* pm_inst_chip_pump_cpred\000frontend\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was chip pump (prediction=correct) for an instruction fetch\000 */
{ 128015 }, /* pm_inst_cmpl\000frontend\000Number of PowerPC Instructions that completed\000event=0x2\000\00000\000PPC Instructions Finished (completed)\000 */
{ 128135 }, /* pm_inst_disp\000frontend\000PPC Dispatched\000event=0x200f2\000\00000\000\000 */
{ 128191 }, /* pm_inst_from_dl2l3_mod\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 128676 }, /* pm_inst_from_dl2l3_shr\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 129157 }, /* pm_inst_from_dl4\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 129550 }, /* pm_inst_from_dmem\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 224935 }, /* pm_inst_from_l1\000other\000Instruction fetches from L1\000event=0x4080\000\00000\000\000 */
{ 129946 }, /* pm_inst_from_l2\000frontend\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\00000\000The processor's Instruction cache was reloaded from local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 225003 }, /* pm_inst_from_l21_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 225399 }, /* pm_inst_from_l21_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 130622 }, /* pm_inst_from_l2_disp_conflict_ldhitst\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 131012 }, /* pm_inst_from_l2_disp_conflict_other\000frontend\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 131388 }, /* pm_inst_from_l2_mepf\000frontend\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 131795 }, /* pm_inst_from_l2_no_conflict\000frontend\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\00000\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 130256 }, /* pm_inst_from_l2miss\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 132151 }, /* pm_inst_from_l3\000frontend\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 225791 }, /* pm_inst_from_l31_eco_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 226199 }, /* pm_inst_from_l31_eco_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 226603 }, /* pm_inst_from_l31_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 226999 }, /* pm_inst_from_l31_shr\000other\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 132953 }, /* pm_inst_from_l3_disp_conflict\000frontend\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 133323 }, /* pm_inst_from_l3_mepf\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 133730 }, /* pm_inst_from_l3_no_conflict\000frontend\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\00000\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 132461 }, /* pm_inst_from_l3miss\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\00000\000Inst from L3 miss\000 */
{ 132599 }, /* pm_inst_from_l3miss_mod\000frontend\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\00000\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 134086 }, /* pm_inst_from_ll4\000frontend\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\00000\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 134417 }, /* pm_inst_from_lmem\000frontend\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\00000\000The processor's Instruction cache was reloaded from the local chip's Memory due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 134745 }, /* pm_inst_from_memory\000frontend\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\00000\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 135147 }, /* pm_inst_from_off_chip_cache\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 135621 }, /* pm_inst_from_on_chip_cache\000frontend\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\00000\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 136048 }, /* pm_inst_from_rl2l3_mod\000frontend\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\00000\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 136525 }, /* pm_inst_from_rl2l3_shr\000frontend\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\00000\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 136998 }, /* pm_inst_from_rl4\000frontend\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\00000\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 137385 }, /* pm_inst_from_rmem\000frontend\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\00000\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to either an instruction fetch or instruction fetch plus prefetch if MMCR1[17] is 1\000 */
{ 137781 }, /* pm_inst_grp_pump_cpred\000frontend\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch\000event=0x24050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was group pump for an instruction fetch\000 */
{ 138025 }, /* pm_inst_grp_pump_mpred\000frontend\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch\000event=0x24052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope OR Final Pump Scope(Group) got data from source that was at smaller scope(Chip) Final pump was group pump and initial pump was chip or final and initial pump was gro\000 */
{ 138434 }, /* pm_inst_grp_pump_mpred_rty\000frontend\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\00000\000Final Pump Scope(Group) to get data sourced, ended up larger than Initial Pump Scope (Chip) Final pump was group pump and initial pump was chip pumpfor an instruction fetch\000 */
{ 138758 }, /* pm_inst_imc_match_cmpl\000frontend\000IMC Match Count ( Not architected in P8)\000event=0x1003a\000\00000\000\000 */
{ 227391 }, /* pm_inst_imc_match_disp\000other\000Matched Instructions Dispatched\000event=0x30016\000\00000\000IMC Matches dispatched\000 */
{ 138850 }, /* pm_inst_pump_cpred\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor an instruction fetch\000 */
{ 139061 }, /* pm_inst_pump_mpred\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor an instruction fetch\000 */
{ 139262 }, /* pm_inst_sys_pump_cpred\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for an instruction fetch\000 */
{ 139508 }, /* pm_inst_sys_pump_mpred\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 139999 }, /* pm_inst_sys_pump_mpred_rty\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for an instruction fetch\000 */
{ 266523 }, /* pm_iops_cmpl\000pipeline\000Internal Operations completed\000event=0x10014\000\00000\000IOPS Completed\000 */
{ 227493 }, /* pm_iops_disp\000other\000Internal Operations dispatched\000event=0x30014\000\00000\000IOPS dispatched\000 */
{ 140284 }, /* pm_ipteg_from_dl2l3_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x45048\000\00000\000\000 */
{ 140518 }, /* pm_ipteg_from_dl2l3_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\00000\000\000 */
{ 140750 }, /* pm_ipteg_from_dl4\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\00000\000\000 */
{ 140935 }, /* pm_ipteg_from_dmem\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\00000\000\000 */
{ 141122 }, /* pm_ipteg_from_l2\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\00000\000\000 */
{ 227577 }, /* pm_ipteg_from_l21_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\00000\000\000 */
{ 227764 }, /* pm_ipteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\00000\000\000 */
{ 227949 }, /* pm_ipteg_from_l2_disp_conflict_ldhitst\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a instruction side request\000event=0x35040\000\00000\000\000 */
{ 228140 }, /* pm_ipteg_from_l2_disp_conflict_other\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a instruction side request\000event=0x45040\000\00000\000\000 */
{ 141438 }, /* pm_ipteg_from_l2_mepf\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\00000\000\000 */
{ 141632 }, /* pm_ipteg_from_l2_no_conflict\000frontend\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\00000\000\000 */
{ 141265 }, /* pm_ipteg_from_l2miss\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\00000\000\000 */
{ 141804 }, /* pm_ipteg_from_l3\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\00000\000\000 */
{ 228323 }, /* pm_ipteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\00000\000\000 */
{ 228518 }, /* pm_ipteg_from_l31_eco_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\00000\000\000 */
{ 228711 }, /* pm_ipteg_from_l31_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\00000\000\000 */
{ 228898 }, /* pm_ipteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\00000\000\000 */
{ 142120 }, /* pm_ipteg_from_l3_disp_conflict\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\00000\000\000 */
{ 142300 }, /* pm_ipteg_from_l3_mepf\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a instruction side request\000event=0x25042\000\00000\000\000 */
{ 142494 }, /* pm_ipteg_from_l3_no_conflict\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a instruction side request\000event=0x15044\000\00000\000\000 */
{ 141947 }, /* pm_ipteg_from_l3miss\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a instruction side request\000event=0x4504e\000\00000\000\000 */
{ 142666 }, /* pm_ipteg_from_ll4\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\00000\000\000 */
{ 142820 }, /* pm_ipteg_from_lmem\000frontend\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\00000\000\000 */
{ 142973 }, /* pm_ipteg_from_memory\000frontend\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\00000\000\000 */
{ 143164 }, /* pm_ipteg_from_off_chip_cache\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\00000\000\000 */
{ 143395 }, /* pm_ipteg_from_on_chip_cache\000frontend\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\00000\000\000 */
{ 143602 }, /* pm_ipteg_from_rl2l3_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\00000\000\000 */
{ 143832 }, /* pm_ipteg_from_rl2l3_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\00000\000\000 */
{ 144060 }, /* pm_ipteg_from_rl4\000frontend\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\00000\000\000 */
{ 144242 }, /* pm_ipteg_from_rmem\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\00000\000\000 */
{ 229083 }, /* pm_iside_l2memacc\000other\000valid when first beat of data comes in for an i-side fetch where data came from mem(or L4)\000event=0x4608e\000\00000\000\000 */
{ 144429 }, /* pm_islb_miss\000frontend\000I SLB Miss\000event=0xd096\000\00000\000\000 */
{ 229217 }, /* pm_isu_ref_fx0\000other\000FX0 ISU reject\000event=0x30ac\000\00000\000\000 */
{ 229271 }, /* pm_isu_ref_fx1\000other\000FX1 ISU reject\000event=0x30ae\000\00000\000\000 */
{ 229325 }, /* pm_isu_ref_fxu\000other\000FXU ISU reject from either pipe\000event=0x38ac\000\00000\000\000 */
{ 229396 }, /* pm_isu_ref_ls0\000other\000LS0 ISU reject\000event=0x30b0\000\00000\000\000 */
{ 229450 }, /* pm_isu_ref_ls1\000other\000LS1 ISU reject\000event=0x30b2\000\00000\000\000 */
{ 229504 }, /* pm_isu_ref_ls2\000other\000LS2 ISU reject\000event=0x30b4\000\00000\000\000 */
{ 229558 }, /* pm_isu_ref_ls3\000other\000LS3 ISU reject\000event=0x30b6\000\00000\000\000 */
{ 229950 }, /* pm_isu_rej_vs0\000other\000VS0 ISU reject\000event=0x30a8\000\00000\000\000 */
{ 230004 }, /* pm_isu_rej_vs1\000other\000VS1 ISU reject\000event=0x30aa\000\00000\000\000 */
{ 230058 }, /* pm_isu_rej_vsu\000other\000VSU ISU reject from either pipe\000event=0x38a8\000\00000\000\000 */
{ 229702 }, /* pm_isu_reject_res_na\000other\000ISU reject due to resource not available\000event=0x30a2\000\00000\000\000 */
{ 229788 }, /* pm_isu_reject_sar_bypass\000other\000Reject because of SAR bypass\000event=0x309e\000\00000\000\000 */
{ 229866 }, /* pm_isu_reject_src_na\000other\000ISU reject due to source not available\000event=0x30a0\000\00000\000\000 */
{ 229612 }, /* pm_isu_rejects_all\000other\000All isu rejects could be more than 1 per cycle\000event=0x309c\000\00000\000\000 */
{ 230129 }, /* pm_isync\000other\000Isync count per thread\000event=0x30b8\000\00000\000\000 */
{ 144480 }, /* pm_itlb_miss\000frontend\000ITLB Reloaded (always zero on POWER6)\000event=0x400fc\000\00000\000\000 */
{ 126315 }, /* pm_l1_dcache_reload_valid\000cache\000DL1 reloaded due to Demand Load\000event=0x300f6\000\00000\000\000 */
{ 126218 }, /* pm_l1_dcache_reloaded_all\000cache\000L1 data cache reloaded for demand or prefetch\000event=0x1002c\000\00000\000\000 */
{ 230919 }, /* pm_l1_demand_write\000other\000Instruction Demand sectors wriittent into IL1\000event=0x408c\000\00000\000\000 */
{ 144559 }, /* pm_l1_icache_miss\000frontend\000Demand iCache Miss\000event=0x200fd\000\00000\000\000 */
{ 144624 }, /* pm_l1_icache_reloaded_all\000frontend\000Counts all Icache reloads includes demand, prefetchm prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\00000\000\000 */
{ 144791 }, /* pm_l1_icache_reloaded_pref\000frontend\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\00000\000\000 */
{ 230185 }, /* pm_l1miss_lat_exc_1024\000other\000L1 misses that took longer than 1024 cyles to resolve (miss to reload)\000event=0x200301ea\000\00000\000Reload latency exceeded 1024 cyc\000 */
{ 230339 }, /* pm_l1miss_lat_exc_2048\000other\000L1 misses that took longer than 2048 cyles to resolve (miss to reload)\000event=0x200401ec\000\00000\000Reload latency exceeded 2048 cyc\000 */
{ 230493 }, /* pm_l1miss_lat_exc_256\000other\000L1 misses that took longer than 256 cyles to resolve (miss to reload)\000event=0x200101e8\000\00000\000Reload latency exceeded 256 cyc\000 */
{ 230644 }, /* pm_l1miss_lat_exc_32\000other\000L1 misses that took longer than 32 cyles to resolve (miss to reload)\000event=0x200201e6\000\00000\000Reload latency exceeded 32 cyc\000 */
{ 230792 }, /* pm_l1pf_l2memacc\000other\000valid when first beat of data comes in for an L1pref where data came from mem(or L4)\000event=0x26086\000\00000\000\000 */
{ 231008 }, /* pm_l2_chip_pump\000other\000RC requests that were local on chip pump attempts\000event=0x27084\000\00000\000\000 */
{ 231099 }, /* pm_l2_group_pump\000other\000RC requests that were on Node Pump attempts\000event=0x27086\000\00000\000\000 */
{ 231185 }, /* pm_l2_rty_st\000other\000RC retries on PB for any store from core\000event=0x3708a\000\00000\000\000 */
{ 231264 }, /* pm_l2_st\000other\000All successful D-side store dispatches for this thread\000event=0x17080\000\00000\000\000 */
{ 231353 }, /* pm_l2_st_miss\000other\000All successful D-side store dispatches for this thread that were L2 Miss\000event=0x17082\000\00000\000\000 */
{ 231465 }, /* pm_l2_tm_req_abort\000other\000TM abort\000event=0x1e05e\000\00000\000\000 */
{ 231518 }, /* pm_l2_tm_st_abort_sister\000other\000TM marked store abort\000event=0x3e05c\000\00000\000\000 */
{ 231590 }, /* pm_l3_ci_usage\000other\000rotating sample of 16 CI or CO actives\000event=0x819082\000\00000\000\000 */
{ 231670 }, /* pm_l3_co0_alloc\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908b\000\00000\0000.0\000 */
{ 231754 }, /* pm_l3_co0_busy\000other\000lifetime, sample of CO machine 0 valid\000event=0x83908a\000\00000\000\000 */
{ 231834 }, /* pm_l3_co_l31\000other\000L3 CO to L3.1 OR of port 0 and 1 ( lossy)\000event=0x28086\000\00000\000\000 */
{ 231914 }, /* pm_l3_co_mem\000other\000L3 CO to memory OR of port 0 and 1 ( lossy)\000event=0x28084\000\00000\000\000 */
{ 169156 }, /* pm_l3_co_mepf\000memory\000L3 CO of line in Mep state ( includes casthrough\000event=0x18082\000\00000\000\000 */
{ 231996 }, /* pm_l3_ld_pref\000other\000L3 Load Prefetches\000event=0x1e052\000\00000\000\000 */
{ 232054 }, /* pm_l3_pf0_alloc\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908d\000\00000\0000.0\000 */
{ 232138 }, /* pm_l3_pf0_busy\000other\000lifetime, sample of PF machine 0 valid\000event=0x84908c\000\00000\000\000 */
{ 232218 }, /* pm_l3_pf_miss_l3\000other\000L3 Prefetch missed in L3\000event=0x18080\000\00000\000\000 */
{ 232285 }, /* pm_l3_pf_off_chip_cache\000other\000L3 Prefetch from Off chip cache\000event=0x3808a\000\00000\000\000 */
{ 232366 }, /* pm_l3_pf_off_chip_mem\000other\000L3 Prefetch from Off chip memory\000event=0x4808e\000\00000\000\000 */
{ 232446 }, /* pm_l3_pf_on_chip_cache\000other\000L3 Prefetch from On chip cache\000event=0x38088\000\00000\000\000 */
{ 232525 }, /* pm_l3_pf_on_chip_mem\000other\000L3 Prefetch from On chip memory\000event=0x4808c\000\00000\000\000 */
{ 232603 }, /* pm_l3_pf_usage\000other\000rotating sample of 32 PF actives\000event=0x829084\000\00000\000\000 */
{ 232677 }, /* pm_l3_pref_all\000other\000Total HW L3 prefetches(Load+store)\000event=0x4e052\000\00000\000\000 */
{ 232752 }, /* pm_l3_rd0_alloc\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908f\000\00000\0000.0\000 */
{ 232836 }, /* pm_l3_rd0_busy\000other\000lifetime, sample of RD machine 0 valid\000event=0x84908e\000\00000\000\000 */
{ 232916 }, /* pm_l3_rd_usage\000other\000rotating sample of 16 RD actives\000event=0x829086\000\00000\000\000 */
{ 232990 }, /* pm_l3_sn0_alloc\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839089\000\00000\0000.0\000 */
{ 233079 }, /* pm_l3_sn0_busy\000other\000lifetime, sample of snooper machine 0 valid\000event=0x839088\000\00000\000\000 */
{ 233164 }, /* pm_l3_sn_usage\000other\000rotating sample of 8 snoop valids\000event=0x819080\000\00000\000\000 */
{ 233239 }, /* pm_l3_st_pref\000other\000L3 store Prefetches\000event=0x2e052\000\00000\000\000 */
{ 233298 }, /* pm_l3_sw_pref\000other\000Data stream touchto L3\000event=0x3e052\000\00000\000\000 */
{ 233360 }, /* pm_l3_wi0_alloc\000other\000lifetime, sample of Write Inject machine 0 valid\000event=0x18081\000\00000\0000.0\000 */
{ 266608 }, /* pm_larx_fin\000pipeline\000Larx finished\000event=0x3c058\000\00000\000\000 */
{ 266662 }, /* pm_ld_cmpl\000pipeline\000count of Loads completed\000event=0x1002e\000\00000\000\000 */
{ 266726 }, /* pm_ld_l3miss_pend_cyc\000pipeline\000Cycles L3 miss was pending for this thread\000event=0x10062\000\00000\000\000 */
{ 126398 }, /* pm_ld_miss_l1\000cache\000Load Missed L1\000event=0x3e054\000\00000\000\000 */
{ 126452 }, /* pm_ld_ref_l1\000cache\000All L1 D cache load references counted at finish, gated by reject\000event=0x100ee\000\00000\000Load Ref count combined for all units\000 */
{ 233453 }, /* pm_ld_ref_l1_lsu0\000other\000LS0 L1 D cache load references counted at finish, gated by reject\000event=0xc080\000\00000\000LS0 L1 D cache load references counted at finish, gated by rejectLSU0 L1 D cache load references\000 */
{ 233657 }, /* pm_ld_ref_l1_lsu1\000other\000LS1 L1 D cache load references counted at finish, gated by reject\000event=0xc082\000\00000\000LS1 L1 D cache load references counted at finish, gated by rejectLSU1 L1 D cache load references\000 */
{ 233861 }, /* pm_ld_ref_l1_lsu2\000other\000LS2 L1 D cache load references counted at finish, gated by reject\000event=0xc094\000\00000\000LS2 L1 D cache load references counted at finish, gated by reject42\000 */
{ 234036 }, /* pm_ld_ref_l1_lsu3\000other\000LS3 L1 D cache load references counted at finish, gated by reject\000event=0xc096\000\00000\000LS3 L1 D cache load references counted at finish, gated by reject42\000 */
{ 234211 }, /* pm_link_stack_invalid_ptr\000other\000A flush were LS ptr is invalid, results in a pop , A lot of interrupts between push and pops\000event=0x509a\000\00000\000\000 */
{ 234354 }, /* pm_link_stack_wrong_add_pred\000other\000Link stack predicts wrong address, because of link stack design limitation\000event=0x5098\000\00000\000\000 */
{ 234482 }, /* pm_ls0_erat_miss_pref\000other\000LS0 Erat miss due to prefetch\000event=0xe080\000\00000\000LS0 Erat miss due to prefetch42\000 */
{ 234589 }, /* pm_ls0_l1_pref\000other\000LS0 L1 cache data prefetches\000event=0xd0b8\000\00000\000LS0 L1 cache data prefetches42\000 */
{ 234687 }, /* pm_ls0_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc098\000\00000\000Software L1 Prefetches, including SW Transient Prefetches42\000 */
{ 234846 }, /* pm_ls1_erat_miss_pref\000other\000LS1 Erat miss due to prefetch\000event=0xe082\000\00000\000LS1 Erat miss due to prefetch42\000 */
{ 234953 }, /* pm_ls1_l1_pref\000other\000LS1 L1 cache data prefetches\000event=0xd0ba\000\00000\000LS1 L1 cache data prefetches42\000 */
{ 235051 }, /* pm_ls1_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xc09a\000\00000\000Software L1 Prefetches, including SW Transient Prefetches42\000 */
{ 235210 }, /* pm_lsu0_flush_lrq\000other\000LS0 Flush: LRQ\000event=0xc0b0\000\00000\000LS0 Flush: LRQLSU0 LRQ flushes\000 */
{ 235297 }, /* pm_lsu0_flush_srq\000other\000LS0 Flush: SRQ\000event=0xc0b8\000\00000\000LS0 Flush: SRQLSU0 SRQ lhs flushes\000 */
{ 235388 }, /* pm_lsu0_flush_uld\000other\000LS0 Flush: Unaligned Load\000event=0xc0a4\000\00000\000LS0 Flush: Unaligned LoadLSU0 unaligned load flushes\000 */
{ 235508 }, /* pm_lsu0_flush_ust\000other\000LS0 Flush: Unaligned Store\000event=0xc0ac\000\00000\000LS0 Flush: Unaligned StoreLSU0 unaligned store flushes\000 */
{ 235631 }, /* pm_lsu0_l1_cam_cancel\000other\000ls0 l1 tm cam cancel\000event=0xf088\000\00000\000ls0 l1 tm cam cancel42\000 */
{ 235720 }, /* pm_lsu0_larx_fin\000other\000Larx finished in LSU pipe0\000event=0x1e056\000\00000\000\000 */
{ 235789 }, /* pm_lsu0_lmq_lhr_merge\000other\000LS0 Load Merged with another cacheline request\000event=0xd08c\000\00000\000LS0 Load Merged with another cacheline request42\000 */
{ 235930 }, /* pm_lsu0_ncld\000other\000LS0 Non-cachable Loads counted at finish\000event=0xc08c\000\00000\000LS0 Non-cachable Loads counted at finishLSU0 non-cacheable loads\000 */
{ 236072 }, /* pm_lsu0_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe090\000\00000\000Primary ERAT hit42\000 */
{ 236156 }, /* pm_lsu0_reject\000other\000LSU0 reject\000event=0x1e05a\000\00000\000\000 */
{ 236208 }, /* pm_lsu0_srq_stfwd\000other\000LS0 SRQ forwarded data to a load\000event=0xc09c\000\00000\000LS0 SRQ forwarded data to a loadLSU0 SRQ store forwarded\000 */
{ 236339 }, /* pm_lsu0_store_reject\000other\000ls0 store reject\000event=0xf084\000\00000\000ls0 store reject42\000 */
{ 236645 }, /* pm_lsu0_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe098\000\00000\000Load tm hit in L142\000 */
{ 236724 }, /* pm_lsu0_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a0\000\00000\000Load tm L1 miss42\000 */
{ 236419 }, /* pm_lsu0_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a8\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 236800 }, /* pm_lsu1_flush_lrq\000other\000LS1 Flush: LRQ\000event=0xc0b2\000\00000\000LS1 Flush: LRQLSU1 LRQ flushes\000 */
{ 236887 }, /* pm_lsu1_flush_srq\000other\000LS1 Flush: SRQ\000event=0xc0ba\000\00000\000LS1 Flush: SRQLSU1 SRQ lhs flushes\000 */
{ 236978 }, /* pm_lsu1_flush_uld\000other\000LS 1 Flush: Unaligned Load\000event=0xc0a6\000\00000\000LS 1 Flush: Unaligned LoadLSU1 unaligned load flushes\000 */
{ 237100 }, /* pm_lsu1_flush_ust\000other\000LS1 Flush: Unaligned Store\000event=0xc0ae\000\00000\000LS1 Flush: Unaligned StoreLSU1 unaligned store flushes\000 */
{ 237223 }, /* pm_lsu1_l1_cam_cancel\000other\000ls1 l1 tm cam cancel\000event=0xf08a\000\00000\000ls1 l1 tm cam cancel42\000 */
{ 237312 }, /* pm_lsu1_larx_fin\000other\000Larx finished in LSU pipe1\000event=0x2e056\000\00000\000\000 */
{ 237381 }, /* pm_lsu1_lmq_lhr_merge\000other\000LS1 Load Merge with another cacheline request\000event=0xd08e\000\00000\000LS1 Load Merge with another cacheline request42\000 */
{ 237520 }, /* pm_lsu1_ncld\000other\000LS1 Non-cachable Loads counted at finish\000event=0xc08e\000\00000\000LS1 Non-cachable Loads counted at finishLSU1 non-cacheable loads\000 */
{ 237662 }, /* pm_lsu1_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe092\000\00000\000Primary ERAT hit42\000 */
{ 237746 }, /* pm_lsu1_reject\000other\000LSU1 reject\000event=0x2e05a\000\00000\000\000 */
{ 237798 }, /* pm_lsu1_srq_stfwd\000other\000LS1 SRQ forwarded data to a load\000event=0xc09e\000\00000\000LS1 SRQ forwarded data to a loadLSU1 SRQ store forwarded\000 */
{ 237929 }, /* pm_lsu1_store_reject\000other\000ls1 store reject\000event=0xf086\000\00000\000ls1 store reject42\000 */
{ 238235 }, /* pm_lsu1_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe09a\000\00000\000Load tm hit in L142\000 */
{ 238314 }, /* pm_lsu1_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a2\000\00000\000Load tm L1 miss42\000 */
{ 238009 }, /* pm_lsu1_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0aa\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 238390 }, /* pm_lsu2_flush_lrq\000other\000LS02Flush: LRQ\000event=0xc0b4\000\00000\000LS02Flush: LRQ42\000 */
{ 238463 }, /* pm_lsu2_flush_srq\000other\000LS2 Flush: SRQ\000event=0xc0bc\000\00000\000LS2 Flush: SRQ42\000 */
{ 238536 }, /* pm_lsu2_flush_uld\000other\000LS3 Flush: Unaligned Load\000event=0xc0a8\000\00000\000LS3 Flush: Unaligned Load42\000 */
{ 238631 }, /* pm_lsu2_l1_cam_cancel\000other\000ls2 l1 tm cam cancel\000event=0xf08c\000\00000\000ls2 l1 tm cam cancel42\000 */
{ 238720 }, /* pm_lsu2_larx_fin\000other\000Larx finished in LSU pipe2\000event=0x3e056\000\00000\000\000 */
{ 238789 }, /* pm_lsu2_ldf\000other\000LS2 Scalar Loads\000event=0xc084\000\00000\000LS2 Scalar Loads42\000 */
{ 238860 }, /* pm_lsu2_ldx\000other\000LS0 Vector Loads\000event=0xc088\000\00000\000LS0 Vector Loads42\000 */
{ 238931 }, /* pm_lsu2_lmq_lhr_merge\000other\000LS0 Load Merged with another cacheline request\000event=0xd090\000\00000\000LS0 Load Merged with another cacheline request42\000 */
{ 239072 }, /* pm_lsu2_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe094\000\00000\000Primary ERAT hit42\000 */
{ 239156 }, /* pm_lsu2_reject\000other\000LSU2 reject\000event=0x3e05a\000\00000\000\000 */
{ 239208 }, /* pm_lsu2_srq_stfwd\000other\000LS2 SRQ forwarded data to a load\000event=0xc0a0\000\00000\000LS2 SRQ forwarded data to a load42\000 */
{ 239543 }, /* pm_lsu2_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe09c\000\00000\000Load tm hit in L142\000 */
{ 239622 }, /* pm_lsu2_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a4\000\00000\000Load tm L1 miss42\000 */
{ 239317 }, /* pm_lsu2_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ac\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 239698 }, /* pm_lsu3_flush_lrq\000other\000LS3 Flush: LRQ\000event=0xc0b6\000\00000\000LS3 Flush: LRQ42\000 */
{ 239771 }, /* pm_lsu3_flush_srq\000other\000LS13 Flush: SRQ\000event=0xc0be\000\00000\000LS13 Flush: SRQ42\000 */
{ 239846 }, /* pm_lsu3_flush_uld\000other\000LS 14Flush: Unaligned Load\000event=0xc0aa\000\00000\000LS 14Flush: Unaligned Load42\000 */
{ 239943 }, /* pm_lsu3_l1_cam_cancel\000other\000ls3 l1 tm cam cancel\000event=0xf08e\000\00000\000ls3 l1 tm cam cancel42\000 */
{ 240032 }, /* pm_lsu3_larx_fin\000other\000Larx finished in LSU pipe3\000event=0x4e056\000\00000\000\000 */
{ 240101 }, /* pm_lsu3_ldf\000other\000LS3 Scalar Loads\000event=0xc086\000\00000\000LS3 Scalar Loads 42\000 */
{ 240173 }, /* pm_lsu3_ldx\000other\000LS1 Vector Loads\000event=0xc08a\000\00000\000LS1 Vector Loads42\000 */
{ 240244 }, /* pm_lsu3_lmq_lhr_merge\000other\000LS1 Load Merge with another cacheline request\000event=0xd092\000\00000\000LS1 Load Merge with another cacheline request42\000 */
{ 240383 }, /* pm_lsu3_primary_erat_hit\000other\000Primary ERAT hit\000event=0xe096\000\00000\000Primary ERAT hit42\000 */
{ 240467 }, /* pm_lsu3_reject\000other\000LSU3 reject\000event=0x4e05a\000\00000\000\000 */
{ 240519 }, /* pm_lsu3_srq_stfwd\000other\000LS3 SRQ forwarded data to a load\000event=0xc0a2\000\00000\000LS3 SRQ forwarded data to a load42\000 */
{ 240854 }, /* pm_lsu3_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe09e\000\00000\000Load tm hit in L142\000 */
{ 240933 }, /* pm_lsu3_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a6\000\00000\000Load tm L1 miss42\000 */
{ 240628 }, /* pm_lsu3_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0ae\000\00000\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding42\000 */
{ 274232 }, /* pm_lsu_derat_miss\000translation\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\00000\000DERAT Reloaded (Miss)\000 */
{ 241009 }, /* pm_lsu_erat_miss_pref\000other\000Erat miss due to prefetch, on either pipe\000event=0xe880\000\00000\000LSU\000 */
{ 266819 }, /* pm_lsu_fin\000pipeline\000LSU Finished an instruction (up to 2 per cycle)\000event=0x30066\000\00000\000\000 */
{ 241100 }, /* pm_lsu_flush_ust\000other\000Unaligned Store Flush on either pipe\000event=0xc8ac\000\00000\000LSU\000 */
{ 241181 }, /* pm_lsu_four_tablewalk_cyc\000other\000Cycles when four tablewalks pending on this thread\000event=0xd0a4\000\00000\000Cycles when four tablewalks pending on this thread42\000 */
{ 241334 }, /* pm_lsu_fx_fin\000other\000LSU Finished a FX operation (up to 2 per cycle\000event=0x10066\000\00000\000\000 */
{ 241420 }, /* pm_lsu_l1_pref\000other\000hw initiated , include sw streaming forms as well , include sw streams as a separate event\000event=0xd8b8\000\00000\000LSU\000 */
{ 241553 }, /* pm_lsu_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches, on both pipes\000event=0xc898\000\00000\000LSU\000 */
{ 241671 }, /* pm_lsu_ldf\000other\000FPU loads only on LS2/LS3 ie LU0/LU1\000event=0xc884\000\00000\000LSU\000 */
{ 241746 }, /* pm_lsu_ldx\000other\000Vector loads can issue only on LS2/LS3\000event=0xc888\000\00000\000LSU\000 */
{ 241823 }, /* pm_lsu_lmq_full_cyc\000other\000LMQ full\000event=0xd0a2\000\00000\000LMQ fullCycles LMQ full\000 */
{ 241899 }, /* pm_lsu_lmq_s0_alloc\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd0a1\000\00000\0000.0\000 */
{ 242352 }, /* pm_lsu_lmq_s0_valid\000other\000Slot 0 of LMQ valid\000event=0xd0a0\000\00000\000Slot 0 of LMQ validLMQ slot 0 valid\000 */
{ 242451 }, /* pm_lsu_lmq_srq_empty_all_cyc\000other\000ALL threads lsu empty (lmq and srq empty)\000event=0x3001c\000\00000\000ALL threads lsu empty (lmq and srq empty). Issue HW016541\000 */
{ 266906 }, /* pm_lsu_lmq_srq_empty_cyc\000pipeline\000LSU empty (lmq and srq empty)\000event=0x2003e\000\00000\000\000 */
{ 242604 }, /* pm_lsu_lrq_s0_alloc\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09f\000\00000\0000.0\000 */
{ 243057 }, /* pm_lsu_lrq_s0_valid\000other\000Slot 0 of LRQ valid\000event=0xd09e\000\00000\000Slot 0 of LRQ validLRQ slot 0 valid\000 */
{ 243156 }, /* pm_lsu_lrq_s43_alloc\000other\000LRQ slot 43 was released\000event=0xf091\000\00000\0000.0\000 */
{ 243229 }, /* pm_lsu_lrq_s43_valid\000other\000LRQ slot 43 was busy\000event=0xf090\000\00000\000LRQ slot 43 was busy42\000 */
{ 243317 }, /* pm_lsu_mrk_derat_miss\000other\000DERAT Reloaded (Miss)\000event=0x30162\000\00000\000\000 */
{ 243386 }, /* pm_lsu_ncld\000other\000count at finish so can return only on ls0 or ls1\000event=0xc88c\000\00000\000LSU\000 */
{ 243474 }, /* pm_lsu_ncst\000other\000Non-cachable Stores sent to nest\000event=0xc092\000\00000\000Non-cachable Stores sent to nest42\000 */
{ 243577 }, /* pm_lsu_reject\000other\000LSU Reject (up to 4 per cycle)\000event=0x10064\000\00000\000\000 */
{ 266989 }, /* pm_lsu_reject_erat_miss\000pipeline\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\00000\000\000 */
{ 267085 }, /* pm_lsu_reject_lhs\000pipeline\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\00000\000\000 */
{ 267173 }, /* pm_lsu_reject_lmq_full\000pipeline\000LSU reject due to LMQ full ( 4 per cycle)\000event=0x1e05c\000\00000\000\000 */
{ 243647 }, /* pm_lsu_set_mpred\000other\000Line already in cache at reload time\000event=0xd082\000\00000\000Line already in cache at reload time42\000 */
{ 243763 }, /* pm_lsu_srq_empty_cyc\000other\000ALL threads srq empty\000event=0x40008\000\00000\000All threads srq empty\000 */
{ 267266 }, /* pm_lsu_srq_full_cyc\000pipeline\000Storage Queue is full and is blocking dispatch\000event=0x1001a\000\00000\000SRQ is Full\000 */
{ 243852 }, /* pm_lsu_srq_s0_alloc\000other\000Per thread - use edge detect to count allocates On a per thread basis, level signal indicating Slot 0 is valid. By instrumenting a single slot we can calculate service time for that slot. Previous machines required a separate signal indicating the slot was allocated. Because any signal can be routed to any counter in P8, we can count level in one PMC and edge detect in another PMC using the same signal\000event=0xd09d\000\00000\0000.0\000 */
{ 244305 }, /* pm_lsu_srq_s0_valid\000other\000Slot 0 of SRQ valid\000event=0xd09c\000\00000\000Slot 0 of SRQ validSRQ slot 0 valid\000 */
{ 244404 }, /* pm_lsu_srq_s39_alloc\000other\000SRQ slot 39 was released\000event=0xf093\000\00000\0000.0\000 */
{ 244477 }, /* pm_lsu_srq_s39_valid\000other\000SRQ slot 39 was busy\000event=0xf092\000\00000\000SRQ slot 39 was busy42\000 */
{ 244565 }, /* pm_lsu_srq_sync\000other\000A sync in the SRQ ended\000event=0xd09b\000\00000\0000.0\000 */
{ 244632 }, /* pm_lsu_srq_sync_cyc\000other\000A sync is in the SRQ (edge detect to count)\000event=0xd09a\000\00000\000A sync is in the SRQ (edge detect to count)SRQ sync duration\000 */
{ 244780 }, /* pm_lsu_store_reject\000other\000Store reject on either pipe\000event=0xf084\000\00000\000LSU\000 */
{ 244855 }, /* pm_lsu_two_tablewalk_cyc\000other\000Cycles when two tablewalks pending on this thread\000event=0xd0a6\000\00000\000Cycles when two tablewalks pending on this thread42\000 */
{ 245005 }, /* pm_lwsync\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\00000\000\000 */
{ 245140 }, /* pm_lwsync_held\000other\000LWSYNC held at dispatch\000event=0x209a\000\00000\000\000 */
{ 169245 }, /* pm_mem_co\000memory\000Memory castouts from this lpar\000event=0x4c058\000\00000\000\000 */
{ 169312 }, /* pm_mem_loc_thresh_ifu\000memory\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\00000\000\000 */
{ 169417 }, /* pm_mem_loc_thresh_lsu_high\000memory\000Local memory above threshold for LSU medium\000event=0x40056\000\00000\000\000 */
{ 169514 }, /* pm_mem_loc_thresh_lsu_med\000memory\000Local memory above theshold for data prefetch\000event=0x1c05e\000\00000\000\000 */
{ 169612 }, /* pm_mem_pref\000memory\000Memory prefetch for this lpar. Includes L4\000event=0x2c058\000\00000\000\000 */
{ 169693 }, /* pm_mem_read\000memory\000Reads from Memory from this lpar (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\00000\000\000 */
{ 169829 }, /* pm_mem_rwitm\000memory\000Memory rwitm for this lpar\000event=0x3c05e\000\00000\000\000 */
{ 145252 }, /* pm_mrk_back_br_cmpl\000marked\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\00000\000\000 */
{ 145459 }, /* pm_mrk_br_cmpl\000marked\000Branch Instruction completed\000event=0x1016e\000\00000\000\000 */
{ 145529 }, /* pm_mrk_br_mpred_cmpl\000marked\000Marked Branch Mispredicted\000event=0x301e4\000\00000\000\000 */
{ 145603 }, /* pm_mrk_br_taken_cmpl\000marked\000Marked Branch Taken completed\000event=0x101e2\000\00000\000\000 */
{ 145394 }, /* pm_mrk_bru_fin\000marked\000bru marked instr finish\000event=0x2013a\000\00000\000\000 */
{ 245203 }, /* pm_mrk_cru_fin\000other\000IFU non-branch finished\000event=0x3013a\000\00000\000IFU non-branch marked instruction finished\000 */
{ 145680 }, /* pm_mrk_data_from_dl2l3_mod\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d148\000\00000\000\000 */
{ 145899 }, /* pm_mrk_data_from_dl2l3_mod_cyc\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2d128\000\00000\000\000 */
{ 146111 }, /* pm_mrk_data_from_dl2l3_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d148\000\00000\000\000 */
{ 146328 }, /* pm_mrk_data_from_dl2l3_shr_cyc\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2c128\000\00000\000\000 */
{ 146538 }, /* pm_mrk_data_from_dl4\000marked\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x3d14c\000\00000\000\000 */
{ 146708 }, /* pm_mrk_data_from_dl4_cyc\000marked\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\00000\000\000 */
{ 146871 }, /* pm_mrk_data_from_dmem\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4d14c\000\00000\000\000 */
{ 147043 }, /* pm_mrk_data_from_dmem_cyc\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x2d12c\000\00000\000\000 */
{ 147208 }, /* pm_mrk_data_from_l2\000marked\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x1d142\000\00000\000\000 */
{ 245309 }, /* pm_mrk_data_from_l21_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x4d146\000\00000\000\000 */
{ 245483 }, /* pm_mrk_data_from_l21_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x2d126\000\00000\000\000 */
{ 245650 }, /* pm_mrk_data_from_l21_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x3d146\000\00000\000\000 */
{ 245822 }, /* pm_mrk_data_from_l21_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2c126\000\00000\000\000 */
{ 147563 }, /* pm_mrk_data_from_l2_cyc\000marked\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x4c122\000\00000\000\000 */
{ 147684 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst\000marked\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x3d140\000\00000\000\000 */
{ 147863 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000marked\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x2c120\000\00000\000\000 */
{ 148035 }, /* pm_mrk_data_from_l2_disp_conflict_other\000marked\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x4d140\000\00000\000\000 */
{ 148206 }, /* pm_mrk_data_from_l2_disp_conflict_other_cyc\000marked\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x2d120\000\00000\000\000 */
{ 148370 }, /* pm_mrk_data_from_l2_mepf\000marked\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x2d140\000\00000\000\000 */
{ 148549 }, /* pm_mrk_data_from_l2_mepf_cyc\000marked\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4d120\000\00000\000\000 */
{ 148721 }, /* pm_mrk_data_from_l2_no_conflict\000marked\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x1d140\000\00000\000\000 */
{ 148878 }, /* pm_mrk_data_from_l2_no_conflict_cyc\000marked\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x4c120\000\00000\000\000 */
{ 147336 }, /* pm_mrk_data_from_l2miss\000marked\000Data cache reload L2 miss\000event=0x1d14e\000\00000\000\000 */
{ 147412 }, /* pm_mrk_data_from_l2miss_cyc\000marked\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x4c12e\000\00000\000\000 */
{ 149028 }, /* pm_mrk_data_from_l3\000marked\000The processor's data cache was reloaded from local core's L3 due to a marked load\000event=0x4d142\000\00000\000\000 */
{ 245987 }, /* pm_mrk_data_from_l31_eco_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x4d144\000\00000\000\000 */
{ 246169 }, /* pm_mrk_data_from_l31_eco_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d124\000\00000\000\000 */
{ 246344 }, /* pm_mrk_data_from_l31_eco_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x3d144\000\00000\000\000 */
{ 246524 }, /* pm_mrk_data_from_l31_eco_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2c124\000\00000\000\000 */
{ 246697 }, /* pm_mrk_data_from_l31_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x2d144\000\00000\000\000 */
{ 246871 }, /* pm_mrk_data_from_l31_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\00000\000\000 */
{ 247038 }, /* pm_mrk_data_from_l31_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x1d146\000\00000\000\000 */
{ 247210 }, /* pm_mrk_data_from_l31_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4c126\000\00000\000\000 */
{ 149465 }, /* pm_mrk_data_from_l3_cyc\000marked\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x2d122\000\00000\000\000 */
{ 149586 }, /* pm_mrk_data_from_l3_disp_conflict\000marked\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x3d142\000\00000\000\000 */
{ 149751 }, /* pm_mrk_data_from_l3_disp_conflict_cyc\000marked\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\00000\000\000 */
{ 149909 }, /* pm_mrk_data_from_l3_mepf\000marked\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\00000\000\000 */
{ 150088 }, /* pm_mrk_data_from_l3_mepf_cyc\000marked\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x4d122\000\00000\000\000 */
{ 150260 }, /* pm_mrk_data_from_l3_no_conflict\000marked\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x1d144\000\00000\000\000 */
{ 150417 }, /* pm_mrk_data_from_l3_no_conflict_cyc\000marked\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\00000\000\000 */
{ 149156 }, /* pm_mrk_data_from_l3miss\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\00000\000\000 */
{ 149314 }, /* pm_mrk_data_from_l3miss_cyc\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x2d12e\000\00000\000\000 */
{ 150567 }, /* pm_mrk_data_from_ll4\000marked\000The processor's data cache was reloaded from the local chip's L4 cache due to a marked load\000event=0x1d14c\000\00000\000\000 */
{ 150706 }, /* pm_mrk_data_from_ll4_cyc\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x4c12c\000\00000\000\000 */
{ 150838 }, /* pm_mrk_data_from_lmem\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x2d148\000\00000\000\000 */
{ 150976 }, /* pm_mrk_data_from_lmem_cyc\000marked\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\00000\000\000 */
{ 247375 }, /* pm_mrk_data_from_mem\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\00000\000\000 */
{ 151107 }, /* pm_mrk_data_from_memory\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x2d14c\000\00000\000\000 */
{ 151283 }, /* pm_mrk_data_from_memory_cyc\000marked\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x4d12c\000\00000\000\000 */
{ 151452 }, /* pm_mrk_data_from_off_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x4d14a\000\00000\000\000 */
{ 151668 }, /* pm_mrk_data_from_off_chip_cache_cyc\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d12a\000\00000\000\000 */
{ 151877 }, /* pm_mrk_data_from_on_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x1d148\000\00000\000\000 */
{ 152069 }, /* pm_mrk_data_from_on_chip_cache_cyc\000marked\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4c128\000\00000\000\000 */
{ 152254 }, /* pm_mrk_data_from_rl2l3_mod\000marked\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d146\000\00000\000\000 */
{ 152469 }, /* pm_mrk_data_from_rl2l3_mod_cyc\000marked\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4d126\000\00000\000\000 */
{ 152677 }, /* pm_mrk_data_from_rl2l3_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\00000\000\000 */
{ 152890 }, /* pm_mrk_data_from_rl2l3_shr_cyc\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\00000\000\000 */
{ 153096 }, /* pm_mrk_data_from_rl4\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x2d14a\000\00000\000\000 */
{ 153263 }, /* pm_mrk_data_from_rl4_cyc\000marked\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\00000\000\000 */
{ 153423 }, /* pm_mrk_data_from_rmem\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x3d14a\000\00000\000\000 */
{ 153595 }, /* pm_mrk_data_from_rmem_cyc\000marked\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\00000\000\000 */
{ 153760 }, /* pm_mrk_dcache_reload_intv\000marked\000Combined Intervention event\000event=0x40118\000\00000\000\000 */
{ 153840 }, /* pm_mrk_derat_miss\000marked\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\00000\000\000 */
{ 153922 }, /* pm_mrk_derat_miss_16g\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16G\000event=0x4d154\000\00000\000\000 */
{ 154024 }, /* pm_mrk_derat_miss_16m\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 16M\000event=0x3d154\000\00000\000\000 */
{ 154126 }, /* pm_mrk_derat_miss_4k\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1d156\000\00000\000\000 */
{ 154226 }, /* pm_mrk_derat_miss_64k\000marked\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\00000\000\000 */
{ 154328 }, /* pm_mrk_dfu_fin\000marked\000Decimal Unit marked Instruction Finish\000event=0x20132\000\00000\000\000 */
{ 154408 }, /* pm_mrk_dpteg_from_dl2l3_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x4f148\000\00000\000\000 */
{ 154644 }, /* pm_mrk_dpteg_from_dl2l3_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request\000event=0x3f148\000\00000\000\000 */
{ 154878 }, /* pm_mrk_dpteg_from_dl4\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request\000event=0x3f14c\000\00000\000\000 */
{ 155065 }, /* pm_mrk_dpteg_from_dmem\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request\000event=0x4f14c\000\00000\000\000 */
{ 155254 }, /* pm_mrk_dpteg_from_l2\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request\000event=0x1f142\000\00000\000\000 */
{ 247547 }, /* pm_mrk_dpteg_from_l21_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request\000event=0x4f146\000\00000\000\000 */
{ 247738 }, /* pm_mrk_dpteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request\000event=0x3f146\000\00000\000\000 */
{ 247927 }, /* pm_mrk_dpteg_from_l2_disp_conflict_ldhitst\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with load hit store conflict due to a marked data side request\000event=0x3f140\000\00000\000\000 */
{ 248122 }, /* pm_mrk_dpteg_from_l2_disp_conflict_other\000other\000A Page Table Entry was loaded into the TLB from local core's L2 with dispatch conflict due to a marked data side request\000event=0x4f140\000\00000\000\000 */
{ 155574 }, /* pm_mrk_dpteg_from_l2_mepf\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request\000event=0x2f140\000\00000\000\000 */
{ 155770 }, /* pm_mrk_dpteg_from_l2_no_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request\000event=0x1f140\000\00000\000\000 */
{ 155399 }, /* pm_mrk_dpteg_from_l2miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request\000event=0x1f14e\000\00000\000\000 */
{ 155944 }, /* pm_mrk_dpteg_from_l3\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request\000event=0x4f142\000\00000\000\000 */
{ 248309 }, /* pm_mrk_dpteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x4f144\000\00000\000\000 */
{ 248508 }, /* pm_mrk_dpteg_from_l31_eco_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request\000event=0x3f144\000\00000\000\000 */
{ 248705 }, /* pm_mrk_dpteg_from_l31_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request\000event=0x2f144\000\00000\000\000 */
{ 248896 }, /* pm_mrk_dpteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request\000event=0x1f146\000\00000\000\000 */
{ 156264 }, /* pm_mrk_dpteg_from_l3_disp_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request\000event=0x3f142\000\00000\000\000 */
{ 156446 }, /* pm_mrk_dpteg_from_l3_mepf\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request\000event=0x2f142\000\00000\000\000 */
{ 156642 }, /* pm_mrk_dpteg_from_l3_no_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request\000event=0x1f144\000\00000\000\000 */
{ 156089 }, /* pm_mrk_dpteg_from_l3miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request\000event=0x4f14e\000\00000\000\000 */
{ 156816 }, /* pm_mrk_dpteg_from_ll4\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request\000event=0x1f14c\000\00000\000\000 */
{ 156972 }, /* pm_mrk_dpteg_from_lmem\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request\000event=0x2f148\000\00000\000\000 */
{ 157127 }, /* pm_mrk_dpteg_from_memory\000marked\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request\000event=0x2f14c\000\00000\000\000 */
{ 157320 }, /* pm_mrk_dpteg_from_off_chip_cache\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request\000event=0x4f14a\000\00000\000\000 */
{ 157553 }, /* pm_mrk_dpteg_from_on_chip_cache\000marked\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request\000event=0x1f148\000\00000\000\000 */
{ 157762 }, /* pm_mrk_dpteg_from_rl2l3_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x2f146\000\00000\000\000 */
{ 157994 }, /* pm_mrk_dpteg_from_rl2l3_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request\000event=0x1f14a\000\00000\000\000 */
{ 158224 }, /* pm_mrk_dpteg_from_rl4\000marked\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request\000event=0x2f14a\000\00000\000\000 */
{ 158408 }, /* pm_mrk_dpteg_from_rmem\000marked\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request\000event=0x3f14a\000\00000\000\000 */
{ 158597 }, /* pm_mrk_dtlb_miss\000marked\000Marked dtlb miss\000event=0x401e4\000\00000\000\000 */
{ 158657 }, /* pm_mrk_dtlb_miss_16g\000marked\000Marked Data TLB Miss page size 16G\000event=0x1d158\000\00000\000\000 */
{ 158739 }, /* pm_mrk_dtlb_miss_16m\000marked\000Marked Data TLB Miss page size 16M\000event=0x4d156\000\00000\000\000 */
{ 158821 }, /* pm_mrk_dtlb_miss_4k\000marked\000Marked Data TLB Miss page size 4k\000event=0x2d156\000\00000\000\000 */
{ 158901 }, /* pm_mrk_dtlb_miss_64k\000marked\000Marked Data TLB Miss page size 64K\000event=0x3d156\000\00000\000\000 */
{ 158983 }, /* pm_mrk_fab_rsp_bkill\000marked\000Marked store had to do a bkill\000event=0x40154\000\00000\000\000 */
{ 159061 }, /* pm_mrk_fab_rsp_bkill_cyc\000marked\000cycles L2 RC took for a bkill\000event=0x2f150\000\00000\000\000 */
{ 159142 }, /* pm_mrk_fab_rsp_claim_rty\000marked\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\00000\000\000 */
{ 159233 }, /* pm_mrk_fab_rsp_dclaim\000marked\000Marked store had to do a dclaim\000event=0x30154\000\00000\000\000 */
{ 159313 }, /* pm_mrk_fab_rsp_dclaim_cyc\000marked\000cycles L2 RC took for a dclaim\000event=0x2f152\000\00000\000\000 */
{ 249085 }, /* pm_mrk_fab_rsp_match\000other\000ttype and cresp matched as specified in MMCR1\000event=0x30156\000\00000\000\000 */
{ 249177 }, /* pm_mrk_fab_rsp_match_cyc\000other\000cresp/ttype match cycles\000event=0x4f152\000\00000\000\000 */
{ 159396 }, /* pm_mrk_fab_rsp_rd_rty\000marked\000Sampled L2 reads retry count\000event=0x4015e\000\00000\000\000 */
{ 159473 }, /* pm_mrk_fab_rsp_rd_t_intv\000marked\000Sampled Read got a T intervention\000event=0x1015e\000\00000\000\000 */
{ 159558 }, /* pm_mrk_fab_rsp_rwitm_cyc\000marked\000cycles L2 RC took for a rwitm\000event=0x4f150\000\00000\000\000 */
{ 159639 }, /* pm_mrk_fab_rsp_rwitm_rty\000marked\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\00000\000\000 */
{ 249252 }, /* pm_mrk_filt_match\000other\000Marked filter Match\000event=0x2013c\000\00000\000\000 */
{ 249315 }, /* pm_mrk_fin_stall_cyc\000other\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count )\000event=0x1013c\000\00000\000Marked instruction Finish Stall cycles (marked finish after NTC) (use edge detect to count #)\000 */
{ 159730 }, /* pm_mrk_fxu_fin\000marked\000fxu marked instr finish\000event=0x20134\000\00000\000\000 */
{ 249547 }, /* pm_mrk_grp_cmpl\000other\000marked instruction finished (completed)\000event=0x40130\000\00000\000\000 */
{ 249628 }, /* pm_mrk_grp_ic_miss\000other\000Marked Group experienced I cache miss\000event=0x4013a\000\00000\000\000 */
{ 249710 }, /* pm_mrk_grp_ntc\000other\000Marked group ntc cycles\000event=0x3013c\000\00000\000\000 */
{ 159795 }, /* pm_mrk_inst_cmpl\000marked\000marked instruction completed\000event=0x401e0\000\00000\000\000 */
{ 159867 }, /* pm_mrk_inst_decoded\000marked\000marked instruction decoded\000event=0x20130\000\00000\000marked instruction decoded. Name from ISU?\000 */
{ 159982 }, /* pm_mrk_inst_disp\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\00000\000Marked Instruction dispatched\000 */
{ 160118 }, /* pm_mrk_inst_fin\000marked\000marked instruction finished\000event=0x30130\000\00000\000marked instr finish any unit\000 */
{ 160216 }, /* pm_mrk_inst_from_l3miss\000marked\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\00000\000n/a\000 */
{ 160342 }, /* pm_mrk_inst_issued\000marked\000Marked instruction issued\000event=0x10132\000\00000\000\000 */
{ 160413 }, /* pm_mrk_inst_timeo\000marked\000marked Instruction finish timeout (instruction lost)\000event=0x40134\000\00000\000\000 */
{ 160510 }, /* pm_mrk_l1_icache_miss\000marked\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\00000\000Marked L1 Icache Miss\000 */
{ 84507 }, /* pm_mrk_l1_reload_valid\000marked\000Marked demand reload\000event=0x101ea\000\00000\000\000 */
{ 160623 }, /* pm_mrk_l2_rc_disp\000marked\000Marked Instruction RC dispatched in L2\000event=0x20114\000\00000\000\000 */
{ 160706 }, /* pm_mrk_l2_rc_done\000marked\000Marked RC done\000event=0x3012a\000\00000\000\000 */
{ 160765 }, /* pm_mrk_larx_fin\000marked\000Larx finished\000event=0x40116\000\00000\000\000 */
{ 249774 }, /* pm_mrk_ld_miss_exposed\000other\000Marked Load exposed Miss (exposed period ended)\000event=0x1013f\000\00000\000Marked Load exposed Miss (use edge detect to count #)\000 */
{ 160821 }, /* pm_mrk_ld_miss_exposed_cyc\000marked\000Marked Load exposed Miss cycles\000event=0x1013e\000\00000\000Marked Load exposed Miss (use edge detect to count #)\000 */
{ 160959 }, /* pm_mrk_ld_miss_l1\000marked\000Marked DL1 Demand Miss counted at exec time\000event=0x201e2\000\00000\000\000 */
{ 161047 }, /* pm_mrk_ld_miss_l1_cyc\000marked\000Marked ld latency\000event=0x4013e\000\00000\000\000 */
{ 161113 }, /* pm_mrk_lsu_fin\000marked\000lsu marked instr finish\000event=0x40132\000\00000\000\000 */
{ 249923 }, /* pm_mrk_lsu_flush\000other\000Flush: (marked) : All Cases\000event=0xd180\000\00000\000Flush: (marked) : All Cases42\000 */
{ 250021 }, /* pm_mrk_lsu_flush_lrq\000other\000Flush: (marked) LRQ\000event=0xd188\000\00000\000Flush: (marked) LRQMarked LRQ flushes\000 */
{ 250123 }, /* pm_mrk_lsu_flush_srq\000other\000Flush: (marked) SRQ\000event=0xd18a\000\00000\000Flush: (marked) SRQMarked SRQ lhs flushes\000 */
{ 250229 }, /* pm_mrk_lsu_flush_uld\000other\000Flush: (marked) Unaligned Load\000event=0xd184\000\00000\000Flush: (marked) Unaligned LoadMarked unaligned load flushes\000 */
{ 250364 }, /* pm_mrk_lsu_flush_ust\000other\000Flush: (marked) Unaligned Store\000event=0xd186\000\00000\000Flush: (marked) Unaligned StoreMarked unaligned store flushes\000 */
{ 250502 }, /* pm_mrk_lsu_reject\000other\000LSU marked reject (up to 2 per cycle)\000event=0x40164\000\00000\000\000 */
{ 250583 }, /* pm_mrk_lsu_reject_erat_miss\000other\000LSU marked reject due to ERAT (up to 2 per cycle)\000event=0x30164\000\00000\000\000 */
{ 161178 }, /* pm_mrk_ntf_fin\000marked\000Marked next to finish instruction finished\000event=0x20112\000\00000\000\000 */
{ 161262 }, /* pm_mrk_run_cyc\000marked\000Marked run cycles\000event=0x1d15e\000\00000\000\000 */
{ 250686 }, /* pm_mrk_src_pref_track_eff\000other\000Marked src pref track was effective\000event=0x1d15a\000\00000\000\000 */
{ 250773 }, /* pm_mrk_src_pref_track_ineff\000other\000Prefetch tracked was ineffective for marked src\000event=0x3d15a\000\00000\000\000 */
{ 250874 }, /* pm_mrk_src_pref_track_mod\000other\000Prefetch tracked was moderate for marked src\000event=0x4d15c\000\00000\000\000 */
{ 250970 }, /* pm_mrk_src_pref_track_mod_l2\000other\000Marked src Prefetch Tracked was moderate (source L2)\000event=0x1d15c\000\00000\000\000 */
{ 251077 }, /* pm_mrk_src_pref_track_mod_l3\000other\000Prefetch tracked was moderate (L3 hit) for marked src\000event=0x3d15c\000\00000\000\000 */
{ 161527 }, /* pm_mrk_st_cmpl\000marked\000marked store completed and sent to nest\000event=0x10134\000\00000\000Marked store completed\000 */
{ 161630 }, /* pm_mrk_st_cmpl_int\000marked\000marked store finished with intervention\000event=0x30134\000\00000\000marked store complete (data home) with intervention\000 */
{ 161766 }, /* pm_mrk_st_drain_to_l2disp_cyc\000marked\000cycles to drain st from core to L2\000event=0x3f150\000\00000\000\000 */
{ 161857 }, /* pm_mrk_st_fwd\000marked\000Marked st forwards\000event=0x3012c\000\00000\000\000 */
{ 161916 }, /* pm_mrk_st_l2disp_to_cmpl_cyc\000marked\000cycles from L2 rc disp to l2 rc completion\000event=0x1f150\000\00000\000\000 */
{ 162014 }, /* pm_mrk_st_nest\000marked\000Marked store sent to nest\000event=0x20138\000\00000\000\000 */
{ 161321 }, /* pm_mrk_stall_cmplu_cyc\000marked\000Marked Group completion Stall\000event=0x3013e\000\00000\000Marked Group Completion Stall cycles (use edge detect to count #)\000 */
{ 161465 }, /* pm_mrk_stcx_fail\000marked\000marked stcx failed\000event=0x3e158\000\00000\000\000 */
{ 251185 }, /* pm_mrk_tgt_pref_track_eff\000other\000Marked target pref track was effective\000event=0x1c15a\000\00000\000\000 */
{ 251275 }, /* pm_mrk_tgt_pref_track_ineff\000other\000Prefetch tracked was ineffective for marked target\000event=0x3c15a\000\00000\000\000 */
{ 251379 }, /* pm_mrk_tgt_pref_track_mod\000other\000Prefetch tracked was moderate for marked target\000event=0x4c15c\000\00000\000\000 */
{ 251478 }, /* pm_mrk_tgt_pref_track_mod_l2\000other\000Marked target Prefetch Tracked was moderate (source L2)\000event=0x1c15c\000\00000\000\000 */
{ 251588 }, /* pm_mrk_tgt_pref_track_mod_l3\000other\000Prefetch tracked was moderate (L3 hit) for marked target\000event=0x3c15c\000\00000\000\000 */
{ 162081 }, /* pm_mrk_vsu_fin\000marked\000VSU marked instr finish\000event=0x30132\000\00000\000vsu (fpu) marked instr finish\000 */
{ 162175 }, /* pm_mult_mrk\000marked\000mult marked instr\000event=0x3d15e\000\00000\000\000 */
{ 169895 }, /* pm_nest_ref_clk\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\00000\000Nest reference clocks\000 */
{ 251699 }, /* pm_nested_tend\000other\000Completion time nested tend\000event=0x20b0\000\00000\000\000 */
{ 251766 }, /* pm_non_fav_tbegin\000other\000Dispatch time non favored tbegin\000event=0x20b6\000\00000\000\000 */
{ 251841 }, /* pm_ntcg_all_fin\000other\000Cycles after all instructions have finished to group completed\000event=0x2001a\000\00000\000Ccycles after all instructions have finished to group completed\000 */
{ 252008 }, /* pm_outer_tbegin\000other\000Completion time outer tbegin\000event=0x20ac\000\00000\000\000 */
{ 252077 }, /* pm_outer_tend\000other\000Completion time outer tend\000event=0x20ae\000\00000\000\000 */
{ 268743 }, /* pm_pmc1_overflow\000pmc\000Overflow from counter 1\000event=0x20010\000\00000\000\000 */
{ 268807 }, /* pm_pmc2_overflow\000pmc\000Overflow from counter 2\000event=0x30010\000\00000\000\000 */
{ 268871 }, /* pm_pmc2_rewind\000pmc\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\00000\000\000 */
{ 268953 }, /* pm_pmc2_saved\000pmc\000PMC2 Rewind Value saved\000event=0x10022\000\00000\000PMC2 Rewind Value saved (matched condition)\000 */
{ 269057 }, /* pm_pmc3_overflow\000pmc\000Overflow from counter 3\000event=0x40010\000\00000\000\000 */
{ 269121 }, /* pm_pmc4_overflow\000pmc\000Overflow from counter 4\000event=0x10010\000\00000\000\000 */
{ 269185 }, /* pm_pmc4_rewind\000pmc\000PMC4 Rewind Event\000event=0x10020\000\00000\000PMC4 Rewind Event (did not match condition)\000 */
{ 269284 }, /* pm_pmc4_saved\000pmc\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\00000\000\000 */
{ 269365 }, /* pm_pmc5_overflow\000pmc\000Overflow from counter 5\000event=0x10024\000\00000\000\000 */
{ 269429 }, /* pm_pmc6_overflow\000pmc\000Overflow from counter 6\000event=0x30024\000\00000\000\000 */
{ 252237 }, /* pm_pref_track_eff\000other\000Prefetch Tracked was effective\000event=0x1005a\000\00000\000\000 */
{ 252311 }, /* pm_pref_track_ineff\000other\000Prefetch tracked was ineffective\000event=0x3005a\000\00000\000\000 */
{ 252389 }, /* pm_pref_track_mod\000other\000Prefetch tracked was moderate\000event=0x4005a\000\00000\000\000 */
{ 252462 }, /* pm_pref_track_mod_l2\000other\000Prefetch Tracked was moderate (source L2)\000event=0x1005c\000\00000\000\000 */
{ 252550 }, /* pm_pref_track_mod_l3\000other\000Prefetch tracked was moderate (L3)\000event=0x3005c\000\00000\000\000 */
{ 252142 }, /* pm_pref_tracked\000other\000Total number of Prefetch Operations that were tracked\000event=0x2005a\000\00000\000\000 */
{ 267372 }, /* pm_probe_nop_disp\000pipeline\000ProbeNops dispatched\000event=0x40014\000\00000\000\000 */
{ 252631 }, /* pm_pte_prefetch\000other\000PTE prefetches\000event=0xe084\000\00000\000PTE prefetches42\000 */
{ 170006 }, /* pm_pump_cpred\000memory\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\00000\000Pump prediction correct. Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 170336 }, /* pm_pump_mpred\000memory\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\00000\000Pump Mis prediction Counts across all types of pumpsfor all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 252702 }, /* pm_rc0_alloc\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16081\000\00000\0000.0\000 */
{ 252825 }, /* pm_rc0_busy\000other\000RC mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x16080\000\00000\000\000 */
{ 252944 }, /* pm_rc_lifetime_exc_1024\000other\000Number of times the RC machine for a sampled instruction was active for more than 1024 cycles\000event=0x200301ea\000\00000\000Reload latency exceeded 1024 cyc\000 */
{ 253122 }, /* pm_rc_lifetime_exc_2048\000other\000Number of times the RC machine for a sampled instruction was active for more than 2048 cycles\000event=0x200401ec\000\00000\000Threshold counter exceeded a value of 2048\000 */
{ 253310 }, /* pm_rc_lifetime_exc_256\000other\000Number of times the RC machine for a sampled instruction was active for more than 256 cycles\000event=0x200101e8\000\00000\000Threshold counter exceed a count of 256\000 */
{ 253493 }, /* pm_rc_lifetime_exc_32\000other\000Number of times the RC machine for a sampled instruction was active for more than 32 cycles\000event=0x200201e6\000\00000\000Reload latency exceeded 32 cyc\000 */
{ 253665 }, /* pm_rc_usage\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x36088\000\00000\000\000 */
{ 253884 }, /* pm_real_srq_full\000other\000Out of real srq entries\000event=0x20004\000\00000\000\000 */
{ 267439 }, /* pm_run_cyc\000pipeline\000Run_cycles\000event=0x600f4\000\00000\000\000 */
{ 267489 }, /* pm_run_cyc_smt2_mode\000pipeline\000Cycles run latch is set and core is in SMT2 mode\000event=0x3006c\000\00000\000\000 */
{ 253950 }, /* pm_run_cyc_smt2_shrd_mode\000other\000cycles this threads run latch is set and the core is in SMT2 shared mode\000event=0x2006a\000\00000\000Cycles run latch is set and core is in SMT2-shared mode\000 */
{ 254129 }, /* pm_run_cyc_smt2_split_mode\000other\000Cycles run latch is set and core is in SMT2-split mode\000event=0x1006a\000\00000\000\000 */
{ 267587 }, /* pm_run_cyc_smt4_mode\000pipeline\000cycles this threads run latch is set and the core is in SMT4 mode\000event=0x2006c\000\00000\000Cycles run latch is set and core is in SMT4 mode\000 */
{ 254236 }, /* pm_run_cyc_smt8_mode\000other\000Cycles run latch is set and core is in SMT8 mode\000event=0x4006c\000\00000\000\000 */
{ 267750 }, /* pm_run_cyc_st_mode\000pipeline\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\00000\000\000 */
{ 267844 }, /* pm_run_inst_cmpl\000pipeline\000Run_Instructions\000event=0x500fa\000\00000\000\000 */
{ 269493 }, /* pm_run_purr\000pmc\000Run_PURR\000event=0x400f4\000\00000\000\000 */
{ 269537 }, /* pm_run_spurr\000pmc\000Run SPURR\000event=0x10008\000\00000\000\000 */
{ 254331 }, /* pm_sec_erat_hit\000other\000secondary ERAT Hit\000event=0xf082\000\00000\000secondary ERAT Hit42\000 */
{ 254410 }, /* pm_shl_created\000other\000Store-Hit-Load Table Entry Created\000event=0x508c\000\00000\000\000 */
{ 254484 }, /* pm_shl_st_convert\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x508e\000\00000\000\000 */
{ 254575 }, /* pm_shl_st_disable\000other\000Store-Hit-Load Table Read Hit with entry Disabled (entry was disabled due to the entry shown to not prevent the flush)\000event=0x5090\000\00000\000\000 */
{ 254736 }, /* pm_sn0_alloc\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26085\000\00000\0000.0\000 */
{ 254859 }, /* pm_sn0_busy\000other\000SN mach 0 Busy. Used by PMU to sample ave RC livetime(mach0 used as sample point)\000event=0x26084\000\00000\000\000 */
{ 255051 }, /* pm_sn_usage\000other\000Continuous 16 cycle(2to1) window where this signals rotates thru sampling each L2 SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x4608c\000\00000\000\000 */
{ 254978 }, /* pm_snoop_tlbie\000other\000TLBIE snoop\000event=0xd0b2\000\00000\000TLBIE snoopSnoop TLBIE\000 */
{ 267959 }, /* pm_st_cmpl\000pipeline\000Store completion count\000event=0x20016\000\00000\000\000 */
{ 268021 }, /* pm_st_fin\000pipeline\000Store Instructions Finished\000event=0x200f0\000\00000\000Store Instructions Finished (store sent to nest)\000 */
{ 268135 }, /* pm_st_fwd\000pipeline\000Store forwards that finished\000event=0x20018\000\00000\000\000 */
{ 126593 }, /* pm_st_miss_l1\000cache\000Store Missed L1\000event=0x300f0\000\00000\000\000 */
{ 255270 }, /* pm_stall_end_gct_empty\000other\000Count ended because GCT went empty\000event=0x10028\000\00000\000\000 */
{ 267906 }, /* pm_stcx_fail\000pipeline\000stcx failed\000event=0x1e058\000\00000\000\000 */
{ 255353 }, /* pm_stcx_lsu\000other\000STCX executed reported at sent to nest\000event=0xc090\000\00000\000STCX executed reported at sent to nest42\000 */
{ 269583 }, /* pm_suspended\000pmc\000Counter OFF\000event=0\000\00000\000\000 */
{ 255468 }, /* pm_swap_cancel\000other\000SWAP cancel , rtag not available\000event=0x3090\000\00000\000\000 */
{ 255540 }, /* pm_swap_cancel_gpr\000other\000SWAP cancel , rtag not available for gpr\000event=0x3092\000\00000\000\000 */
{ 255624 }, /* pm_swap_complete\000other\000swap cast in completed\000event=0x308c\000\00000\000\000 */
{ 255688 }, /* pm_swap_complete_gpr\000other\000swap cast in completed fpr gpr\000event=0x308e\000\00000\000\000 */
{ 162231 }, /* pm_sync_mrk_br_link\000marked\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\00000\000\000 */
{ 162346 }, /* pm_sync_mrk_br_mpred\000marked\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\00000\000\000 */
{ 162457 }, /* pm_sync_mrk_fx_divide\000marked\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\00000\000\000 */
{ 162570 }, /* pm_sync_mrk_l2hit\000marked\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\00000\000\000 */
{ 162668 }, /* pm_sync_mrk_l2miss\000marked\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\00000\000\000 */
{ 162767 }, /* pm_sync_mrk_l3miss\000marked\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\00000\000\000 */
{ 162868 }, /* pm_sync_mrk_probe_nop\000marked\000Marked probeNops which can cause synchronous interrupts\000event=0x15150\000\00000\000\000 */
{ 170656 }, /* pm_sys_pump_cpred\000memory\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\00000\000Initial and Final Pump Scope and data sourced across this scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 171000 }, /* pm_sys_pump_mpred\000memory\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope(Chip/Group) OR Final Pump Scope(system) got data from source that was at smaller scope(Chip/group) Final pump was system pump and initial pump was chip or group or\000 */
{ 171547 }, /* pm_sys_pump_mpred_rty\000memory\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\00000\000Final Pump Scope(system) to get data sourced, ended up larger than Initial Pump Scope (Chip or Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000 */
{ 268202 }, /* pm_tablewalk_cyc\000pipeline\000Cycles when a tablewalk (I or D) is active\000event=0x10026\000\00000\000Tablewalk Active\000 */
{ 255764 }, /* pm_tablewalk_cyc_pref\000other\000tablewalk qualified for pte prefetches\000event=0xe086\000\00000\000tablewalk qualified for pte prefetches42\000 */
{ 255889 }, /* pm_tabort_treclaim\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x20b2\000\00000\000\000 */
{ 268306 }, /* pm_tb_bit_trans\000pipeline\000timebase event\000event=0x300f8\000\00000\000\000 */
{ 255980 }, /* pm_tend_pend_cyc\000other\000TEND latency per thread\000event=0xe0ba\000\00000\000TEND latency per thread42\000 */
{ 268365 }, /* pm_thrd_all_run_cyc\000pipeline\000All Threads in Run_cycles (was both threads in run_cycles)\000event=0x2000c\000\00000\000\000 */
{ 144921 }, /* pm_thrd_conc_run_inst\000frontend\000PPC Instructions Finished when both threads in run_cycles\000event=0x300f4\000\00000\000Concurrent Run Instructions\000 */
{ 256070 }, /* pm_thrd_grp_cmpl_both_cyc\000other\000Cycles group completed on both completion slots by any thread\000event=0x10012\000\00000\000Two threads finished same cycle (gated by run latch)\000 */
{ 256235 }, /* pm_thrd_prio_0_1_cyc\000other\000Cycles thread running at priority level 0 or 1\000event=0x40bc\000\00000\000\000 */
{ 256327 }, /* pm_thrd_prio_2_3_cyc\000other\000Cycles thread running at priority level 2 or 3\000event=0x40be\000\00000\000\000 */
{ 256419 }, /* pm_thrd_prio_4_5_cyc\000other\000Cycles thread running at priority level 4 or 5\000event=0x5080\000\00000\000\000 */
{ 256511 }, /* pm_thrd_prio_6_7_cyc\000other\000Cycles thread running at priority level 6 or 7\000event=0x5082\000\00000\000\000 */
{ 256603 }, /* pm_thrd_rebal_cyc\000other\000cycles rebalance was active\000event=0x3098\000\00000\000\000 */
{ 117045 }, /* pm_thresh_exc_1024\000pmc\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\00000\000\000 */
{ 118202 }, /* pm_thresh_exc_128\000pmc\000Threshold counter exceeded a value of 128\000event=0x401ea\000\00000\000\000 */
{ 269625 }, /* pm_thresh_exc_2048\000pmc\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\00000\000\000 */
{ 269710 }, /* pm_thresh_exc_256\000pmc\000Threshold counter exceed a count of 256\000event=0x101e8\000\00000\000\000 */
{ 116150 }, /* pm_thresh_exc_32\000pmc\000Threshold counter exceeded a value of 32\000event=0x201e6\000\00000\000\000 */
{ 269791 }, /* pm_thresh_exc_4096\000pmc\000Threshold counter exceed a count of 4096\000event=0x101e6\000\00000\000\000 */
{ 116231 }, /* pm_thresh_exc_512\000pmc\000Threshold counter exceeded a value of 512\000event=0x201e8\000\00000\000\000 */
{ 269874 }, /* pm_thresh_exc_64\000pmc\000IFU non-branch finished\000event=0x301e8\000\00000\000Threshold counter exceeded a value of 64\000 */
{ 269978 }, /* pm_thresh_met\000pmc\000threshold exceeded\000event=0x101ec\000\00000\000\000 */
{ 270034 }, /* pm_thresh_not_met\000pmc\000Threshold counter did not meet threshold\000event=0x4016e\000\00000\000\000 */
{ 274337 }, /* pm_tlb_miss\000translation\000TLB Miss (I + D)\000event=0x20066\000\00000\000\000 */
{ 268472 }, /* pm_tlbie_fin\000pipeline\000tlbie finished\000event=0x30058\000\00000\000\000 */
{ 256673 }, /* pm_tm_begin_all\000other\000Tm any tbegin\000event=0x20b8\000\00000\000\000 */
{ 256727 }, /* pm_tm_end_all\000other\000Tm any tend\000event=0x20ba\000\00000\000\000 */
{ 256855 }, /* pm_tm_fail_con_tm\000other\000TEXAS fail reason @ completion\000event=0x3088\000\00000\000\000 */
{ 256777 }, /* pm_tm_fail_conf_non_tm\000other\000TEXAS fail reason @ completion\000event=0x3086\000\00000\000\000 */
{ 256928 }, /* pm_tm_fail_disallow\000other\000TM fail disallow\000event=0xe0b2\000\00000\000TM fail disallow42\000 */
{ 257007 }, /* pm_tm_fail_footprint_overflow\000other\000TEXAS fail reason @ completion\000event=0x3084\000\00000\000\000 */
{ 257092 }, /* pm_tm_fail_non_tx_conflict\000other\000Non transactional conflict from LSU whtver gets repoted to texas\000event=0xe0b8\000\00000\000Non transactional conflict from LSU whtver gets repoted to texas42\000 */
{ 257274 }, /* pm_tm_fail_self\000other\000TEXAS fail reason @ completion\000event=0x308a\000\00000\000\000 */
{ 257345 }, /* pm_tm_fail_tlbie\000other\000TLBIE hit bloom filter\000event=0xe0b4\000\00000\000TLBIE hit bloom filter42\000 */
{ 257433 }, /* pm_tm_fail_tx_conflict\000other\000Transactional conflict from LSU, whatever gets reported to texas\000event=0xe0b6\000\00000\000Transactional conflict from LSU, whatever gets reported to texas 42\000 */
{ 257612 }, /* pm_tm_tbegin\000other\000Tm nested tbegin\000event=0x20bc\000\00000\000\000 */
{ 268528 }, /* pm_tm_trans_run_cyc\000pipeline\000run cycles in transactional state\000event=0x10060\000\00000\000\000 */
{ 145056 }, /* pm_tm_trans_run_inst\000frontend\000Instructions completed in transactional state\000event=0x30060\000\00000\000\000 */
{ 257666 }, /* pm_tm_tresume\000other\000Tm resume\000event=0x3080\000\00000\000\000 */
{ 257714 }, /* pm_tm_tsuspend\000other\000Tm suspend\000event=0x20be\000\00000\000\000 */
{ 268610 }, /* pm_tm_tx_pass_run_cyc\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\00000\000run cycles spent in successful transactions\000 */
{ 145151 }, /* pm_tm_tx_pass_run_inst\000frontend\000run instructions spent in successful transactions\000event=0x4e014\000\00000\000\000 */
{ 257764 }, /* pm_up_pref_l3\000other\000Micropartition prefetch\000event=0xe08c\000\00000\000Micropartition prefetch42\000 */
{ 257851 }, /* pm_up_pref_pointer\000other\000Micrpartition pointer prefetches\000event=0xe08e\000\00000\000Micrpartition pointer prefetches42\000 */
{ 257961 }, /* pm_vsu0_16flop\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a4\000\00000\000\000 */
{ 258059 }, /* pm_vsu0_1flop\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa080\000\00000\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finishedDecode into 1,2,4 FLOP according to instr IOP, multiplied by #vector elements according to route( eg x1, x2, x4) Only if instr sends finish to ISU\000 */
{ 258426 }, /* pm_vsu0_2flop\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa098\000\00000\000\000 */
{ 258573 }, /* pm_vsu0_4flop\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09c\000\00000\000\000 */
{ 258752 }, /* pm_vsu0_8flop\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a0\000\00000\000\000 */
{ 258899 }, /* pm_vsu0_complex_issued\000other\000Complex VMX instruction issued\000event=0xb0a4\000\00000\000\000 */
{ 258977 }, /* pm_vsu0_cy_issued\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b4\000\00000\000\000 */
{ 259061 }, /* pm_vsu0_dd_issued\000other\00064BIT Decimal Issued\000event=0xb0a8\000\00000\000\000 */
{ 259124 }, /* pm_vsu0_dp_2flop\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08c\000\00000\000\000 */
{ 259242 }, /* pm_vsu0_dp_fma\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa090\000\00000\000\000 */
{ 259328 }, /* pm_vsu0_dp_fsqrt_fdiv\000other\000DP vector versions of fdiv,fsqrt\000event=0xa094\000\00000\000\000 */
{ 259407 }, /* pm_vsu0_dq_issued\000other\000128BIT Decimal Issued\000event=0xb0ac\000\00000\000\000 */
{ 259471 }, /* pm_vsu0_ex_issued\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b0\000\00000\000\000 */
{ 259557 }, /* pm_vsu0_fin\000other\000VSU0 Finished an instruction\000event=0xa0bc\000\00000\000\000 */
{ 259622 }, /* pm_vsu0_fma\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa084\000\00000\000\000 */
{ 259735 }, /* pm_vsu0_fpscr\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb098\000\00000\000\000 */
{ 259826 }, /* pm_vsu0_fsqrt_fdiv\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa088\000\00000\000\000 */
{ 259929 }, /* pm_vsu0_permute_issued\000other\000Permute VMX Instruction Issued\000event=0xb090\000\00000\000\000 */
{ 260007 }, /* pm_vsu0_scalar_dp_issued\000other\000Double Precision scalar instruction issued on Pipe0\000event=0xb088\000\00000\000\000 */
{ 260108 }, /* pm_vsu0_simple_issued\000other\000Simple VMX instruction issued\000event=0xb094\000\00000\000\000 */
{ 260184 }, /* pm_vsu0_single\000other\000FPU single precision\000event=0xa0a8\000\00000\000\000 */
{ 260244 }, /* pm_vsu0_sq\000other\000Store Vector Issued\000event=0xb09c\000\00000\000\000 */
{ 260299 }, /* pm_vsu0_stf\000other\000FPU store (SP or DP) issued on Pipe0\000event=0xb08c\000\00000\000\000 */
{ 260372 }, /* pm_vsu0_vector_dp_issued\000other\000Double Precision vector instruction issued on Pipe0\000event=0xb080\000\00000\000\000 */
{ 260473 }, /* pm_vsu0_vector_sp_issued\000other\000Single Precision vector instruction issued (executed)\000event=0xb084\000\00000\000\000 */
{ 260576 }, /* pm_vsu1_16flop\000other\000Sixteen flops operation (SP vector versions of fdiv,fsqrt)\000event=0xa0a6\000\00000\000\000 */
{ 260674 }, /* pm_vsu1_1flop\000other\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation finished\000event=0xa082\000\00000\000\000 */
{ 260804 }, /* pm_vsu1_2flop\000other\000two flops operation (scalar fmadd, fnmadd, fmsub, fnmsub and DP vector versions of single flop instructions)\000event=0xa09a\000\00000\000\000 */
{ 260951 }, /* pm_vsu1_4flop\000other\000four flops operation (scalar fdiv, fsqrt, DP vector version of fmadd, fnmadd, fmsub, fnmsub, SP vector versions of single flop instructions)\000event=0xa09e\000\00000\000\000 */
{ 261130 }, /* pm_vsu1_8flop\000other\000eight flops operation (DP vector versions of fdiv,fsqrt and SP vector versions of fmadd,fnmadd,fmsub,fnmsub)\000event=0xa0a2\000\00000\000\000 */
{ 261277 }, /* pm_vsu1_complex_issued\000other\000Complex VMX instruction issued\000event=0xb0a6\000\00000\000\000 */
{ 261355 }, /* pm_vsu1_cy_issued\000other\000Cryptographic instruction RFC02196 Issued\000event=0xb0b6\000\00000\000\000 */
{ 261439 }, /* pm_vsu1_dd_issued\000other\00064BIT Decimal Issued\000event=0xb0aa\000\00000\000\000 */
{ 261502 }, /* pm_vsu1_dp_2flop\000other\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0xa08e\000\00000\000\000 */
{ 261620 }, /* pm_vsu1_dp_fma\000other\000DP vector version of fmadd,fnmadd,fmsub,fnmsub\000event=0xa092\000\00000\000\000 */
{ 261706 }, /* pm_vsu1_dp_fsqrt_fdiv\000other\000DP vector versions of fdiv,fsqrt\000event=0xa096\000\00000\000\000 */
{ 261785 }, /* pm_vsu1_dq_issued\000other\000128BIT Decimal Issued\000event=0xb0ae\000\00000\000\000 */
{ 261849 }, /* pm_vsu1_ex_issued\000other\000Direct move 32/64b VRFtoGPR RFC02206 Issued\000event=0xb0b2\000\00000\000\000 */
{ 261935 }, /* pm_vsu1_fin\000other\000VSU1 Finished an instruction\000event=0xa0be\000\00000\000\000 */
{ 262000 }, /* pm_vsu1_fma\000other\000two flops operation (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only!\000event=0xa086\000\00000\000\000 */
{ 262113 }, /* pm_vsu1_fpscr\000other\000Move to/from FPSCR type instruction issued on Pipe 0\000event=0xb09a\000\00000\000\000 */
{ 262204 }, /* pm_vsu1_fsqrt_fdiv\000other\000four flops operation (fdiv,fsqrt) Scalar Instructions only!\000event=0xa08a\000\00000\000\000 */
{ 262307 }, /* pm_vsu1_permute_issued\000other\000Permute VMX Instruction Issued\000event=0xb092\000\00000\000\000 */
{ 262385 }, /* pm_vsu1_scalar_dp_issued\000other\000Double Precision scalar instruction issued on Pipe1\000event=0xb08a\000\00000\000\000 */
{ 262486 }, /* pm_vsu1_simple_issued\000other\000Simple VMX instruction issued\000event=0xb096\000\00000\000\000 */
{ 262562 }, /* pm_vsu1_single\000other\000FPU single precision\000event=0xa0aa\000\00000\000\000 */
{ 262622 }, /* pm_vsu1_sq\000other\000Store Vector Issued\000event=0xb09e\000\00000\000\000 */
{ 262677 }, /* pm_vsu1_stf\000other\000FPU store (SP or DP) issued on Pipe1\000event=0xb08e\000\00000\000\000 */
{ 262750 }, /* pm_vsu1_vector_dp_issued\000other\000Double Precision vector instruction issued on Pipe1\000event=0xb082\000\00000\000\000 */
{ 262851 }, /* pm_vsu1_vector_sp_issued\000other\000Single Precision vector instruction issued (executed)\000event=0xb086\000\00000\000\000 */

};

const struct pmu_table_entry pmu_events__power8[] = {
{
     .entries = pmu_events__power8_default_core,
     .num_entries = ARRAY_SIZE(pmu_events__power8_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__power8_default_core[] = {
{ 453887 }, /* mem_ecc_delay_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_MEM_ECC_DELAY / PM_RUN_INST_CMPL\000\000\000\000\000\000\000\00000 */
{ 454110 }, /* ntcg_all_fin_cpi\000cpi_breakdown\000PM_NTCG_ALL_FIN / PM_RUN_INST_CMPL\000\000\000\000\000\000\000\00000 */
{ 454185 }, /* ntcg_flush_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NTCG_FLUSH / PM_RUN_INST_CMPL\000\000\000\000\000\000\000\00000 */
{ 495340 }, /* any_centaur_ld_hit_ratio\000\000PM_DATA_FROM_MEMORY / PM_LD_REF_L1\000\000Fraction of hits on any Centaur (local, remote, or distant) on either L4 or DRAM per L1 load ref\000\000\000\000\000\00000 */
{ 446427 }, /* any_pump_mpred_percent\000bus_stats\000PM_PUMP_MPRED * 100 / (PM_PUMP_CPRED + PM_PUMP_MPRED)\000\000Percent of chip+group+sys pumps that were incorrectly predicted\000\000\000\000\000\00000 */
{ 481197 }, /* average_dl1miss_latency\000latency\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000\000average L1 miss latency using marked events\000\000\000\000\000\00000 */
{ 481323 }, /* average_il1_miss_latency\000latency\000PM_IC_DEMAND_CYC / PM_IC_DEMAND_REQ\000\000Average icache miss latency\000\000\000\000\000\00000 */
{ 481428 }, /* average_sync_cyc\000latency\000PM_LSU_SRQ_SYNC_CYC / PM_LSU_SRQ_SYNC\000\000average service time for SYNC\000\000\000\000\000\00000 */
{ 481529 }, /* avg_lmq_life_time\000latency\000PM_LSU_LMQ_S0_VALID / PM_LSU_LMQ_S0_ALLOC\000\000Cycles LMQ slot0 was active on an average\000\000\000\000\000\00000 */
{ 481647 }, /* avg_lrq_life_time_even\000latency\000PM_LSU_LRQ_S0_VALID / PM_LSU_LRQ_S0_ALLOC\000\000Average number of cycles LRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000\00000 */
{ 481823 }, /* avg_lrq_life_time_odd\000latency\000PM_LSU_LRQ_S43_VALID / PM_LSU_LRQ_S43_ALLOC\000\000Average number of cycles LRQ stays active for one load.  Slot 43 is valid ONLY FOR ODD THREADS\000\000\000\000\000\00000 */
{ 482000 }, /* avg_srq_life_time_even\000latency\000PM_LSU_SRQ_S0_VALID / PM_LSU_SRQ_S0_ALLOC\000\000Average number of cycles SRQ stays active for one load.  Slot 0 is VALID ONLY FOR EVEN THREADS\000\000\000\000\000\00000 */
{ 482176 }, /* avg_srq_life_time_odd\000latency\000PM_LSU_SRQ_S39_VALID / PM_LSU_SRQ_S39_ALLOC\000\000Average number of cycles SRQ stays active for one load.  Slot 39 is valid ONLY FOR ODD THREADS\000\000\000\000\000\00000 */
{ 480686 }, /* avg_stores_gathered\000l2_stats\000PM_ST_CMPL / (PM_L2_ST / 2)\000\000Average number of stores that gather in the store buffer before being sent to an L2 RC machine\000\000\000\000\000\00000 */
{ 495506 }, /* base_completion_cpi\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000\000Base Completion Cycles\000\000\000\000\000\00000 */
{ 444320 }, /* bc_8_branch_ratio_percent\000branch_prediction\000PM_BR_BC_8_CONV / PM_BRU_FIN * 100\000\000% of finished branches that were treated as BC+8\000\000\000\000\000\00000 */
{ 444456 }, /* bc_8_not_converted_branch_ratio_percent\000branch_prediction\000PM_BR_BC_8 / PM_BRU_FIN * 100\000\000% of finished branches that were pairable but not treated as BC+8\000\000\000\000\000\00000 */
{ 482353 }, /* bkill_latency\000latency\000PM_MRK_FAB_RSP_BKILL_CYC / PM_MRK_FAB_RSP_BKILL\000\000Marked background kill latency, measured in L2\000\000\000\000\000\00000 */
{ 495595 }, /* bkill_ratio_percent\000\000PM_MRK_FAB_RSP_BKILL_CYC / PM_MRK_FAB_RSP_BKILL\000\000Marked background kill latency, measured in L2\000\000\000\000\000\00000 */
{ 444618 }, /* br_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CMPL / (PM_BR_PRED_BR0 + PM_BR_PRED_BR1) * 100\000\000Percent of mispredicted branches out of all predicted (correctly and incorrectly) branches that completed\000\000\000\000\000\00000 */
{ 469683 }, /* br_mpred_flush_rate_percent\000general\000PM_FLUSH_BR_MPRED / PM_RUN_INST_CMPL * 100\000\000Branch Mispredict flushes per instruction\000\000\000\000\000\00000 */
{ 444834 }, /* branch_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_CMPL / PM_RUN_INST_CMPL * 100\000\000% of Branch miss predictions per instruction\000\000\000\000\000\00000 */
{ 476922 }, /* branches_per_inst\000instruction_mix\000PM_BRU_FIN / PM_RUN_INST_CMPL\000\000% Branches per instruction\000\000\000\000\000\00000 */
{ 447089 }, /* bru_cru_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_BRU_CRU / PM_RUN_INST_CMPL\000\000Cycles stalled due to CRU or BRU operations\000\000\000\000\000\00000 */
{ 447215 }, /* bru_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000\000Cycles stalled due to ISU Branch Operations\000\000\000\000\000\00000 */
{ 444978 }, /* ccache_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_CCACHE / PM_RUN_INST_CMPL * 100\000\000Count cache branch misprediction per instruction\000\000\000\000\000\00000 */
{ 445128 }, /* ccache_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CCACHE / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1) * 100\000\000Percent of count catch mispredictions out of all completed branches that required count cache predictionn\000\000\000\000\000\00000 */
{ 446586 }, /* chip_pump_cpred_percent\000bus_stats\000PM_CHIP_PUMP_CPRED * 100 / PM_L2_CHIP_PUMP\000\000Percent of chip pumps that were correctly predicted as chip pumps the first time\000\000\000\000\000\00000 */
{ 447333 }, /* completion_cpi\000cpi_breakdown\000PM_GRP_CMPL / PM_RUN_INST_CMPL\000\000Cycles in which a Group Completed\000\000\000\000\000\00000 */
{ 447435 }, /* coq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_COQ_FULL / PM_RUN_INST_CMPL\000\000Cycles stalled by CO queue full\000\000\000\000\000\00000 */
{ 469812 }, /* cpi\000general\000PM_CYC / PM_INST_CMPL\000\000Cycles per instruction\000\000\000\000\000\00000 */
{ 445364 }, /* cr_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_CR / PM_RUN_INST_CMPL * 100\000\000CR MisPredictions per Instruction\000\000\000\000\000\00000 */
{ 447551 }, /* cru_stall_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_BRU_CRU - PM_CMPLU_STALL_BRU) / PM_RUN_INST_CMPL\000\000Cycles stalled due to CRU Operations\000\000\000\000\000\00000 */
{ 495719 }, /* custom_secs\000\000PM_RUN_CYC\000\000cycles\000\000\000\000\000\00000 */
{ 469877 }, /* cyc_grp_completed_percent\000general\000PM_GRP_CMPL / PM_CYC * 100\000\000Percentage Cycles a group completed\000\000\000\000\000\00000 */
{ 469982 }, /* cyc_grp_dispatched_percent\000general\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000\000Percentage Cycles a group dispatched\000\000\000\000\000\00000 */
{ 470095 }, /* cyc_per_group\000general\000PM_CYC / PM_1PLUS_PPC_CMPL\000\000Cycles per group\000\000\000\000\000\00000 */
{ 464839 }, /* dcache_miss_cpi_percent\000estimated_dcache_miss_cpi\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL / (PM_RUN_CYC / PM_RUN_INST_CMPL) * 100\000\000dL1 miss portion of CPI\000\000\000\000\000\00000 */
{ 482478 }, /* dclaim_latency\000latency\000PM_MRK_FAB_RSP_DCLAIM_CYC / PM_MRK_FAB_RSP_DCLAIM\000\000Marked dclaim latency, measured in L2\000\000\000\000\000\00000 */
{ 494170 }, /* derat_16g_miss_rate_percent\000translation\000100 * PM_DERAT_MISS_16G / PM_RUN_INST_CMPL\000\000% DERAT miss ratio for 16G page per inst\000\000\000\000\000\00000 */
{ 494302 }, /* derat_16g_miss_ratio\000translation\000PM_DERAT_MISS_16G / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 16G page\000\000\000\000\000\00000 */
{ 494411 }, /* derat_16m_miss_rate_percent\000translation\000PM_DERAT_MISS_16M * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss rate for 16M page per inst\000\000\000\000\000\00000 */
{ 494542 }, /* derat_16m_miss_ratio\000translation\000PM_DERAT_MISS_16M / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 16M page\000\000\000\000\000\00000 */
{ 494651 }, /* derat_4k_miss_rate_percent\000translation\000PM_DERAT_MISS_4K * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss rate for 4K page per inst\000\000\000\000\000\00000 */
{ 494779 }, /* derat_4k_miss_ratio\000translation\000PM_DERAT_MISS_4K / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 4K page\000\000\000\000\000\00000 */
{ 494885 }, /* derat_64k_miss_rate_percent\000translation\000PM_DERAT_MISS_64K * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss ratio for 64K page per inst\000\000\000\000\000\00000 */
{ 495017 }, /* derat_64k_miss_ratio\000translation\000PM_DERAT_MISS_64K / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 64K page\000\000\000\000\000\00000 */
{ 488949 }, /* derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000\000DERAT Miss Rate (per run  instruction)(%)\000\000\000\000\000\00000 */
{ 491710 }, /* derat_miss_reload_percent\000pteg_reloads_percent_per_ref\000PM_DTLB_MISS * 100 / PM_LSU_DERAT_MISS\000\000% of DERAT misses that result in an ERAT reload\000\000\000\000\000\00000 */
{ 470169 }, /* disp_flush_rate_percent\000general\000PM_FLUSH_DISP / PM_RUN_INST_CMPL * 100\000\000GCT empty cycles\000\000\000\000\000\00000 */
{ 495758 }, /* distant_centaur_ld_hit_ratio\000\000(PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4) / PM_LD_REF_L1\000\000Fraction of hits on a distant chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000\00000 */
{ 460842 }, /* dl1_miss_reloads_percent\000dl1_reloads_percent_per_ref\000PM_L1_DCACHE_RELOAD_VALID * 100 / PM_LD_MISS_L1\000\000% of DL1 misses that result in a cache reload\000\000\000\000\000\00000 */
{ 460997 }, /* dl1_reload_from_dl2l3_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 456574 }, /* dl1_reload_from_dl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000\00000 */
{ 461178 }, /* dl1_reload_from_dl2l3_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 456757 }, /* dl1_reload_from_dl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000\00000 */
{ 461357 }, /* dl1_reload_from_dl4_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000\00000 */
{ 456938 }, /* dl1_reload_from_dl4_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000\00000 */
{ 461509 }, /* dl1_reload_from_dmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant Memory\000\000\000\000\000\00000 */
{ 457092 }, /* dl1_reload_from_dmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant Memory per Inst\000\000\000\000\000\00000 */
{ 461667 }, /* dl1_reload_from_l21_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L21_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 457252 }, /* dl1_reload_from_l21_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 461835 }, /* dl1_reload_from_l21_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L21_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 457426 }, /* dl1_reload_from_l21_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 462003 }, /* dl1_reload_from_l2_lhs_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L2 with a Load-Hit-Store conflict\000\000\000\000\000\00000 */
{ 457600 }, /* dl1_reload_from_l2_lhs_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 load hits per instruction where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000\00000 */
{ 495924 }, /* dl1_reload_from_l2_miss_percent\000\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads that came from the L3 and beyond\000\000\000\000\000\00000 */
{ 457830 }, /* dl1_reload_from_l2_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L2 per Inst\000\000\000\000\000\00000 */
{ 462207 }, /* dl1_reload_from_l2_no_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L2 with no conflicts\000\000\000\000\000\00000 */
{ 457983 }, /* dl1_reload_from_l2_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 load hits per instruction where the L2 did not experience a conflict\000\000\000\000\000\00000 */
{ 462396 }, /* dl1_reload_from_l2_other_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L2 with some conflict other than Load-Hit-Store\000\000\000\000\000\00000 */
{ 458203 }, /* dl1_reload_from_l2_other_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 load hits per instruction where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000\00000 */
{ 462623 }, /* dl1_reload_from_l2_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from L2\000\000\000\000\000\00000 */
{ 458456 }, /* dl1_reload_from_l2_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L2 per Inst\000\000\000\000\000\00000 */
{ 462761 }, /* dl1_reload_from_l31_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L31_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 458600 }, /* dl1_reload_from_l31_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3 M state, other core per Inst\000\000\000\000\000\00000 */
{ 496069 }, /* dl1_reload_from_l31_rate_percent\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 462929 }, /* dl1_reload_from_l31_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L31_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 458782 }, /* dl1_reload_from_l31_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3 S tate, other core per Inst\000\000\000\000\000\00000 */
{ 463097 }, /* dl1_reload_from_l3_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L3 where the load collided with a pending prefetch\000\000\000\000\000\00000 */
{ 458963 }, /* dl1_reload_from_l3_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3_DISP_CONFLICT * 100 / PM_RUN_INST_CMPL\000\000Percentage of L3 load hits per instruction where the load collided with a pending prefetch\000\000\000\000\000\00000 */
{ 496236 }, /* dl1_reload_from_l3_mepf_percent\000\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L3 where the lines were brought into the L3 by a prefetch operation\000\000\000\000\000\00000 */
{ 463315 }, /* dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000\000Percentage of L3 load hits per instruction where the line was brought into the L3 by a prefetch operation\000\000\000\000\000\00000 */
{ 496431 }, /* dl1_reload_from_l3_miss_percent\000\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from beyond the local L3\000\000\000\000\000\00000 */
{ 459187 }, /* dl1_reload_from_l3_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L3 per Inst\000\000\000\000\000\00000 */
{ 463540 }, /* dl1_reload_from_l3_no_conflict_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000Percentage of DL1 reloads from L3 without conflicts\000\000\000\000\000\00000 */
{ 459340 }, /* dl1_reload_from_l3_no_conflict_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3_NO_CONFLICT * 100 / PM_RUN_INST_CMPL\000\000Percentage of L3 load hits per instruction where the L3 did not experience a conflict\000\000\000\000\000\00000 */
{ 463729 }, /* dl1_reload_from_l3_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from L3\000\000\000\000\000\00000 */
{ 459560 }, /* dl1_reload_from_l3_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from L3 per Inst\000\000\000\000\000\00000 */
{ 463867 }, /* dl1_reload_from_ll4_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000\00000 */
{ 459704 }, /* dl1_reload_from_ll4_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000\00000 */
{ 464017 }, /* dl1_reload_from_lmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_LMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Local Memory\000\000\000\000\000\00000 */
{ 459856 }, /* dl1_reload_from_lmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Local Memory per Inst\000\000\000\000\000\00000 */
{ 464173 }, /* dl1_reload_from_rl2l3_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 460014 }, /* dl1_reload_from_rl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 464353 }, /* dl1_reload_from_rl2l3_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 460192 }, /* dl1_reload_from_rl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 464531 }, /* dl1_reload_from_rl4_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000\00000 */
{ 460370 }, /* dl1_reload_from_rl4_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000\00000 */
{ 464682 }, /* dl1_reload_from_rmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote Memory\000\000\000\000\000\00000 */
{ 460527 }, /* dl1_reload_from_rmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000\00000 */
{ 465007 }, /* dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482597 }, /* dl2l3_mod_latency\000latency\000PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000 */
{ 496568 }, /* dl2l3_mod_ld_hit_ratio\000\000PM_DATA_FROM_DL2L3_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000\00000 */
{ 465323 }, /* dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482723 }, /* dl2l3_shr_latency\000latency\000PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR\000\000Marked L2L3 distant Load latency\000\000\000\000\000\00000 */
{ 496752 }, /* dl2l3_shr_ld_hit_ratio\000\000PM_DATA_FROM_DL2L3_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a distant chip per L1 load ref\000\000\000\000\000\00000 */
{ 465639 }, /* dl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL4 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482850 }, /* dl4_latency\000latency\000PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4\000\000Distant L4 average load latency\000\000\000\000\000\00000 */
{ 496924 }, /* dl4_ld_hit_ratio\000\000PM_DATA_FROM_DL4 / PM_LD_REF_L1\000\000Fraction of hits on a distant Centaur's cache per L1 load ref\000\000\000\000\000\00000 */
{ 465918 }, /* dmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DMEM / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482958 }, /* dmem_latency\000latency\000PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM\000\000Marked Dmem Load latency\000\000\000\000\000\00000 */
{ 497044 }, /* dmem_ld_hit_ratio\000\000PM_DATA_FROM_DMEM / PM_LD_REF_L1\000\000Fraction of hits on a distant Centaur's DRAM per L1 load ref\000\000\000\000\000\00000 */
{ 497165 }, /* dpteg_from_l2_rate_percent\000\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Rate of DERAT reloads from L2\000\000\000\000\000\00000 */
{ 497273 }, /* dpteg_from_l3_rate_percent\000\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Rate of DERAT reloads from L3\000\000\000\000\000\00000 */
{ 495126 }, /* dslb_miss_rate_percent\000translation\000PM_DSLB_MISS * 100 / PM_RUN_INST_CMPL\000\000% DSLB_Miss_Rate per inst\000\000\000\000\000\00000 */
{ 470265 }, /* dtlb_miss_rate_percent\000general\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000\000% DTLB miss rate per inst\000\000\000\000\000\00000 */
{ 486866 }, /* erat_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_ERAT_MISS * 100 / PM_RUN_INST_CMPL\000\000ERAT miss reject ratio\000\000\000\000\000\00000 */
{ 486983 }, /* erat_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT_ERAT_MISS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000\000ERAT miss reject ratio\000\000\000\000\000\00000 */
{ 497381 }, /* expansion_overhead_cpi\000\000PM_GRP_CMPL / PM_RUN_INST_CMPL - PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000\000Overhead of expansion cycles\000\000\000\000\000\00000 */
{ 483062 }, /* exposed_dl1miss_latency\000latency\000PM_MRK_LD_MISS_EXPOSED_CYC / PM_MRK_LD_MISS_EXPOSED\000\000estimated exposed miss latency for dL1 misses, ie load miss when we were NTC\000\000\000\000\000\00000 */
{ 497512 }, /* fixed_in_lsu_per_inst\000\000PM_LSU_FX_FIN / PM_RUN_INST_CMPL\000\000Total Fixed point operations executded in the Load/Store Unit following a load/store operation\000\000\000\000\000\00000 */
{ 477021 }, /* fixed_per_inst\000instruction_mix\000(PM_FXU0_FIN + PM_FXU1_FIN) / PM_RUN_INST_CMPL\000\000Total Fixed point operations\000\000\000\000\000\00000 */
{ 470368 }, /* flush_rate_percent\000general\000PM_FLUSH * 100 / PM_RUN_INST_CMPL\000\000Flush rate (%)\000\000\000\000\000\00000 */
{ 447689 }, /* flush_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FLUSH / PM_RUN_INST_CMPL\000\000Cycles stalled by flushes\000\000\000\000\000\00000 */
{ 477136 }, /* fxu0_balance\000instruction_mix\000PM_FXU0_FIN / (PM_FXU0_FIN + PM_FXU1_FIN)\000\000FXU0 balance\000\000\000\000\000\00000 */
{ 477228 }, /* fxu0_fin\000instruction_mix\000PM_FXU0_FIN / PM_RUN_CYC\000\000Fraction of cycles that FXU0 is in use\000\000\000\000\000\00000 */
{ 477325 }, /* fxu0_only_busy\000instruction_mix\000PM_FXU0_BUSY_FXU1_IDLE / PM_CYC\000\000FXU0 only Busy\000\000\000\000\000\00000 */
{ 477411 }, /* fxu1_fin\000instruction_mix\000PM_FXU1_FIN / PM_RUN_CYC\000\000Fraction of cycles that FXU1 is in use\000\000\000\000\000\00000 */
{ 477508 }, /* fxu1_only_busy\000instruction_mix\000PM_FXU1_BUSY_FXU0_IDLE / PM_CYC\000\000FXU1 only Busy\000\000\000\000\000\00000 */
{ 477594 }, /* fxu_both_busy\000instruction_mix\000PM_FXU_BUSY / PM_CYC\000\000Both FXU Busy\000\000\000\000\000\00000 */
{ 477667 }, /* fxu_both_idle\000instruction_mix\000PM_FXU_IDLE / PM_CYC\000\000Both FXU Idle\000\000\000\000\000\00000 */
{ 447793 }, /* fxu_multi_cyc_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000\000Cycles stalled by FXU Multi-Cycle Instructions\000\000\000\000\000\00000 */
{ 447921 }, /* fxu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000\000Cycles stalled by FXU\000\000\000\000\000\00000 */
{ 448017 }, /* fxu_stall_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000\000Other cycles stalled by FXU\000\000\000\000\000\00000 */
{ 448168 }, /* gct_empty_br_mpred_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000\000Cycles GCT empty due to Branch Mispredicts\000\000\000\000\000\00000 */
{ 448298 }, /* gct_empty_br_mpred_ic_miss_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000\000Cycles GCT empty due to Branch Mispredicts and Icache Misses\000\000\000\000\000\00000 */
{ 448461 }, /* gct_empty_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL\000\000GCT empty cycles\000\000\000\000\000\00000 */
{ 448551 }, /* gct_empty_disp_held_cpi\000cpi_breakdown\000(PM_GCT_NOSLOT_DISP_HELD_MAP + PM_GCT_NOSLOT_DISP_HELD_SRQ + PM_GCT_NOSLOT_DISP_HELD_ISSQ + PM_GCT_NOSLOT_DISP_HELD_OTHER) / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held\000\000\000\000\000\00000 */
{ 448780 }, /* gct_empty_disp_held_issq_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to issue queue\000\000\000\000\000\00000 */
{ 448939 }, /* gct_empty_disp_held_map_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_MAP / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to maps\000\000\000\000\000\00000 */
{ 449089 }, /* gct_empty_disp_held_other_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_OTHER / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to syncs and other effects\000\000\000\000\000\00000 */
{ 449262 }, /* gct_empty_disp_held_srq_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_DISP_HELD_SRQ / PM_RUN_INST_CMPL\000\000Cycles GCT empty where dispatch was held due to SRQ\000\000\000\000\000\00000 */
{ 449411 }, /* gct_empty_ic_miss_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by GCT empty due to Icache misses\000\000\000\000\000\00000 */
{ 449545 }, /* gct_empty_ic_miss_l2l3_cpi\000cpi_breakdown\000(PM_GCT_NOSLOT_IC_MISS - PM_GCT_NOSLOT_IC_L3MISS) / PM_RUN_INST_CMPL\000\000Cycles stalled by GCT empty due to Icache misses that resolve in the local L2 or L3\000\000\000\000\000\00000 */
{ 449747 }, /* gct_empty_ic_miss_l3miss_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by GCT empty due to Icache misses that resolve off-chip\000\000\000\000\000\00000 */
{ 449912 }, /* gct_empty_other_cpi\000cpi_breakdown\000PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL - (PM_GCT_NOSLOT_DISP_HELD_MAP / PM_RUN_INST_CMPL + PM_GCT_NOSLOT_DISP_HELD_SRQ / PM_RUN_INST_CMPL + PM_GCT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL + PM_GCT_NOSLOT_DISP_HELD_OTHER / PM_RUN_INST_CMPL)\000\000Other GCT empty cycles\000\000\000\000\000\00000 */
{ 497671 }, /* gct_empty_percent\000\000PM_GCT_NOSLOT_CYC / PM_RUN_CYC * 100\000\000GCT empty cycles\000\000\000\000\000\00000 */
{ 470452 }, /* gct_util_11to14_slots_percent\000general\000PM_GCT_UTIL_11_14_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (11 to 14) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000 */
{ 470652 }, /* gct_util_15to17_slots_percent\000general\000PM_GCT_UTIL_15_17_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (15 to 17) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000 */
{ 470852 }, /* gct_util_18plus_slots_percent\000general\000PM_GCT_UTIL_18_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization 18+ as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000 */
{ 471042 }, /* gct_util_1to2_slots_percent\000general\000PM_GCT_UTIL_1_2_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (1 to 2) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000 */
{ 471236 }, /* gct_util_3to6_slots_percent\000general\000PM_GCT_UTIL_3_6_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (3 to 6) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000 */
{ 471430 }, /* gct_util_7to10_slots_percent\000general\000PM_GCT_UTIL_7_10_ENTRIES / (PM_RUN_CYC - PM_GCT_NOSLOT_CYC) * 100\000\000GCT slot utilization (7 to 10) as a % of cycles this thread had at least 1 slot valid\000\000\000\000\000\00000 */
{ 446752 }, /* group_pump_cpred_percent\000bus_stats\000PM_GRP_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000\000Percent of group pumps that were correctly predicted as group pumps the first time\000\000\000\000\000\00000 */
{ 471627 }, /* group_size\000general\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Avg. group size\000\000\000\000\000\00000 */
{ 450353 }, /* hwsync_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_HWSYNC / PM_RUN_INST_CMPL\000\000Cycles stalled by heavyweight syncs\000\000\000\000\000\00000 */
{ 477925 }, /* icache_miss_reload\000instruction_stats_percent_per_ref\000(PM_L1_ICACHE_MISS - PM_IC_PREF_WRITE) / PM_L1_ICACHE_MISS\000\000Icache Fetchs per Icache Miss\000\000\000\000\000\00000 */
{ 478075 }, /* icache_pref_percent\000instruction_stats_percent_per_ref\000PM_IC_PREF_WRITE * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads due to prefetch\000\000\000\000\000\00000 */
{ 478216 }, /* inst_from_dl2l3_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 474047 }, /* inst_from_dl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000\00000 */
{ 478388 }, /* inst_from_dl2l3_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 474234 }, /* inst_from_dl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000\00000 */
{ 478558 }, /* inst_from_dl4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L4\000\000\000\000\000\00000 */
{ 474419 }, /* inst_from_dl4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L4 per Inst\000\000\000\000\000\00000 */
{ 478701 }, /* inst_from_dmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant Memory\000\000\000\000\000\00000 */
{ 474577 }, /* inst_from_dmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant Memory per Inst\000\000\000\000\000\00000 */
{ 478850 }, /* inst_from_l21_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L21_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 474741 }, /* inst_from_l21_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 479013 }, /* inst_from_l21_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L21_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 474919 }, /* inst_from_l21_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 479176 }, /* inst_from_l2_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from L2\000\000\000\000\000\00000 */
{ 475097 }, /* inst_from_l2_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from L2 per Inst\000\000\000\000\000\00000 */
{ 479309 }, /* inst_from_l31_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L31_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 475245 }, /* inst_from_l31_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 479472 }, /* inst_from_l31_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L31_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 475423 }, /* inst_from_l31_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L3 other core per Inst\000\000\000\000\000\00000 */
{ 479635 }, /* inst_from_l3_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from L3\000\000\000\000\000\00000 */
{ 475600 }, /* inst_from_l3_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from L3 per Inst\000\000\000\000\000\00000 */
{ 479768 }, /* inst_from_ll4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_LL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Local L4\000\000\000\000\000\00000 */
{ 475748 }, /* inst_from_ll4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Local L4 per Inst\000\000\000\000\000\00000 */
{ 479909 }, /* inst_from_lmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Local Memory\000\000\000\000\000\00000 */
{ 475904 }, /* inst_from_lmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Local Memory per Inst\000\000\000\000\000\00000 */
{ 480056 }, /* inst_from_rl2l3_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 476066 }, /* inst_from_rl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L2 or L3 (Modified) per Inst\000\000\000\000\000\00000 */
{ 480227 }, /* inst_from_rl2l3_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 476252 }, /* inst_from_rl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L2 or L3 (Shared) per Inst\000\000\000\000\000\00000 */
{ 480396 }, /* inst_from_rl4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L4\000\000\000\000\000\00000 */
{ 476436 }, /* inst_from_rl4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L4 per Inst\000\000\000\000\000\00000 */
{ 480538 }, /* inst_from_rmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote Memory\000\000\000\000\000\00000 */
{ 476593 }, /* inst_from_rmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote Memory per Inst\000\000\000\000\000\00000 */
{ 471703 }, /* inst_per_group\000general\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Instructions per group\000\000\000\000\000\00000 */
{ 471790 }, /* ipc\000general\000PM_INST_CMPL / PM_CYC\000\000Instructions per cycles\000\000\000\000\000\00000 */
{ 497752 }, /* ipteg_from_l2_rate_percent\000\000PM_IPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from L2\000\000\000\000\000\00000 */
{ 497860 }, /* ipteg_from_l3_rate_percent\000\000PM_IPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from L3\000\000\000\000\000\00000 */
{ 497968 }, /* ipteg_from_ll4_rate_percent\000\000PM_IPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from local memory\000\000\000\000\000\00000 */
{ 498088 }, /* ipteg_from_lmem_rate_percent\000\000PM_IPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from local memory\000\000\000\000\000\00000 */
{ 495233 }, /* islb_miss_rate_percent\000translation\000PM_ISLB_MISS * 100 / PM_RUN_INST_CMPL\000\000% ISLB miss rate per inst\000\000\000\000\000\00000 */
{ 471856 }, /* itlb_miss_rate_percent\000general\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000\000% ITLB miss rate per inst\000\000\000\000\000\00000 */
{ 476756 }, /* l1_inst_miss_rate_percent\000instruction_misses_percent_per_inst\000PM_L1_ICACHE_MISS * 100 / PM_RUN_INST_CMPL\000\000Instruction Cache Miss Rate (Per run Instruction)(%)\000\000\000\000\000\00000 */
{ 498210 }, /* l1_ld_hit_ratio\000\000(PM_LD_REF_L1 - PM_LD_MISS_L1) / PM_LD_REF_L1\000\000Fraction of L1 hits per load ref\000\000\000\000\000\00000 */
{ 460686 }, /* l1_ld_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_LD_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L1 demand load misses per run instruction\000\000\000\000\000\00000 */
{ 498314 }, /* l1_ld_miss_ratio\000\000PM_LD_MISS_L1 / PM_LD_REF_L1\000\000Fraction of L1 load misses per L1 load ref\000\000\000\000\000\00000 */
{ 471959 }, /* l1_ld_miss_ratio_percent\000general\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000\000Percentage of L1 load misses per L1 load ref\000\000\000\000\000\00000 */
{ 472080 }, /* l1_st_miss_rate_percent\000general\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L1 store misses per run instruction\000\000\000\000\000\00000 */
{ 472209 }, /* l1_st_miss_ratio_percent\000general\000PM_ST_MISS_L1 / PM_ST_FIN * 100\000\000Percentage of L1 store misses per L1 store ref\000\000\000\000\000\00000 */
{ 466206 }, /* l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 483231 }, /* l21_mod_latency\000latency\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000\000Average load latency for all marked demand loads that came from L2.1 in the M state\000\000\000\000\000\00000 */
{ 466503 }, /* l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 483403 }, /* l21_shr_latency\000latency\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000\000Average load latency for all marked demand loads that came from L2.1 in the S state\000\000\000\000\000\00000 */
{ 498412 }, /* l2_1_ld_hit_ratio\000\000(PM_DATA_FROM_L21_MOD + PM_DATA_FROM_L21_SHR) / PM_LD_REF_L1\000\000Fraction of hits on another core's L2 on the same chip per L1 load ref\000\000\000\000\000\00000 */
{ 498571 }, /* l2_1_mod_ld_hit_ratio\000\000PM_DATA_FROM_L21_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000\00000 */
{ 498746 }, /* l2_1_shr_ld_hit_ratio\000\000PM_DATA_FROM_L21_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on another core's L2 on the same chip per L1 load ref\000\000\000\000\000\00000 */
{ 498909 }, /* l2_co_usage\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000\000Average number of Castout machines used.  1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000\00000 */
{ 466800 }, /* l2_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L2 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 483575 }, /* l2_disp_conflict_ldhitst_latency\000latency\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_LDHITST\000\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time due to load-hit-store\000\000\000\000\000\00000 */
{ 483859 }, /* l2_disp_conflict_other_latency\000latency\000PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER_CYC / PM_MRK_DATA_FROM_L2_DISP_CONFLICT_OTHER\000\000Average load latency for all marked demand loads that came from the L2 and suffered a conflict at RC machine dispatch time NOT due load-hit-store\000\000\000\000\000\00000 */
{ 472329 }, /* l2_inst_miss_rate_percent\000general\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000\00000 */
{ 484138 }, /* l2_latency\000latency\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that came from the L2\000\000\000\000\000\00000 */
{ 499048 }, /* l2_ld_hit_ratio\000\000PM_DATA_FROM_L2 / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref\000\000\000\000\000\00000 */
{ 472462 }, /* l2_ld_miss_rate_percent\000general\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 dmand  Load Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 499145 }, /* l2_ld_miss_ratio\000\000PM_DATA_FROM_L2MISS / PM_LD_REF_L1\000\000Fraction of L2 load misses per L1 load ref\000\000\000\000\000\00000 */
{ 499249 }, /* l2_lhs_ld_hit_ratio\000\000PM_DATA_FROM_L2_DISP_CONFLICT_LDHITST / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref where the L2 experienced a Load-Hit-Store conflict\000\000\000\000\000\00000 */
{ 484282 }, /* l2_mepf_latency\000latency\000PM_MRK_DATA_FROM_L2_MEPF_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that were satisfied by lines prefetched into the L3.  This information is forwarded from the L3\000\000\000\000\000\00000 */
{ 484510 }, /* l2_no_conflict_latency\000latency\000PM_MRK_DATA_FROM_L2_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that came from the L2 and suffered no conflicts\000\000\000\000\000\00000 */
{ 499423 }, /* l2_no_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L2_NO_CONFLICT / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref where the L2 did not experience a conflict\000\000\000\000\000\00000 */
{ 499587 }, /* l2_other_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L2_DISP_CONFLICT_OTHER / PM_LD_REF_L1\000\000Fraction of L2 load hits per L1 load ref where the L2 experienced some conflict other than Load-Hit-Store\000\000\000\000\000\00000 */
{ 472597 }, /* l2_pteg_miss_rate_percent\000general\000PM_DPTEG_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 499784 }, /* l2_rc_usage\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000\000Average number of Read/Claim machines used.  1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000\00000 */
{ 499926 }, /* l2_sn_usage\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000\000Average number of Snoop machines used.  1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000\00000 */
{ 472728 }, /* l2_st_miss_rate_percent\000general\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L2 store misses per run instruction\000\000\000\000\000\00000 */
{ 480846 }, /* l2_st_miss_ratio_percent\000l2_stats\000PM_L2_ST_MISS / PM_L2_ST * 100\000\000L2  Store misses  as a % of total L2  Store dispatches (per thread)\000\000\000\000\000\00000 */
{ 480987 }, /* l2_store_miss_ratio_percent\000l2_stats\000PM_L2_ST_MISS / (PM_L2_ST / 2)\000\000Percentage of L2 store misses per drained store.  A drained store may contain multiple individual stores if they target the same line\000\000\000\000\000\00000 */
{ 484704 }, /* l2miss_latency\000latency\000PM_MRK_DATA_FROM_L2MISS_CYC / PM_MRK_DATA_FROM_L2MISS\000\000Average load latency for all marked demand loads that came from the L3 and beyond\000\000\000\000\000\00000 */
{ 500061 }, /* l31_latency\000\000(PM_MRK_DATA_FROM_L31_SHR_CYC + PM_MRK_DATA_FROM_L31_MOD_CYC) / (PM_MRK_DATA_FROM_L31_SHR + PM_MRK_DATA_FROM_L31_MOD)\000\000Marked L31 Load latency\000\000\000\000\000\00000 */
{ 467067 }, /* l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 484871 }, /* l31_mod_latency\000latency\000PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD\000\000Marked L31 Load latency\000\000\000\000\000\00000 */
{ 467364 }, /* l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 484983 }, /* l31_shr_latency\000latency\000PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR\000\000Marked L31 Load latency\000\000\000\000\000\00000 */
{ 500224 }, /* l3_1_ld_hit_ratio\000\000(PM_DATA_FROM_L31_MOD + PM_DATA_FROM_L31_SHR) / PM_LD_REF_L1\000\000Fraction of hits on another core's L3 on the same chip per L1 load ref\000\000\000\000\000\00000 */
{ 500383 }, /* l3_1_mod_ld_hit_ratio\000\000PM_DATA_FROM_L31_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000\00000 */
{ 500558 }, /* l3_1_shr_ld_hit_ratio\000\000PM_DATA_FROM_L31_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on another core's L3 on the same chip per L1 load ref\000\000\000\000\000\00000 */
{ 500721 }, /* l3_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L3_DISP_CONFLICT / PM_LD_REF_L1\000\000Fraction of L3 load hits per load ref where the demand load collided with a pending prefetch\000\000\000\000\000\00000 */
{ 467661 }, /* l3_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L3 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000\00000 */
{ 472857 }, /* l3_inst_miss_rate_percent\000general\000PM_INST_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000\00000 */
{ 485095 }, /* l3_latency\000latency\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000\000Average load latency for all marked demand loads that came from the L3\000\000\000\000\000\00000 */
{ 500893 }, /* l3_ld_hit_ratio\000\000PM_DATA_FROM_L3 / PM_LD_REF_L1\000\000Fraction of L3 load hits per L1 load ref\000\000\000\000\000\00000 */
{ 472990 }, /* l3_ld_miss_rate_percent\000general\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 demand Load Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 500990 }, /* l3_ld_miss_ratio\000\000PM_DATA_FROM_L3MISS / PM_LD_REF_L1\000\000Fraction of L3 load misses per L1 load ref\000\000\000\000\000\00000 */
{ 485239 }, /* l3_no_conflict_latency\000latency\000PM_MRK_DATA_FROM_L3_NO_CONFLICT_CYC / PM_MRK_DATA_FROM_L2\000\000Average load latency for all marked demand loads that came from the L3 and suffered no conflicts\000\000\000\000\000\00000 */
{ 501094 }, /* l3_no_conflict_ld_hit_ratio\000\000PM_DATA_FROM_L3_NO_CONFLICT / PM_LD_REF_L1\000\000Fraction of L3 load hits per load ref where the L3 did not experience a conflict\000\000\000\000\000\00000 */
{ 473125 }, /* l3_pteg_miss_rate_percent\000general\000PM_DPTEG_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 485433 }, /* l3miss_latency\000latency\000PM_MRK_DATA_FROM_L3MISS_CYC / PM_MRK_DATA_FROM_L3MISS\000\000Average load latency for all marked demand loads that come from beyond the L3\000\000\000\000\000\00000 */
{ 501255 }, /* l3other_ld_hit_ratio\000\000(PM_DATA_FROM_L3 - PM_DATA_FROM_L3_MEPF) / PM_LD_REF_L1\000\000Fraction of L3 hits on lines that were not in the MEPF state per L1 load ref\000\000\000\000\000\00000 */
{ 485596 }, /* l3pref_latency\000latency\000PM_MRK_DATA_FROM_L3_MEPF_CYC / PM_MRK_DATA_FROM_L3_MEPF\000\000Average latency for marked reloads that hit in the L3 on the MEPF state.  i.e. lines that were prefetched into the L3\000\000\000\000\000\00000 */
{ 501418 }, /* l3pref_ld_hit_ratio\000\000PM_DATA_FROM_L3_MEPF / PM_LD_REF_L1\000\000Fraction of L3 hits on lines that were recently prefetched into the L3 (MEPF state) per L1 load ref\000\000\000\000\000\00000 */
{ 487783 }, /* ld_ll4_per_ld_dmem\000memory\000PM_DATA_FROM_LL4 / PM_DATA_FROM_DL4\000\000Ratio of reloads from local L4 to distant L4\000\000\000\000\000\00000 */
{ 487898 }, /* ld_ll4_per_ld_mem\000memory\000PM_DATA_FROM_LL4 / (PM_DATA_FROM_DL4 + PM_DATA_FROM_RL4)\000\000Ratio of reloads from local L4 to remote+distant L4\000\000\000\000\000\00000 */
{ 488040 }, /* ld_ll4_per_ld_rl4\000memory\000PM_DATA_FROM_LL4 / PM_DATA_FROM_RL4\000\000Ratio of reloads from local L4 to remote L4\000\000\000\000\000\00000 */
{ 488153 }, /* ld_lmem_per_ld_dmem\000memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000\000Number of loads from local memory per loads from distant memory\000\000\000\000\000\00000 */
{ 488290 }, /* ld_lmem_per_ld_mem\000memory\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000\000Number of loads from local memory per loads from remote and distant memory\000\000\000\000\000\00000 */
{ 488459 }, /* ld_lmem_per_ld_rmem\000memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000\000Number of loads from local memory per loads from remote memory\000\000\000\000\000\00000 */
{ 488595 }, /* ld_rmem_per_ld_dmem\000memory\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000\000Number of loads from remote memory per loads from distant memory\000\000\000\000\000\00000 */
{ 487113 }, /* lhs_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_LHS * 100 / PM_RUN_INST_CMPL\000\000LHS reject ratio\000\000\000\000\000\00000 */
{ 487217 }, /* lhs_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT_LHS * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000\000LHS reject ratio\000\000\000\000\000\00000 */
{ 467929 }, /* ll4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_LL4 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of Local L4 miss rates with measured LL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 485801 }, /* ll4_latency\000latency\000PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4\000\000Local L4 average load latency\000\000\000\000\000\00000 */
{ 501583 }, /* ll4_ld_hit_ratio\000\000PM_DATA_FROM_LL4 / PM_LD_REF_L1\000\000Fraction of hits on a local Centaur's cache per L1 load ref\000\000\000\000\000\00000 */
{ 468206 }, /* lmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_LMEM / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 485907 }, /* lmem_latency\000latency\000PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM\000\000Marked Lmem Load latency\000\000\000\000\000\00000 */
{ 501701 }, /* lmem_ld_hit_ratio\000\000PM_DATA_FROM_LMEM / PM_LD_REF_L1\000\000Fraction of hits on a local Centaur's DRAM per L1 load ref\000\000\000\000\000\00000 */
{ 487334 }, /* lmq_full_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000\000LMQ full reject ratio\000\000\000\000\000\00000 */
{ 487453 }, /* lmq_full_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_LD_REF_L1\000\000ERAT miss reject ratio\000\000\000\000\000\00000 */
{ 477740 }, /* loads_per_inst\000instruction_mix\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000\000PCT instruction loads\000\000\000\000\000\00000 */
{ 501820 }, /* local_centaur_ld_hit_ratio\000\000(PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4) / PM_LD_REF_L1\000\000Fraction of hits on a local Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000\00000 */
{ 445491 }, /* lstack_mispredict_rate_percent\000branch_prediction\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / PM_RUN_INST_CMPL * 100\000\000Link stack branch misprediction\000\000\000\000\000\00000 */
{ 445643 }, /* lstack_misprediction_percent\000branch_prediction\000(PM_BR_MPRED_TA - PM_BR_MPRED_CCACHE) / (PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000\000Percent of link stack mispredictions out of all completed branches that required link stack prediction\000\000\000\000\000\00000 */
{ 487570 }, /* lsu_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT * 100 / PM_RUN_INST_CMPL\000\000LSU reject ratio\000\000\000\000\000\00000 */
{ 487670 }, /* lsu_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT * 100 / (PM_LSU_FIN - PM_LSU_FX_FIN)\000\000LSU reject ratio\000\000\000\000\000\00000 */
{ 501975 }, /* lsu_stall_avg_cyc_per_l1hit_stfw\000\000(PM_CMPLU_STALL_LSU - PM_CMPLU_STALL_REJECT - PM_CMPLU_STALL_DCACHE_MISS - PM_CMPLU_STALL_STORE) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000\000Cycles stalled by Other LSU Operations\000\000\000\000\000\00000 */
{ 450469 }, /* lsu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU\000\000\000\000\000\00000 */
{ 450565 }, /* lsu_stall_dcache_miss_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses\000\000\000\000\000\00000 */
{ 450692 }, /* lsu_stall_dcache_miss_distant_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_DMISS_L3MISS - PM_CMPLU_STALL_DMISS_LMEM - PM_CMPLU_STALL_DMISS_L21_L31 - PM_CMPLU_STALL_DMISS_REMOTE) / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in distant interventions and memory\000\000\000\000\000\00000 */
{ 450969 }, /* lsu_stall_dcache_miss_l21l31_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in remote or distant caches\000\000\000\000\000\00000 */
{ 451147 }, /* lsu_stall_dcache_miss_l2l3_conflict_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was a conflict\000\000\000\000\000\00000 */
{ 451360 }, /* lsu_stall_dcache_miss_l2l3_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3\000\000\000\000\000\00000 */
{ 451527 }, /* lsu_stall_dcache_miss_l2l3_noconflict_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_DMISS_L2L3 - PM_CMPLU_STALL_DMISS_L2L3_CONFLICT) / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in the local L2 or L3, where there was no conflict\000\000\000\000\000\00000 */
{ 451773 }, /* lsu_stall_dcache_miss_l3miss_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in other core's caches or memory\000\000\000\000\000\00000 */
{ 451955 }, /* lsu_stall_dcache_miss_lmem_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in local memory or local L4\000\000\000\000\000\00000 */
{ 452128 }, /* lsu_stall_dcache_miss_remote_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses that resolved in remote interventions and memory\000\000\000\000\000\00000 */
{ 452312 }, /* lsu_stall_erat_miss_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by ERAT Translation rejects\000\000\000\000\000\00000 */
{ 452445 }, /* lsu_stall_ld_fin_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU load finishes\000\000\000\000\000\00000 */
{ 452570 }, /* lsu_stall_lhs_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJECT_LHS / PM_RUN_INST_CMPL\000\000Cycles stalled by LHS rejects\000\000\000\000\000\00000 */
{ 452685 }, /* lsu_stall_lmq_full_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJ_LMQ_FULL / PM_RUN_INST_CMPL\000\000Cycles stalled by LMQ Full rejects\000\000\000\000\000\00000 */
{ 452812 }, /* lsu_stall_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL - PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL - PM_CMPLU_STALL_STORE / PM_RUN_INST_CMPL - PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL - PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000\000Cycles stalled by Other LSU Operations\000\000\000\000\000\00000 */
{ 453155 }, /* lsu_stall_reject_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU Rejects\000\000\000\000\000\00000 */
{ 453269 }, /* lsu_stall_reject_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_REJECT / PM_RUN_INST_CMPL - PM_CMPLU_STALL_REJECT_LHS / PM_RUN_INST_CMPL - PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL - PM_CMPLU_STALL_REJ_LMQ_FULL / PM_RUN_INST_CMPL\000\000Cycles stalled by Other LSU Rejects\000\000\000\000\000\00000 */
{ 453537 }, /* lsu_stall_st_fwd_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU store forwarding\000\000\000\000\000\00000 */
{ 453660 }, /* lsu_stall_store_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE / PM_RUN_INST_CMPL\000\000Cycles stalled by LSU Stores\000\000\000\000\000\00000 */
{ 453771 }, /* lwsync_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LWSYNC / PM_RUN_INST_CMPL\000\000Cycles stalled by lightweight syncs\000\000\000\000\000\00000 */
{ 488733 }, /* mem_locality_percent\000memory\000(PM_DATA_FROM_LL4 + PM_DATA_FROM_LMEM) * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_LL4 + PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4 + PM_DATA_FROM_DMEM + PM_DATA_FROM_DL4)\000\000Memory locality\000\000\000\000\000\00000 */
{ 453982 }, /* no_ntf_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NO_NTF / PM_RUN_INST_CMPL\000\000Cycles stalled by nops (nothing next to finish)\000\000\000\000\000\00000 */
{ 486011 }, /* off_chip_cache_latency\000latency\000PM_MRK_DATA_FROM_OFF_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_OFF_CHIP_CACHE\000\000Latency for marked reloads that hit in the L2 or L3 of any other core on a different chip\000\000\000\000\000\00000 */
{ 502186 }, /* off_chip_cache_ld_hit_ratio\000\000PM_DATA_FROM_OFF_CHIP_CACHE / PM_LD_REF_L1\000\000Fraction of hits on another core's L2 or L3 on a different chip (remote or distant) per L1 load ref\000\000\000\000\000\00000 */
{ 486210 }, /* on_chip_cache_latency\000latency\000PM_MRK_DATA_FROM_ON_CHIP_CACHE_CYC / PM_MRK_DATA_FROM_ON_CHIP_CACHE\000\000Latency for marked reloads that hit in the L2 or L3 of any other core on the same chip\000\000\000\000\000\00000 */
{ 502366 }, /* on_chip_cache_ld_hit_ratio\000\000PM_DATA_FROM_ON_CHIP_CACHE / PM_LD_REF_L1\000\000Fraction of hits on another core's L2 or L3 on the same chip per L1 load ref\000\000\000\000\000\00000 */
{ 454268 }, /* other_block_stall_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_THRD - PM_CMPLU_STALL_LWSYNC - PM_CMPLU_STALL_HWSYNC - PM_CMPLU_STALL_MEM_ECC_DELAY - PM_CMPLU_STALL_FLUSH - PM_CMPLU_STALL_COQ_FULL) / PM_RUN_INST_CMPL\000\000Other thread block stall cycles\000\000\000\000\000\00000 */
{ 454513 }, /* other_cpi\000cpi_breakdown\000PM_RUN_CYC / PM_RUN_INST_CMPL - PM_CMPLU_STALL / PM_RUN_INST_CMPL - PM_GCT_NOSLOT_CYC / PM_RUN_INST_CMPL - PM_NTCG_ALL_FIN / PM_RUN_INST_CMPL - PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL - PM_GRP_CMPL / PM_RUN_INST_CMPL\000\000Cycles unaccounted for\000\000\000\000\000\00000 */
{ 454784 }, /* other_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL / PM_RUN_INST_CMPL - PM_CMPLU_STALL_BRU_CRU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_VSU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL - PM_CMPLU_STALL_NTCG_FLUSH / PM_RUN_INST_CMPL - PM_CMPLU_STALL_NO_NTF / PM_RUN_INST_CMPL\000\000Stall cycles unaccounted for\000\000\000\000\000\00000 */
{ 491860 }, /* pteg_from_dl2l3_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 489096 }, /* pteg_from_dl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L2 or L3 (Modified) per inst\000\000\000\000\000\00000 */
{ 492022 }, /* pteg_from_dl2l3_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 489277 }, /* pteg_from_dl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L2 or L3 (Shared) per inst\000\000\000\000\000\00000 */
{ 492182 }, /* pteg_from_dl4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L4\000\000\000\000\000\00000 */
{ 489456 }, /* pteg_from_dl4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L4 per inst\000\000\000\000\000\00000 */
{ 492315 }, /* pteg_from_dmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant Memory\000\000\000\000\000\00000 */
{ 489608 }, /* pteg_from_dmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant Memory per inst\000\000\000\000\000\00000 */
{ 492454 }, /* pteg_from_l21_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L21_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 489766 }, /* pteg_from_l21_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000\00000 */
{ 492607 }, /* pteg_from_l21_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L21_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 489938 }, /* pteg_from_l21_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000\00000 */
{ 492760 }, /* pteg_from_l2_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L2 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from L2\000\000\000\000\000\00000 */
{ 490110 }, /* pteg_from_l2_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from L2 per inst\000\000\000\000\000\00000 */
{ 492883 }, /* pteg_from_l31_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L31_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 490252 }, /* pteg_from_l31_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000\00000 */
{ 493036 }, /* pteg_from_l31_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L31_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 490424 }, /* pteg_from_l31_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000\00000 */
{ 493189 }, /* pteg_from_l3_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L3 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from L3\000\000\000\000\000\00000 */
{ 490596 }, /* pteg_from_l3_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from L3 per inst\000\000\000\000\000\00000 */
{ 493312 }, /* pteg_from_ll4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_LL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Local L4\000\000\000\000\000\00000 */
{ 490738 }, /* pteg_from_ll4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Local L4 per inst\000\000\000\000\000\00000 */
{ 493443 }, /* pteg_from_lmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_LMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Local Memory\000\000\000\000\000\00000 */
{ 490888 }, /* pteg_from_lmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Local Memory per inst\000\000\000\000\000\00000 */
{ 493580 }, /* pteg_from_rl2l3_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 491044 }, /* pteg_from_rl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L2 or L3 (Modified) per inst\000\000\000\000\000\00000 */
{ 493741 }, /* pteg_from_rl2l3_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 491224 }, /* pteg_from_rl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L2 or L3 (Shared) per inst\000\000\000\000\000\00000 */
{ 493900 }, /* pteg_from_rl4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L4\000\000\000\000\000\00000 */
{ 491402 }, /* pteg_from_rl4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L4 per inst\000\000\000\000\000\00000 */
{ 494032 }, /* pteg_from_rmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote Memory\000\000\000\000\000\00000 */
{ 491553 }, /* pteg_from_rmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote Memory per inst\000\000\000\000\000\00000 */
{ 502521 }, /* remote_centaur_ld_hit_ratio\000\000(PM_DATA_FROM_RMEM + PM_DATA_FROM_RL4) / PM_LD_REF_L1\000\000Fraction of hits on a remote chip's Centaur (L4 or DRAM) per L1 load ref\000\000\000\000\000\00000 */
{ 502685 }, /* resource_na_reject_rate_percent\000\000PM_ISU_REJECT_RES_NA * 100 / PM_RUN_INST_CMPL\000\000Percent of all FXU/VSU instructions that got rejected because of unavailable resources or facilities\000\000\000\000\000\00000 */
{ 468492 }, /* rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_MOD / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486403 }, /* rl2l3_mod_latency\000latency\000PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000 */
{ 502873 }, /* rl2l3_mod_ld_hit_ratio\000\000PM_DATA_FROM_RL2L3_MOD / PM_LD_REF_L1\000\000Fraction of hits of a line in the M (exclusive) state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000\00000 */
{ 468807 }, /* rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_SHR / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486529 }, /* rl2l3_shr_latency\000latency\000PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000 */
{ 503056 }, /* rl2l3_shr_ld_hit_ratio\000\000PM_DATA_FROM_RL2L3_SHR / PM_LD_REF_L1\000\000Fraction of hits of a line in the S state on the L2 or L3 of a core on a remote chip per L1 load ref\000\000\000\000\000\00000 */
{ 469118 }, /* rl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL4 / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486655 }, /* rl4_latency\000latency\000PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4\000\000Remote L4 average load latency\000\000\000\000\000\00000 */
{ 503227 }, /* rl4_ld_hit_ratio\000\000PM_DATA_FROM_RL4 / PM_LD_REF_L1\000\000Fraction of hits on a remote Centaur's cache per L1 load ref\000\000\000\000\000\00000 */
{ 469396 }, /* rmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RMEM / PM_RUN_INST_CMPL * (PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM) / (PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL) * 100\000\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486762 }, /* rmem_latency\000latency\000PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM\000\000Marked Rmem Load latency\000\000\000\000\000\00000 */
{ 503346 }, /* rmem_ld_hit_ratio\000\000PM_DATA_FROM_RMEM / PM_LD_REF_L1\000\000Fraction of hits on a remote Centaur's DRAM per L1 load ref\000\000\000\000\000\00000 */
{ 455139 }, /* run_cpi\000cpi_breakdown\000PM_RUN_CYC / PM_RUN_INST_CMPL\000\000Run cycles per run instruction\000\000\000\000\000\00000 */
{ 473256 }, /* run_cycles_percent\000general\000PM_RUN_CYC / PM_CYC * 100\000\000Run cycles per cycle\000\000\000\000\000\00000 */
{ 503466 }, /* sar_bypass_reject_rate_percent\000\000PM_ISU_REJECT_SAR_BYPASS * 100 / PM_RUN_INST_CMPL\000\000Percent of all FXU/VSU instructions that got rejected due to SAR Bypass\000\000\000\000\000\00000 */
{ 473338 }, /* smt2_cycles_percent\000general\000PM_RUN_CYC_SMT2_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in SMT2 Mode\000\000\000\000\000\00000 */
{ 473454 }, /* smt4_cycles_percent\000general\000PM_RUN_CYC_SMT4_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in SMT4 Mode\000\000\000\000\000\00000 */
{ 473570 }, /* smt8_cycles_percent\000general\000PM_RUN_CYC_SMT8_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in SMT8 Mode\000\000\000\000\000\00000 */
{ 473686 }, /* smt_benefit\000general\000PM_CMPLU_STALL_OTHER_CMPL / PM_RUN_CYC\000\000IPC of all instructions completed by the core while this thread was stalled\000\000\000\000\000\00000 */
{ 503628 }, /* source_na_reject_rate_percent\000\000PM_ISU_REJECT_SRC_NA * 100 / PM_RUN_INST_CMPL\000\000Percent of all FXU/VSU instructions that got rejected because of unavailable sources\000\000\000\000\000\00000 */
{ 473829 }, /* speculation\000general\000PM_INST_DISP / PM_INST_CMPL\000\000Instruction dispatch-to-completion ratio\000\000\000\000\000\00000 */
{ 473926 }, /* st_cycles_percent\000general\000PM_RUN_CYC_ST_MODE / PM_RUN_CYC * 100\000\000Percentage of cycles spent in Single Thread Mode\000\000\000\000\000\00000 */
{ 455230 }, /* stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000\000Completion Stall Cycles\000\000\000\000\000\00000 */
{ 503798 }, /* store_forward_rate_percent\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / PM_RUN_INST_CMPL\000\000Store forward rate\000\000\000\000\000\00000 */
{ 503918 }, /* store_forward_ratio_percent\000\000100 * (PM_LSU0_SRQ_STFWD + PM_LSU1_SRQ_STFWD) / (PM_LD_REF_L1 - PM_LD_MISS_L1)\000\000Store forward rate\000\000\000\000\000\00000 */
{ 504053 }, /* store_latency\000\000(PM_MRK_ST_L2DISP_TO_CMPL_CYC + PM_MRK_ST_DRAIN_TO_L2DISP_CYC) / PM_MRK_ST_NEST\000\000Marked store latency, from core completion to L2 RC machine completion\000\000\000\000\000\00000 */
{ 477833 }, /* stores_per_inst\000instruction_mix\000PM_ST_FIN / PM_RUN_INST_CMPL\000\000PCT instruction stores\000\000\000\000\000\00000 */
{ 504227 }, /* sync_stall_cpi\000\000(PM_CMPLU_STALL_LWSYNC + PM_CMPLU_STALL_HWSYNC) / PM_RUN_INST_CMPL\000\000Cycles stalled by any sync\000\000\000\000\000\00000 */
{ 446921 }, /* sys_pump_cpred_percent\000bus_stats\000PM_SYS_PUMP_CPRED * 100 / PM_L2_GROUP_PUMP\000\000Percent of system pumps that were correctly predicted as group pumps the first time\000\000\000\000\000\00000 */
{ 445895 }, /* ta_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_TA / PM_RUN_INST_CMPL * 100\000\000TA MisPredictions per Instruction\000\000\000\000\000\00000 */
{ 446022 }, /* ta_misprediction_percent\000branch_prediction\000PM_BR_MPRED_TA / (PM_BR_PRED_CCACHE_BR0 + PM_BR_PRED_CCACHE_BR1 + PM_BR_PRED_LSTACK_BR0 + PM_BR_PRED_LSTACK_BR1) * 100\000\000Percent of target address mispredictions out of all completed branches that required address prediction\000\000\000\000\000\00000 */
{ 446296 }, /* taken_branches_percent\000branch_prediction\000PM_BR_TAKEN_CMPL * 100 / PM_BR_CMPL\000\000Percent of branches completed that were taken\000\000\000\000\000\00000 */
{ 455320 }, /* thread_block_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000\000Cycles a thread was blocked\000\000\000\000\000\00000 */
{ 455432 }, /* vsu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VSU / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU\000\000\000\000\000\00000 */
{ 455528 }, /* vsu_stall_other_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_VSU - PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_SCALAR) / PM_RUN_INST_CMPL\000\000Cycles stalled by other VSU Operations\000\000\000\000\000\00000 */
{ 455697 }, /* vsu_stall_scalar_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SCALAR / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Scalar Operations\000\000\000\000\000\00000 */
{ 455821 }, /* vsu_stall_scalar_long_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SCALAR_LONG / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Scalar Long Operations\000\000\000\000\000\00000 */
{ 455960 }, /* vsu_stall_scalar_other_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SCALAR / PM_RUN_INST_CMPL - PM_CMPLU_STALL_SCALAR_LONG / PM_RUN_INST_CMPL\000\000Cycles stalled by Other VSU Scalar Operations\000\000\000\000\000\00000 */
{ 456144 }, /* vsu_stall_vector_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VECTOR / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Vector Operations\000\000\000\000\000\00000 */
{ 456268 }, /* vsu_stall_vector_long_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VECTOR_LONG / PM_RUN_INST_CMPL\000\000Cycles stalled by VSU Vector Long Operations\000\000\000\000\000\00000 */
{ 456407 }, /* vsu_stall_vector_other_cpi\000cpi_breakdown\000(PM_CMPLU_STALL_VECTOR - PM_CMPLU_STALL_VECTOR_LONG) / PM_RUN_INST_CMPL\000\000Cycles stalled by other VSU Vector Operations\000\000\000\000\000\00000 */
{ 504345 }, /* wasted_l3_prefetch_percent\000\000PM_L3_CO_MEPF / 2 / PM_L3_PREF_ALL * 100\000\000Percentage of lines that were prefetched into the L3 and evicted before they were consumed\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__power8[] = {
{
     .entries = pmu_metrics__power8_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__power8_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__power9_default_core[] = {
{ 392086 }, /* pm_1flop_cmpl\000pmc\000one flop (fadd, fmul, fsub, fcmp, fsel, fabs, fnabs, fres, fsqrte, fneg) operation completed\000event=0x45050\000\00000\000\000 */
{ 282042 }, /* pm_1plus_ppc_cmpl\000frontend\0001 or more ppc insts finished\000event=0x100f2\000\00000\000\000 */
{ 114229 }, /* pm_1plus_ppc_disp\000pipeline\000Cycles at least one Instr Dispatched\000event=0x400f2\000\00000\000\000 */
{ 386347 }, /* pm_2flop_cmpl\000pipeline\000DP vector version of fmul, fsub, fcmp, fsel, fabs, fnabs, fres ,fsqrte, fneg\000event=0x4d052\000\00000\000\000 */
{ 390091 }, /* pm_4flop_cmpl\000pmc\0004 FLOP instruction completed\000event=0x45052\000\00000\000\000 */
{ 390644 }, /* pm_8flop_cmpl\000pmc\0008 FLOP instruction completed\000event=0x4d054\000\00000\000\000 */
{ 344712 }, /* pm_any_thrd_run_cyc\000other\000Cycles in which at least one thread has the run latch set\000event=0x100fa\000\00000\000\000 */
{ 353948 }, /* pm_back_br_cmpl\000other\000Branch instruction completed with a target address less than current instruction address\000event=0x2505e\000\00000\000\000 */
{ 334380 }, /* pm_bank_conflict\000other\000Read blocked due to interleave conflict.  The ifar logic will detect an interleave conflict and kill the data that was read that cycle\000event=0x4880\000\00000\000\000 */
{ 357933 }, /* pm_bfu_busy\000other\000Cycles in which all 4 Binary Floating Point units are busy. The BFU is running at capacity\000event=0x3005c\000\00000\000\000 */
{ 388691 }, /* pm_br_2path\000pmc\000Branches that are not strongly biased\000event=0x20036\000\00000\000\000 */
{ 365114 }, /* pm_br_cmpl\000other\000Any Branch instruction completed\000event=0x4d05e\000\00000\000\000 */
{ 366050 }, /* pm_br_corect_pred_taken_cmpl\000other\000Conditional Branch Completed in which the HW correctly predicted the direction as taken.  Counted at completion time\000event=0x489c\000\00000\000\000 */
{ 176395 }, /* pm_br_mpred_ccache\000other\000Conditional Branch Completed that was Mispredicted due to the Count Cache Target Prediction\000event=0x40ac\000\00000\000\000 */
{ 276465 }, /* pm_br_mpred_cmpl\000cache\000Number of Branch Mispredicts\000event=0x400f6\000\00000\000\000 */
{ 333402 }, /* pm_br_mpred_lstack\000other\000Conditional Branch Completed that was Mispredicted due to the Link Stack Target Prediction\000event=0x48ac\000\00000\000\000 */
{ 331616 }, /* pm_br_mpred_pcache\000other\000Conditional Branch Completed that was Mispredicted due to pattern cache prediction\000event=0x48b0\000\00000\000\000 */
{ 311335 }, /* pm_br_mpred_taken_cr\000other\000A Conditional Branch that resolved to taken was mispredicted as not taken (due to the BHT Direction Prediction)\000event=0x40b8\000\00000\000\000 */
{ 346393 }, /* pm_br_mpred_taken_ta\000other\000Conditional Branch Completed that was Mispredicted due to the Target Address Prediction from the Count Cache or Link Stack.  Only XL-form branches that resolved Taken set this event\000event=0x48b8\000\00000\000\000 */
{ 369361 }, /* pm_br_pred\000other\000Conditional Branch Executed in which the HW predicted the Direction or Target.  Includes taken and not taken and is counted at execution time\000event=0x409c\000\00000\000\000 */
{ 360033 }, /* pm_br_pred_ccache\000other\000Conditional Branch Completed that used the Count Cache for Target Prediction\000event=0x40a4\000\00000\000\000 */
{ 329860 }, /* pm_br_pred_lstack\000other\000Conditional Branch Completed  that used the Link Stack for Target Prediction\000event=0x40a8\000\00000\000\000 */
{ 358061 }, /* pm_br_pred_pcache\000other\000Conditional branch completed that used pattern cache prediction\000event=0x48a0\000\00000\000\000 */
{ 325178 }, /* pm_br_pred_ta\000other\000Conditional Branch Completed that had its target address predicted. Only XL-form branches set this event.  This equal the sum of CCACHE, LSTACK, and PCACHE\000event=0x40b4\000\00000\000\000 */
{ 351458 }, /* pm_br_pred_taken_cr\000other\000Conditional Branch that had its direction predicted. I-form branches do not set this event.  In addition, B-form branches which do not use the BHT do not set this event - these are branches with BO-field set to 'always taken' and branches\000event=0x40b0\000\00000\000\000 */
{ 127186 }, /* pm_br_taken_cmpl\000frontend\000New event for Branch Taken\000event=0x200fa\000\00000\000\000 */
{ 323411 }, /* pm_br_uncond\000other\000Unconditional Branch Completed. HW branch prediction was not used for this branch. This can be an I-form branch, a B-form branch with BO-field set to branch always, or a B-form branch which was covenrted to a Resolve\000event=0x40a0\000\00000\000\000 */
{ 383398 }, /* pm_bru_fin\000pipeline\000Branch Instruction Finished\000event=0x10068\000\00000\000\000 */
{ 346620 }, /* pm_btac_bad_result\000other\000BTAC thinks branch will be taken but it is either predicted not-taken by the BHT, or the target address is wrong (less common).  In both cases, a redirect will happen\000event=0x50b0\000\00000\000\000 */
{ 322674 }, /* pm_btac_good_result\000other\000BTAC predicts a taken branch and the BHT agrees, and the target address is correct\000event=0x58b0\000\00000\000\000 */
{ 377797 }, /* pm_chip_pump_cpred\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10050\000\00000\000\000 */
{ 370054 }, /* pm_clb_held\000other\000CLB (control logic block - indicates quadword fetch block) Hold: Any Reason\000event=0x208c\000\00000\000\000 */
{ 373592 }, /* pm_cmplu_stall\000pipeline\000Nothing completed and ICT not empty\000event=0x1e054\000\00000\000\000 */
{ 357167 }, /* pm_cmplu_stall_any_sync\000other\000Cycles in which the NTC sync instruction (isync, lwsync or hwsync) is not allowed to complete\000event=0x1e05a\000\00000\000\000 */
{ 390011 }, /* pm_cmplu_stall_bru\000pmc\000Completion stall due to a Branch Unit\000event=0x4d018\000\00000\000\000 */
{ 390292 }, /* pm_cmplu_stall_crypto\000pmc\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000event=0x4c01e\000\00000\000\000 */
{ 390797 }, /* pm_cmplu_stall_dcache_miss\000pmc\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000event=0x2c012\000\00000\000\000 */
{ 372439 }, /* pm_cmplu_stall_dflong\000pipeline\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Qualified by multicycle\000event=0x1005a\000\00000\000\000 */
{ 380887 }, /* pm_cmplu_stall_dfu\000pipeline\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish. Includes decimal floating point instructions + 128 bit binary floating point instructions. Not qualified by multicycle\000event=0x2d012\000\00000\000\000 */
{ 263606 }, /* pm_cmplu_stall_dmiss_l21_l31\000pipeline\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000event=0x2c018\000\00000\000\000 */
{ 275236 }, /* pm_cmplu_stall_dmiss_l2l3\000cache\000Completion stall by Dcache miss which resolved in L2/L3\000event=0x1003c\000\00000\000\000 */
{ 277202 }, /* pm_cmplu_stall_dmiss_l2l3_conflict\000cache\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000event=0x4c016\000\00000\000\000 */
{ 319160 }, /* pm_cmplu_stall_dmiss_l3miss\000other\000Completion stall due to cache miss resolving missed the L3\000event=0x4c01a\000\00000\000\000 */
{ 367456 }, /* pm_cmplu_stall_dmiss_lmem\000other\000Completion stall due to cache miss that resolves in local memory\000event=0x30038\000\00000\000\000 */
{ 289340 }, /* pm_cmplu_stall_dmiss_remote\000marked\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000event=0x2c01c\000\00000\000\000 */
{ 300939 }, /* pm_cmplu_stall_dp\000marked\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by NOT vector\000event=0x1005c\000\00000\000\000 */
{ 386020 }, /* pm_cmplu_stall_dplong\000pipeline\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3405c\000\00000\000\000 */
{ 295387 }, /* pm_cmplu_stall_eieio\000marked\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000event=0x4d01a\000\00000\000\000 */
{ 388376 }, /* pm_cmplu_stall_emq_full\000pipeline\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000event=0x30004\000\00000\000\000 */
{ 386812 }, /* pm_cmplu_stall_erat_miss\000pipeline\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000event=0x4c012\000\00000\000\000 */
{ 291298 }, /* pm_cmplu_stall_exception\000marked\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000event=0x3003a\000\00000\000\000 */
{ 370656 }, /* pm_cmplu_stall_exec_unit\000other\000Completion stall due to execution units (FXU/VSU/CRU)\000event=0x2d018\000\00000\000\000 */
{ 274536 }, /* pm_cmplu_stall_flush_any_thread\000cache\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000event=0x1e056\000\00000\000\000 */
{ 274744 }, /* pm_cmplu_stall_fxlong\000cache\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000event=0x4d016\000\00000\000\000 */
{ 274885 }, /* pm_cmplu_stall_fxu\000cache\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x2d016\000\00000\000\000 */
{ 277798 }, /* pm_cmplu_stall_larx\000cache\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000event=0x1002a\000\00000\000\000 */
{ 277343 }, /* pm_cmplu_stall_lhs\000cache\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000event=0x2c01a\000\00000\000\000 */
{ 275343 }, /* pm_cmplu_stall_lmq_full\000cache\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000event=0x4c014\000\00000\000\000 */
{ 275758 }, /* pm_cmplu_stall_load_finish\000cache\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000event=0x4d014\000\00000\000\000 */
{ 335231 }, /* pm_cmplu_stall_lrq_full\000other\000Finish stall because the NTF instruction was a load that was held in LSAQ (load-store address queue) because the LRQ (load-reorder queue) was full\000event=0x2d014\000\00000\000\000 */
{ 284587 }, /* pm_cmplu_stall_lrq_other\000frontend\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000event=0x10004\000\00000\000\000 */
{ 279137 }, /* pm_cmplu_stall_lsaq_arb\000frontend\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000event=0x4e016\000\00000\000\000 */
{ 281626 }, /* pm_cmplu_stall_lsu\000frontend\000Completion stall by LSU instruction\000event=0x2c010\000\00000\000\000 */
{ 288041 }, /* pm_cmplu_stall_lsu_fin\000frontend\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000event=0x1003a\000\00000\000\000 */
{ 281241 }, /* pm_cmplu_stall_lsu_flush_next\000frontend\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000event=0x2e01a\000\00000\000\000 */
{ 282703 }, /* pm_cmplu_stall_lsu_mfspr\000frontend\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000event=0x34056\000\00000\000\000 */
{ 281885 }, /* pm_cmplu_stall_mtfpscr\000frontend\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000event=0x4e012\000\00000\000\000 */
{ 345475 }, /* pm_cmplu_stall_nested_tbegin\000other\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000event=0x1e05c\000\00000\000\000 */
{ 304159 }, /* pm_cmplu_stall_nested_tend\000marked\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000event=0x3003c\000\00000\000\000 */
{ 299832 }, /* pm_cmplu_stall_ntc_disp_fin\000marked\000Finish stall because the NTF instruction was one that must finish at dispatch\000event=0x4e018\000\00000\000\000 */
{ 290229 }, /* pm_cmplu_stall_ntc_flush\000marked\000Completion stall due to ntc flush\000event=0x2e01e\000\00000\000\000 */
{ 300826 }, /* pm_cmplu_stall_other_cmpl\000marked\000Instructions the core completed while this tread was stalled\000event=0x30006\000\00000\000\000 */
{ 306745 }, /* pm_cmplu_stall_paste\000marked\000Finish stall because the NTF instruction was a paste waiting for response from L2\000event=0x2c016\000\00000\000\000 */
{ 292875 }, /* pm_cmplu_stall_pm\000marked\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish. Includes permute and decimal fixed point instructions (128 bit BCD arithmetic) + a few 128 bit fixpoint add/subtract instructions with carry. Not qualified by vector or multicycle\000event=0x3000a\000\00000\000\000 */
{ 292338 }, /* pm_cmplu_stall_slb\000marked\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000event=0x1e052\000\00000\000\000 */
{ 297273 }, /* pm_cmplu_stall_spec_finish\000marked\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000event=0x30028\000\00000\000\000 */
{ 325029 }, /* pm_cmplu_stall_srq_full\000other\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000event=0x30016\000\00000\000\000 */
{ 287543 }, /* pm_cmplu_stall_st_fwd\000frontend\000Completion stall due to store forward\000event=0x4c01c\000\00000\000\000 */
{ 281497 }, /* pm_cmplu_stall_stcx\000frontend\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000event=0x2d01c\000\00000\000\000 */
{ 286382 }, /* pm_cmplu_stall_store_data\000frontend\000Finish stall because the next to finish instruction was a store waiting on data\000event=0x30026\000\00000\000\000 */
{ 280552 }, /* pm_cmplu_stall_store_fin_arb\000frontend\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000event=0x30014\000\00000\000\000 */
{ 283495 }, /* pm_cmplu_stall_store_finish\000frontend\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000event=0x2c014\000\00000\000\000 */
{ 287280 }, /* pm_cmplu_stall_store_pipe_arb\000frontend\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000event=0x4c010\000\00000\000\000 */
{ 285244 }, /* pm_cmplu_stall_sync_pmu_int\000frontend\000Cycles in which the NTC instruction is waiting for a synchronous PMU interrupt\000event=0x2c01e\000\00000\000\000 */
{ 285801 }, /* pm_cmplu_stall_tend\000frontend\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000event=0x1e050\000\00000\000\000 */
{ 314409 }, /* pm_cmplu_stall_thrd\000other\000Completion Stalled because the thread was blocked\000event=0x1001c\000\00000\000\000 */
{ 399460 }, /* pm_cmplu_stall_tlbie\000translation\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000event=0x2e01c\000\00000\000\000 */
{ 395465 }, /* pm_cmplu_stall_vdp\000translation\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Not qualified multicycle. Qualified by vector\000event=0x4405c\000\00000\000\000 */
{ 399129 }, /* pm_cmplu_stall_vdplong\000translation\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format. Qualified by NOT vector AND multicycle\000event=0x3c05a\000\00000\000\000 */
{ 394095 }, /* pm_cmplu_stall_vfxlong\000translation\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000event=0x2e018\000\00000\000\000 */
{ 393297 }, /* pm_cmplu_stall_vfxu\000translation\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000event=0x3c05c\000\00000\000\000 */
{ 340841 }, /* pm_co0_busy\000other\000CO mach 0 Busy. Used by PMU to sample ave CO lifetime (mach0 used as sample point)\000event=0x3608c\000\00000\000\000 */
{ 349781 }, /* pm_co_disp_fail\000other\000CO dispatch failed due to all CO machines being busy\000event=0x16886\000\00000\000\000 */
{ 356968 }, /* pm_co_tm_sc_footprint\000other\000L2 did a cleanifdirty CO to the L3 (ie created an SC line in the L3) OR L2 TM_store hit dirty HPC line and L3 indicated SC line formed in L3 on RDR bus\000event=0x26086\000\00000\000\000 */
{ 346176 }, /* pm_co_usage\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each CO machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x2688c\000\00000\000\000 */
{ 392216 }, /* pm_cyc\000translation\000Processor cycles\000event=0x1e\000\00000\000\000 */
{ 298498 }, /* pm_darq0_0_3_entries\000marked\000Cycles in which 3 or less DARQ entries (out of 12) are in use\000event=0x4d04a\000\00000\000\000 */
{ 300620 }, /* pm_darq0_10_12_entries\000marked\000Cycles in which 10 or more DARQ entries (out of 12) are in use\000event=0x1d058\000\00000\000\000 */
{ 306252 }, /* pm_darq0_4_6_entries\000marked\000Cycles in which 4, 5, or 6 DARQ entries (out of 12) are in use\000event=0x3504e\000\00000\000\000 */
{ 289672 }, /* pm_darq0_7_9_entries\000marked\000Cycles in which 7,8, or 9 DARQ entries (out of 12) are in use\000event=0x2e050\000\00000\000\000 */
{ 300074 }, /* pm_darq1_0_3_entries\000marked\000Cycles in which 3 or fewer DARQ1 entries (out of 12) are in use\000event=0x4c122\000\00000\000\000 */
{ 320097 }, /* pm_darq1_10_12_entries\000other\000Cycles in which 10 or  more DARQ1 entries (out of 12) are in use\000event=0x20058\000\00000\000\000 */
{ 310179 }, /* pm_darq1_4_6_entries\000memory\000Cycles in which 4, 5, or 6 DARQ1 entries (out of 12) are in use\000event=0x3e050\000\00000\000\000 */
{ 307201 }, /* pm_darq1_7_9_entries\000memory\000Cycles in which 7 to 9 DARQ1 entries (out of 12) are in use\000event=0x2005a\000\00000\000\000 */
{ 302597 }, /* pm_darq_store_reject\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry but It was rejected. Divide by PM_DARQ_STORE_XMIT to get reject ratio\000event=0x4405e\000\00000\000\000 */
{ 306362 }, /* pm_darq_store_xmit\000marked\000The DARQ attempted to transmit a store into an LSAQ or SRQ entry. Includes rejects. Not qualified by thread, so it includes counts for the whole core\000event=0x30064\000\00000\000\000 */
{ 308586 }, /* pm_data_chip_pump_cpred\000memory\000Initial and Final Pump Scope was chip pump (prediction=correct) for a demand load\000event=0x1c050\000\00000\000\000 */
{ 307649 }, /* pm_data_from_dl2l3_mod\000memory\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x4c048\000\00000\000\000 */
{ 307308 }, /* pm_data_from_dl2l3_shr\000memory\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a demand load\000event=0x3c048\000\00000\000\000 */
{ 374392 }, /* pm_data_from_dl4\000pipeline\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a demand load\000event=0x3c04c\000\00000\000\000 */
{ 381299 }, /* pm_data_from_dmem\000pipeline\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a demand load\000event=0x4c04c\000\00000\000\000 */
{ 302779 }, /* pm_data_from_l2\000marked\000The processor's data cache was reloaded from local core's L2 due to a demand load\000event=0x1c042\000\00000\000\000 */
{ 394875 }, /* pm_data_from_l21_mod\000translation\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a demand load\000event=0x4c046\000\00000\000\000 */
{ 392340 }, /* pm_data_from_l21_shr\000translation\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a demand load\000event=0x3c046\000\00000\000\000 */
{ 313725 }, /* pm_data_from_l2_disp_conflict_ldhitst\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a demand load\000event=0x3c040\000\00000\000\000 */
{ 308718 }, /* pm_data_from_l2_disp_conflict_other\000memory\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a demand load\000event=0x4c040\000\00000\000\000 */
{ 309469 }, /* pm_data_from_l2_mepf\000memory\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state due to a demand load\000event=0x2c040\000\00000\000\000 */
{ 309316 }, /* pm_data_from_l2_no_conflict\000memory\000The processor's data cache was reloaded from local core's L2 without conflict due to a demand load\000event=0x1c040\000\00000\000\000 */
{ 396014 }, /* pm_data_from_l2miss\000translation\000Demand LD - L2 Miss (not L2 hit)\000event=0x200fe\000\00000\000\000 */
{ 394243 }, /* pm_data_from_l2miss_mod\000translation\000The processor's data cache was reloaded from a location other than the local core's L2 due to a demand load\000event=0x1c04e\000\00000\000\000 */
{ 308027 }, /* pm_data_from_l3\000memory\000The processor's data cache was reloaded from local core's L3 due to a demand load\000event=0x4c042\000\00000\000\000 */
{ 279975 }, /* pm_data_from_l31_eco_mod\000frontend\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a demand load\000event=0x4c044\000\00000\000\000 */
{ 302995 }, /* pm_data_from_l31_eco_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a demand load\000event=0x3c044\000\00000\000\000 */
{ 294299 }, /* pm_data_from_l31_mod\000marked\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a demand load\000event=0x2c044\000\00000\000\000 */
{ 294130 }, /* pm_data_from_l31_shr\000marked\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a demand load\000event=0x1c046\000\00000\000\000 */
{ 326259 }, /* pm_data_from_l3_disp_conflict\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a demand load\000event=0x3c042\000\00000\000\000 */
{ 281709 }, /* pm_data_from_l3_mepf\000frontend\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state due to a demand load\000event=0x2c042\000\00000\000\000 */
{ 280156 }, /* pm_data_from_l3_no_conflict\000frontend\000The processor's data cache was reloaded from local core's L3 without conflict due to a demand load\000event=0x1c044\000\00000\000\000 */
{ 300732 }, /* pm_data_from_l3miss\000marked\000Demand LD - L3 Miss (not L2 hit and not L3 hit)\000event=0x300fe\000\00000\000\000 */
{ 299468 }, /* pm_data_from_l3miss_mod\000marked\000The processor's data cache was reloaded from a location other than the local core's L3 due to a demand load\000event=0x4c04e\000\00000\000\000 */
{ 322801 }, /* pm_data_from_ll4\000other\000The processor's data cache was reloaded from the local chip's L4 cache due to a demand load\000event=0x1c04c\000\00000\000\000 */
{ 292741 }, /* pm_data_from_lmem\000marked\000The processor's data cache was reloaded from the local chip's Memory due to a demand load\000event=0x2c048\000\00000\000\000 */
{ 296542 }, /* pm_data_from_memory\000marked\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a demand load\000event=0x400fe\000\00000\000\000 */
{ 296330 }, /* pm_data_from_off_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a demand load\000event=0x4c04a\000\00000\000\000 */
{ 302288 }, /* pm_data_from_on_chip_cache\000marked\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a demand load\000event=0x1c048\000\00000\000\000 */
{ 378845 }, /* pm_data_from_rl2l3_mod\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x2c046\000\00000\000\000 */
{ 324715 }, /* pm_data_from_rl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a demand load\000event=0x1c04a\000\00000\000\000 */
{ 294470 }, /* pm_data_from_rl4\000marked\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a demand load\000event=0x2c04a\000\00000\000\000 */
{ 289172 }, /* pm_data_from_rmem\000marked\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a demand load\000event=0x3c04a\000\00000\000\000 */
{ 336186 }, /* pm_data_grp_pump_cpred\000other\000Initial and Final Pump Scope was group pump (prediction=correct) for a demand load\000event=0x2c050\000\00000\000\000 */
{ 294983 }, /* pm_data_grp_pump_mpred\000marked\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for a demand load\000event=0x2c052\000\00000\000\000 */
{ 293375 }, /* pm_data_grp_pump_mpred_rty\000marked\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for a demand load\000event=0x1c052\000\00000\000\000 */
{ 302476 }, /* pm_data_pump_cpred\000marked\000Pump prediction correct. Counts across all types of pumps for a demand load\000event=0x1c054\000\00000\000\000 */
{ 303172 }, /* pm_data_pump_mpred\000marked\000Pump misprediction. Counts across all types of pumps for a demand load\000event=0x4c052\000\00000\000\000 */
{ 317988 }, /* pm_data_store\000other\000All ops that drain from s2q to L2 containing data\000event=0xf0a0\000\00000\000\000 */
{ 293805 }, /* pm_data_sys_pump_cpred\000marked\000Initial and Final Pump Scope was system pump (prediction=correct) for a demand load\000event=0x3c050\000\00000\000\000 */
{ 296863 }, /* pm_data_sys_pump_mpred\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for a demand load\000event=0x3c052\000\00000\000\000 */
{ 294833 }, /* pm_data_sys_pump_mpred_rty\000marked\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for a demand load\000event=0x4c050\000\00000\000\000 */
{ 314625 }, /* pm_data_tablewalk_cyc\000other\000Data Tablewalk Cycles.  Could be 1 or 2 active tablewalks. Includes data prefetches\000event=0x3001a\000\00000\000\000 */
{ 311492 }, /* pm_dc_dealloc_no_conf\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8ac\000\00000\000\000 */
{ 325630 }, /* pm_dc_pref_conf\000other\000A demand load referenced a line in an active prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software. Includes forwards and backwards streams\000event=0xf0a8\000\00000\000\000 */
{ 315009 }, /* pm_dc_pref_cons_alloc\000other\000Prefetch stream allocated in the conservative phase by either the hardware prefetch mechanism or software prefetch. The sum of this pair subtracted from the total number of allocs will give the total allocs in normal phase\000event=0xf0b4\000\00000\000\000 */
{ 323665 }, /* pm_dc_pref_fuzzy_conf\000other\000A demand load referenced a line in an active fuzzy prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software.Fuzzy stream confirm (out of order effects, or pf cant keep up)\000event=0xf8a8\000\00000\000\000 */
{ 316736 }, /* pm_dc_pref_hw_alloc\000other\000Prefetch stream allocated by the hardware prefetch mechanism\000event=0xf0a4\000\00000\000\000 */
{ 347904 }, /* pm_dc_pref_strided_conf\000other\000A demand load referenced a line in an active strided prefetch stream. The stream could have been allocated through the hardware prefetch mechanism or through software\000event=0xf0ac\000\00000\000\000 */
{ 323940 }, /* pm_dc_pref_sw_alloc\000other\000Prefetch stream allocated by software prefetching\000event=0xf8a4\000\00000\000\000 */
{ 358282 }, /* pm_dc_pref_xcons_alloc\000other\000Prefetch stream allocated in the Ultra conservative phase by either the hardware prefetch mechanism or software prefetch\000event=0xf8b4\000\00000\000\000 */
{ 328956 }, /* pm_decode_fusion_const_gen\000other\00032-bit constant generation\000event=0x48b4\000\00000\000\000 */
{ 350978 }, /* pm_decode_fusion_ld_st_disp\000other\00032-bit displacement D-form and 16-bit displacement X-form\000event=0x48a8\000\00000\000\000 */
{ 317352 }, /* pm_decode_hold_ict_full\000other\000Counts the number of cycles in which the IFU was not able to decode and transmit one or more instructions because all itags were in use.  This means the ICT is full for this thread\000event=0x58a8\000\00000\000\000 */
{ 311845 }, /* pm_derat_miss_16g_1g\000other\000Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) or 1G (radix mode)\000event=0x4c054\000\00000\000\000 */
{ 381173 }, /* pm_derat_miss_16m_2m\000pipeline\000Data ERAT Miss (Data TLB Access) page size 16M (HPT mode) or 2M (Radix mode)\000event=0x3c054\000\00000\000\000 */
{ 375169 }, /* pm_derat_miss_4k\000pipeline\000Data ERAT Miss (Data TLB Access) page size 4K\000event=0x1c056\000\00000\000\000 */
{ 385681 }, /* pm_derat_miss_64k\000pipeline\000Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2c054\000\00000\000\000 */
{ 371949 }, /* pm_dfu_busy\000pipeline\000Cycles in which all 4 Decimal Floating Point units are busy. The DFU is running at capacity\000event=0x4d04c\000\00000\000\000 */
{ 318948 }, /* pm_disp_clb_held_bal\000other\000Dispatch/CLB Hold: Balance Flush\000event=0x288c\000\00000\000\000 */
{ 340427 }, /* pm_disp_clb_held_sb\000other\000Dispatch/CLB Hold: Scoreboard\000event=0x2090\000\00000\000\000 */
{ 314334 }, /* pm_disp_clb_held_tlbie\000other\000Dispatch Hold: Due to TLBIE\000event=0x2890\000\00000\000\000 */
{ 265703 }, /* pm_disp_held\000pipeline\000Dispatch Held\000event=0x10006\000\00000\000\000 */
{ 304362 }, /* pm_disp_held_hb_full\000marked\000Dispatch held due to History Buffer full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x3d05c\000\00000\000\000 */
{ 310770 }, /* pm_disp_held_issq_full\000other\000Dispatch held due to Issue q full. Includes issue queue and branch queue\000event=0x20006\000\00000\000\000 */
{ 348909 }, /* pm_disp_held_tbegin\000other\000This outer tbegin transaction cannot be dispatched until the previous tend instruction completes\000event=0x28b0\000\00000\000\000 */
{ 293518 }, /* pm_disp_starved\000marked\000Dispatched Starved\000event=0x30008\000\00000\000\000 */
{ 392514 }, /* pm_dp_qp_flop_cmpl\000translation\000Double-Precion or Quad-Precision instruction completed\000event=0x4d05c\000\00000\000\000 */
{ 397259 }, /* pm_dpteg_from_dl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e048\000\00000\000\000 */
{ 393768 }, /* pm_dpteg_from_dl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e048\000\00000\000\000 */
{ 397958 }, /* pm_dpteg_from_dl4\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04c\000\00000\000\000 */
{ 392619 }, /* pm_dpteg_from_dmem\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04c\000\00000\000\000 */
{ 301259 }, /* pm_dpteg_from_l2\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e042\000\00000\000\000 */
{ 374560 }, /* pm_dpteg_from_l21_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e046\000\00000\000\000 */
{ 384515 }, /* pm_dpteg_from_l21_shr\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e046\000\00000\000\000 */
{ 355686 }, /* pm_dpteg_from_l2_mepf\000other\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e040\000\00000\000\000 */
{ 373232 }, /* pm_dpteg_from_l2_no_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e040\000\00000\000\000 */
{ 364852 }, /* pm_dpteg_from_l2miss\000other\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04e\000\00000\000\000 */
{ 284876 }, /* pm_dpteg_from_l3\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e042\000\00000\000\000 */
{ 311048 }, /* pm_dpteg_from_l31_eco_mod\000other\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e044\000\00000\000\000 */
{ 291817 }, /* pm_dpteg_from_l31_eco_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e044\000\00000\000\000 */
{ 304807 }, /* pm_dpteg_from_l31_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e044\000\00000\000\000 */
{ 288894 }, /* pm_dpteg_from_l31_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e046\000\00000\000\000 */
{ 376794 }, /* pm_dpteg_from_l3_disp_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e042\000\00000\000\000 */
{ 380601 }, /* pm_dpteg_from_l3_mepf\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e042\000\00000\000\000 */
{ 301949 }, /* pm_dpteg_from_l3_no_conflict\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e044\000\00000\000\000 */
{ 389267 }, /* pm_dpteg_from_l3miss\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04e\000\00000\000\000 */
{ 391845 }, /* pm_dpteg_from_ll4\000pmc\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04c\000\00000\000\000 */
{ 297957 }, /* pm_dpteg_from_lmem\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e048\000\00000\000\000 */
{ 390971 }, /* pm_dpteg_from_memory\000pmc\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04c\000\00000\000\000 */
{ 336548 }, /* pm_dpteg_from_off_chip_cache\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4e04a\000\00000\000\000 */
{ 365568 }, /* pm_dpteg_from_on_chip_cache\000other\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e048\000\00000\000\000 */
{ 379989 }, /* pm_dpteg_from_rl2l3_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e046\000\00000\000\000 */
{ 379426 }, /* pm_dpteg_from_rl2l3_shr\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1e04a\000\00000\000\000 */
{ 360152 }, /* pm_dpteg_from_rl4\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2e04a\000\00000\000\000 */
{ 284223 }, /* pm_dpteg_from_rmem\000frontend\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3e04a\000\00000\000\000 */
{ 343796 }, /* pm_dside_l2memacc\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory (excluding hpcread64 accesses), i.e., total memory accesses by RCs\000event=0x36092\000\00000\000\000 */
{ 321348 }, /* pm_dside_mru_touch\000other\000D-side L2 MRU touch commands sent to the L2\000event=0x26884\000\00000\000\000 */
{ 342798 }, /* pm_dside_other_64b_l2memacc\000other\000Valid when first beat of data comes in for an D-side fetch where data came EXCLUSIVELY from memory that was for hpc_read64, (RC had to fetch other 64B of a line from MC) i.e., number of times RC had to go to memory to get 'missing' 64B\000event=0x36892\000\00000\000\000 */
{ 385240 }, /* pm_dslb_miss\000pipeline\000gate_and(sd_pc_c0_comp_valid AND sd_pc_c0_comp_thread(0:1)=tid,sd_pc_c0_comp_ppc_count(0:3)) + gate_and(sd_pc_c1_comp_valid AND sd_pc_c1_comp_thread(0:1)=tid,sd_pc_c1_comp_ppc_count(0:3))\000event=0xd0a8\000\00000\000\000 */
{ 378787 }, /* pm_dtlb_miss\000pipeline\000Data PTEG reload\000event=0x300fc\000\00000\000\000 */
{ 386712 }, /* pm_dummy1_remove_me\000pipeline\000Space holder for L2_PC_PM_MK_LDST_SCOPE_PRED_STATUS\000event=0x40062\000\00000\000\000 */
{ 383689 }, /* pm_dummy2_remove_me\000pipeline\000Space holder for LS_PC_RELOAD_RA\000event=0x40064\000\00000\000\000 */
{ 321661 }, /* pm_eat_force_mispred\000other\000XL-form branch was mispredicted due to the predicted target address missing from EAT.  The EAT forces a mispredict in this case since there is no predicated target to validate.  This is a rare case that may occur when the EAT is full and a branch is issued\000event=0x50a8\000\00000\000\000 */
{ 335951 }, /* pm_eat_full_cyc\000other\000Cycles No room in EAT\000event=0x4084\000\00000\000\000 */
{ 368099 }, /* pm_ee_off_ext_int\000other\000CyclesMSR[EE] is off and external interrupts are active\000event=0x2080\000\00000\000\000 */
{ 265840 }, /* pm_ext_int\000pipeline\000external interrupt\000event=0x200f8\000\00000\000\000 */
{ 375764 }, /* pm_flop_cmpl\000pipeline\000Floating Point Operation Finished\000event=0x4505e\000\00000\000\000 */
{ 114312 }, /* pm_flush\000pipeline\000Flush (any type)\000event=0x400f8\000\00000\000\000 */
{ 278369 }, /* pm_flush_completion\000floating point\000The instruction that was next to complete did not complete because it suffered a flush\000event=0x30012\000\00000\000\000 */
{ 368891 }, /* pm_flush_disp\000other\000Dispatch flush\000event=0x2880\000\00000\000\000 */
{ 359028 }, /* pm_flush_disp_sb\000other\000Dispatch Flush: Scoreboard\000event=0x2088\000\00000\000\000 */
{ 315345 }, /* pm_flush_disp_tlbie\000other\000Dispatch Flush: TLBIE\000event=0x2888\000\00000\000\000 */
{ 311968 }, /* pm_flush_hb_restore_cyc\000other\000Cycles in which no new instructions can be dispatched to the ICT after a flush.  History buffer recovery\000event=0x2084\000\00000\000\000 */
{ 360869 }, /* pm_flush_lsu\000other\000LSU flushes.  Includes all lsu flushes\000event=0x58a4\000\00000\000\000 */
{ 338487 }, /* pm_flush_mpred\000other\000Branch mispredict flushes.  Includes target and address misprecition\000event=0x50a4\000\00000\000\000 */
{ 348119 }, /* pm_fma_cmpl\000other\000two flops operation completed (fmadd, fnmadd, fmsub, fnmsub) Scalar instructions only\000event=0x45054\000\00000\000\000 */
{ 390444 }, /* pm_freq_down\000pmc\000Power Management: Below Threshold B\000event=0x3000c\000\00000\000\000 */
{ 293732 }, /* pm_freq_up\000marked\000Power Management: Above Threshold A\000event=0x4000c\000\00000\000\000 */
{ 292657 }, /* pm_fxu_1plus_busy\000marked\000At least one of the 4 FXU units is busy\000event=0x3000e\000\00000\000\000 */
{ 387848 }, /* pm_fxu_busy\000pipeline\000Cycles in which all 4 FXUs are busy. The FXU is running at capacity\000event=0x2000e\000\00000\000\000 */
{ 385539 }, /* pm_fxu_fin\000pipeline\000The fixed point unit Unit finished an instruction. Instructions that finish may not necessary complete\000event=0x40004\000\00000\000\000 */
{ 373496 }, /* pm_fxu_idle\000pipeline\000Cycles in which FXU0, FXU1, FXU2, and FXU3 are all idle\000event=0x24052\000\00000\000\000 */
{ 303288 }, /* pm_grp_pump_cpred\000marked\000Initial and Final Pump Scope and data sourced across this scope was group pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20050\000\00000\000\000 */
{ 379058 }, /* pm_grp_pump_mpred\000pipeline\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x20052\000\00000\000\000 */
{ 353741 }, /* pm_grp_pump_mpred_rty\000other\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10052\000\00000\000\000 */
{ 378381 }, /* pm_hv_cyc\000pipeline\000Cycles in which msr_hv is high. Note that this event does not take msr_pr into consideration\000event=0x2000a\000\00000\000\000 */
{ 315814 }, /* pm_hwsync\000other\000A hwsync instruction was decoded and transferred\000event=0xd0b0\000\00000\000\000 */
{ 313164 }, /* pm_ibuf_full_cyc\000other\000Cycles No room in ibuff\000event=0x4884\000\00000\000\000 */
{ 385774 }, /* pm_ic_demand_cyc\000pipeline\000Icache miss demand cycles\000event=0x10018\000\00000\000\000 */
{ 209080 }, /* pm_ic_demand_l2_bht_redirect\000other\000L2 I cache demand request due to BHT redirect, branch redirect ( 2 bubbles 3 cycles)\000event=0x4098\000\00000\000\000 */
{ 334260 }, /* pm_ic_demand_l2_br_redirect\000other\000L2 I cache demand request due to branch Mispredict ( 15 cycle path)\000event=0x4898\000\00000\000\000 */
{ 209338 }, /* pm_ic_demand_req\000other\000Demand Instruction fetch request\000event=0x4088\000\00000\000\000 */
{ 314273 }, /* pm_ic_invalidate\000other\000Ic line invalidated\000event=0x5888\000\00000\000\000 */
{ 377996 }, /* pm_ic_miss_cmpl\000pipeline\000Non-speculative icache miss, counted at completion\000event=0x45058\000\00000\000\000 */
{ 364428 }, /* pm_ic_miss_icbi\000other\000threaded version, IC Misses where we got EA dir hit but no sector valids were on. ICBI took line out\000event=0x5094\000\00000\000\000 */
{ 369653 }, /* pm_ic_pref_cancel_hit\000other\000Prefetch Canceled due to icache hit\000event=0x4890\000\00000\000\000 */
{ 333316 }, /* pm_ic_pref_cancel_l2\000other\000L2 Squashed a demand or prefetch request\000event=0x4094\000\00000\000\000 */
{ 209620 }, /* pm_ic_pref_cancel_page\000other\000Prefetch Canceled due to page boundary\000event=0x4090\000\00000\000\000 */
{ 332048 }, /* pm_ic_pref_req\000other\000Instruction prefetch requests\000event=0x4888\000\00000\000\000 */
{ 332419 }, /* pm_ic_pref_write\000other\000Instruction prefetch written into IL1\000event=0x488c\000\00000\000\000 */
{ 326836 }, /* pm_ic_reload_private\000other\000Reloading line was brought in private for a specific thread.  Most lines are brought in shared for all eight threads.  If RA does not match then invalidates and then brings it shared to other thread. In P7 line brought in private , then line was invalidat\000event=0x4894\000\00000\000\000 */
{ 373833 }, /* pm_ict_empty_cyc\000pipeline\000Cycles in which the ICT is completely empty. No itags are assigned to any thread\000event=0x20008\000\00000\000\000 */
{ 384105 }, /* pm_ict_noslot_br_mpred\000pipeline\000Ict empty for this thread due to branch mispred\000event=0x4d01e\000\00000\000\000 */
{ 378193 }, /* pm_ict_noslot_br_mpred_icmiss\000pipeline\000Ict empty for this thread due to Icache Miss and branch mispred\000event=0x34058\000\00000\000\000 */
{ 376686 }, /* pm_ict_noslot_cyc\000pipeline\000Number of cycles the ICT has no itags assigned to this thread\000event=0x100f8\000\00000\000\000 */
{ 382108 }, /* pm_ict_noslot_disp_held\000pipeline\000Cycles in which the NTC instruction is held at dispatch for any reason\000event=0x4e01a\000\00000\000\000 */
{ 343242 }, /* pm_ict_noslot_disp_held_hb_full\000other\000Ict empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF; CR; XVF (XER/VSCR/FPSCR)\000event=0x30018\000\00000\000\000 */
{ 338301 }, /* pm_ict_noslot_disp_held_issq\000other\000Ict empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000event=0x2d01e\000\00000\000\000 */
{ 376139 }, /* pm_ict_noslot_disp_held_sync\000pipeline\000Dispatch held due to a synchronizing instruction at dispatch\000event=0x4d01c\000\00000\000\000 */
{ 379746 }, /* pm_ict_noslot_disp_held_tbegin\000pipeline\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000event=0x10064\000\00000\000\000 */
{ 382536 }, /* pm_ict_noslot_ic_l3\000pipeline\000Ict empty for this thread due to icache misses that were sourced from the local L3\000event=0x3e052\000\00000\000\000 */
{ 375924 }, /* pm_ict_noslot_ic_l3miss\000pipeline\000Ict empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000event=0x4e010\000\00000\000\000 */
{ 376257 }, /* pm_ict_noslot_ic_miss\000pipeline\000Ict empty for this thread due to Icache Miss\000event=0x2d01a\000\00000\000\000 */
{ 372081 }, /* pm_ierat_reload\000pipeline\000Number of I-ERAT reloads\000event=0x100f6\000\00000\000\000 */
{ 375839 }, /* pm_ierat_reload_16m\000pipeline\000IERAT Reloaded (Miss) for a 16M page\000event=0x4006a\000\00000\000\000 */
{ 310581 }, /* pm_ierat_reload_4k\000other\000IERAT reloaded (after a miss) for 4K pages\000event=0x20064\000\00000\000\000 */
{ 334662 }, /* pm_ierat_reload_64k\000other\000IERAT Reloaded (Miss) for a 64k page\000event=0x3006a\000\00000\000\000 */
{ 387707 }, /* pm_inst_chip_pump_cpred\000pipeline\000Initial and Final Pump Scope was chip pump (prediction=correct) for an instruction fetch\000event=0x14050\000\00000\000\000 */
{ 373671 }, /* pm_inst_cmpl\000pipeline\000Number of PowerPC Instructions that completed\000event=0x2\000\00000\000\000 */
{ 370359 }, /* pm_inst_disp\000other\000# PPC Dispatched\000event=0x200f2\000\00000\000\000 */
{ 299038 }, /* pm_inst_from_dl2l3_mod\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x44048\000\00000\000\000 */
{ 305087 }, /* pm_inst_from_dl2l3_shr\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to an instruction fetch (not prefetch)\000event=0x34048\000\00000\000\000 */
{ 297530 }, /* pm_inst_from_dl4\000marked\000The processor's Instruction cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x3404c\000\00000\000\000 */
{ 292460 }, /* pm_inst_from_dmem\000marked\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group (Distant) due to an instruction fetch (not prefetch)\000event=0x4404c\000\00000\000\000 */
{ 337030 }, /* pm_inst_from_l1\000other\000Instruction fetches from L1.  L1 instruction hit\000event=0x4080\000\00000\000\000 */
{ 293579 }, /* pm_inst_from_l2\000marked\000The processor's Instruction cache was reloaded from local core's L2 due to an instruction fetch (not prefetch)\000event=0x14042\000\00000\000\000 */
{ 351259 }, /* pm_inst_from_l21_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x44046\000\00000\000\000 */
{ 394616 }, /* pm_inst_from_l21_shr\000translation\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L2 on the same chip due to an instruction fetch (not prefetch)\000event=0x34046\000\00000\000\000 */
{ 298834 }, /* pm_inst_from_l2_disp_conflict_ldhitst\000marked\000The processor's Instruction cache was reloaded from local core's L2 with load hit store conflict due to an instruction fetch (not prefetch)\000event=0x34040\000\00000\000\000 */
{ 289476 }, /* pm_inst_from_l2_disp_conflict_other\000marked\000The processor's Instruction cache was reloaded from local core's L2 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x44040\000\00000\000\000 */
{ 338028 }, /* pm_inst_from_l2_mepf\000other\000The processor's Instruction cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24040\000\00000\000\000 */
{ 290945 }, /* pm_inst_from_l2_no_conflict\000marked\000The processor's Instruction cache was reloaded from local core's L2 without conflict due to an instruction fetch (not prefetch)\000event=0x14040\000\00000\000\000 */
{ 396876 }, /* pm_inst_from_l2miss\000translation\000The processor's Instruction cache was reloaded from a location other than the local core's L2 due to an instruction fetch (not prefetch)\000event=0x1404e\000\00000\000\000 */
{ 395856 }, /* pm_inst_from_l3\000translation\000The processor's Instruction cache was reloaded from local core's L3 due to an instruction fetch (not prefetch)\000event=0x44042\000\00000\000\000 */
{ 349574 }, /* pm_inst_from_l31_eco_mod\000other\000The processor's Instruction cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x44044\000\00000\000\000 */
{ 299626 }, /* pm_inst_from_l31_eco_shr\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x34044\000\00000\000\000 */
{ 294633 }, /* pm_inst_from_l31_mod\000marked\000The processor's Instruction cache was reloaded with Modified (M) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x24044\000\00000\000\000 */
{ 300422 }, /* pm_inst_from_l31_shr\000marked\000The processor's Instruction cache was reloaded with Shared (S) data from another core's L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14046\000\00000\000\000 */
{ 397064 }, /* pm_inst_from_l3_disp_conflict\000translation\000The processor's Instruction cache was reloaded from local core's L3 with dispatch conflict due to an instruction fetch (not prefetch)\000event=0x34042\000\00000\000\000 */
{ 398497 }, /* pm_inst_from_l3_mepf\000translation\000The processor's Instruction cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to an instruction fetch (not prefetch)\000event=0x24042\000\00000\000\000 */
{ 397771 }, /* pm_inst_from_l3_no_conflict\000translation\000The processor's Instruction cache was reloaded from local core's L3 without conflict due to an instruction fetch (not prefetch)\000event=0x14044\000\00000\000\000 */
{ 285563 }, /* pm_inst_from_l3miss\000frontend\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x300fa\000\00000\000\000 */
{ 291127 }, /* pm_inst_from_l3miss_mod\000marked\000The processor's Instruction cache was reloaded from a location other than the local core's L3 due to a instruction fetch\000event=0x4404e\000\00000\000\000 */
{ 298607 }, /* pm_inst_from_ll4\000marked\000The processor's Instruction cache was reloaded from the local chip's L4 cache due to an instruction fetch (not prefetch)\000event=0x1404c\000\00000\000\000 */
{ 312339 }, /* pm_inst_from_lmem\000other\000The processor's Instruction cache was reloaded from the local chip's Memory due to an instruction fetch (not prefetch)\000event=0x24048\000\00000\000\000 */
{ 383126 }, /* pm_inst_from_memory\000pipeline\000The processor's Instruction cache was reloaded from a memory location including L4 from local remote or distant due to an instruction fetch (not prefetch)\000event=0x2404c\000\00000\000\000 */
{ 341405 }, /* pm_inst_from_off_chip_cache\000other\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to an instruction fetch (not prefetch)\000event=0x4404a\000\00000\000\000 */
{ 275542 }, /* pm_inst_from_on_chip_cache\000cache\000The processor's Instruction cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to an instruction fetch (not prefetch)\000event=0x14048\000\00000\000\000 */
{ 277559 }, /* pm_inst_from_rl2l3_mod\000cache\000The processor's Instruction cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x24046\000\00000\000\000 */
{ 276143 }, /* pm_inst_from_rl2l3_shr\000cache\000The processor's Instruction cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to an instruction fetch (not prefetch)\000event=0x1404a\000\00000\000\000 */
{ 275952 }, /* pm_inst_from_rl4\000cache\000The processor's Instruction cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x2404a\000\00000\000\000 */
{ 308308 }, /* pm_inst_from_rmem\000memory\000The processor's Instruction cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to an instruction fetch (not prefetch)\000event=0x3404a\000\00000\000\000 */
{ 309949 }, /* pm_inst_grp_pump_cpred\000memory\000Initial and Final Pump Scope was group pump (prediction=correct) for an instruction fetch (demand only)\000event=0x2c05c\000\00000\000\000 */
{ 349109 }, /* pm_inst_grp_pump_mpred\000other\000Final Pump Scope (Group) ended up either larger or smaller than Initial Pump Scope for an instruction fetch (demand only)\000event=0x2c05e\000\00000\000\000 */
{ 385088 }, /* pm_inst_grp_pump_mpred_rty\000pipeline\000Final Pump Scope (Group) ended up larger than Initial Pump Scope (Chip) for an instruction fetch\000event=0x14052\000\00000\000\000 */
{ 329796 }, /* pm_inst_imc_match_cmpl\000other\000IMC Match Count\000event=0x4001c\000\00000\000\000 */
{ 286048 }, /* pm_inst_pump_cpred\000frontend\000Pump prediction correct. Counts across all types of pumps for an instruction fetch\000event=0x14054\000\00000\000\000 */
{ 286257 }, /* pm_inst_pump_mpred\000frontend\000Pump misprediction. Counts across all types of pumps for an instruction fetch\000event=0x44052\000\00000\000\000 */
{ 283872 }, /* pm_inst_sys_pump_cpred\000frontend\000Initial and Final Pump Scope was system pump (prediction=correct) for an instruction fetch\000event=0x34050\000\00000\000\000 */
{ 279648 }, /* pm_inst_sys_pump_mpred\000frontend\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for an instruction fetch\000event=0x34052\000\00000\000\000 */
{ 280311 }, /* pm_inst_sys_pump_mpred_rty\000frontend\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for an instruction fetch\000event=0x44050\000\00000\000\000 */
{ 285379 }, /* pm_iops_cmpl\000frontend\000Internal Operations completed\000event=0x24050\000\00000\000\000 */
{ 140284 }, /* pm_ipteg_from_dl2l3_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x45048\000\00000\000\000 */
{ 358450 }, /* pm_ipteg_from_dl2l3_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a instruction side request\000event=0x35048\000\00000\000\000 */
{ 348458 }, /* pm_ipteg_from_dl4\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a instruction side request\000event=0x3504c\000\00000\000\000 */
{ 355246 }, /* pm_ipteg_from_dmem\000other\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a instruction side request\000event=0x4504c\000\00000\000\000 */
{ 305470 }, /* pm_ipteg_from_l2\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 due to a instruction side request\000event=0x15042\000\00000\000\000 */
{ 306557 }, /* pm_ipteg_from_l21_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a instruction side request\000event=0x45046\000\00000\000\000 */
{ 299282 }, /* pm_ipteg_from_l21_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a instruction side request\000event=0x35046\000\00000\000\000 */
{ 293938 }, /* pm_ipteg_from_l2_mepf\000marked\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a instruction side request\000event=0x25040\000\00000\000\000 */
{ 351741 }, /* pm_ipteg_from_l2_no_conflict\000other\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a instruction side request\000event=0x15040\000\00000\000\000 */
{ 293204 }, /* pm_ipteg_from_l2miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a instruction side request\000event=0x1504e\000\00000\000\000 */
{ 305329 }, /* pm_ipteg_from_l3\000marked\000A Page Table Entry was loaded into the TLB from local core's L3 due to a instruction side request\000event=0x45042\000\00000\000\000 */
{ 288315 }, /* pm_ipteg_from_l31_eco_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x45044\000\00000\000\000 */
{ 287084 }, /* pm_ipteg_from_l31_eco_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a instruction side request\000event=0x35044\000\00000\000\000 */
{ 278713 }, /* pm_ipteg_from_l31_mod\000frontend\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a instruction side request\000event=0x25044\000\00000\000\000 */
{ 282216 }, /* pm_ipteg_from_l31_shr\000frontend\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a instruction side request\000event=0x15046\000\00000\000\000 */
{ 351966 }, /* pm_ipteg_from_l3_disp_conflict\000other\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a instruction side request\000event=0x35042\000\00000\000\000 */
{ 142300 }, /* pm_ipteg_from_l3_mepf\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a instruction side request\000event=0x25042\000\00000\000\000 */
{ 142494 }, /* pm_ipteg_from_l3_no_conflict\000frontend\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a instruction side request\000event=0x15044\000\00000\000\000 */
{ 141947 }, /* pm_ipteg_from_l3miss\000frontend\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a instruction side request\000event=0x4504e\000\00000\000\000 */
{ 338595 }, /* pm_ipteg_from_ll4\000other\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a instruction side request\000event=0x1504c\000\00000\000\000 */
{ 344979 }, /* pm_ipteg_from_lmem\000other\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a instruction side request\000event=0x25048\000\00000\000\000 */
{ 396448 }, /* pm_ipteg_from_memory\000translation\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a instruction side request\000event=0x2504c\000\00000\000\000 */
{ 396642 }, /* pm_ipteg_from_off_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a instruction side request\000event=0x4504a\000\00000\000\000 */
{ 394406 }, /* pm_ipteg_from_on_chip_cache\000translation\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a instruction side request\000event=0x15048\000\00000\000\000 */
{ 398706 }, /* pm_ipteg_from_rl2l3_mod\000translation\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x25046\000\00000\000\000 */
{ 392992 }, /* pm_ipteg_from_rl2l3_shr\000translation\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a instruction side request\000event=0x1504a\000\00000\000\000 */
{ 395051 }, /* pm_ipteg_from_rl4\000translation\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a instruction side request\000event=0x2504a\000\00000\000\000 */
{ 398939 }, /* pm_ipteg_from_rmem\000translation\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a instruction side request\000event=0x3504a\000\00000\000\000 */
{ 348718 }, /* pm_iside_disp\000other\000All I-side-instruction-fetch dispatch attempts for this thread\000event=0x1688a\000\00000\000\000 */
{ 340018 }, /* pm_iside_disp_fail_addr\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflict with an L2 machine already working on this line (e.g. ld-hit-stq or RC/CO/SN machines)\000event=0x2608a\000\00000\000\000 */
{ 354078 }, /* pm_iside_disp_fail_other\000other\000All I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflict with an L2 machine (e.g. no available RC/CO machines)\000event=0x2688a\000\00000\000\000 */
{ 350231 }, /* pm_iside_l2memacc\000other\000Valid when first beat of data comes in for an I-side fetch where data came from memory\000event=0x26890\000\00000\000\000 */
{ 356138 }, /* pm_iside_mru_touch\000other\000I-side L2 MRU touch sent to L2 for this thread I-side L2 MRU touch commands sent to the L2 for this thread\000event=0x46880\000\00000\000\000 */
{ 345129 }, /* pm_islb_miss\000other\000Instruction SLB Miss - Total of all segment sizes\000event=0xd8a8\000\00000\000\000 */
{ 354412 }, /* pm_isq_0_8_entries\000other\000Cycles in which 8 or less Issue Queue entries are in use. This is a shared event, not per thread\000event=0x3005a\000\00000\000\000 */
{ 303566 }, /* pm_isq_36_44_entries\000marked\000Cycles in which 36 or more Issue Queue entries are in use. This is a shared event, not per thread. There are 44 issue queue entries across 4 slices in the whole core\000event=0x4000a\000\00000\000\000 */
{ 345819 }, /* pm_isu0_iss_hold_all\000other\000All ISU rejects\000event=0x3080\000\00000\000\000 */
{ 310290 }, /* pm_isu1_iss_hold_all\000other\000All ISU rejects\000event=0x3084\000\00000\000\000 */
{ 370886 }, /* pm_isu2_iss_hold_all\000other\000All ISU rejects\000event=0x3880\000\00000\000\000 */
{ 314009 }, /* pm_isu3_iss_hold_all\000other\000All ISU rejects\000event=0x3884\000\00000\000\000 */
{ 344092 }, /* pm_isync\000other\000Isync completion count per thread\000event=0x2884\000\00000\000\000 */
{ 301800 }, /* pm_itlb_miss\000marked\000ITLB Reloaded. Counts 1 per ITLB miss for HPT but multiple for radix depending on number of levels traveresed\000event=0x400fc\000\00000\000\000 */
{ 292103 }, /* pm_l1_dcache_reload_valid\000marked\000DL1 reloaded due to Demand Load\000event=0x300f6\000\00000\000\000 */
{ 305710 }, /* pm_l1_dcache_reloaded_all\000marked\000L1 data cache reloaded for demand. If MMCR1[16] is 1, prefetches will be included as well\000event=0x1002c\000\00000\000\000 */
{ 328594 }, /* pm_l1_demand_write\000other\000Instruction Demand sectors written into IL1\000event=0x408c\000\00000\000\000 */
{ 298771 }, /* pm_l1_icache_miss\000marked\000Demand iCache Miss\000event=0x200fd\000\00000\000\000 */
{ 303994 }, /* pm_l1_icache_reloaded_all\000marked\000Counts all Icache reloads includes demand, prefetch, prefetch turned into demand and demand turned into prefetch\000event=0x40012\000\00000\000\000 */
{ 296202 }, /* pm_l1_icache_reloaded_pref\000marked\000Counts all Icache prefetch reloads ( includes demand turned into prefetch)\000event=0x30068\000\00000\000\000 */
{ 320691 }, /* pm_l1_pref\000other\000A data line was written to the L1 due to a hardware or software prefetch\000event=0x20054\000\00000\000\000 */
{ 318852 }, /* pm_l1_sw_pref\000other\000Software L1 Prefetches, including SW Transient Prefetches\000event=0xe880\000\00000\000\000 */
{ 355125 }, /* pm_l1pf_l2memacc\000other\000Valid when first beat of data comes in for an L1PF where data came from memory\000event=0x16890\000\00000\000\000 */
{ 337311 }, /* pm_l2_castout_mod\000other\000L2 Castouts - Modified (M,Mu,Me)\000event=0x16082\000\00000\000\000 */
{ 344159 }, /* pm_l2_castout_shr\000other\000L2 Castouts - Shared (Tx,Sx)\000event=0x16882\000\00000\000\000 */
{ 320525 }, /* pm_l2_chip_pump\000other\000RC requests that were local (aka chip) pump attempts\000event=0x46088\000\00000\000\000 */
{ 312244 }, /* pm_l2_dc_inv\000other\000D-cache invalidates sent over the reload bus to the core\000event=0x26882\000\00000\000\000 */
{ 328138 }, /* pm_l2_disp_all_l2miss\000other\000All successful D-side-Ld/St or I-side-instruction-fetch dispatches for this thread that were an L2 miss\000event=0x46080\000\00000\000\000 */
{ 362771 }, /* pm_l2_group_pump\000other\000RC requests that were on group (aka nodel) pump attempts\000event=0x46888\000\00000\000\000 */
{ 338810 }, /* pm_l2_grp_guess_correct\000other\000L2 guess grp (GS or NNS) and guess was correct (data intra-group AND ^on-chip)\000event=0x26088\000\00000\000\000 */
{ 362081 }, /* pm_l2_grp_guess_wrong\000other\000L2 guess grp (GS or NNS) and guess was not correct (ie data on-chip OR beyond-group)\000event=0x26888\000\00000\000\000 */
{ 317581 }, /* pm_l2_ic_inv\000other\000I-cache Invalidates sent over the realod bus to the core\000event=0x26082\000\00000\000\000 */
{ 348327 }, /* pm_l2_inst\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread\000event=0x36080\000\00000\000\000 */
{ 369128 }, /* pm_l2_inst_miss\000other\000All successful I-side-instruction-fetch (e.g. i-demand, i-prefetch) dispatches for this thread that were an L2 miss\000event=0x36880\000\00000\000\000 */
{ 362966 }, /* pm_l2_ld\000other\000All successful D-side Load dispatches for this thread (L2 miss + L2 hits)\000event=0x16080\000\00000\000\000 */
{ 330737 }, /* pm_l2_ld_disp\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread\000event=0x36082\000\00000\000\000 */
{ 353003 }, /* pm_l2_ld_hit\000other\000All successful D-side-Ld or I-side-instruction-fetch dispatches for this thread that were L2 hits\000event=0x36882\000\00000\000\000 */
{ 344427 }, /* pm_l2_ld_miss\000other\000All successful D-Side Load dispatches that were an L2 miss for this thread\000event=0x26080\000\00000\000\000 */
{ 342183 }, /* pm_l2_ld_miss_128b\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16092\000\00000\000\000 */
{ 344231 }, /* pm_l2_ld_miss_64b\000other\000All successful D-side load dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B(i.e., M=1)\000event=0x26092\000\00000\000\000 */
{ 318247 }, /* pm_l2_loc_guess_correct\000other\000L2 guess local (LNS) and guess was correct (ie data local)\000event=0x16088\000\00000\000\000 */
{ 325870 }, /* pm_l2_loc_guess_wrong\000other\000L2 guess local (LNS) and guess was not correct (ie data not on chip)\000event=0x16888\000\00000\000\000 */
{ 350749 }, /* pm_l2_rc_st_done\000other\000Read-claim machine did store to line that was in Tx or Sx (Tagged or Shared state)\000event=0x36086\000\00000\000\000 */
{ 366993 }, /* pm_l2_rcld_disp\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread\000event=0x16084\000\00000\000\000 */
{ 331060 }, /* pm_l2_rcld_disp_fail_addr\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to an address collision conflicts with an L2 machines already working on this line (e.g. ld-hit-stq or Read-claim/Castout/Snoop machines)\000event=0x16884\000\00000\000\000 */
{ 327221 }, /* pm_l2_rcld_disp_fail_other\000other\000All D-side-Ld or I-side-instruction-fetch dispatch attempts for this thread that failed due to reasons other than an address collision conflicts with an L2 machines (e.g. Read-Claim/Snoop machine not available)\000event=0x26084\000\00000\000\000 */
{ 347654 }, /* pm_l2_rcst_disp\000other\000All D-side store dispatch attempts for this thread\000event=0x36084\000\00000\000\000 */
{ 371720 }, /* pm_l2_rcst_disp_fail_addr\000other\000All D-side store dispatch attempts for this thread that failed due to address collision with RC/CO/SN/SQ\000event=0x36884\000\00000\000\000 */
{ 347746 }, /* pm_l2_rcst_disp_fail_other\000other\000All D-side store dispatch attempts for this thread that failed due to reason other than address collision\000event=0x46084\000\00000\000\000 */
{ 325372 }, /* pm_l2_rty_ld\000other\000RC retries on PB for any load from core (excludes DCBFs)\000event=0x3688a\000\00000\000\000 */
{ 337932 }, /* pm_l2_rty_st\000other\000RC retries on PB for any store from core (excludes DCBFs)\000event=0x3608a\000\00000\000\000 */
{ 334996 }, /* pm_l2_sn_m_rd_done\000other\000Snoop dispatched for a read and was M (true M)\000event=0x46086\000\00000\000\000 */
{ 365864 }, /* pm_l2_sn_m_wr_done\000other\000SNP dispatched for a write and was M (true M); for DMA cacheinj this will pulse if rty/push is required (won't pulse if cacheinj is accepted)\000event=0x16086\000\00000\000\000 */
{ 336464 }, /* pm_l2_sn_sx_i_done\000other\000Snoop dispatched and went from Sx to Ix\000event=0x36886\000\00000\000\000 */
{ 369802 }, /* pm_l2_st\000other\000All successful D-side store dispatches for this thread (L2 miss + L2 hits)\000event=0x16880\000\00000\000\000 */
{ 369034 }, /* pm_l2_st_disp\000other\000All successful D-side store dispatches for this thread\000event=0x46082\000\00000\000\000 */
{ 357738 }, /* pm_l2_st_hit\000other\000All successful D-side store dispatches for this thread that were L2 hits\000event=0x46882\000\00000\000\000 */
{ 358167 }, /* pm_l2_st_miss\000other\000All successful D-Side Store dispatches that were an L2 miss for this thread\000event=0x26880\000\00000\000\000 */
{ 350031 }, /* pm_l2_st_miss_128b\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 128B (i.e., M=0)\000event=0x16892\000\00000\000\000 */
{ 345978 }, /* pm_l2_st_miss_64b\000other\000All successful D-side store dispatches that were an L2 miss (NOT Sx,Tx,Mx) for this thread and the RC calculated the request should be for 64B (i.e., M=1)\000event=0x26892\000\00000\000\000 */
{ 356638 }, /* pm_l2_sys_guess_correct\000other\000L2 guess system (VGS or RNS) and guess was correct (ie data beyond-group)\000event=0x36088\000\00000\000\000 */
{ 367973 }, /* pm_l2_sys_guess_wrong\000other\000L2 guess system (VGS or RNS) and guess was not correct (ie data ^beyond-group)\000event=0x36888\000\00000\000\000 */
{ 329626 }, /* pm_l2_sys_pump\000other\000RC requests that were system pump attempts\000event=0x4688a\000\00000\000\000 */
{ 345320 }, /* pm_l3_ci_hit\000other\000L3 Castins Hit (total count)\000event=0x260a2\000\00000\000\000 */
{ 329979 }, /* pm_l3_ci_miss\000other\000L3 castins miss (total count)\000event=0x268a2\000\00000\000\000 */
{ 353139 }, /* pm_l3_ci_usage\000other\000Rotating sample of 16 CI or CO actives\000event=0x168ac\000\00000\000\000 */
{ 371131 }, /* pm_l3_cinj\000other\000L3 castin of cache inject\000event=0x368a4\000\00000\000\000 */
{ 371020 }, /* pm_l3_co\000other\000L3 castout occurring (does not include casthrough or log writes (cinj/dmaw))\000event=0x360a8\000\00000\000\000 */
{ 355607 }, /* pm_l3_co0_busy\000other\000Lifetime, sample of CO machine 0 valid\000event=0x368ac\000\00000\000\000 */
{ 359822 }, /* pm_l3_co_l31\000other\000L3 CO to L3.1 OR of port 0 and 1 (lossy = may undercount if two cresps come in the same cyc)\000event=0x268a0\000\00000\000\000 */
{ 369538 }, /* pm_l3_co_lco\000other\000Total L3 COs occurred on LCO L3.1 (good cresp, may end up in mem on a retry)\000event=0x360a4\000\00000\000\000 */
{ 337179 }, /* pm_l3_co_mem\000other\000L3 CO to memory OR of port 0 and 1 (lossy = may undercount if two cresp come in the same cyc)\000event=0x260a0\000\00000\000\000 */
{ 335427 }, /* pm_l3_co_mepf\000other\000L3 CO of line in Mep state (includes casthrough to memory).  The Mepf state indicates that a line was brought in to satisfy an L3 prefetch request\000event=0x3e05e\000\00000\000\000 */
{ 371482 }, /* pm_l3_grp_guess_correct\000other\000Prefetch scope predictor selected GS or NNS and was correct\000event=0x168b2\000\00000\000\000 */
{ 361320 }, /* pm_l3_grp_guess_wrong_high\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was VGS or RNS\000event=0x368b2\000\00000\000\000 */
{ 312839 }, /* pm_l3_grp_guess_wrong_low\000other\000Prefetch scope predictor selected GS or NNS, but was wrong because scope was LNS\000event=0x360b2\000\00000\000\000 */
{ 318355 }, /* pm_l3_hit\000other\000L3 Hits (L2 miss hitting L3, including data/instrn/xlate)\000event=0x160a4\000\00000\000\000 */
{ 343744 }, /* pm_l3_l2_co_hit\000other\000L2 CO hits\000event=0x360a2\000\00000\000\000 */
{ 340788 }, /* pm_l3_l2_co_miss\000other\000L2 CO miss\000event=0x368a2\000\00000\000\000 */
{ 335613 }, /* pm_l3_lat_ci_hit\000other\000L3 Lateral Castins Hit\000event=0x460a2\000\00000\000\000 */
{ 368735 }, /* pm_l3_lat_ci_miss\000other\000L3 Lateral Castins Miss\000event=0x468a2\000\00000\000\000 */
{ 317927 }, /* pm_l3_ld_hit\000other\000L3 Hits for demand LDs\000event=0x260a4\000\00000\000\000 */
{ 338746 }, /* pm_l3_ld_miss\000other\000L3 Misses for demand LDs\000event=0x268a4\000\00000\000\000 */
{ 327799 }, /* pm_l3_ld_pref\000other\000L3 load prefetch, sourced from a hardware or software stream, was sent to the nest\000event=0xf0b0\000\00000\000\000 */
{ 328853 }, /* pm_l3_loc_guess_correct\000other\000Prefetch scope predictor selected LNS and was correct\000event=0x160b2\000\00000\000\000 */
{ 356538 }, /* pm_l3_loc_guess_wrong\000other\000Prefetch scope predictor selected LNS, but was wrong\000event=0x268b2\000\00000\000\000 */
{ 367200 }, /* pm_l3_miss\000other\000L3 Misses (L2 miss also missing L3, including data/instrn/xlate)\000event=0x168a4\000\00000\000\000 */
{ 368802 }, /* pm_l3_p0_co_l31\000other\000L3 CO to L3.1 (LCO) port 0 with or without data\000event=0x460aa\000\00000\000\000 */
{ 316651 }, /* pm_l3_p0_co_mem\000other\000L3 CO to memory port 0 with or without data\000event=0x360aa\000\00000\000\000 */
{ 368542 }, /* pm_l3_p0_co_rty\000other\000L3 CO received retry port 0 (memory only), every retry counted\000event=0x360ae\000\00000\000\000 */
{ 365183 }, /* pm_l3_p0_grp_pump\000other\000L3 PF sent with grp scope port 0, counts even retried requests\000event=0x260b0\000\00000\000\000 */
{ 331979 }, /* pm_l3_p0_lco_data\000other\000LCO sent with data port 0\000event=0x260aa\000\00000\000\000 */
{ 369980 }, /* pm_l3_p0_lco_no_data\000other\000Dataless L3 LCO sent port 0\000event=0x160aa\000\00000\000\000 */
{ 342696 }, /* pm_l3_p0_lco_rty\000other\000L3 initiated LCO received retry on port 0 (can try 4 times)\000event=0x160b4\000\00000\000\000 */
{ 352454 }, /* pm_l3_p0_node_pump\000other\000L3 PF sent with nodal scope port 0, counts even retried requests\000event=0x160b0\000\00000\000\000 */
{ 356448 }, /* pm_l3_p0_pf_rty\000other\000L3 PF received retry port 0, every retry counted\000event=0x160ae\000\00000\000\000 */
{ 334556 }, /* pm_l3_p0_sys_pump\000other\000L3 PF sent with sys scope port 0, counts even retried requests\000event=0x360b0\000\00000\000\000 */
{ 348820 }, /* pm_l3_p1_co_l31\000other\000L3 CO to L3.1 (LCO) port 1 with or without data\000event=0x468aa\000\00000\000\000 */
{ 327647 }, /* pm_l3_p1_co_mem\000other\000L3 CO to memory port 1 with or without data\000event=0x368aa\000\00000\000\000 */
{ 345216 }, /* pm_l3_p1_co_rty\000other\000L3 CO received retry port 1 (memory only), every retry counted\000event=0x368ae\000\00000\000\000 */
{ 324923 }, /* pm_l3_p1_grp_pump\000other\000L3 PF sent with grp scope port 1, counts even retried requests\000event=0x268b0\000\00000\000\000 */
{ 314144 }, /* pm_l3_p1_lco_data\000other\000LCO sent with data port 1\000event=0x268aa\000\00000\000\000 */
{ 326419 }, /* pm_l3_p1_lco_no_data\000other\000Dataless L3 LCO sent port 1\000event=0x168aa\000\00000\000\000 */
{ 318507 }, /* pm_l3_p1_lco_rty\000other\000L3 initiated LCO received retry on port 1 (can try 4 times)\000event=0x168b4\000\00000\000\000 */
{ 315897 }, /* pm_l3_p1_node_pump\000other\000L3 PF sent with nodal scope port 1, counts even retried requests\000event=0x168b0\000\00000\000\000 */
{ 368944 }, /* pm_l3_p1_pf_rty\000other\000L3 PF received retry port 1, every retry counted\000event=0x168ae\000\00000\000\000 */
{ 363222 }, /* pm_l3_p1_sys_pump\000other\000L3 PF sent with sys scope port 1, counts even retried requests\000event=0x368b0\000\00000\000\000 */
{ 322570 }, /* pm_l3_p2_co_rty\000other\000L3 CO received retry port 2 (memory only), every retry counted\000event=0x460ae\000\00000\000\000 */
{ 310668 }, /* pm_l3_p2_lco_rty\000other\000L3 initiated LCO received retry on port 2 (can try 4 times)\000event=0x260b4\000\00000\000\000 */
{ 356761 }, /* pm_l3_p2_pf_rty\000other\000L3 PF received retry port 2, every retry counted\000event=0x260ae\000\00000\000\000 */
{ 316436 }, /* pm_l3_p3_co_rty\000other\000L3 CO received retry port 3 (memory only), every retry counted\000event=0x468ae\000\00000\000\000 */
{ 329106 }, /* pm_l3_p3_lco_rty\000other\000L3 initiated LCO received retry on port 3 (can try 4 times)\000event=0x268b4\000\00000\000\000 */
{ 354761 }, /* pm_l3_p3_pf_rty\000other\000L3 PF received retry port 3, every retry counted\000event=0x268ae\000\00000\000\000 */
{ 358748 }, /* pm_l3_pf0_busy\000other\000Lifetime, sample of PF machine 0 valid\000event=0x360b4\000\00000\000\000 */
{ 358679 }, /* pm_l3_pf_hit_l3\000other\000L3 PF hit in L3 (abandoned)\000event=0x260a8\000\00000\000\000 */
{ 324654 }, /* pm_l3_pf_miss_l3\000other\000L3 PF missed in L3\000event=0x160a0\000\00000\000\000 */
{ 329343 }, /* pm_l3_pf_off_chip_cache\000other\000L3 PF from Off chip cache\000event=0x368a0\000\00000\000\000 */
{ 314070 }, /* pm_l3_pf_off_chip_mem\000other\000L3 PF from Off chip memory\000event=0x468a0\000\00000\000\000 */
{ 330319 }, /* pm_l3_pf_on_chip_cache\000other\000L3 PF from On chip cache\000event=0x360a0\000\00000\000\000 */
{ 331341 }, /* pm_l3_pf_on_chip_mem\000other\000L3 PF from On chip memory\000event=0x460a0\000\00000\000\000 */
{ 371876 }, /* pm_l3_pf_usage\000other\000Rotating sample of 32 PF actives\000event=0x260ac\000\00000\000\000 */
{ 328059 }, /* pm_l3_rd0_busy\000other\000Lifetime, sample of RD machine 0 valid\000event=0x368b4\000\00000\000\000 */
{ 318609 }, /* pm_l3_rd_usage\000other\000Rotating sample of 16 RD actives\000event=0x268ac\000\00000\000\000 */
{ 357849 }, /* pm_l3_sn0_busy\000other\000Lifetime, sample of snooper machine 0 valid\000event=0x360ac\000\00000\000\000 */
{ 330542 }, /* pm_l3_sn_usage\000other\000Rotating sample of 16 snoop valids\000event=0x160ac\000\00000\000\000 */
{ 330856 }, /* pm_l3_sw_pref\000other\000L3 load prefetch, sourced from a software prefetch stream, was sent to the nest\000event=0xf8b0\000\00000\000\000 */
{ 362433 }, /* pm_l3_sys_guess_correct\000other\000Prefetch scope predictor selected VGS or RNS and was correct\000event=0x260b2\000\00000\000\000 */
{ 359355 }, /* pm_l3_sys_guess_wrong\000other\000Prefetch scope predictor selected VGS or RNS, but was wrong\000event=0x460b2\000\00000\000\000 */
{ 333237 }, /* pm_l3_trans_pf\000other\000L3 Transient prefetch received from L2\000event=0x468a4\000\00000\000\000 */
{ 355525 }, /* pm_l3_wi0_busy\000other\000Rotating sample of 8 WI valid (duplicate)\000event=0x160b6\000\00000\000\000 */
{ 368646 }, /* pm_l3_wi_usage\000other\000Lifetime, sample of Write Inject machine 0 valid\000event=0x168a8\000\00000\000\000 */
{ 309264 }, /* pm_larx_fin\000memory\000Larx finished\000event=0x3c058\000\00000\000\000 */
{ 307965 }, /* pm_ld_cmpl\000memory\000count of Loads completed\000event=0x4003e\000\00000\000\000 */
{ 266726 }, /* pm_ld_l3miss_pend_cyc\000pipeline\000Cycles L3 miss was pending for this thread\000event=0x10062\000\00000\000\000 */
{ 280815 }, /* pm_ld_miss_l1\000frontend\000Load Missed L1, counted at execution time (can be greater than loads finished). LMQ merges are not included in this count. i.e. if a load instruction misses on an address that is already allocated on the LMQ, this event will not increment for that load). Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x3e054\000\00000\000\000 */
{ 324365 }, /* pm_ld_miss_l1_fin\000other\000Number of load instructions that finished with an L1 miss. Note that even if a load spans multiple slices this event will increment only once per load op\000event=0x2c04e\000\00000\000\000 */
{ 367676 }, /* pm_ld_ref_l1\000other\000All L1 D cache load references counted at finish, gated by reject\000event=0x100fc\000\00000\000\000 */
{ 336384 }, /* pm_link_stack_correct\000other\000Link stack predicts right address\000event=0x58a0\000\00000\000\000 */
{ 320330 }, /* pm_link_stack_invalid_ptr\000other\000It is most often caused by certain types of flush where the pointer is not available. Can result in the data in the link stack becoming unusable\000event=0x5898\000\00000\000\000 */
{ 336013 }, /* pm_link_stack_wrong_add_pred\000other\000Link stack predicts wrong address, because of link stack design limitation or software violating the coding conventions\000event=0x5098\000\00000\000\000 */
{ 299964 }, /* pm_lmq_empty_cyc\000marked\000Cycles in which the LMQ has no pending load misses for this thread\000event=0x2e05e\000\00000\000\000 */
{ 355430 }, /* pm_lmq_merge\000other\000A demand miss collides with a prefetch for the same line\000event=0x1002e\000\00000\000\000 */
{ 309643 }, /* pm_lrq_reject\000memory\000Internal LSU reject from LRQ. Rejects cause the load to go back to LRQ, but it stays contained within the LSU once it gets issued. This event counts the number of times the LRQ attempts to relaunch an instruction after a reject. Any load can suffer multiple rejects\000event=0x2e05a\000\00000\000\000 */
{ 311767 }, /* pm_ls0_dc_collisions\000other\000Read-write data cache collisions\000event=0xd090\000\00000\000\000 */
{ 369285 }, /* pm_ls0_erat_miss_pref\000other\000LS0 Erat miss due to prefetch\000event=0xe084\000\00000\000\000 */
{ 337387 }, /* pm_ls0_launch_held_pref\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc09c\000\00000\000\000 */
{ 363149 }, /* pm_ls0_ld_vector_fin\000other\000LS0 finished load vector op\000event=0xc080\000\00000\000\000 */
{ 313899 }, /* pm_ls0_pte_tablewalk_cyc\000other\000Cycles when a tablewalk is pending on this thread on table 0\000event=0xe0bc\000\00000\000\000 */
{ 321214 }, /* pm_ls0_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b4\000\00000\000\000 */
{ 321963 }, /* pm_ls0_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc094\000\00000\000\000 */
{ 366220 }, /* pm_ls0_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0b8\000\00000\000\000 */
{ 348640 }, /* pm_ls1_dc_collisions\000other\000Read-write data cache collisions\000event=0xd890\000\00000\000\000 */
{ 354851 }, /* pm_ls1_erat_miss_pref\000other\000LS1 Erat miss due to prefetch\000event=0xe884\000\00000\000\000 */
{ 326656 }, /* pm_ls1_launch_held_pref\000other\000Number of times a load or store instruction was unable to launch/relaunch because a high priority prefetch used that relaunch cycle\000event=0xc89c\000\00000\000\000 */
{ 324093 }, /* pm_ls1_ld_vector_fin\000other\000LS1 finished load vector op\000event=0xc880\000\00000\000\000 */
{ 361460 }, /* pm_ls1_pte_tablewalk_cyc\000other\000Cycles when a tablewalk is pending on this thread on table 1\000event=0xe8bc\000\00000\000\000 */
{ 339378 }, /* pm_ls1_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b4\000\00000\000\000 */
{ 343442 }, /* pm_ls1_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc894\000\00000\000\000 */
{ 328289 }, /* pm_ls1_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8b8\000\00000\000\000 */
{ 350361 }, /* pm_ls2_dc_collisions\000other\000Read-write data cache collisions\000event=0xd094\000\00000\000\000 */
{ 325554 }, /* pm_ls2_erat_miss_pref\000other\000LS0 Erat miss due to prefetch\000event=0xe088\000\00000\000\000 */
{ 345664 }, /* pm_ls2_ld_vector_fin\000other\000LS2 finished load vector op\000event=0xc084\000\00000\000\000 */
{ 349440 }, /* pm_ls2_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe0b8\000\00000\000\000 */
{ 319795 }, /* pm_ls2_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc098\000\00000\000\000 */
{ 316841 }, /* pm_ls2_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf0bc\000\00000\000\000 */
{ 314756 }, /* pm_ls3_dc_collisions\000other\000Read-write data cache collisions\000event=0xd894\000\00000\000\000 */
{ 327983 }, /* pm_ls3_erat_miss_pref\000other\000LS1 Erat miss due to prefetch\000event=0xe888\000\00000\000\000 */
{ 370947 }, /* pm_ls3_ld_vector_fin\000other\000LS3 finished load vector op\000event=0xc884\000\00000\000\000 */
{ 368197 }, /* pm_ls3_tm_disallow\000other\000A TM-ineligible instruction tries to execute inside a transaction and the LSU disallows it\000event=0xe8b8\000\00000\000\000 */
{ 332117 }, /* pm_ls3_unaligned_ld\000other\000Load instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the load of that size.  If the load wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xc898\000\00000\000\000 */
{ 322265 }, /* pm_ls3_unaligned_st\000other\000Store instructions whose data crosses a double-word boundary, which causes it to require an additional slice than than what normally would be required of the Store of that size.  If the Store wraps from slice 3 to slice 0, thee is an additional 3-cycle penalty\000event=0xf8bc\000\00000\000\000 */
{ 316006 }, /* pm_lsu0_1_lrqf_full_cyc\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd0bc\000\00000\000\000 */
{ 325467 }, /* pm_lsu0_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe08c\000\00000\000\000 */
{ 367780 }, /* pm_lsu0_false_lhs\000other\000False LHS match detected\000event=0xc0a0\000\00000\000\000 */
{ 357310 }, /* pm_lsu0_l1_cam_cancel\000other\000ls0 l1 tm cam cancel\000event=0xf090\000\00000\000\000 */
{ 338938 }, /* pm_lsu0_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd088\000\00000\000\000 */
{ 329208 }, /* pm_lsu0_lmq_s0_valid\000other\000Slot 0 of LMQ valid\000event=0xd8b8\000\00000\000\000 */
{ 312501 }, /* pm_lsu0_lrq_s0_valid_cyc\000other\000Slot 0 of LRQ valid\000event=0xd8b4\000\00000\000\000 */
{ 369911 }, /* pm_lsu0_srq_s0_valid_cyc\000other\000Slot 0 of SRQ valid\000event=0xd0b4\000\00000\000\000 */
{ 312646 }, /* pm_lsu0_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf088\000\00000\000\000 */
{ 362711 }, /* pm_lsu0_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe094\000\00000\000\000 */
{ 318448 }, /* pm_lsu0_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe09c\000\00000\000\000 */
{ 333536 }, /* pm_lsu1_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe88c\000\00000\000\000 */
{ 361161 }, /* pm_lsu1_false_lhs\000other\000False LHS match detected\000event=0xc8a0\000\00000\000\000 */
{ 354694 }, /* pm_lsu1_l1_cam_cancel\000other\000ls1 l1 tm cam cancel\000event=0xf890\000\00000\000\000 */
{ 346830 }, /* pm_lsu1_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd888\000\00000\000\000 */
{ 319602 }, /* pm_lsu1_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf888\000\00000\000\000 */
{ 314213 }, /* pm_lsu1_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe894\000\00000\000\000 */
{ 354927 }, /* pm_lsu1_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe89c\000\00000\000\000 */
{ 334744 }, /* pm_lsu2_3_lrqf_full_cyc\000other\000Counts the number of cycles the LRQF is full.  LRQF is the queue that holds loads between finish and completion.  If it fills up, instructions stay in LRQ until completion, potentially backing up the LRQ\000event=0xd8bc\000\00000\000\000 */
{ 329709 }, /* pm_lsu2_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe090\000\00000\000\000 */
{ 336317 }, /* pm_lsu2_false_lhs\000other\000False LHS match detected\000event=0xc0a4\000\00000\000\000 */
{ 335164 }, /* pm_lsu2_l1_cam_cancel\000other\000ls2 l1 tm cam cancel\000event=0xf094\000\00000\000\000 */
{ 313229 }, /* pm_lsu2_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd08c\000\00000\000\000 */
{ 330126 }, /* pm_lsu2_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf08c\000\00000\000\000 */
{ 349380 }, /* pm_lsu2_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe098\000\00000\000\000 */
{ 324034 }, /* pm_lsu2_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe0a0\000\00000\000\000 */
{ 359641 }, /* pm_lsu3_erat_hit\000other\000Primary ERAT hit.  There is no secondary ERAT\000event=0xe890\000\00000\000\000 */
{ 327732 }, /* pm_lsu3_false_lhs\000other\000False LHS match detected\000event=0xc8a4\000\00000\000\000 */
{ 315278 }, /* pm_lsu3_l1_cam_cancel\000other\000ls3 l1 tm cam cancel\000event=0xf894\000\00000\000\000 */
{ 352563 }, /* pm_lsu3_ldmx_fin\000other\000New P9 instruction LDMX. The definition of this new PMU event is (from the ldmx RFC02491):  The thread has executed an ldmx instruction that accessed a doubleword that contains an effective address within an enabled section of the Load Monitored region.  This event, therefore, should not occur if the FSCR has disabled the load monitored facility (FSCR[52]) or disabled the EBB facility (FSCR[56])\000event=0xd88c\000\00000\000\000 */
{ 370166 }, /* pm_lsu3_store_reject\000other\000All internal store rejects cause the instruction to go back to the SRQ and go to sleep until woken up to try again after the condition has been met\000event=0xf88c\000\00000\000\000 */
{ 337119 }, /* pm_lsu3_tm_l1_hit\000other\000Load tm hit in L1\000event=0xe898\000\00000\000\000 */
{ 349050 }, /* pm_lsu3_tm_l1_miss\000other\000Load tm L1 miss\000event=0xe8a0\000\00000\000\000 */
{ 307570 }, /* pm_lsu_derat_miss\000memory\000DERAT Reloaded due to a DERAT miss\000event=0x200f6\000\00000\000\000 */
{ 333026 }, /* pm_lsu_dtlb_miss_16g_1g\000other\000Data TLB Miss page size 16G (HPT) or 1G (Radix)\000event=0xc88c\000\00000\000\000 */
{ 362870 }, /* pm_lsu_dtlb_miss_16m_2m\000other\000Data TLB Miss page size 16M (HPT) or 2M (Radix)\000event=0xc08c\000\00000\000\000 */
{ 326188 }, /* pm_lsu_dtlb_miss_4k\000other\000Data TLB Miss page size 4K\000event=0xc088\000\00000\000\000 */
{ 325986 }, /* pm_lsu_dtlb_miss_64k\000other\000Data TLB Miss page size 64K\000event=0xc888\000\00000\000\000 */
{ 393490 }, /* pm_lsu_fin\000translation\000LSU Finished a PPC instruction (up to 4 per cycle)\000event=0x30066\000\00000\000\000 */
{ 364569 }, /* pm_lsu_flush_atomic\000other\000Quad-word loads (lq) are considered atomic because they always span at least 2 slices.  If a snoop or store from another thread changes the data the load is accessing between the 2 or 3 pieces of the lq instruction, the lq will be flushed\000event=0xc8a8\000\00000\000\000 */
{ 357377 }, /* pm_lsu_flush_ci\000other\000Load was not issued to LSU as a cache inhibited (non-cacheable) load but it was later determined to be cache inhibited\000event=0xc0a8\000\00000\000\000 */
{ 362213 }, /* pm_lsu_flush_emsh\000other\000An ERAT miss was detected after a set-p hit. Erat tracker indicates fail due to tlbmiss and the instruction gets flushed because the instruction was working on the wrong address\000event=0xc0ac\000\00000\000\000 */
{ 337567 }, /* pm_lsu_flush_larx_stcx\000other\000A larx is flushed because an older larx has an LMQ reservation for the same thread.  A stcx is flushed because an older stcx is in the LMQ.  The flush happens when the older larx/stcx relaunches\000event=0xc8b8\000\00000\000\000 */
{ 360634 }, /* pm_lsu_flush_lhl_shl\000other\000The instruction was flushed because of a sequential load/store consistency.  If a load or store hits on an older load that has either been snooped (for loads) or has stale data (for stores)\000event=0xc8b4\000\00000\000\000 */
{ 366743 }, /* pm_lsu_flush_lhs\000other\000Effective Address alias flush : no EA match but Real Address match.  If the data has not yet been returned for this load, the instruction will just be rejected, but if it has returned data, it will be flushed\000event=0xc8b0\000\00000\000\000 */
{ 370760 }, /* pm_lsu_flush_next\000other\000LSU flush next reported at flush time.  Sometimes these also come with an exception\000event=0x20b0\000\00000\000\000 */
{ 363717 }, /* pm_lsu_flush_other\000other\000Other LSU flushes including: Sync (sync ack from L2 caused search of LRQ for oldest snooped load, This will either signal a Precise Flush of the oldest snooped loa or a Flush Next PPC); Data Valid Flush Next (several cases of this, one example is store and reload are lined up such that a store-hit-reload scenario exists and the CDF has already launched and has gotten bad/stale data); Bad Data Valid Flush Next (might be a few cases of this, one example is a larxa (D$ hit) return data and dval but can't allocate to LMQ (LMQ full or other reason). Already gave dval but can't watch it for snoop_hit_larx. Need to take the 'bad dval' back and flush all younger ops)\000event=0xc0bc\000\00000\000\000 */
{ 317676 }, /* pm_lsu_flush_relaunch_miss\000other\000If a load that has already returned data and has to relaunch for any reason then gets a miss (erat, setp, data cache), it will often be flushed at relaunch time because the data might be inconsistent\000event=0xc8ac\000\00000\000\000 */
{ 321520 }, /* pm_lsu_flush_sao\000other\000A load-hit-load condition with Strong Address Ordering will have address compare disabled and flush\000event=0xc0b8\000\00000\000\000 */
{ 358827 }, /* pm_lsu_flush_ue\000other\000Correctable ECC error on reload data, reported at critical data forward time\000event=0xc0b0\000\00000\000\000 */
{ 333623 }, /* pm_lsu_flush_wrk_arnd\000other\000LSU workaround flush.  These flushes are setup with programmable scan only latches to perform various actions when the flush macro receives a trigger from the dbg macros. These actions include things like flushing the next op encountered for a particular thread or flushing the next op that is NTC op that is encountered on a particular slice. The kind of flush that the workaround is setup to perform is highly variable\000event=0xc0b4\000\00000\000\000 */
{ 371394 }, /* pm_lsu_lmq_full_cyc\000other\000Counts the number of cycles the LMQ is full\000event=0xd0b8\000\00000\000\000 */
{ 395236 }, /* pm_lsu_lmq_srq_empty_cyc\000translation\000Cycles in which the LSU is empty for all threads (lmq and srq are completely empty)\000event=0x2003e\000\00000\000\000 */
{ 371193 }, /* pm_lsu_ncst\000other\000Asserts when a i=1 store op is sent to the nest. No record of issue pipe (LS0/LS1) is maintained so this is for both pipes. Probably don't need separate LS0 and LS1\000event=0xc890\000\00000\000\000 */
{ 308885 }, /* pm_lsu_reject_erat_miss\000memory\000LSU Reject due to ERAT (up to 4 per cycles)\000event=0x2e05c\000\00000\000\000 */
{ 397680 }, /* pm_lsu_reject_lhs\000translation\000LSU Reject due to LHS (up to 4 per cycle)\000event=0x4e05c\000\00000\000\000 */
{ 282117 }, /* pm_lsu_reject_lmq_full\000frontend\000LSU Reject due to LMQ full (up to 4 per cycles)\000event=0x3001c\000\00000\000\000 */
{ 279387 }, /* pm_lsu_srq_full_cyc\000frontend\000Cycles in which the Store Queue is full on all 4 slices. This is event is not per thread. All the threads will see the same count for this core resource\000event=0x1001a\000\00000\000\000 */
{ 350527 }, /* pm_lsu_stcx\000other\000STCX sent to nest, i.e. total\000event=0xc090\000\00000\000\000 */
{ 367301 }, /* pm_lsu_stcx_fail\000other\000The LSU detects the condition that a stcx instruction failed. No requirement to wait for a response from the nest\000event=0xf080\000\00000\000\000 */
{ 342540 }, /* pm_lwsync\000other\000An lwsync instruction was decoded and transferred\000event=0xd8ac\000\00000\000\000 */
{ 363074 }, /* pm_math_flop_cmpl\000other\000Math flop instruction completed\000event=0x4505c\000\00000\000\000 */
{ 385468 }, /* pm_mem_co\000pipeline\000Memory castouts from this thread\000event=0x4c058\000\00000\000\000 */
{ 278099 }, /* pm_mem_loc_thresh_ifu\000floating point\000Local Memory above threshold for IFU speculation control\000event=0x10058\000\00000\000\000 */
{ 388764 }, /* pm_mem_loc_thresh_lsu_high\000pmc\000Local memory above threshold for LSU medium\000event=0x40056\000\00000\000\000 */
{ 305611 }, /* pm_mem_loc_thresh_lsu_med\000marked\000Local memory above threshold for data prefetch\000event=0x1c05e\000\00000\000\000 */
{ 303911 }, /* pm_mem_pref\000marked\000Memory prefetch for this thread. Includes L4\000event=0x2c058\000\00000\000\000 */
{ 374252 }, /* pm_mem_read\000pipeline\000Reads from Memory from this thread (includes data/inst/xlate/l1prefetch/inst prefetch). Includes L4\000event=0x10056\000\00000\000\000 */
{ 350439 }, /* pm_mem_rwitm\000other\000Memory Read With Intent to Modify for this thread\000event=0x3c05e\000\00000\000\000 */
{ 354553 }, /* pm_mrk_back_br_cmpl\000other\000Marked branch instruction completed with a target address less than current instruction address\000event=0x3515e\000\00000\000\000 */
{ 344005 }, /* pm_mrk_br_2path\000other\000marked branches which are not strongly biased\000event=0x10138\000\00000\000\000 */
{ 145459 }, /* pm_mrk_br_cmpl\000marked\000Branch Instruction completed\000event=0x1016e\000\00000\000\000 */
{ 145529 }, /* pm_mrk_br_mpred_cmpl\000marked\000Marked Branch Mispredicted\000event=0x301e4\000\00000\000\000 */
{ 145603 }, /* pm_mrk_br_taken_cmpl\000marked\000Marked Branch Taken completed\000event=0x101e2\000\00000\000\000 */
{ 145394 }, /* pm_mrk_bru_fin\000marked\000bru marked instr finish\000event=0x2013a\000\00000\000\000 */
{ 335678 }, /* pm_mrk_data_from_dl2l3_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x3d14e\000\00000\000\000 */
{ 360423 }, /* pm_mrk_data_from_dl2l3_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x4d12e\000\00000\000\000 */
{ 360945 }, /* pm_mrk_data_from_dl2l3_shr\000other\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x1d150\000\00000\000\000 */
{ 146328 }, /* pm_mrk_data_from_dl2l3_shr_cyc\000marked\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked load\000event=0x2c128\000\00000\000\000 */
{ 355969 }, /* pm_mrk_data_from_dl4\000other\000The processor's data cache was reloaded from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x1d152\000\00000\000\000 */
{ 336868 }, /* pm_mrk_data_from_dl4_cyc\000other\000Duration in cycles to reload from another chip's L4 on a different Node or Group (Distant) due to a marked load\000event=0x2c12c\000\00000\000\000 */
{ 344541 }, /* pm_mrk_data_from_dmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x3d14c\000\00000\000\000 */
{ 315411 }, /* pm_mrk_data_from_dmem_cyc\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group (Distant) due to a marked load\000event=0x4e11e\000\00000\000\000 */
{ 331742 }, /* pm_mrk_data_from_l2\000other\000The processor's data cache was reloaded from local core's L2 due to a marked load\000event=0x2c126\000\00000\000\000 */
{ 245309 }, /* pm_mrk_data_from_l21_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x4d146\000\00000\000\000 */
{ 381605 }, /* pm_mrk_data_from_l21_mod_cyc\000pipeline\000Duration in cycles to reload with Modified (M) data from another core's L2 on the same chip due to a marked load\000event=0x3d148\000\00000\000\000 */
{ 385845 }, /* pm_mrk_data_from_l21_shr\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x2d14e\000\00000\000\000 */
{ 388523 }, /* pm_mrk_data_from_l21_shr_cyc\000pipeline\000Duration in cycles to reload with Shared (S) data from another core's L2 on the same chip due to a marked load\000event=0x1d154\000\00000\000\000 */
{ 315575 }, /* pm_mrk_data_from_l2_cyc\000other\000Duration in cycles to reload from local core's L2 due to a marked load\000event=0x14156\000\00000\000\000 */
{ 316258 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst\000other\000The processor's data cache was reloaded from local core's L2 with load hit store conflict due to a marked load\000event=0x2d148\000\00000\000\000 */
{ 277919 }, /* pm_mrk_data_from_l2_disp_conflict_ldhitst_cyc\000floating point\000Duration in cycles to reload from local core's L2 with load hit store conflict due to a marked load\000event=0x1415a\000\00000\000\000 */
{ 282990 }, /* pm_mrk_data_from_l2_disp_conflict_other\000frontend\000The processor's data cache was reloaded from local core's L2 with dispatch conflict due to a marked load\000event=0x2c124\000\00000\000\000 */
{ 326493 }, /* pm_mrk_data_from_l2_disp_conflict_other_cyc\000other\000Duration in cycles to reload from local core's L2 with dispatch conflict due to a marked load\000event=0x3d140\000\00000\000\000 */
{ 387232 }, /* pm_mrk_data_from_l2_mepf\000pipeline\000The processor's data cache was reloaded from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x4c120\000\00000\000\000 */
{ 351088 }, /* pm_mrk_data_from_l2_mepf_cyc\000other\000Duration in cycles to reload from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked load\000event=0x3d144\000\00000\000\000 */
{ 350593 }, /* pm_mrk_data_from_l2_no_conflict\000other\000The processor's data cache was reloaded from local core's L2 without conflict due to a marked load\000event=0x2c120\000\00000\000\000 */
{ 332712 }, /* pm_mrk_data_from_l2_no_conflict_cyc\000other\000Duration in cycles to reload from local core's L2 without conflict due to a marked load\000event=0x14158\000\00000\000\000 */
{ 359096 }, /* pm_mrk_data_from_l2miss\000other\000The processor's data cache was reloaded from a location other than the local core's L2 due to a marked load\000event=0x401e8\000\00000\000\000 */
{ 330392 }, /* pm_mrk_data_from_l2miss_cyc\000other\000Duration in cycles to reload from a location other than the local core's L2 due to a marked load\000event=0x35152\000\00000\000\000 */
{ 149028 }, /* pm_mrk_data_from_l3\000marked\000The processor's data cache was reloaded from local core's L3 due to a marked load\000event=0x4d142\000\00000\000\000 */
{ 245987 }, /* pm_mrk_data_from_l31_eco_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x4d144\000\00000\000\000 */
{ 314834 }, /* pm_mrk_data_from_l31_eco_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's ECO L3 on the same chip due to a marked load\000event=0x35158\000\00000\000\000 */
{ 287800 }, /* pm_mrk_data_from_l31_eco_shr\000frontend\000The processor's data cache was reloaded with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x2d14c\000\00000\000\000 */
{ 398318 }, /* pm_mrk_data_from_l31_eco_shr_cyc\000translation\000Duration in cycles to reload with Shared (S) data from another core's ECO L3 on the same chip due to a marked load\000event=0x1d142\000\00000\000\000 */
{ 246697 }, /* pm_mrk_data_from_l31_mod\000other\000The processor's data cache was reloaded with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x2d144\000\00000\000\000 */
{ 341238 }, /* pm_mrk_data_from_l31_mod_cyc\000other\000Duration in cycles to reload with Modified (M) data from another core's L3 on the same chip due to a marked load\000event=0x1d140\000\00000\000\000 */
{ 388201 }, /* pm_mrk_data_from_l31_shr\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x4d124\000\00000\000\000 */
{ 332861 }, /* pm_mrk_data_from_l31_shr_cyc\000other\000Duration in cycles to reload with Shared (S) data from another core's L3 on the same chip due to a marked load\000event=0x35156\000\00000\000\000 */
{ 341118 }, /* pm_mrk_data_from_l3_cyc\000other\000Duration in cycles to reload from local core's L3 due to a marked load\000event=0x35154\000\00000\000\000 */
{ 320891 }, /* pm_mrk_data_from_l3_disp_conflict\000other\000The processor's data cache was reloaded from local core's L3 with dispatch conflict due to a marked load\000event=0x1d144\000\00000\000\000 */
{ 340961 }, /* pm_mrk_data_from_l3_disp_conflict_cyc\000other\000Duration in cycles to reload from local core's L3 with dispatch conflict due to a marked load\000event=0x2c122\000\00000\000\000 */
{ 352276 }, /* pm_mrk_data_from_l3_mepf\000other\000The processor's data cache was reloaded from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked load\000event=0x2d142\000\00000\000\000 */
{ 318682 }, /* pm_mrk_data_from_l3_mepf_cyc\000other\000Duration in cycles to reload from local core's L3 without dispatch conflicts hit on Mepf state due to a marked load\000event=0x1415c\000\00000\000\000 */
{ 349875 }, /* pm_mrk_data_from_l3_no_conflict\000other\000The processor's data cache was reloaded from local core's L3 without conflict due to a marked load\000event=0x3d146\000\00000\000\000 */
{ 361650 }, /* pm_mrk_data_from_l3_no_conflict_cyc\000other\000Duration in cycles to reload from local core's L3 without conflict due to a marked load\000event=0x4c124\000\00000\000\000 */
{ 310891 }, /* pm_mrk_data_from_l3miss\000other\000The processor's data cache was reloaded from a location other than the local core's L3 due to a marked load\000event=0x201e4\000\00000\000\000 */
{ 292187 }, /* pm_mrk_data_from_l3miss_cyc\000marked\000Duration in cycles to reload from a location other than the local core's L3 due to a marked load\000event=0x1415e\000\00000\000\000 */
{ 150567 }, /* pm_mrk_data_from_ll4\000marked\000The processor's data cache was reloaded from the local chip's L4 cache due to a marked load\000event=0x1d14c\000\00000\000\000 */
{ 303779 }, /* pm_mrk_data_from_ll4_cyc\000marked\000Duration in cycles to reload from the local chip's L4 cache due to a marked load\000event=0x2c12e\000\00000\000\000 */
{ 390157 }, /* pm_mrk_data_from_lmem\000pmc\000The processor's data cache was reloaded from the local chip's Memory due to a marked load\000event=0x3d142\000\00000\000\000 */
{ 390516 }, /* pm_mrk_data_from_lmem_cyc\000pmc\000Duration in cycles to reload from the local chip's Memory due to a marked load\000event=0x4d128\000\00000\000\000 */
{ 340613 }, /* pm_mrk_data_from_memory\000other\000The processor's data cache was reloaded from a memory location including L4 from local remote or distant due to a marked load\000event=0x201e0\000\00000\000\000 */
{ 362543 }, /* pm_mrk_data_from_memory_cyc\000other\000Duration in cycles to reload from a memory location including L4 from local remote or distant due to a marked load\000event=0x1d146\000\00000\000\000 */
{ 365353 }, /* pm_mrk_data_from_off_chip_cache\000other\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x2d120\000\00000\000\000 */
{ 319394 }, /* pm_mrk_data_from_off_chip_cache_cyc\000other\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked load\000event=0x1d14e\000\00000\000\000 */
{ 372750 }, /* pm_mrk_data_from_on_chip_cache\000pipeline\000The processor's data cache was reloaded either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x4d140\000\00000\000\000 */
{ 283685 }, /* pm_mrk_data_from_on_chip_cache_cyc\000frontend\000Duration in cycles to reload either shared or modified data from another core's L2/L3 on the same chip due to a marked load\000event=0x3515a\000\00000\000\000 */
{ 377580 }, /* pm_mrk_data_from_rl2l3_mod\000pipeline\000The processor's data cache was reloaded with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x1d14a\000\00000\000\000 */
{ 396098 }, /* pm_mrk_data_from_rl2l3_mod_cyc\000translation\000Duration in cycles to reload with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x2d14a\000\00000\000\000 */
{ 382321 }, /* pm_mrk_data_from_rl2l3_shr\000pipeline\000The processor's data cache was reloaded with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x35150\000\00000\000\000 */
{ 283163 }, /* pm_mrk_data_from_rl2l3_shr_cyc\000frontend\000Duration in cycles to reload with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked load\000event=0x4c12a\000\00000\000\000 */
{ 287631 }, /* pm_mrk_data_from_rl4\000frontend\000The processor's data cache was reloaded from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x3515c\000\00000\000\000 */
{ 275077 }, /* pm_mrk_data_from_rl4_cyc\000cache\000Duration in cycles to reload from another chip's L4 on the same Node or Group ( Remote) due to a marked load\000event=0x4d12a\000\00000\000\000 */
{ 318076 }, /* pm_mrk_data_from_rmem\000other\000The processor's data cache was reloaded from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x1d148\000\00000\000\000 */
{ 344815 }, /* pm_mrk_data_from_rmem_cyc\000other\000Duration in cycles to reload from another chip's memory on the same Node or Group ( Remote) due to a marked load\000event=0x2c12a\000\00000\000\000 */
{ 388858 }, /* pm_mrk_dcache_reload_intv\000pmc\000Combined Intervention event\000event=0x40118\000\00000\000\000 */
{ 286516 }, /* pm_mrk_derat_miss\000frontend\000Erat Miss (TLB Access) All page sizes\000event=0x301e6\000\00000\000\000 */
{ 375557 }, /* pm_mrk_derat_miss_16g_1g\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16G (hpt mode) and 1G (radix mode)\000event=0x4c15c\000\00000\000\000 */
{ 383465 }, /* pm_mrk_derat_miss_16m_2m\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 16M (hpt mode) or 2M (radix mode)\000event=0x3d154\000\00000\000\000 */
{ 378091 }, /* pm_mrk_derat_miss_4k\000pipeline\000Marked Data ERAT Miss (Data TLB Access) page size 4K\000event=0x2d150\000\00000\000\000 */
{ 278510 }, /* pm_mrk_derat_miss_64k\000floating point\000Marked Data ERAT Miss (Data TLB Access) page size 64K\000event=0x2d154\000\00000\000\000 */
{ 366525 }, /* pm_mrk_dfu_fin\000other\000Decimal Unit marked Instruction Finish\000event=0x20132\000\00000\000\000 */
{ 388935 }, /* pm_mrk_dpteg_from_dl2l3_mod\000pmc\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f148\000\00000\000\000 */
{ 383770 }, /* pm_mrk_dpteg_from_dl2l3_shr\000pipeline\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on a different Node or Group (Distant), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f148\000\00000\000\000 */
{ 372944 }, /* pm_mrk_dpteg_from_dl4\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's L4 on a different Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14c\000\00000\000\000 */
{ 380311 }, /* pm_mrk_dpteg_from_dmem\000pipeline\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group (Distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14c\000\00000\000\000 */
{ 386466 }, /* pm_mrk_dpteg_from_l2\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f142\000\00000\000\000 */
{ 373959 }, /* pm_mrk_dpteg_from_l21_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f146\000\00000\000\000 */
{ 323123 }, /* pm_mrk_dpteg_from_l21_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L2 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f146\000\00000\000\000 */
{ 276536 }, /* pm_mrk_dpteg_from_l2_mepf\000cache\000A Page Table Entry was loaded into the TLB from local core's L2 hit without dispatch conflicts on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f140\000\00000\000\000 */
{ 377066 }, /* pm_mrk_dpteg_from_l2_no_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L2 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f140\000\00000\000\000 */
{ 389739 }, /* pm_mrk_dpteg_from_l2miss\000pmc\000A Page Table Entry was loaded into the TLB from a location other than the local core's L2 due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14e\000\00000\000\000 */
{ 391527 }, /* pm_mrk_dpteg_from_l3\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f142\000\00000\000\000 */
{ 291518 }, /* pm_mrk_dpteg_from_l31_eco_mod\000marked\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f144\000\00000\000\000 */
{ 290570 }, /* pm_mrk_dpteg_from_l31_eco_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's ECO L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f144\000\00000\000\000 */
{ 384795 }, /* pm_mrk_dpteg_from_l31_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another core's L3 on the same chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f144\000\00000\000\000 */
{ 363328 }, /* pm_mrk_dpteg_from_l31_shr\000other\000A Page Table Entry was loaded into the TLB with Shared (S) data from another core's L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f146\000\00000\000\000 */
{ 391249 }, /* pm_mrk_dpteg_from_l3_disp_conflict\000pmc\000A Page Table Entry was loaded into the TLB from local core's L3 with dispatch conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f142\000\00000\000\000 */
{ 375260 }, /* pm_mrk_dpteg_from_l3_mepf\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without dispatch conflicts hit on Mepf state. due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f142\000\00000\000\000 */
{ 378512 }, /* pm_mrk_dpteg_from_l3_no_conflict\000pipeline\000A Page Table Entry was loaded into the TLB from local core's L3 without conflict due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f144\000\00000\000\000 */
{ 295516 }, /* pm_mrk_dpteg_from_l3miss\000marked\000A Page Table Entry was loaded into the TLB from a location other than the local core's L3 due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14e\000\00000\000\000 */
{ 290314 }, /* pm_mrk_dpteg_from_ll4\000marked\000A Page Table Entry was loaded into the TLB from the local chip's L4 cache due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14c\000\00000\000\000 */
{ 295133 }, /* pm_mrk_dpteg_from_lmem\000marked\000A Page Table Entry was loaded into the TLB from the local chip's Memory due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f148\000\00000\000\000 */
{ 387413 }, /* pm_mrk_dpteg_from_memory\000pipeline\000A Page Table Entry was loaded into the TLB from a memory location including L4 from local remote or distant due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14c\000\00000\000\000 */
{ 376352 }, /* pm_mrk_dpteg_from_off_chip_cache\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on a different chip (remote or distant) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x4f14a\000\00000\000\000 */
{ 384204 }, /* pm_mrk_dpteg_from_on_chip_cache\000pipeline\000A Page Table Entry was loaded into the TLB either shared or modified data from another core's L2/L3 on the same chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f148\000\00000\000\000 */
{ 381775 }, /* pm_mrk_dpteg_from_rl2l3_mod\000pipeline\000A Page Table Entry was loaded into the TLB with Modified (M) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f146\000\00000\000\000 */
{ 305922 }, /* pm_mrk_dpteg_from_rl2l3_shr\000marked\000A Page Table Entry was loaded into the TLB with Shared (S) data from another chip's L2 or L3 on the same Node or Group (Remote), as this chip due to a marked data side request.. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x1f14a\000\00000\000\000 */
{ 361799 }, /* pm_mrk_dpteg_from_rl4\000other\000A Page Table Entry was loaded into the TLB from another chip's L4 on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x2f14a\000\00000\000\000 */
{ 276915 }, /* pm_mrk_dpteg_from_rmem\000cache\000A Page Table Entry was loaded into the TLB from another chip's memory on the same Node or Group ( Remote) due to a marked data side request. When using Radix Page Translation, this count excludes PDE reloads. Only PTE reloads are included\000event=0x3f14a\000\00000\000\000 */
{ 277500 }, /* pm_mrk_dtlb_miss\000cache\000Marked dtlb miss\000event=0x401e4\000\00000\000\000 */
{ 335087 }, /* pm_mrk_fab_rsp_bkill\000other\000Marked store had to do a bkill\000event=0x40154\000\00000\000\000 */
{ 361570 }, /* pm_mrk_fab_rsp_bkill_cyc\000other\000cycles L2 RC took for a bkill\000event=0x1f152\000\00000\000\000 */
{ 284014 }, /* pm_mrk_fab_rsp_claim_rty\000frontend\000Sampled store did a rwitm and got a rty\000event=0x3015e\000\00000\000\000 */
{ 280470 }, /* pm_mrk_fab_rsp_dclaim\000frontend\000Marked store had to do a dclaim\000event=0x30154\000\00000\000\000 */
{ 284502 }, /* pm_mrk_fab_rsp_dclaim_cyc\000frontend\000cycles L2 RC took for a dclaim\000event=0x2f152\000\00000\000\000 */
{ 286178 }, /* pm_mrk_fab_rsp_rd_rty\000frontend\000Sampled L2 reads retry count\000event=0x4015e\000\00000\000\000 */
{ 282404 }, /* pm_mrk_fab_rsp_rd_t_intv\000frontend\000Sampled Read got a T intervention\000event=0x1015e\000\00000\000\000 */
{ 284793 }, /* pm_mrk_fab_rsp_rwitm_cyc\000frontend\000cycles L2 RC took for a rwitm\000event=0x4f150\000\00000\000\000 */
{ 286991 }, /* pm_mrk_fab_rsp_rwitm_rty\000frontend\000Sampled store did a rwitm and got a rty\000event=0x2015e\000\00000\000\000 */
{ 353218 }, /* pm_mrk_fxu_fin\000other\000fxu marked instr finish\000event=0x20134\000\00000\000\000 */
{ 358944 }, /* pm_mrk_ic_miss\000other\000Marked instruction experienced I cache miss\000event=0x4013a\000\00000\000\000 */
{ 86326 }, /* pm_mrk_inst\000marked\000An instruction was marked. Includes both Random Instruction Sampling (RIS) at decode time and Random Event Sampling (RES) at the time the configured event happens\000event=0x24158\000\00000\000\000 */
{ 159795 }, /* pm_mrk_inst_cmpl\000marked\000marked instruction completed\000event=0x401e0\000\00000\000\000 */
{ 84807 }, /* pm_mrk_inst_decoded\000marked\000An instruction was marked at decode time. Random Instruction Sampling (RIS) only\000event=0x20130\000\00000\000\000 */
{ 84209 }, /* pm_mrk_inst_disp\000marked\000The thread has dispatched a randomly sampled marked instruction\000event=0x101e0\000\00000\000\000 */
{ 305852 }, /* pm_mrk_inst_fin\000marked\000marked instruction finished\000event=0x30130\000\00000\000\000 */
{ 317230 }, /* pm_mrk_inst_from_l3miss\000other\000Marked instruction was reloaded from a location beyond the local chiplet\000event=0x401e6\000\00000\000\000 */
{ 160342 }, /* pm_mrk_inst_issued\000marked\000Marked instruction issued\000event=0x10132\000\00000\000\000 */
{ 160413 }, /* pm_mrk_inst_timeo\000marked\000marked Instruction finish timeout (instruction lost)\000event=0x40134\000\00000\000\000 */
{ 327484 }, /* pm_mrk_l1_icache_miss\000other\000sampled Instruction suffered an icache Miss\000event=0x101e4\000\00000\000\000 */
{ 319026 }, /* pm_mrk_l1_reload_valid\000other\000Marked demand reload\000event=0x101ea\000\00000\000\000 */
{ 279890 }, /* pm_mrk_l2_rc_disp\000frontend\000Marked Instruction RC dispatched in L2\000event=0x20114\000\00000\000\000 */
{ 288254 }, /* pm_mrk_l2_rc_done\000frontend\000Marked RC done\000event=0x3012a\000\00000\000\000 */
{ 279588 }, /* pm_mrk_l2_tm_req_abort\000frontend\000TM abort\000event=0x1e15e\000\00000\000\000 */
{ 287983 }, /* pm_mrk_larx_fin\000frontend\000Larx finished\000event=0x40116\000\00000\000\000 */
{ 285939 }, /* pm_mrk_ld_miss_exposed_cyc\000frontend\000Marked Load exposed Miss (use edge detect to count #)\000event=0x1013e\000\00000\000\000 */
{ 372150 }, /* pm_mrk_ld_miss_l1\000pipeline\000Marked DL1 Demand Miss counted at exec time. Note that this count is per slice, so if a load spans multiple slices this event will increment multiple times for a single load\000event=0x201e2\000\00000\000\000 */
{ 319095 }, /* pm_mrk_ld_miss_l1_cyc\000other\000Marked ld latency\000event=0x1d156\000\00000\000\000 */
{ 324562 }, /* pm_mrk_lsu_derat_miss\000other\000Marked derat reload (miss) for any page size\000event=0x30162\000\00000\000\000 */
{ 393223 }, /* pm_mrk_lsu_fin\000translation\000lsu marked instr PPC finish\000event=0x40132\000\00000\000\000 */
{ 393583 }, /* pm_mrk_ntc_cyc\000translation\000Cycles during which the marked instruction is next to complete (completion is held up because the marked instruction hasn't completed yet)\000event=0x2011c\000\00000\000\000 */
{ 398238 }, /* pm_mrk_probe_nop_cmpl\000translation\000Marked probeNops completed\000event=0x1f15e\000\00000\000\000 */
{ 307864 }, /* pm_mrk_run_cyc\000memory\000Run cycles in which a marked instruction is in the pipeline\000event=0x1d15e\000\00000\000\000 */
{ 308505 }, /* pm_mrk_st_cmpl\000memory\000Marked store completed and sent to nest\000event=0x301e2\000\00000\000\000 */
{ 321436 }, /* pm_mrk_st_cmpl_int\000other\000marked store finished with intervention\000event=0x30134\000\00000\000\000 */
{ 367110 }, /* pm_mrk_st_drain_to_l2disp_cyc\000other\000cycles to drain st from core to L2\000event=0x3f150\000\00000\000\000 */
{ 161857 }, /* pm_mrk_st_fwd\000marked\000Marked st forwards\000event=0x3012c\000\00000\000\000 */
{ 161916 }, /* pm_mrk_st_l2disp_to_cmpl_cyc\000marked\000cycles from L2 rc disp to l2 rc completion\000event=0x1f150\000\00000\000\000 */
{ 162014 }, /* pm_mrk_st_nest\000marked\000Marked store sent to nest\000event=0x20138\000\00000\000\000 */
{ 288513 }, /* pm_mrk_stall_cmplu_cyc\000marked\000Number of cycles the marked instruction is experiencing a stall while it is next to complete (NTC)\000event=0x3013e\000\00000\000\000 */
{ 161465 }, /* pm_mrk_stcx_fail\000marked\000marked stcx failed\000event=0x3e158\000\00000\000\000 */
{ 306874 }, /* pm_mrk_stcx_fin\000marked\000Number of marked stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x24156\000\00000\000\000 */
{ 367572 }, /* pm_mrk_tend_fail\000other\000Nested or not nested tend failed for a marked tend instruction\000event=0x28a4\000\00000\000\000 */
{ 365289 }, /* pm_mrk_vsu_fin\000other\000VSU marked instr finish\000event=0x30132\000\00000\000\000 */
{ 335896 }, /* pm_mult_mrk\000other\000mult marked instr\000event=0x3d15e\000\00000\000\000 */
{ 307044 }, /* pm_nest_ref_clk\000memory\000Multiply by 4 to obtain the number of PB cycles\000event=0x3006e\000\00000\000\000 */
{ 323027 }, /* pm_non_data_store\000other\000All ops that drain from s2q to L2 and contain no data\000event=0xf8a0\000\00000\000\000 */
{ 310102 }, /* pm_non_fma_flop_cmpl\000memory\000Non FMA instruction completed\000event=0x4d056\000\00000\000\000 */
{ 302211 }, /* pm_non_math_flop_cmpl\000marked\000Non FLOP operation completed\000event=0x4d05a\000\00000\000\000 */
{ 337809 }, /* pm_non_tm_rst_sc\000other\000Non-TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x260a6\000\00000\000\000 */
{ 354313 }, /* pm_ntc_all_fin\000other\000Cycles after instruction finished to instruction completed\000event=0x2001a\000\00000\000\000 */
{ 382667 }, /* pm_ntc_fin\000pipeline\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000event=0x2405a\000\00000\000\000 */
{ 374842 }, /* pm_ntc_issue_held_arb\000pipeline\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000event=0x2e016\000\00000\000\000 */
{ 278989 }, /* pm_ntc_issue_held_darq_full\000frontend\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000event=0x1006a\000\00000\000\000 */
{ 297725 }, /* pm_ntc_issue_held_other\000marked\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000event=0x3d05a\000\00000\000\000 */
{ 334090 }, /* pm_partial_st_fin\000other\000Any store finished by an LSU slice\000event=0x34054\000\00000\000\000 */
{ 307134 }, /* pm_pmc1_overflow\000memory\000Overflow from counter 1\000event=0x20010\000\00000\000\000 */
{ 308151 }, /* pm_pmc1_rewind\000memory\000PMC1 rewind event\000event=0x4d02c\000\00000\000\000 */
{ 395787 }, /* pm_pmc1_saved\000translation\000PMC1 Rewind Value saved\000event=0x4d010\000\00000\000\000 */
{ 392268 }, /* pm_pmc2_overflow\000translation\000Overflow from counter 2\000event=0x30010\000\00000\000\000 */
{ 383602 }, /* pm_pmc2_rewind\000pipeline\000PMC2 Rewind Event (did not match condition)\000event=0x30020\000\00000\000\000 */
{ 378315 }, /* pm_pmc2_saved\000pipeline\000PMC2 Rewind Value saved\000event=0x10022\000\00000\000\000 */
{ 372370 }, /* pm_pmc3_overflow\000pipeline\000Overflow from counter 3\000event=0x40010\000\00000\000\000 */
{ 308979 }, /* pm_pmc3_rewind\000memory\000PMC3 rewind event. A rewind happens when a speculative event (such as latency or CPI stack) is selected on PMC3 and the stall reason or reload source did not match the one programmed in PMC3. When this occurs, the count in PMC3 will not change\000event=0x1000a\000\00000\000\000 */
{ 327920 }, /* pm_pmc3_saved\000other\000PMC3 Rewind Value saved\000event=0x4d012\000\00000\000\000 */
{ 284154 }, /* pm_pmc4_overflow\000frontend\000Overflow from counter 4\000event=0x10010\000\00000\000\000 */
{ 282552 }, /* pm_pmc4_rewind\000frontend\000PMC4 Rewind Event\000event=0x10020\000\00000\000\000 */
{ 381469 }, /* pm_pmc4_saved\000pipeline\000PMC4 Rewind Value saved (matched condition)\000event=0x30022\000\00000\000\000 */
{ 375695 }, /* pm_pmc5_overflow\000pipeline\000Overflow from counter 5\000event=0x10024\000\00000\000\000 */
{ 383329 }, /* pm_pmc6_overflow\000pipeline\000Overflow from counter 6\000event=0x30024\000\00000\000\000 */
{ 353677 }, /* pm_probe_nop_disp\000other\000ProbeNops dispatched\000event=0x40014\000\00000\000\000 */
{ 331413 }, /* pm_pte_prefetch\000other\000PTE prefetches\000event=0xf084\000\00000\000\000 */
{ 356851 }, /* pm_ptesync\000other\000A ptesync instruction was counted when the instruction is decoded and transmitted\000event=0xd8b0\000\00000\000\000 */
{ 388013 }, /* pm_pump_cpred\000pipeline\000Pump prediction correct. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x10054\000\00000\000\000 */
{ 382868 }, /* pm_pump_mpred\000pipeline\000Pump misprediction. Counts across all types of pumps for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40052\000\00000\000\000 */
{ 331468 }, /* pm_radix_pwc_l1_pde_from_l2\000other\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L2 data cache\000event=0x2d026\000\00000\000\000 */
{ 296714 }, /* pm_radix_pwc_l1_pde_from_l3\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from the core's L3 data cache\000event=0x3f058\000\00000\000\000 */
{ 288661 }, /* pm_radix_pwc_l1_pde_from_l3miss\000marked\000A Page Directory Entry was reloaded to a level 1 page walk cache from beyond the core's L3 data cache. The source could be local/remote/distant memory or another core's cache\000event=0x4f056\000\00000\000\000 */
{ 278212 }, /* pm_radix_pwc_l2_pde_from_l2\000floating point\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L2 data cache\000event=0x2d028\000\00000\000\000 */
{ 379275 }, /* pm_radix_pwc_l2_pde_from_l3\000pipeline\000A Page Directory Entry was reloaded to a level 2 page walk cache from the core's L3 data cache\000event=0x3f05a\000\00000\000\000 */
{ 377341 }, /* pm_radix_pwc_l2_pte_from_l2\000pipeline\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L2 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x1f058\000\00000\000\000 */
{ 300185 }, /* pm_radix_pwc_l2_pte_from_l3\000marked\000A Page Table Entry was reloaded to a level 2 page walk cache from the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation\000event=0x4f058\000\00000\000\000 */
{ 353357 }, /* pm_radix_pwc_l2_pte_from_l3miss\000other\000A Page Table Entry was reloaded to a level 2 page walk cache from beyond the core's L3 data cache. This implies that level 3 and level 4 PWC accesses were not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05c\000\00000\000\000 */
{ 298200 }, /* pm_radix_pwc_l3_pde_from_l2\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L2 data cache\000event=0x2d02a\000\00000\000\000 */
{ 298349 }, /* pm_radix_pwc_l3_pde_from_l3\000marked\000A Page Directory Entry was reloaded to a level 3 page walk cache from the core's L3 data cache\000event=0x1f05c\000\00000\000\000 */
{ 289781 }, /* pm_radix_pwc_l3_pte_from_l2\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L2 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x2d02e\000\00000\000\000 */
{ 290005 }, /* pm_radix_pwc_l3_pte_from_l3\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation\000event=0x3f05e\000\00000\000\000 */
{ 301492 }, /* pm_radix_pwc_l3_pte_from_l3miss\000marked\000A Page Table Entry was reloaded to a level 3 page walk cache from beyond the core's L3 data cache. This implies that a level 4 PWC access was not necessary for this translation. The source could be local/remote/distant memory or another core's cache\000event=0x4f05e\000\00000\000\000 */
{ 295996 }, /* pm_radix_pwc_l4_pte_from_l2\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L2 data cache. This is the deepest level of PWC possible for a translation\000event=0x1f05a\000\00000\000\000 */
{ 295790 }, /* pm_radix_pwc_l4_pte_from_l3\000marked\000A Page Table Entry was reloaded to a level 4 page walk cache from the core's L3 data cache. This is the deepest level of PWC possible for a translation\000event=0x4f05a\000\00000\000\000 */
{ 339729 }, /* pm_radix_pwc_l4_pte_from_l3miss\000other\000A Page Table Entry was reloaded to a level 4 page walk cache from beyond the core's L3 data cache. This is the deepest level of PWC possible for a translation. The source could be local/remote/distant memory or another core's cache\000event=0x3f054\000\00000\000\000 */
{ 312121 }, /* pm_radix_pwc_miss\000other\000A radix translation attempt missed in the TLB and all levels of page walk cache\000event=0x4f054\000\00000\000\000 */
{ 330617 }, /* pm_rc0_busy\000other\000RC mach 0 Busy. Used by PMU to sample ave RC lifetime (mach0 used as sample point)\000event=0x1608c\000\00000\000\000 */
{ 339512 }, /* pm_rc_usage\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each RC machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x1688c\000\00000\000\000 */
{ 315695 }, /* pm_rd_clearing_sc\000other\000Core TM load hits line in L3 in TM_SC state and causes it to be invalidated\000event=0x468a6\000\00000\000\000 */
{ 351910 }, /* pm_rd_forming_sc\000other\000Doesn't occur\000event=0x460a6\000\00000\000\000 */
{ 369735 }, /* pm_rd_hit_pf\000other\000RD machine hit L3 PF machine\000event=0x268a8\000\00000\000\000 */
{ 381555 }, /* pm_run_cyc\000pipeline\000Run_cycles\000event=0x200f4\000\00000\000\000 */
{ 319272 }, /* pm_run_cyc_smt4_mode\000other\000Cycles in which this thread's run latch is set and the core is in SMT4 mode\000event=0x2006c\000\00000\000\000 */
{ 302903 }, /* pm_run_cyc_st_mode\000marked\000Cycles run latch is set and core is in ST mode\000event=0x1006c\000\00000\000\000 */
{ 321055 }, /* pm_run_inst_cmpl\000other\000Run_Instructions\000event=0x400fa\000\00000\000\000 */
{ 297483 }, /* pm_run_purr\000marked\000Run_PURR\000event=0x400f4\000\00000\000\000 */
{ 307521 }, /* pm_run_spurr\000memory\000Run SPURR\000event=0x10008\000\00000\000\000 */
{ 329034 }, /* pm_s2q_full\000other\000Cycles during which the S2Q is full\000event=0xe080\000\00000\000\000 */
{ 342106 }, /* pm_scalar_flop_cmpl\000other\000Scalar flop operation completed\000event=0x45056\000\00000\000\000 */
{ 254410 }, /* pm_shl_created\000other\000Store-Hit-Load Table Entry Created\000event=0x508c\000\00000\000\000 */
{ 357643 }, /* pm_shl_st_dep_created\000other\000Store-Hit-Load Table Read Hit with entry Enabled\000event=0x588c\000\00000\000\000 */
{ 368422 }, /* pm_sn0_busy\000other\000SN mach 0 Busy. Used by PMU to sample ave SN lifetime (mach0 used as sample point)\000event=0x16090\000\00000\000\000 */
{ 316540 }, /* pm_sn_hit\000other\000Any port snooper hit L3.  Up to 4 can happen in a cycle but we only count 1\000event=0x460a8\000\00000\000\000 */
{ 328681 }, /* pm_sn_invl\000other\000Any port snooper detects a store to a line in the Sx state and invalidates the line.  Up to 4 can happen in a cycle but we only count 1\000event=0x368a8\000\00000\000\000 */
{ 367847 }, /* pm_sn_miss\000other\000Any port snooper L3 miss or collision.  Up to 4 can happen in a cycle but we only count 1\000event=0x468a8\000\00000\000\000 */
{ 347437 }, /* pm_sn_usage\000other\000Continuous 16 cycle (2to1) window where this signals rotates thru sampling each SN machine busy. PMU uses this wave to then do 16 cyc count to sample total number of machs running\000event=0x3688c\000\00000\000\000 */
{ 310351 }, /* pm_snoop_tlbie\000other\000TLBIE snoop\000event=0xf880\000\00000\000\000 */
{ 320210 }, /* pm_snp_tm_hit_m\000other\000TM snoop that is a store hits line in L3 in M or Mu state (exclusive modified)\000event=0x360a6\000\00000\000\000 */
{ 314504 }, /* pm_snp_tm_hit_t\000other\000TM snoop that is a store hits line in L3 in T, Tn or Te state (shared modified)\000event=0x368a6\000\00000\000\000 */
{ 303499 }, /* pm_sp_flop_cmpl\000marked\000SP instruction completed\000event=0x4505a\000\00000\000\000 */
{ 310472 }, /* pm_srq_empty_cyc\000other\000Cycles in which the SRQ has at least one (out of four) empty slice\000event=0x40008\000\00000\000\000 */
{ 317146 }, /* pm_srq_sync_cyc\000other\000A sync is in the S2Q (edge detect to count)\000event=0xd0ac\000\00000\000\000 */
{ 345737 }, /* pm_st_caused_fail\000other\000Non-TM Store caused any thread to fail\000event=0x1608e\000\00000\000\000 */
{ 397588 }, /* pm_st_cmpl\000translation\000Stores completed from S2Q (2nd-level store queue)\000event=0x200f0\000\00000\000\000 */
{ 392901 }, /* pm_st_fin\000translation\000Store finish count. Includes speculative activity\000event=0x20016\000\00000\000\000 */
{ 118382 }, /* pm_st_fwd\000translation\000Store forwards that finished\000event=0x20018\000\00000\000\000 */
{ 118873 }, /* pm_st_miss_l1\000translation\000Store Missed L1\000event=0x300f0\000\00000\000\000 */
{ 396311 }, /* pm_stall_end_ict_empty\000translation\000The number a times the core transitioned from a stall to ICT-empty for this thread\000event=0x10028\000\00000\000\000 */
{ 394819 }, /* pm_stcx_fail\000translation\000stcx failed\000event=0x1e058\000\00000\000\000 */
{ 342382 }, /* pm_stcx_fin\000other\000Number of stcx instructions finished. This includes instructions in the speculative path of a branch that may be flushed\000event=0x2e014\000\00000\000\000 */
{ 349279 }, /* pm_stcx_success_cmpl\000other\000Number of stcx instructions that completed successfully\000event=0xc8bc\000\00000\000\000 */
{ 371591 }, /* pm_stop_fetch_pending_cyc\000other\000Fetching is stopped due to an incoming instruction that will result in a flush\000event=0x48a4\000\00000\000\000 */
{ 284107 }, /* pm_suspended\000frontend\000Counter OFF\000event=0\000\00000\000\000 */
{ 285684 }, /* pm_sync_mrk_br_link\000frontend\000Marked Branch and link branch that can cause a synchronous interrupt\000event=0x15152\000\00000\000\000 */
{ 285450 }, /* pm_sync_mrk_br_mpred\000frontend\000Marked Branch mispredict that can cause a synchronous interrupt\000event=0x1515c\000\00000\000\000 */
{ 375054 }, /* pm_sync_mrk_fx_divide\000pipeline\000Marked fixed point divide that can cause a synchronous interrupt\000event=0x15156\000\00000\000\000 */
{ 308210 }, /* pm_sync_mrk_l2hit\000memory\000Marked L2 Hits that can throw a synchronous interrupt\000event=0x15158\000\00000\000\000 */
{ 345880 }, /* pm_sync_mrk_l2miss\000other\000Marked L2 Miss that can throw a synchronous interrupt\000event=0x1515a\000\00000\000\000 */
{ 321114 }, /* pm_sync_mrk_l3miss\000other\000Marked L3 misses that can throw a synchronous interrupt\000event=0x15154\000\00000\000\000 */
{ 162868 }, /* pm_sync_mrk_probe_nop\000marked\000Marked probeNops which can cause synchronous interrupts\000event=0x15150\000\00000\000\000 */
{ 297096 }, /* pm_sys_pump_cpred\000marked\000Initial and Final Pump Scope was system pump for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30050\000\00000\000\000 */
{ 304509 }, /* pm_sys_pump_mpred\000marked\000Final Pump Scope (system) mispredicted. Either the original scope was too small (Chip/Group) or the original scope was System and it should have been smaller. Counts for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x30052\000\00000\000\000 */
{ 389527 }, /* pm_sys_pump_mpred_rty\000pmc\000Final Pump Scope (system) ended up larger than Initial Pump Scope (Chip/Group) for all data types excluding data prefetch (demand load,inst prefetch,inst fetch,xlate)\000event=0x40050\000\00000\000\000 */
{ 390710 }, /* pm_tablewalk_cyc\000pmc\000Cycles when an instruction tablewalk is active\000event=0x10026\000\00000\000\000 */
{ 330974 }, /* pm_tablewalk_cyc_pref\000other\000tablewalk qualified for pte  prefetches\000event=0xf884\000\00000\000\000 */
{ 347270 }, /* pm_tage_correct\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b4\000\00000\000\000 */
{ 340266 }, /* pm_tage_correct_taken_cmpl\000other\000The TAGE overrode BHT direction prediction and it was correct.  Counted at completion for taken branches only\000event=0x50b4\000\00000\000\000 */
{ 356289 }, /* pm_tage_override_wrong\000other\000The TAGE overrode BHT direction prediction but it was incorrect.  Counted at completion for taken branches only\000event=0x50b8\000\00000\000\000 */
{ 359462 }, /* pm_tage_override_wrong_spec\000other\000The TAGE overrode BHT direction prediction and it was correct.   Includes taken and not taken and is counted at execution time\000event=0x58b8\000\00000\000\000 */
{ 329418 }, /* pm_taken_br_mpred_cmpl\000other\000Total number of taken branches that were incorrectly predicted as not-taken. This event counts branches completed and does not include speculative instructions\000event=0x20056\000\00000\000\000 */
{ 313669 }, /* pm_tb_bit_trans\000other\000timebase event\000event=0x300f8\000\00000\000\000 */
{ 313099 }, /* pm_tend_pend_cyc\000other\000TEND latency per thread\000event=0xe8b0\000\00000\000\000 */
{ 363617 }, /* pm_thrd_all_run_cyc\000other\000Cycles in which all the threads have the run latch set\000event=0x2000c\000\00000\000\000 */
{ 274397 }, /* pm_thrd_conc_run_inst\000cache\000PPC Instructions Finished by this thread when all threads in the core had the run-latch set\000event=0x300f4\000\00000\000\000 */
{ 256235 }, /* pm_thrd_prio_0_1_cyc\000other\000Cycles thread running at priority level 0 or 1\000event=0x40bc\000\00000\000\000 */
{ 361228 }, /* pm_thrd_prio_2_3_cyc\000other\000Cycles thread running at priority level 2 or 3\000event=0x48bc\000\00000\000\000 */
{ 256419 }, /* pm_thrd_prio_4_5_cyc\000other\000Cycles thread running at priority level 4 or 5\000event=0x5080\000\00000\000\000 */
{ 334168 }, /* pm_thrd_prio_6_7_cyc\000other\000Cycles thread running at priority level 6 or 7\000event=0x5880\000\00000\000\000 */
{ 286600 }, /* pm_thresh_acc\000frontend\000This event increments every time the threshold event counter ticks. Thresholding must be enabled (via MMCRA) and the thresholding start event must occur for this counter to increment. It will stop incrementing when the thresholding stop event occurs or when thresholding is disabled, until the next time a configured thresholding start event occurs\000event=0x24154\000\00000\000\000 */
{ 282613 }, /* pm_thresh_exc_1024\000frontend\000Threshold counter exceeded a value of 1024\000event=0x301ea\000\00000\000\000 */
{ 276380 }, /* pm_thresh_exc_128\000cache\000Threshold counter exceeded a value of 128\000event=0x401ea\000\00000\000\000 */
{ 382231 }, /* pm_thresh_exc_2048\000pipeline\000Threshold counter exceeded a value of 2048\000event=0x401ec\000\00000\000\000 */
{ 278903 }, /* pm_thresh_exc_256\000frontend\000Threshold counter exceed a count of 256\000event=0x101e8\000\00000\000\000 */
{ 395376 }, /* pm_thresh_exc_32\000translation\000Threshold counter exceeded a value of 32\000event=0x201e6\000\00000\000\000 */
{ 276830 }, /* pm_thresh_exc_4096\000cache\000Threshold counter exceed a count of 4096\000event=0x101e6\000\00000\000\000 */
{ 348242 }, /* pm_thresh_exc_512\000other\000Threshold counter exceeded a value of 512\000event=0x201e8\000\00000\000\000 */
{ 116964 }, /* pm_thresh_exc_64\000pmc\000Threshold counter exceeded a value of 64\000event=0x301e8\000\00000\000\000 */
{ 282491 }, /* pm_thresh_met\000frontend\000threshold exceeded\000event=0x101ec\000\00000\000\000 */
{ 278620 }, /* pm_thresh_not_met\000floating point\000Threshold counter did not meet threshold\000event=0x4016e\000\00000\000\000 */
{ 285111 }, /* pm_tlb_hit\000frontend\000Number of times the TLB had the data required by the instruction. Applies to both HPT and RPT\000event=0x1f054\000\00000\000\000 */
{ 387956 }, /* pm_tlb_miss\000pipeline\000TLB Miss (I + D)\000event=0x20066\000\00000\000\000 */
{ 268472 }, /* pm_tlbie_fin\000pipeline\000tlbie finished\000event=0x30058\000\00000\000\000 */
{ 383051 }, /* pm_tm_aborts\000pipeline\000Number of TM transactions aborted\000event=0x30056\000\00000\000\000 */
{ 312971 }, /* pm_tm_cam_overflow\000other\000L3 TM CAM is full when a L2 castout of TM_SC line occurs.  Line is pushed to memory\000event=0x168a6\000\00000\000\000 */
{ 353282 }, /* pm_tm_cap_overflow\000other\000TM Footprint Capacity Overflow\000event=0x4608e\000\00000\000\000 */
{ 354986 }, /* pm_tm_fail_conf_non_tm\000other\000TM aborted because a conflict occurred with a non-transactional access by another processor\000event=0x28a8\000\00000\000\000 */
{ 357536 }, /* pm_tm_fail_conf_tm\000other\000TM aborted because a conflict occurred with another transaction\000event=0x20ac\000\00000\000\000 */
{ 343087 }, /* pm_tm_fail_footprint_overflow\000other\000TM aborted because the tracking limit for transactional storage accesses was exceeded.. Asynchronous\000event=0x20a8\000\00000\000\000 */
{ 340501 }, /* pm_tm_fail_non_tx_conflict\000other\000Non transactional conflict from LSU, gets reported to TEXASR\000event=0xe0b0\000\00000\000\000 */
{ 341645 }, /* pm_tm_fail_self\000other\000TM aborted because a self-induced conflict occurred in Suspended state, due to one of the following: a store to a storage location that was previously accessed transactionally; a dcbf, dcbi, or icbi specify- ing a block that was previously accessed transactionally; a dcbst specifying a block that was previously written transactionally; or a tlbie that specifies a translation that was pre- viously used transactionally\000event=0x28ac\000\00000\000\000 */
{ 331869 }, /* pm_tm_fail_tlbie\000other\000Transaction failed because there was a TLBIE hit in the bloom filter\000event=0xe0ac\000\00000\000\000 */
{ 350874 }, /* pm_tm_fail_tx_conflict\000other\000Transactional conflict from LSU, gets reported to TEXASR\000event=0xe8ac\000\00000\000\000 */
{ 368331 }, /* pm_tm_fav_caused_fail\000other\000TM Load (fav) caused another thread to fail\000event=0x2688e\000\00000\000\000 */
{ 338231 }, /* pm_tm_fav_tbegin\000other\000Dispatch time Favored tbegin\000event=0x209c\000\00000\000\000 */
{ 327137 }, /* pm_tm_ld_caused_fail\000other\000Non-TM Load caused any thread to fail\000event=0x1688e\000\00000\000\000 */
{ 320800 }, /* pm_tm_ld_conf\000other\000TM Load (fav or non-fav) ran into conflict (failed)\000event=0x2608e\000\00000\000\000 */
{ 327575 }, /* pm_tm_nested_tbegin\000other\000Completion Tm nested tbegin\000event=0x20a0\000\00000\000\000 */
{ 329273 }, /* pm_tm_nested_tend\000other\000Completion time nested tend\000event=0x2098\000\00000\000\000 */
{ 330048 }, /* pm_tm_non_fav_tbegin\000other\000Dispatch time non favored tbegin\000event=0x289c\000\00000\000\000 */
{ 342624 }, /* pm_tm_outer_tbegin\000other\000Completion time outer tbegin\000event=0x2094\000\00000\000\000 */
{ 370414 }, /* pm_tm_outer_tbegin_disp\000other\000Number of outer tbegin instructions dispatched. The dispatch unit determines whether the tbegin instruction is outer or nested. This is a speculative count, which includes flushed instructions\000event=0x4e05e\000\00000\000\000 */
{ 324166 }, /* pm_tm_outer_tend\000other\000Completion time outer tend\000event=0x2894\000\00000\000\000 */
{ 312570 }, /* pm_tm_passed\000other\000Number of TM transactions that passed\000event=0x2e052\000\00000\000\000 */
{ 333122 }, /* pm_tm_rst_sc\000other\000TM snoop hits line in L3 that is TM_SC state and causes it to be invalidated\000event=0x268a6\000\00000\000\000 */
{ 366604 }, /* pm_tm_sc_co\000other\000L3 castout of line that was StoreCopy (original value of speculatively written line) in a Transaction\000event=0x160a6\000\00000\000\000 */
{ 359253 }, /* pm_tm_st_caused_fail\000other\000TM Store (fav or non-fav) caused another thread to fail\000event=0x3688e\000\00000\000\000 */
{ 322935 }, /* pm_tm_st_conf\000other\000TM Store (fav or non-fav) ran into conflict (failed)\000event=0x3608e\000\00000\000\000 */
{ 359728 }, /* pm_tm_tabort_treclaim\000other\000Completion time tabortnoncd, tabortcd, treclaim\000event=0x2898\000\00000\000\000 */
{ 391768 }, /* pm_tm_trans_run_cyc\000pmc\000run cycles in transactional state\000event=0x10060\000\00000\000\000 */
{ 283371 }, /* pm_tm_trans_run_inst\000frontend\000Run instructions completed in transactional state (gated by the run latch)\000event=0x30060\000\00000\000\000 */
{ 310402 }, /* pm_tm_tresume\000other\000TM resume instruction completed\000event=0x20a4\000\00000\000\000 */
{ 320619 }, /* pm_tm_tsuspend\000other\000TM suspend instruction completed\000event=0x28a0\000\00000\000\000 */
{ 387037 }, /* pm_tm_tx_pass_run_cyc\000pipeline\000cycles spent in successful transactions\000event=0x2e012\000\00000\000\000 */
{ 326059 }, /* pm_tma_req_l2\000other\000addrs only req to L2 only on the first one,Indication that Load footprint is not expanding\000event=0xe0a4\000\00000\000\000 */
{ 290867 }, /* pm_vector_flop_cmpl\000marked\000Vector FP instruction completed\000event=0x4d058\000\00000\000\000 */
{ 345387 }, /* pm_vector_ld_cmpl\000other\000Number of vector load instructions completed\000event=0x44054\000\00000\000\000 */
{ 282898 }, /* pm_vector_st_cmpl\000frontend\000Number of vector store instructions completed\000event=0x44056\000\00000\000\000 */
{ 373754 }, /* pm_vsu_dp_fsqrt_fdiv\000pipeline\000vector versions of fdiv,fsqrt\000event=0x3d058\000\00000\000\000 */
{ 359953 }, /* pm_vsu_fin\000other\000VSU instruction finished. Up to 4 per cycle\000event=0x2505c\000\00000\000\000 */
{ 387127 }, /* pm_vsu_fsqrt_fdiv\000pipeline\000four flops operation (fdiv,fsqrt) Scalar Instructions only\000event=0x4d04e\000\00000\000\000 */
{ 386959 }, /* pm_vsu_non_flop_cmpl\000pipeline\000Non FLOP operation completed\000event=0x4d050\000\00000\000\000 */
{ 324234 }, /* pm_xlate_hpt_mode\000other\000LSU reports every cycle the thread is in HPT translation mode (as opposed to radix mode)\000event=0xf098\000\00000\000\000 */
{ 332498 }, /* pm_xlate_miss\000other\000The LSU requested a line from L2 for translation.  It may be satisfied from any source beyond L2.  Includes speculative instructions. Includes instruction, prefetch and demand\000event=0xf89c\000\00000\000\000 */
{ 352143 }, /* pm_xlate_radix_mode\000other\000LSU reports every cycle the thread is in radix translation mode (as opposed to HPT mode)\000event=0xf898\000\00000\000\000 */

};

const struct pmu_table_entry pmu_events__power9[] = {
{
     .entries = pmu_events__power9_default_core,
     .num_entries = ARRAY_SIZE(pmu_events__power9_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__power9_default_core[] = {
{ 533903 }, /* CPM_CS_32MHZ_CYC\000\000hv_24x7@CPM_CS_32MHZ_CYC\\,domain\\=3\\,core\\=?@\000\000\000\0001MHz\000\000\000\00020 */
{ 534591 }, /* Memory-bandwidth-MCS\000memory-bandwidth\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000 */
{ 533359 }, /* Memory_RD_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS01_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_RD_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_RD_DISP_PORT23\\,chip\\=?@\000\000\000\0001.6e-2MB\000\000\000\00010 */
{ 533598 }, /* Memory_WR_BW_Chip\000Memory_BW\000hv_24x7@PM_MCS01_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS01_128B_WR_DISP_PORT23\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT01\\,chip\\=?@ + hv_24x7@PM_MCS23_128B_WR_DISP_PORT23\\,chip\\=?@\000\000\000\0001.6e-2MB\000\000\000\00010 */
{ 533837 }, /* PowerBUS_Frequency\000\000hv_24x7@PM_PB_CYC\\,chip\\=?@\000\000\000\0002.5e-7GHz\000\000\000\00010 */
{ 504513 }, /* br_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CMPL / PM_BR_PRED * 100\000\000\000\000\000\000\000\00000 */
{ 508760 }, /* emq_stall_cpi\000cpi_breakdown\000erat_miss_stall_cpi + emq_full_stall_cpi\000\000\000\000\000\000\000\00000 */
{ 513032 }, /* issue_hold_cpi\000cpi_breakdown\000ntc_issue_held_darq_full_cpi + ntc_issue_held_arb_cpi + ntc_issue_held_other_cpi\000\000\000\000\000\000\000\00000 */
{ 514378 }, /* lrq_stall_cpi\000cpi_breakdown\000lmq_full_stall_cpi + st_fwd_stall_cpi + lhs_stall_cpi + lsu_mfspr_stall_cpi + larx_stall_cpi + lrq_other_stall_cpi\000\000\000\000\000\000\000\00000 */
{ 514812 }, /* lsaq_stall_cpi\000cpi_breakdown\000lrq_full_stall_cpi + srq_full_stall_cpi + lsaq_arb_stall_cpi\000\000\000\000\000\000\000\00000 */
{ 533980 }, /* mcs01-read\000memory-bandwidth\000nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_RD_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000 */
{ 534254 }, /* mcs01-write\000memory-bandwidth\000nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT01@ + nest_mcs01_imc@PM_MCS01_128B_WR_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000 */
{ 534117 }, /* mcs23-read\000memory-bandwidth\000nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_RD_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000 */
{ 534392 }, /* mcs23-write\000memory-bandwidth\000nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT01@ + nest_mcs23_imc@PM_MCS23_128B_WR_DISP_PORT23@\000\000\000\0006.1e-5MB\000\000\000\00000 */
{ 534530 }, /* powerbus_freq\000\000nest_powerbus0_imc@PM_PB_CYC@\000\000\000\0001e-9GHz\000\000\000\00000 */
{ 518833 }, /* scalar_stall_cpi\000cpi_breakdown\000fxu_stall_cpi + dp_stall_cpi + dfu_stall_cpi + pm_stall_cpi + crypto_stall_cpi\000\000\000\000\000\000\000\00000 */
{ 519534 }, /* srq_stall_cpi\000cpi_breakdown\000store_data_stall_cpi + eieio_stall_cpi + stcx_stall_cpi + slb_stall_cpi + tend_stall_cpi + paste_stall_cpi + tlbie_stall_cpi + store_pipe_arb_stall_cpi + store_fin_arb_stall_cpi\000\000\000\000\000\000\000\00000 */
{ 522265 }, /* vector_stall_cpi\000cpi_breakdown\000vfxu_stall_cpi + vdp_stall_cpi\000\000\000\000\000\000\000\00000 */
{ 529407 }, /* any_sync_stall_cpi\000\000PM_CMPLU_STALL_ANY_SYNC / PM_RUN_INST_CMPL\000\000ANY_SYNC_STALL_CPI\000\000\000\000\000\00000 */
{ 529497 }, /* average_completed_instruction_set_size\000\000PM_INST_CMPL / PM_1PLUS_PPC_CMPL\000\000Avg. more than 1 instructions completed\000\000\000\000\000\00000 */
{ 481323 }, /* average_il1_miss_latency\000latency\000PM_IC_DEMAND_CYC / PM_IC_DEMAND_REQ\000\000Average icache miss latency\000\000\000\000\000\00000 */
{ 527398 }, /* br_mpred_flush_rate_percent\000general\000PM_FLUSH_MPRED / PM_RUN_INST_CMPL * 100\000\000Branch Mispredict flushes per instruction\000\000\000\000\000\00000 */
{ 529618 }, /* branches_per_inst\000\000PM_BRU_FIN / PM_RUN_INST_CMPL\000\000% Branches per instruction\000\000\000\000\000\00000 */
{ 505101 }, /* bru_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_BRU / PM_RUN_INST_CMPL\000\000Completion stall due to a Branch Unit\000\000\000\000\000\00000 */
{ 444978 }, /* ccache_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_CCACHE / PM_RUN_INST_CMPL * 100\000\000Count cache branch misprediction per instruction\000\000\000\000\000\00000 */
{ 504601 }, /* ccache_misprediction_percent\000branch_prediction\000PM_BR_MPRED_CCACHE / PM_BR_PRED_CCACHE * 100\000\000Count cache branch misprediction\000\000\000\000\000\00000 */
{ 529702 }, /* completion_cpi\000\000PM_1PLUS_PPC_CMPL / PM_RUN_INST_CMPL\000\000Cycles in which at least one instruction completes in this thread\000\000\000\000\000\00000 */
{ 469812 }, /* cpi\000general\000PM_CYC / PM_INST_CMPL\000\000Cycles per instruction\000\000\000\000\000\00000 */
{ 505213 }, /* crypto_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_CRYPTO / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was routed to the crypto execution pipe and was waiting to finish\000\000\000\000\000\00000 */
{ 495719 }, /* custom_secs\000\000PM_RUN_CYC\000\000cycles\000\000\000\000\000\00000 */
{ 529829 }, /* cycles_atleast_one_inst_dispatched_percent\000\000PM_1PLUS_PPC_DISP / PM_CYC * 100\000\000Percentage Cycles at least one instruction dispatched\000\000\000\000\000\00000 */
{ 529968 }, /* cycles_per_completed_instructions_set\000\000PM_CYC / PM_1PLUS_PPC_CMPL\000\000Cycles per instruction group\000\000\000\000\000\00000 */
{ 505400 }, /* dcache_miss_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that missed the L1 and was waiting for the data to return from the nest\000\000\000\000\000\00000 */
{ 494651 }, /* derat_4k_miss_rate_percent\000translation\000PM_DERAT_MISS_4K * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss rate for 4K page per inst\000\000\000\000\000\00000 */
{ 494779 }, /* derat_4k_miss_ratio\000translation\000PM_DERAT_MISS_4K / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 4K page\000\000\000\000\000\00000 */
{ 494885 }, /* derat_64k_miss_rate_percent\000translation\000PM_DERAT_MISS_64K * 100 / PM_RUN_INST_CMPL\000\000% DERAT miss ratio for 64K page per inst\000\000\000\000\000\00000 */
{ 495017 }, /* derat_64k_miss_ratio\000translation\000PM_DERAT_MISS_64K / PM_LSU_DERAT_MISS\000\000DERAT miss ratio for 64K page\000\000\000\000\000\00000 */
{ 529169 }, /* derat_miss_rate_percent\000pteg_reloads_percent_per_inst\000PM_LSU_DERAT_MISS * 100 / PM_RUN_INST_CMPL\000\000DERAT Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 529315 }, /* derat_miss_ratio\000translation\000PM_LSU_DERAT_MISS / PM_LSU_DERAT_MISS\000\000DERAT miss ratio\000\000\000\000\000\00000 */
{ 491710 }, /* derat_miss_reload_percent\000pteg_reloads_percent_per_ref\000PM_DTLB_MISS * 100 / PM_LSU_DERAT_MISS\000\000% of DERAT misses that result in an ERAT reload\000\000\000\000\000\00000 */
{ 505614 }, /* dflong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DFLONG / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a multi-cycle instruction issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000\00000 */
{ 505839 }, /* dfu_other_stall_cpi\000cpi_breakdown\000dfu_stall_cpi - dflong_stall_cpi\000\000Stalls due to short latency decimal floating ops\000\000\000\000\000\00000 */
{ 505963 }, /* dfu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DFU / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was issued to the Decimal Floating Point execution pipe and waiting to finish\000\000\000\000\000\00000 */
{ 470169 }, /* disp_flush_rate_percent\000general\000PM_FLUSH_DISP / PM_RUN_INST_CMPL * 100\000\000GCT empty cycles\000\000\000\000\000\00000 */
{ 460842 }, /* dl1_miss_reloads_percent\000dl1_reloads_percent_per_ref\000PM_L1_DCACHE_RELOAD_VALID * 100 / PM_LD_MISS_L1\000\000% of DL1 misses that result in a cache reload\000\000\000\000\000\00000 */
{ 460997 }, /* dl1_reload_from_dl2l3_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 456574 }, /* dl1_reload_from_dl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000\00000 */
{ 461178 }, /* dl1_reload_from_dl2l3_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 456757 }, /* dl1_reload_from_dl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000\00000 */
{ 530071 }, /* dl1_reload_from_dl4_percent\000\000PM_DATA_FROM_DL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant L4\000\000\000\000\000\00000 */
{ 530196 }, /* dl1_reload_from_dl4_rate_percent\000\000PM_DATA_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant L4 per Inst\000\000\000\000\000\00000 */
{ 461509 }, /* dl1_reload_from_dmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_DMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Distant Memory\000\000\000\000\000\00000 */
{ 457092 }, /* dl1_reload_from_dmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Distant Memory per Inst\000\000\000\000\000\00000 */
{ 461667 }, /* dl1_reload_from_l21_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L21_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 457252 }, /* dl1_reload_from_l21_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 461835 }, /* dl1_reload_from_l21_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L21_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 457426 }, /* dl1_reload_from_l21_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 523084 }, /* dl1_reload_from_l2_miss_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from sources beyond the local L2\000\000\000\000\000\00000 */
{ 457830 }, /* dl1_reload_from_l2_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L2 per Inst\000\000\000\000\000\00000 */
{ 462623 }, /* dl1_reload_from_l2_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L2 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from L2\000\000\000\000\000\00000 */
{ 458456 }, /* dl1_reload_from_l2_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L2 per Inst\000\000\000\000\000\00000 */
{ 462761 }, /* dl1_reload_from_l31_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L31_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 458600 }, /* dl1_reload_from_l31_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3 M state, other core per Inst\000\000\000\000\000\00000 */
{ 530322 }, /* dl1_reload_from_l31_rate_percent\000\000dl1_reload_from_l31_mod_rate_percent + dl1_reload_from_l31_shr_rate_percent\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 462929 }, /* dl1_reload_from_l31_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L31_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 458782 }, /* dl1_reload_from_l31_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3 S tate, other core per Inst\000\000\000\000\000\00000 */
{ 523256 }, /* dl1_reload_from_l3_mepf_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3_MEPF * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads that came from L3 and were brought into the L3 by a prefetch\000\000\000\000\000\00000 */
{ 522855 }, /* dl1_reload_from_l3_mepf_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3_MEPF * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads that came from the L3 and were brought into the L3 by a prefetch, per instruction completed\000\000\000\000\000\00000 */
{ 523457 }, /* dl1_reload_from_l3_miss_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3MISS * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from sources beyond the local L3\000\000\000\000\000\00000 */
{ 459187 }, /* dl1_reload_from_l3_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from L3 per Inst\000\000\000\000\000\00000 */
{ 463729 }, /* dl1_reload_from_l3_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_L3 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 Reloads from L3\000\000\000\000\000\00000 */
{ 459560 }, /* dl1_reload_from_l3_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from L3 per Inst\000\000\000\000\000\00000 */
{ 530494 }, /* dl1_reload_from_ll4_percent\000\000PM_DATA_FROM_LL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Local L4\000\000\000\000\000\00000 */
{ 530617 }, /* dl1_reload_from_ll4_rate_percent\000\000PM_DATA_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Local L4 per Inst\000\000\000\000\000\00000 */
{ 464017 }, /* dl1_reload_from_lmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_LMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Local Memory\000\000\000\000\000\00000 */
{ 459856 }, /* dl1_reload_from_lmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Local Memory per Inst\000\000\000\000\000\00000 */
{ 464173 }, /* dl1_reload_from_rl2l3_mod_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 460014 }, /* dl1_reload_from_rl2l3_mod_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 464353 }, /* dl1_reload_from_rl2l3_shr_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 460192 }, /* dl1_reload_from_rl2l3_shr_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DL1 reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 530741 }, /* dl1_reload_from_rl4_percent\000\000PM_DATA_FROM_RL4 * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote L4\000\000\000\000\000\00000 */
{ 530865 }, /* dl1_reload_from_rl4_rate_percent\000\000PM_DATA_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000\00000 */
{ 464682 }, /* dl1_reload_from_rmem_percent\000dl1_reloads_percent_per_ref\000PM_DATA_FROM_RMEM * 100 / PM_L1_DCACHE_RELOAD_VALID\000\000% of DL1 dL1_Reloads from Remote Memory\000\000\000\000\000\00000 */
{ 460527 }, /* dl1_reload_from_rmem_rate_percent\000dl1_reloads_percent_per_inst\000PM_DATA_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of DL1 Reloads from Remote Memory per Inst\000\000\000\000\000\00000 */
{ 523629 }, /* dl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_MOD * PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 distant MOD miss rates with measured DL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482597 }, /* dl2l3_mod_latency\000latency\000PM_MRK_DATA_FROM_DL2L3_MOD_CYC / PM_MRK_DATA_FROM_DL2L3_MOD\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000 */
{ 523903 }, /* dl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL2L3_SHR * PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 distant SHR miss rates with measured DL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482723 }, /* dl2l3_shr_latency\000latency\000PM_MRK_DATA_FROM_DL2L3_SHR_CYC / PM_MRK_DATA_FROM_DL2L3_SHR\000\000Marked L2L3 distant Load latency\000\000\000\000\000\00000 */
{ 524177 }, /* dl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DL4 * PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of distant L4 miss rates with measured DL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482850 }, /* dl4_latency\000latency\000PM_MRK_DATA_FROM_DL4_CYC / PM_MRK_DATA_FROM_DL4\000\000Distant L4 average load latency\000\000\000\000\000\00000 */
{ 524414 }, /* dmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_DMEM * PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of distant memory miss rates with measured DMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 482958 }, /* dmem_latency\000latency\000PM_MRK_DATA_FROM_DMEM_CYC / PM_MRK_DATA_FROM_DMEM\000\000Marked Dmem Load latency\000\000\000\000\000\00000 */
{ 506156 }, /* dmiss_distant_stall_cpi\000cpi_breakdown\000dmiss_non_local_stall_cpi - dmiss_remote_stall_cpi\000\000Completion stall by Dcache miss which resolved off node memory/cache\000\000\000\000\000\00000 */
{ 506322 }, /* dmiss_l21_l31_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L21_L31 / PM_RUN_INST_CMPL\000\000Completion stall by Dcache miss which resolved on chip ( excluding local L2/L3)\000\000\000\000\000\00000 */
{ 506496 }, /* dmiss_l2l3_conflict_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3_CONFLICT / PM_RUN_INST_CMPL\000\000Completion stall due to cache miss that resolves in the L2 or L3 with a conflict\000\000\000\000\000\00000 */
{ 506683 }, /* dmiss_l2l3_noconflict_stall_cpi\000cpi_breakdown\000dmiss_l2l3_stall_cpi - dmiss_l2l3_conflict_stall_cpi\000\000Completion stall due to cache miss that resolves in the L2 or L3 without conflict\000\000\000\000\000\00000 */
{ 506872 }, /* dmiss_l2l3_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L2L3 / PM_RUN_INST_CMPL\000\000Completion stall by Dcache miss which resolved in L2/L3\000\000\000\000\000\00000 */
{ 507016 }, /* dmiss_l3miss_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_L3MISS / PM_RUN_INST_CMPL\000\000Completion stall due to cache miss resolving missed the L3\000\000\000\000\000\00000 */
{ 507167 }, /* dmiss_lmem_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_LMEM / PM_RUN_INST_CMPL\000\000Completion stall due to cache miss that resolves in local memory\000\000\000\000\000\00000 */
{ 507320 }, /* dmiss_non_local_stall_cpi\000cpi_breakdown\000dmiss_l3miss_stall_cpi - dmiss_l21_l31_stall_cpi - dmiss_lmem_stall_cpi\000\000Completion stall by Dcache miss which resolved outside of local memory\000\000\000\000\000\00000 */
{ 507511 }, /* dmiss_remote_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DMISS_REMOTE / PM_RUN_INST_CMPL\000\000Completion stall by Dcache miss which resolved from remote chip (cache or memory)\000\000\000\000\000\00000 */
{ 507685 }, /* dp_other_stall_cpi\000cpi_breakdown\000dp_stall_cpi - dplong_stall_cpi\000\000Stalls due to short latency double precision ops\000\000\000\000\000\00000 */
{ 507807 }, /* dp_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DP / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a scalar instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000\00000 */
{ 508104 }, /* dplong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_DPLONG / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000\00000 */
{ 497165 }, /* dpteg_from_l2_rate_percent\000\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Rate of DERAT reloads from L2\000\000\000\000\000\00000 */
{ 497273 }, /* dpteg_from_l3_rate_percent\000\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Rate of DERAT reloads from L3\000\000\000\000\000\00000 */
{ 495126 }, /* dslb_miss_rate_percent\000translation\000PM_DSLB_MISS * 100 / PM_RUN_INST_CMPL\000\000% DSLB_Miss_Rate per inst\000\000\000\000\000\00000 */
{ 470265 }, /* dtlb_miss_rate_percent\000general\000PM_DTLB_MISS / PM_RUN_INST_CMPL * 100\000\000% DTLB miss rate per inst\000\000\000\000\000\00000 */
{ 508421 }, /* eieio_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EIEIO / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction is an EIEIO waiting for response from L2\000\000\000\000\000\00000 */
{ 508581 }, /* emq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EMQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the next to finish instruction suffered an ERAT miss and the EMQ was full\000\000\000\000\000\00000 */
{ 508838 }, /* erat_miss_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ERAT_MISS / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load or store that suffered a translation miss\000\000\000\000\000\00000 */
{ 486866 }, /* erat_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_ERAT_MISS * 100 / PM_RUN_INST_CMPL\000\000ERAT miss reject ratio\000\000\000\000\000\00000 */
{ 528091 }, /* estimated_dl1miss_latency\000latency\000PM_MRK_LD_MISS_L1_CYC / PM_MRK_LD_MISS_L1\000\000average L1 miss latency using marked events\000\000\000\000\000\00000 */
{ 509018 }, /* exception_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EXCEPTION / PM_RUN_INST_CMPL\000\000Cycles in which the NTC instruction is not allowed to complete because it was interrupted by ANY exception, which has to be serviced before the instruction can complete\000\000\000\000\000\00000 */
{ 509273 }, /* exec_unit_other_stall_cpi\000cpi_breakdown\000exec_unit_stall_cpi - scalar_stall_cpi - vector_stall_cpi\000\000Completion stall due to execution units for other reasons\000\000\000\000\000\00000 */
{ 509437 }, /* exec_unit_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_EXEC_UNIT / PM_RUN_INST_CMPL\000\000Completion stall due to execution units (FXU/VSU/CRU)\000\000\000\000\000\00000 */
{ 530994 }, /* finish_to_cmpl_cpi\000\000PM_NTC_ALL_FIN / PM_RUN_INST_CMPL\000\000Cycles in which the oldest instruction is finished and ready to complete for waiting to get through the completion pipe\000\000\000\000\000\00000 */
{ 531176 }, /* fixed_per_inst\000\000PM_FXU_FIN / PM_RUN_INST_CMPL\000\000Total Fixed point operations\000\000\000\000\000\00000 */
{ 509577 }, /* flush_any_thread_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FLUSH_ANY_THREAD / PM_RUN_INST_CMPL\000\000Cycles in which the NTC instruction is not allowed to complete because any of the 4 threads in the same core suffered a flush, which blocks completion\000\000\000\000\000\00000 */
{ 470368 }, /* flush_rate_percent\000general\000PM_FLUSH * 100 / PM_RUN_INST_CMPL\000\000Flush rate (%)\000\000\000\000\000\00000 */
{ 509828 }, /* fxlong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXLONG / PM_RUN_INST_CMPL\000\000Completion stall due to a long latency scalar fixed point instruction (division, square root)\000\000\000\000\000\00000 */
{ 531259 }, /* fxu_all_busy\000\000PM_FXU_BUSY / PM_CYC\000\000All FXU Busy\000\000\000\000\000\00000 */
{ 531315 }, /* fxu_all_idle\000\000PM_FXU_IDLE / PM_CYC\000\000All FXU Idle\000\000\000\000\000\00000 */
{ 510002 }, /* fxu_other_stall_cpi\000cpi_breakdown\000fxu_stall_cpi - fxlong_stall_cpi\000\000Stalls due to short latency integer ops\000\000\000\000\000\00000 */
{ 510117 }, /* fxu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_FXU / PM_RUN_INST_CMPL\000\000Finish stall due to a scalar fixed point or CR instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000\00000 */
{ 477925 }, /* icache_miss_reload\000instruction_stats_percent_per_ref\000(PM_L1_ICACHE_MISS - PM_IC_PREF_WRITE) / PM_L1_ICACHE_MISS\000\000Icache Fetchs per Icache Miss\000\000\000\000\000\00000 */
{ 478075 }, /* icache_pref_percent\000instruction_stats_percent_per_ref\000PM_IC_PREF_WRITE * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads due to prefetch\000\000\000\000\000\00000 */
{ 510339 }, /* ict_noslot_br_mpred_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_BR_MPRED / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to branch mispred\000\000\000\000\000\00000 */
{ 510500 }, /* ict_noslot_br_mpred_icmiss_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_BR_MPRED_ICMISS / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to Icache Miss and branch mispred\000\000\000\000\000\00000 */
{ 510691 }, /* ict_noslot_cyc_other_cpi\000cpi_breakdown\000nothing_dispatched_cpi - ict_noslot_ic_miss_cpi - ict_noslot_br_mpred_icmiss_cpi - ict_noslot_br_mpred_cpi - ict_noslot_disp_held_cpi\000\000Instruction Completion Table other stalls\000\000\000\000\000\00000 */
{ 510914 }, /* ict_noslot_disp_held_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD / PM_RUN_INST_CMPL\000\000Cycles in which the NTC instruciton is held at dispatch for any reason\000\000\000\000\000\00000 */
{ 511075 }, /* ict_noslot_disp_held_hb_full_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_HB_FULL / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to dispatch holds because the History Buffer was full. Could be GPR/VSR/VMR/FPR/CR/XVF\000\000\000\000\000\00000 */
{ 511323 }, /* ict_noslot_disp_held_issq_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_ISSQ / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to dispatch hold on this thread due to Issue q full, BRQ full, XVCF Full, Count cache, Link, Tar full\000\000\000\000\000\00000 */
{ 511580 }, /* ict_noslot_disp_held_other_cpi\000cpi_breakdown\000ict_noslot_disp_held_cpi - ict_noslot_disp_held_hb_full_cpi - ict_noslot_disp_held_sync_cpi - ict_noslot_disp_held_tbegin_cpi - ict_noslot_disp_held_issq_cpi\000\000ICT_NOSLOT_DISP_HELD_OTHER_CPI\000\000\000\000\000\00000 */
{ 511822 }, /* ict_noslot_disp_held_sync_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_SYNC / PM_RUN_INST_CMPL\000\000Dispatch held due to a synchronizing instruction at dispatch\000\000\000\000\000\00000 */
{ 511983 }, /* ict_noslot_disp_held_tbegin_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_DISP_HELD_TBEGIN / PM_RUN_INST_CMPL\000\000the NTC instruction is being held at dispatch because it is a tbegin instruction and there is an older tbegin in the pipeline that must complete before the younger tbegin can dispatch\000\000\000\000\000\00000 */
{ 512271 }, /* ict_noslot_ic_l2_cpi\000cpi_breakdown\000ict_noslot_ic_miss_cpi - ict_noslot_ic_l3_cpi - ict_noslot_ic_l3miss_cpi\000\000ICT_NOSLOT_IC_L2_CPI\000\000\000\000\000\00000 */
{ 512408 }, /* ict_noslot_ic_l3_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_IC_L3 / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to icache misses that were sourced from the local L3\000\000\000\000\000\00000 */
{ 512598 }, /* ict_noslot_ic_l3miss_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_IC_L3MISS / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to icache misses that were sourced from beyond the local L3. The source could be local/remote/distant memory or another core's cache\000\000\000\000\000\00000 */
{ 512876 }, /* ict_noslot_ic_miss_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_IC_MISS / PM_RUN_INST_CMPL\000\000Instruction Completion Table empty for this thread due to Icache Miss\000\000\000\000\000\00000 */
{ 478216 }, /* inst_from_dl2l3_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 474047 }, /* inst_from_dl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L2 or L3 (Modified) per Inst\000\000\000\000\000\00000 */
{ 478388 }, /* inst_from_dl2l3_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 474234 }, /* inst_from_dl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L2 or L3 (Shared) per Inst\000\000\000\000\000\00000 */
{ 478558 }, /* inst_from_dl4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant L4\000\000\000\000\000\00000 */
{ 474419 }, /* inst_from_dl4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant L4 per Inst\000\000\000\000\000\00000 */
{ 478701 }, /* inst_from_dmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_DMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Distant Memory\000\000\000\000\000\00000 */
{ 474577 }, /* inst_from_dmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Distant Memory per Inst\000\000\000\000\000\00000 */
{ 478850 }, /* inst_from_l21_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L21_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 474741 }, /* inst_from_l21_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 479013 }, /* inst_from_l21_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L21_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 474919 }, /* inst_from_l21_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L2, other core per Inst\000\000\000\000\000\00000 */
{ 479176 }, /* inst_from_l2_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L2 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from L2\000\000\000\000\000\00000 */
{ 475097 }, /* inst_from_l2_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from L2 per Inst\000\000\000\000\000\00000 */
{ 479309 }, /* inst_from_l31_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L31_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 475245 }, /* inst_from_l31_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L3, other core per Inst\000\000\000\000\000\00000 */
{ 479472 }, /* inst_from_l31_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L31_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 475423 }, /* inst_from_l31_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Private L3 other core per Inst\000\000\000\000\000\00000 */
{ 479635 }, /* inst_from_l3_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_L3 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from L3\000\000\000\000\000\00000 */
{ 475600 }, /* inst_from_l3_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from L3 per Inst\000\000\000\000\000\00000 */
{ 479768 }, /* inst_from_ll4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_LL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Local L4\000\000\000\000\000\00000 */
{ 475748 }, /* inst_from_ll4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Local L4 per Inst\000\000\000\000\000\00000 */
{ 479909 }, /* inst_from_lmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_LMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Local Memory\000\000\000\000\000\00000 */
{ 475904 }, /* inst_from_lmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Local Memory per Inst\000\000\000\000\000\00000 */
{ 480056 }, /* inst_from_rl2l3_mod_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL2L3_MOD * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 476066 }, /* inst_from_rl2l3_mod_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L2 or L3 (Modified) per Inst\000\000\000\000\000\00000 */
{ 480227 }, /* inst_from_rl2l3_shr_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL2L3_SHR * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 476252 }, /* inst_from_rl2l3_shr_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L2 or L3 (Shared) per Inst\000\000\000\000\000\00000 */
{ 480396 }, /* inst_from_rl4_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RL4 * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote L4\000\000\000\000\000\00000 */
{ 476436 }, /* inst_from_rl4_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote L4 per Inst\000\000\000\000\000\00000 */
{ 480538 }, /* inst_from_rmem_percent\000instruction_stats_percent_per_ref\000PM_INST_FROM_RMEM * 100 / PM_L1_ICACHE_MISS\000\000% of ICache reloads from Remote Memory\000\000\000\000\000\00000 */
{ 476593 }, /* inst_from_rmem_rate_percent\000instruction_misses_percent_per_inst\000PM_INST_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of ICache reloads from Remote Memory per Inst\000\000\000\000\000\00000 */
{ 471790 }, /* ipc\000general\000PM_INST_CMPL / PM_CYC\000\000Instructions per cycles\000\000\000\000\000\00000 */
{ 497752 }, /* ipteg_from_l2_rate_percent\000\000PM_IPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from L2\000\000\000\000\000\00000 */
{ 497860 }, /* ipteg_from_l3_rate_percent\000\000PM_IPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from L3\000\000\000\000\000\00000 */
{ 497968 }, /* ipteg_from_ll4_rate_percent\000\000PM_IPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from local memory\000\000\000\000\000\00000 */
{ 498088 }, /* ipteg_from_lmem_rate_percent\000\000PM_IPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000Rate of IERAT reloads from local memory\000\000\000\000\000\00000 */
{ 495233 }, /* islb_miss_rate_percent\000translation\000PM_ISLB_MISS * 100 / PM_RUN_INST_CMPL\000\000% ISLB miss rate per inst\000\000\000\000\000\00000 */
{ 471856 }, /* itlb_miss_rate_percent\000general\000PM_ITLB_MISS / PM_RUN_INST_CMPL * 100\000\000% ITLB miss rate per inst\000\000\000\000\000\00000 */
{ 476756 }, /* l1_inst_miss_rate_percent\000instruction_misses_percent_per_inst\000PM_L1_ICACHE_MISS * 100 / PM_RUN_INST_CMPL\000\000Instruction Cache Miss Rate (Per run Instruction)(%)\000\000\000\000\000\00000 */
{ 460686 }, /* l1_ld_miss_rate_percent\000dl1_reloads_percent_per_inst\000PM_LD_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L1 demand load misses per run instruction\000\000\000\000\000\00000 */
{ 471959 }, /* l1_ld_miss_ratio_percent\000general\000PM_LD_MISS_L1 / PM_LD_REF_L1 * 100\000\000Percentage of L1 load misses per L1 load ref\000\000\000\000\000\00000 */
{ 529017 }, /* l1_prefetch_rate_percent\000prefetch\000PM_L1_PREF / PM_RUN_INST_CMPL * 100\000\000L1 Prefetches issued by the prefetch machine per instruction (per thread)\000\000\000\000\000\00000 */
{ 472080 }, /* l1_st_miss_rate_percent\000general\000PM_ST_MISS_L1 * 100 / PM_RUN_INST_CMPL\000\000Percentage of L1 store misses per run instruction\000\000\000\000\000\00000 */
{ 472209 }, /* l1_st_miss_ratio_percent\000general\000PM_ST_MISS_L1 / PM_ST_FIN * 100\000\000Percentage of L1 store misses per L1 store ref\000\000\000\000\000\00000 */
{ 524660 }, /* l21_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_MOD * PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl21 MOD miss rates with measured L21 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 528219 }, /* l21_mod_latency\000latency\000PM_MRK_DATA_FROM_L21_MOD_CYC / PM_MRK_DATA_FROM_L21_MOD\000\000Marked L21 Load latency\000\000\000\000\000\00000 */
{ 524915 }, /* l21_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L21_SHR * PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl21 SHR miss rates with measured L21 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 528331 }, /* l21_shr_latency\000latency\000PM_MRK_DATA_FROM_L21_SHR_CYC / PM_MRK_DATA_FROM_L21_SHR\000\000Marked L21 Load latency\000\000\000\000\000\00000 */
{ 531371 }, /* l2_co_usage\000\000PM_CO_USAGE / PM_RUN_CYC * 16\000\000Average number of Castout machines used. 1 of 16 CO machines is sampled every L2 cycle\000\000\000\000\000\00000 */
{ 525170 }, /* l2_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L2 * PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2 miss rates with measured L2 latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 527658 }, /* l2_dem_ld_disp_percent\000l2_stats\000PM_L1_DCACHE_RELOAD_VALID / (PM_L2_LD / 2) * 100\000\000Demand load misses as a % of L2 LD dispatches (per thread)\000\000\000\000\000\00000 */
{ 472329 }, /* l2_inst_miss_rate_percent\000general\000PM_INST_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000\00000 */
{ 531509 }, /* l2_instr_commands_percent\000\000PM_ISIDE_DISP * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000\000Percent of instruction reads out of all L2 commands\000\000\000\000\000\00000 */
{ 528443 }, /* l2_latency\000latency\000PM_MRK_DATA_FROM_L2_CYC / PM_MRK_DATA_FROM_L2\000\000Marked L2 Load latency\000\000\000\000\000\00000 */
{ 531656 }, /* l2_ld_commands_percent\000\000PM_L2_LD * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000\000Percent of loads out of all L2 commands\000\000\000\000\000\00000 */
{ 527524 }, /* l2_ld_miss_rate_percent\000general\000PM_DATA_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 dmand Load Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 472597 }, /* l2_pteg_miss_rate_percent\000general\000PM_DPTEG_FROM_L2MISS * 100 / PM_RUN_INST_CMPL\000\000L2 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 531783 }, /* l2_rc_st_disp_fail_rate_percent\000\000100 * (PM_L2_RCST_DISP_FAIL_ADDR + PM_L2_RCST_DISP_FAIL_OTHER) / 2 / PM_RUN_INST_CMPL\000\000Rate of L2 store dispatches that failed per core\000\000\000\000\000\00000 */
{ 531959 }, /* l2_rc_usage\000\000PM_RC_USAGE / PM_RUN_CYC * 16\000\000Average number of Read/Claim machines used. 1 of 16 RC machines is sampled every L2 cycle\000\000\000\000\000\00000 */
{ 532100 }, /* l2_sn_usage\000\000PM_SN_USAGE / PM_RUN_CYC * 8\000\000Average number of Snoop machines used. 1 of 8 SN machines is sampled every L2 cycle\000\000\000\000\000\00000 */
{ 532234 }, /* l2_st_commands_percent\000\000PM_L2_ST * 100 / (PM_L2_ST + PM_L2_LD + PM_ISIDE_DISP)\000\000Percent of stores out of all L2 commands\000\000\000\000\000\00000 */
{ 532362 }, /* l2_st_disp_fail_rate_percent\000\000100 * (PM_L2_RCST_DISP_FAIL_ADDR + PM_L2_RCST_DISP_FAIL_OTHER) / 2 / PM_RUN_INST_CMPL\000\000Rate of L2 store dispatches that failed per core\000\000\000\000\000\00000 */
{ 532535 }, /* l2_st_disp_rate_percent\000\000100 * PM_L2_RCST_DISP / 2 / PM_RUN_INST_CMPL\000\000Rate of L2 dispatches per core\000\000\000\000\000\00000 */
{ 527806 }, /* l2_st_miss_ratio_percent\000l2_stats\000PM_L2_ST_MISS / PM_L2_ST * 100\000\000L2 Store misses as a % of total L2 Store dispatches (per thread)\000\000\000\000\000\00000 */
{ 527944 }, /* l2_st_wr_util\000l2_stats\000PM_L2_ST_DISP / 2 * 4 / PM_RUN_CYC * 100\000\000L2 stores that require a cache write (4 pclks per disp attempt) % of pclks\000\000\000\000\000\00000 */
{ 500061 }, /* l31_latency\000\000(PM_MRK_DATA_FROM_L31_SHR_CYC + PM_MRK_DATA_FROM_L31_MOD_CYC) / (PM_MRK_DATA_FROM_L31_SHR + PM_MRK_DATA_FROM_L31_MOD)\000\000Marked L31 Load latency\000\000\000\000\000\00000 */
{ 525395 }, /* l31_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_MOD * PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl31 MOD miss rates with measured L31 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 484871 }, /* l31_mod_latency\000latency\000PM_MRK_DATA_FROM_L31_MOD_CYC / PM_MRK_DATA_FROM_L31_MOD\000\000Marked L31 Load latency\000\000\000\000\000\00000 */
{ 525650 }, /* l31_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L31_SHR * PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl31 SHR miss rates with measured L31 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 484983 }, /* l31_shr_latency\000latency\000PM_MRK_DATA_FROM_L31_SHR_CYC / PM_MRK_DATA_FROM_L31_SHR\000\000Marked L31 Load latency\000\000\000\000\000\00000 */
{ 525905 }, /* l3_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_L3 * PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl3 miss rates with measured L3 latency as a % of dcache miss cpi\000\000\000\000\000\00000 */
{ 472857 }, /* l3_inst_miss_rate_percent\000general\000PM_INST_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 Instruction Miss Rate (per instruction)(%)\000\000\000\000\000\00000 */
{ 528539 }, /* l3_latency\000latency\000PM_MRK_DATA_FROM_L3_CYC / PM_MRK_DATA_FROM_L3\000\000Marked L3 Load latency\000\000\000\000\000\00000 */
{ 472990 }, /* l3_ld_miss_rate_percent\000general\000PM_DATA_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 demand Load Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 473125 }, /* l3_pteg_miss_rate_percent\000general\000PM_DPTEG_FROM_L3MISS * 100 / PM_RUN_INST_CMPL\000\000L3 PTEG Miss Rate (per run instruction)(%)\000\000\000\000\000\00000 */
{ 528755 }, /* l4_locality\000memory\000PM_DATA_FROM_LL4 * 100 / (PM_DATA_FROM_LL4 + PM_DATA_FROM_RL4 + PM_DATA_FROM_DL4)\000\000L4 locality(%)\000\000\000\000\000\00000 */
{ 513151 }, /* larx_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LARX / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a larx waiting to be satisfied\000\000\000\000\000\00000 */
{ 487783 }, /* ld_ll4_per_ld_dmem\000memory\000PM_DATA_FROM_LL4 / PM_DATA_FROM_DL4\000\000Ratio of reloads from local L4 to distant L4\000\000\000\000\000\00000 */
{ 487898 }, /* ld_ll4_per_ld_mem\000memory\000PM_DATA_FROM_LL4 / (PM_DATA_FROM_DL4 + PM_DATA_FROM_RL4)\000\000Ratio of reloads from local L4 to remote+distant L4\000\000\000\000\000\00000 */
{ 488040 }, /* ld_ll4_per_ld_rl4\000memory\000PM_DATA_FROM_LL4 / PM_DATA_FROM_RL4\000\000Ratio of reloads from local L4 to remote L4\000\000\000\000\000\00000 */
{ 488153 }, /* ld_lmem_per_ld_dmem\000memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_DMEM\000\000Number of loads from local memory per loads from distant memory\000\000\000\000\000\00000 */
{ 488290 }, /* ld_lmem_per_ld_mem\000memory\000PM_DATA_FROM_LMEM / (PM_DATA_FROM_DMEM + PM_DATA_FROM_RMEM)\000\000Number of loads from local memory per loads from remote and distant memory\000\000\000\000\000\00000 */
{ 488459 }, /* ld_lmem_per_ld_rmem\000memory\000PM_DATA_FROM_LMEM / PM_DATA_FROM_RMEM\000\000Number of loads from local memory per loads from remote memory\000\000\000\000\000\00000 */
{ 488595 }, /* ld_rmem_per_ld_dmem\000memory\000PM_DATA_FROM_RMEM / PM_DATA_FROM_DMEM\000\000Number of loads from remote memory per loads from distant memory\000\000\000\000\000\00000 */
{ 487113 }, /* lhs_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_LHS * 100 / PM_RUN_INST_CMPL\000\000LHS reject ratio\000\000\000\000\000\00000 */
{ 513303 }, /* lhs_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LHS / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that hit on an older store and it was waiting for store data\000\000\000\000\000\00000 */
{ 485801 }, /* ll4_latency\000latency\000PM_MRK_DATA_FROM_LL4_CYC / PM_MRK_DATA_FROM_LL4\000\000Local L4 average load latency\000\000\000\000\000\00000 */
{ 526131 }, /* lmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_LMEM * PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of Local memory miss rates with measured LMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 485907 }, /* lmem_latency\000latency\000PM_MRK_DATA_FROM_LMEM_CYC / PM_MRK_DATA_FROM_LMEM\000\000Marked Lmem Load latency\000\000\000\000\000\00000 */
{ 528635 }, /* lmq_full_reject_rate_percent\000lsu_rejects\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_RUN_INST_CMPL\000\000ERAT miss reject ratio\000\000\000\000\000\00000 */
{ 487453 }, /* lmq_full_reject_ratio_percent\000lsu_rejects\000PM_LSU_REJECT_LMQ_FULL * 100 / PM_LD_REF_L1\000\000ERAT miss reject ratio\000\000\000\000\000\00000 */
{ 513490 }, /* lmq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LMQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that missed in the L1 and the LMQ was unable to accept this load miss request because it was full\000\000\000\000\000\00000 */
{ 513724 }, /* load_finish_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LOAD_FINISH / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load instruction with all its dependencies satisfied just going through the LSU pipe to finish\000\000\000\000\000\00000 */
{ 532644 }, /* loads_per_inst\000\000PM_LD_REF_L1 / PM_RUN_INST_CMPL\000\000PCT instruction loads\000\000\000\000\000\00000 */
{ 513956 }, /* lrq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LRQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load that was held in LSAQ because the LRQ was full\000\000\000\000\000\00000 */
{ 514139 }, /* lrq_other_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LRQ_OTHER / PM_RUN_INST_CMPL\000\000Finish stall due to LRQ miscellaneous reasons, lost arbitration to LMQ slot, bank collisions, set prediction cleanup, set prediction multihit and others\000\000\000\000\000\00000 */
{ 514530 }, /* lsaq_arb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSAQ_ARB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a load or store that was held in LSAQ because an older instruction from SRQ or LRQ won arbitration to the LSU pipe when this instruction tried to launch\000\000\000\000\000\00000 */
{ 504734 }, /* lstack_mispredict_rate_percent\000branch_prediction\000PM_BR_MPRED_LSTACK / PM_RUN_INST_CMPL * 100\000\000Link stack branch misprediction\000\000\000\000\000\00000 */
{ 504867 }, /* lstack_misprediction_percent\000branch_prediction\000PM_BR_MPRED_LSTACK / PM_BR_PRED_LSTACK * 100\000\000Link stack branch misprediction\000\000\000\000\000\00000 */
{ 514911 }, /* lsu_fin_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU_FIN / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was an LSU op (other than a load or a store) with all its dependencies met and just going through the LSU pipe to finish\000\000\000\000\000\00000 */
{ 515155 }, /* lsu_flush_next_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU_FLUSH_NEXT / PM_RUN_INST_CMPL\000\000Completion stall of one cycle because the LSU requested to flush the next iop in the sequence. It takes 1 cycle for the ISU to process this request before the LSU instruction is allowed to complete\000\000\000\000\000\00000 */
{ 515449 }, /* lsu_mfspr_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU_MFSPR / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a mfspr instruction targeting an LSU SPR and it was waiting for the register data to be returned\000\000\000\000\000\00000 */
{ 515677 }, /* lsu_other_stall_cpi\000cpi_breakdown\000lsu_stall_cpi - lsu_fin_stall_cpi - store_finish_stall_cpi - srq_stall_cpi - load_finish_stall_cpi + lsu_stall_dcache_miss_cpi - lrq_stall_cpi + emq_stall_cpi - lsaq_stall_cpi\000\000Completion LSU stall for other reasons\000\000\000\000\000\00000 */
{ 515934 }, /* lsu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_LSU / PM_RUN_INST_CMPL\000\000Completion stall by LSU instruction\000\000\000\000\000\00000 */
{ 532722 }, /* lsu_stall_dcache_miss_cpi\000\000PM_CMPLU_STALL_DCACHE_MISS / PM_RUN_INST_CMPL\000\000Cycles stalled by D-Cache Misses\000\000\000\000\000\00000 */
{ 528879 }, /* mem_locality_percent\000memory\000PM_DATA_FROM_LMEM * 100 / (PM_DATA_FROM_LMEM + PM_DATA_FROM_RMEM + PM_DATA_FROM_DMEM)\000\000Memory locality\000\000\000\000\000\00000 */
{ 516044 }, /* mtfpscr_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_MTFPSCR / PM_RUN_INST_CMPL\000\000Completion stall because the ISU is updating the register and notifying the Effective Address Table (EAT)\000\000\000\000\000\00000 */
{ 516232 }, /* nested_tbegin_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NESTED_TBEGIN / PM_RUN_INST_CMPL\000\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tbegin. This is a short delay, and it includes ROT\000\000\000\000\000\00000 */
{ 516461 }, /* nested_tend_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NESTED_TEND / PM_RUN_INST_CMPL\000\000Completion stall because the ISU is updating the TEXASR to keep track of the nested tend and decrement the TEXASR nested level. This is a short delay\000\000\000\000\000\00000 */
{ 516701 }, /* nothing_dispatched_cpi\000cpi_breakdown\000PM_ICT_NOSLOT_CYC / PM_RUN_INST_CMPL\000\000Number of cycles the Instruction Completion Table has no itags assigned to this thread\000\000\000\000\000\00000 */
{ 516870 }, /* ntc_disp_fin_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NTC_DISP_FIN / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was one that must finish at dispatch\000\000\000\000\000\00000 */
{ 517040 }, /* ntc_fin_cpi\000cpi_breakdown\000PM_NTC_FIN / PM_RUN_INST_CMPL\000\000Cycles in which the oldest instruction in the pipeline (NTC) finishes. This event is used to account for cycles in which work is being completed in the CPI stack\000\000\000\000\000\00000 */
{ 517266 }, /* ntc_flush_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_NTC_FLUSH / PM_RUN_INST_CMPL\000\000Completion stall due to ntc flush\000\000\000\000\000\00000 */
{ 517386 }, /* ntc_issue_held_arb_cpi\000cpi_breakdown\000PM_NTC_ISSUE_HELD_ARB / PM_RUN_INST_CMPL\000\000The NTC instruction is being held at dispatch because it lost arbitration onto the issue pipe to another instruction (from the same thread or a different thread)\000\000\000\000\000\00000 */
{ 517634 }, /* ntc_issue_held_darq_full_cpi\000cpi_breakdown\000PM_NTC_ISSUE_HELD_DARQ_FULL / PM_RUN_INST_CMPL\000\000The NTC instruction is being held at dispatch because there are no slots in the DARQ for it\000\000\000\000\000\00000 */
{ 517824 }, /* ntc_issue_held_other_cpi\000cpi_breakdown\000PM_NTC_ISSUE_HELD_OTHER / PM_RUN_INST_CMPL\000\000The NTC instruction is being held at dispatch during regular pipeline cycles, or because the VSU is busy with multi-cycle instructions, or because of a write-back collision with VSU\000\000\000\000\000\00000 */
{ 518096 }, /* other_cpi\000cpi_breakdown\000run_cpi - completion_cpi - thread_block_stall_cpi - stall_cpi - nothing_dispatched_cpi\000\000Cycles unaccounted for\000\000\000\000\000\00000 */
{ 518238 }, /* other_stall_cpi\000cpi_breakdown\000stall_cpi - ntc_disp_fin_stall_cpi - ntc_flush_stall_cpi - lsu_stall_cpi - exec_unit_stall_cpi - bru_stall_cpi\000\000Completion stall for other reasons\000\000\000\000\000\00000 */
{ 532836 }, /* other_thread_cmpl_stall\000\000thread_block_stall_cpi - exception_stall_cpi - any_sync_stall_cpi - sync_pmu_int_stall_cpi - spec_finish_stall_cpi - flush_any_thread_stall_cpi - lsu_flush_next_stall_cpi - nested_tbegin_stall_cpi - nested_tend_stall_cpi - mtfpscr_stall_cpi\000\000Completion stall because a different thread was using the completion pipe\000\000\000\000\000\00000 */
{ 518422 }, /* paste_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_PASTE / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a paste waiting for response from L2\000\000\000\000\000\00000 */
{ 518582 }, /* pm_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_PM / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was issued to the Permute execution pipe and waiting to finish\000\000\000\000\000\00000 */
{ 491860 }, /* pteg_from_dl2l3_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 489096 }, /* pteg_from_dl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L2 or L3 (Modified) per inst\000\000\000\000\000\00000 */
{ 492022 }, /* pteg_from_dl2l3_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 489277 }, /* pteg_from_dl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L2 or L3 (Shared) per inst\000\000\000\000\000\00000 */
{ 492182 }, /* pteg_from_dl4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant L4\000\000\000\000\000\00000 */
{ 489456 }, /* pteg_from_dl4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant L4 per inst\000\000\000\000\000\00000 */
{ 492315 }, /* pteg_from_dmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_DMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Distant Memory\000\000\000\000\000\00000 */
{ 489608 }, /* pteg_from_dmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_DMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Distant Memory per inst\000\000\000\000\000\00000 */
{ 492454 }, /* pteg_from_l21_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L21_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 489766 }, /* pteg_from_l21_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L21_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000\00000 */
{ 492607 }, /* pteg_from_l21_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L21_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L2, other core\000\000\000\000\000\00000 */
{ 489938 }, /* pteg_from_l21_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L21_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L2, other core per inst\000\000\000\000\000\00000 */
{ 492760 }, /* pteg_from_l2_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L2 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from L2\000\000\000\000\000\00000 */
{ 490110 }, /* pteg_from_l2_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L2 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from L2 per inst\000\000\000\000\000\00000 */
{ 492883 }, /* pteg_from_l31_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L31_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 490252 }, /* pteg_from_l31_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L31_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000\00000 */
{ 493036 }, /* pteg_from_l31_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L31_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Private L3, other core\000\000\000\000\000\00000 */
{ 490424 }, /* pteg_from_l31_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L31_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Private L3, other core per inst\000\000\000\000\000\00000 */
{ 493189 }, /* pteg_from_l3_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_L3 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from L3\000\000\000\000\000\00000 */
{ 490596 }, /* pteg_from_l3_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_L3 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from L3 per inst\000\000\000\000\000\00000 */
{ 493312 }, /* pteg_from_ll4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_LL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Local L4\000\000\000\000\000\00000 */
{ 490738 }, /* pteg_from_ll4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_LL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Local L4 per inst\000\000\000\000\000\00000 */
{ 493443 }, /* pteg_from_lmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_LMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Local Memory\000\000\000\000\000\00000 */
{ 490888 }, /* pteg_from_lmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_LMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Local Memory per inst\000\000\000\000\000\00000 */
{ 493580 }, /* pteg_from_rl2l3_mod_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L2 or L3 (Modified)\000\000\000\000\000\00000 */
{ 491044 }, /* pteg_from_rl2l3_mod_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL2L3_MOD * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L2 or L3 (Modified) per inst\000\000\000\000\000\00000 */
{ 493741 }, /* pteg_from_rl2l3_shr_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L2 or L3 (Shared)\000\000\000\000\000\00000 */
{ 491224 }, /* pteg_from_rl2l3_shr_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL2L3_SHR * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L2 or L3 (Shared) per inst\000\000\000\000\000\00000 */
{ 493900 }, /* pteg_from_rl4_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RL4 * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote L4\000\000\000\000\000\00000 */
{ 491402 }, /* pteg_from_rl4_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RL4 * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote L4 per inst\000\000\000\000\000\00000 */
{ 494032 }, /* pteg_from_rmem_percent\000pteg_reloads_percent_per_ref\000PM_DPTEG_FROM_RMEM * 100 / PM_DTLB_MISS\000\000% of DERAT reloads from Remote Memory\000\000\000\000\000\00000 */
{ 491553 }, /* pteg_from_rmem_rate_percent\000pteg_reloads_percent_per_inst\000PM_DPTEG_FROM_RMEM * 100 / PM_RUN_INST_CMPL\000\000% of DERAT reloads from Remote Memory per inst\000\000\000\000\000\00000 */
{ 526375 }, /* rl2l3_mod_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_MOD * PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 remote MOD miss rates with measured RL2L3 MOD latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486403 }, /* rl2l3_mod_latency\000latency\000PM_MRK_DATA_FROM_RL2L3_MOD_CYC / PM_MRK_DATA_FROM_RL2L3_MOD\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000 */
{ 526648 }, /* rl2l3_shr_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL2L3_SHR * PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of dl2l3 shared miss rates with measured RL2L3 SHR latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486529 }, /* rl2l3_shr_latency\000latency\000PM_MRK_DATA_FROM_RL2L3_SHR_CYC / PM_MRK_DATA_FROM_RL2L3_SHR\000\000Marked L2L3 remote Load latency\000\000\000\000\000\00000 */
{ 526917 }, /* rl4_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RL4 * PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4 / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of remote L4 miss rates with measured RL4 latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486655 }, /* rl4_latency\000latency\000PM_MRK_DATA_FROM_RL4_CYC / PM_MRK_DATA_FROM_RL4\000\000Remote L4 average load latency\000\000\000\000\000\00000 */
{ 527153 }, /* rmem_cpi_percent\000estimated_dcache_miss_cpi\000PM_DATA_FROM_RMEM * PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM / PM_CMPLU_STALL_DCACHE_MISS * 100\000\000estimate of remote memory miss rates with measured RMEM latency as a %of dcache miss cpi\000\000\000\000\000\00000 */
{ 486762 }, /* rmem_latency\000latency\000PM_MRK_DATA_FROM_RMEM_CYC / PM_MRK_DATA_FROM_RMEM\000\000Marked Rmem Load latency\000\000\000\000\000\00000 */
{ 455139 }, /* run_cpi\000cpi_breakdown\000PM_RUN_CYC / PM_RUN_INST_CMPL\000\000Run cycles per run instruction\000\000\000\000\000\00000 */
{ 518758 }, /* run_cyc_cpi\000cpi_breakdown\000PM_RUN_CYC / PM_RUN_INST_CMPL\000\000Run_cycles\000\000\000\000\000\00000 */
{ 473256 }, /* run_cycles_percent\000general\000PM_RUN_CYC / PM_CYC * 100\000\000Run cycles per cycle\000\000\000\000\000\00000 */
{ 518952 }, /* slb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SLB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was awaiting L2 response for an SLB\000\000\000\000\000\00000 */
{ 519103 }, /* spec_finish_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SPEC_FINISH / PM_RUN_INST_CMPL\000\000Finish stall while waiting for the non-speculative finish of either a stcx waiting for its result or a load waiting for non-critical sectors of data and ECC\000\000\000\000\000\00000 */
{ 473829 }, /* speculation\000general\000PM_INST_DISP / PM_INST_CMPL\000\000Instruction dispatch-to-completion ratio\000\000\000\000\000\00000 */
{ 519350 }, /* srq_full_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_SRQ_FULL / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store that was held in LSAQ because the SRQ was full\000\000\000\000\000\00000 */
{ 519749 }, /* st_fwd_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_ST_FWD / PM_RUN_INST_CMPL\000\000Completion stall due to store forward\000\000\000\000\000\00000 */
{ 519867 }, /* stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL / PM_RUN_INST_CMPL\000\000Nothing completed and Instruction Completion Table not empty\000\000\000\000\000\00000 */
{ 519994 }, /* stcx_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STCX / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a stcx waiting for response from L2\000\000\000\000\000\00000 */
{ 520151 }, /* store_data_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_DATA / PM_RUN_INST_CMPL\000\000Finish stall because the next to finish instruction was a store waiting on data\000\000\000\000\000\00000 */
{ 520319 }, /* store_fin_arb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_FIN_ARB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store waiting for a slot in the store finish pipe. This means the instruction is ready to finish but there are instructions ahead of it, using the finish pipe\000\000\000\000\000\00000 */
{ 520619 }, /* store_finish_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_FINISH / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store with all its dependencies met, just waiting to go through the LSU pipe to finish\000\000\000\000\000\00000 */
{ 520845 }, /* store_pipe_arb_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_STORE_PIPE_ARB / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a store waiting for the next relaunch opportunity after an internal reject. This means the instruction is ready to relaunch and tried once but lost arbitration\000\000\000\000\000\00000 */
{ 533184 }, /* stores_per_inst\000\000PM_ST_FIN / PM_RUN_INST_CMPL\000\000PCT instruction stores\000\000\000\000\000\00000 */
{ 533261 }, /* sync_pmu_int_stall_cpi\000\000PM_CMPLU_STALL_SYNC_PMU_INT / PM_RUN_INST_CMPL\000\000ANY_SYNC_STALL_CPI\000\000\000\000\000\00000 */
{ 504999 }, /* taken_branches_percent\000branch_prediction\000PM_BR_TAKEN_CMPL * 100 / PM_BRU_FIN\000\000% Branches Taken\000\000\000\000\000\00000 */
{ 521146 }, /* tend_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_TEND / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a tend instruction awaiting response from L2\000\000\000\000\000\00000 */
{ 521312 }, /* thread_block_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_THRD / PM_RUN_INST_CMPL\000\000Completion Stalled because the thread was blocked\000\000\000\000\000\00000 */
{ 521446 }, /* tlbie_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_TLBIE / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a tlbie waiting for response from L2\000\000\000\000\000\00000 */
{ 521606 }, /* vdp_other_stall_cpi\000cpi_breakdown\000vdp_stall_cpi - vdplong_stall_cpi\000\000Vector stalls due to small latency double precision ops\000\000\000\000\000\00000 */
{ 521738 }, /* vdp_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VDP / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a vector instruction issued to the Double Precision execution pipe and waiting to finish\000\000\000\000\000\00000 */
{ 521946 }, /* vdplong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VDPLONG / PM_RUN_INST_CMPL\000\000Finish stall because the NTF instruction was a scalar multi-cycle instruction issued to the Double Precision execution pipe and waiting to finish. Includes binary floating point instructions in 32 and 64 bit binary floating point format\000\000\000\000\000\00000 */
{ 522336 }, /* vfxlong_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VFXLONG / PM_RUN_INST_CMPL\000\000Completion stall due to a long latency vector fixed point instruction (division, square root)\000\000\000\000\000\00000 */
{ 522512 }, /* vfxu_other_stall_cpi\000cpi_breakdown\000vfxu_stall_cpi - vfxlong_stall_cpi\000\000Vector stalls due to small latency integer ops\000\000\000\000\000\00000 */
{ 522637 }, /* vfxu_stall_cpi\000cpi_breakdown\000PM_CMPLU_STALL_VFXU / PM_RUN_INST_CMPL\000\000Finish stall due to a vector fixed point instruction in the execution pipeline. These instructions get routed to the ALU, ALU2, and DIV pipes\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__power9[] = {
{
     .entries = pmu_metrics__power9_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__power9_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__test_soc_cpu_default_core[] = {
{ 399594 }, /* bp_l1_btb_correct\000branch\000L1 BTB Correction\000event=0x8a\000\00000\000\000 */
{ 399653 }, /* bp_l2_btb_correct\000branch\000L2 BTB Correction\000event=0x8b\000\00000\000\000 */
{ 399908 }, /* dispatch_blocked.any\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\00000\000\000 */
{ 400040 }, /* eist_trans\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\00000\000\000 */
{ 399712 }, /* l3_cache_rd\000cache\000L3 cache access, read\000event=0x40\000\00000\000Attributable Level 3 cache access, read\000 */
{ 399807 }, /* segment_reg_loads.any\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\00000\000\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_hisi_sccl_ddrc[] = {
{ 400180 }, /* uncore_hisi_ddrc.flux_wcmd\000uncore\000DDRC write commands\000event=0x2\000\00000\000DDRC write commands\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_hisi_sccl_l3c[] = {
{ 400683 }, /* uncore_hisi_l3c.rd_hit_cpipe\000uncore\000Total read hits\000event=0x7\000\00000\000Total read hits\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_uncore_cbox[] = {
{ 400511 }, /* event-hyphen\000uncore\000UNC_CBO_HYPHEN\000event=0xe0,umask=0x00\000\00000\000UNC_CBO_HYPHEN\000 */
{ 400587 }, /* event-two-hyph\000uncore\000UNC_CBO_TWO_HYPH\000event=0xc0,umask=0x00\000\00000\000UNC_CBO_TWO_HYPH\000 */
{ 400280 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000event=0x22,umask=0x81\000\00000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_uncore_imc[] = {
{ 400895 }, /* uncore_imc.cache_hits\000uncore\000Total cache hits\000event=0x34\000\00000\000Total cache hits\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_uncore_imc_free_running[] = {
{ 400789 }, /* uncore_imc_free_running.cache_miss\000uncore\000Total cache misses\000event=0x12\000\00000\000Total cache misses\000 */

};

const struct pmu_table_entry pmu_events__test_soc_cpu[] = {
{
     .entries = pmu_events__test_soc_cpu_default_core,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_hisi_sccl_ddrc,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_hisi_sccl_ddrc),
     .pmu_name = { 400165 /* hisi_sccl,ddrc\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_hisi_sccl_l3c,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_hisi_sccl_l3c),
     .pmu_name = { 400669 /* hisi_sccl,l3c\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_uncore_cbox,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_uncore_cbox),
     .pmu_name = { 400268 /* uncore_cbox\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_uncore_imc,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_uncore_imc),
     .pmu_name = { 400884 /* uncore_imc\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_uncore_imc_free_running,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_uncore_imc_free_running),
     .pmu_name = { 400765 /* uncore_imc_free_running\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__test_soc_cpu_default_core[] = {
{ 535020 }, /* CPI\000\0001 / IPC\000\000\000\000\000\000\000\00000 */
{ 535701 }, /* DCache_L2_All\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000\000\00000 */
{ 535473 }, /* DCache_L2_All_Hits\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000\000\00000 */
{ 535567 }, /* DCache_L2_All_Miss\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000\000\00000 */
{ 535765 }, /* DCache_L2_Hits\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000\000\00000 */
{ 535833 }, /* DCache_L2_Misses\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000\000\00000 */
{ 535105 }, /* Frontend_Bound_SMT\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000\000\00000 */
{ 535042 }, /* IPC\000group1\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000\000\00000 */
{ 535967 }, /* L1D_Cache_Fill_BW\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000\000\00000 */
{ 535903 }, /* M1\000\000ipc + M2\000\000\000\000\000\000\000\00000 */
{ 535925 }, /* M2\000\000ipc + M1\000\000\000\000\000\000\000\00000 */
{ 535947 }, /* M3\000\0001 / M3\000\000\000\000\000\000\000\00000 */
{ 535402 }, /* cache_miss_cycles\000group1\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000\000\00000 */
{ 535271 }, /* dcache_miss_cpi\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000 */
{ 535335 }, /* icache_miss_cycles\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__test_soc_cpu[] = {
{
     .entries = pmu_metrics__test_soc_cpu_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__test_soc_cpu_default_core),
     .pmu_name = { 0 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__test_soc_sys_uncore_sys_ccn_pmu[] = {
{ 401084 }, /* sys_ccn_pmu.read_cycles\000uncore\000ccn read-cycles event\000config=0x2c\0000x01\00000\000\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_sys_uncore_sys_cmn_pmu[] = {
{ 401177 }, /* sys_cmn_pmu.hnf_cache_miss\000uncore\000Counts total cache misses in first lookup result (high priority)\000eventid=0x1,type=0x5\000(434|436|43c|43a).*\00000\000\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_sys_uncore_sys_ddr_pmu[] = {
{ 400992 }, /* sys_ddr_pmu.write_cycles\000uncore\000ddr write-cycles event\000event=0x2b\000v8\00000\000\000 */

};

const struct pmu_table_entry pmu_events__test_soc_sys[] = {
{
     .entries = pmu_events__test_soc_sys_uncore_sys_ccn_pmu,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_sys_uncore_sys_ccn_pmu),
     .pmu_name = { 401065 /* uncore_sys_ccn_pmu\000 */ },
},
{
     .entries = pmu_events__test_soc_sys_uncore_sys_cmn_pmu,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_sys_uncore_sys_cmn_pmu),
     .pmu_name = { 401158 /* uncore_sys_cmn_pmu\000 */ },
},
{
     .entries = pmu_events__test_soc_sys_uncore_sys_ddr_pmu,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_sys_uncore_sys_ddr_pmu),
     .pmu_name = { 400973 /* uncore_sys_ddr_pmu\000 */ },
},
};


/* Struct used to make the PMU event table implementation opaque to callers. */
struct pmu_events_table {
        const struct pmu_table_entry *pmus;
        uint32_t num_pmus;
};

/* Struct used to make the PMU metric table implementation opaque to callers. */
struct pmu_metrics_table {
        const struct pmu_table_entry *pmus;
        uint32_t num_pmus;
};

/*
 * Map a CPU to its table of PMU events. The CPU is identified by the
 * cpuid field, which is an arch-specific identifier for the CPU.
 * The identifier specified in tools/perf/pmu-events/arch/xxx/mapfile
 * must match the get_cpuid_str() in tools/perf/arch/xxx/util/header.c)
 *
 * The  cpuid can contain any character other than the comma.
 */
struct pmu_events_map {
        const char *arch;
        const char *cpuid;
        struct pmu_events_table event_table;
        struct pmu_metrics_table metric_table;
};

/*
 * Global table mapping each known CPU for the architecture to its
 * table of PMU events.
 */
const struct pmu_events_map pmu_events_map[] = {
{
	.arch = "powerpc",
	.cpuid = "0x004[bcd][[:xdigit:]]{4}",
	.event_table = {
		.pmus = pmu_events__power8,
		.num_pmus = ARRAY_SIZE(pmu_events__power8)
	},
	.metric_table = {
		.pmus = pmu_metrics__power8,
		.num_pmus = ARRAY_SIZE(pmu_metrics__power8)
	}
},
{
	.arch = "powerpc",
	.cpuid = "0x0066[[:xdigit:]]{4}",
	.event_table = {
		.pmus = pmu_events__power8,
		.num_pmus = ARRAY_SIZE(pmu_events__power8)
	},
	.metric_table = {
		.pmus = pmu_metrics__power8,
		.num_pmus = ARRAY_SIZE(pmu_metrics__power8)
	}
},
{
	.arch = "powerpc",
	.cpuid = "0x004e[[:xdigit:]]{4}",
	.event_table = {
		.pmus = pmu_events__power9,
		.num_pmus = ARRAY_SIZE(pmu_events__power9)
	},
	.metric_table = {
		.pmus = pmu_metrics__power9,
		.num_pmus = ARRAY_SIZE(pmu_metrics__power9)
	}
},
{
	.arch = "powerpc",
	.cpuid = "0x0080[[:xdigit:]]{4}",
	.event_table = {
		.pmus = pmu_events__power10,
		.num_pmus = ARRAY_SIZE(pmu_events__power10)
	},
	.metric_table = {
		.pmus = pmu_metrics__power10,
		.num_pmus = ARRAY_SIZE(pmu_metrics__power10)
	}
},
{
	.arch = "testarch",
	.cpuid = "testcpu",
	.event_table = {
		.pmus = pmu_events__test_soc_cpu,
		.num_pmus = ARRAY_SIZE(pmu_events__test_soc_cpu),
	},
	.metric_table = {
		.pmus = pmu_metrics__test_soc_cpu,
		.num_pmus = ARRAY_SIZE(pmu_metrics__test_soc_cpu),
	}
},
{
	.arch = 0,
	.cpuid = 0,
	.event_table = { 0, 0 },
	.metric_table = { 0, 0 },
}
};

struct pmu_sys_events {
	const char *name;
	struct pmu_events_table event_table;
	struct pmu_metrics_table metric_table;
};

static const struct pmu_sys_events pmu_sys_event_tables[] = {
	{
		.event_table = {
			.pmus = pmu_events__test_soc_sys,
			.num_pmus = ARRAY_SIZE(pmu_events__test_soc_sys)
		},
		.name = "pmu_events__test_soc_sys",
	},
	{
		.event_table = { 0, 0 },
		.metric_table = { 0, 0 },
	},
};

static void decompress_event(int offset, struct pmu_event *pe)
{
	const char *p = &big_c_string[offset];

	pe->name = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->topic = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->event = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->deprecated = *p - '0';
	p++;
	pe->perpkg = *p - '0';
	p++;
	pe->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->long_desc = (*p == '\0' ? NULL : p);
}

static void decompress_metric(int offset, struct pmu_metric *pm)
{
	const char *p = &big_c_string[offset];

	pm->metric_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_expr = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_threshold = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->long_desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metricgroup_no_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->default_metricgroup_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->aggr_mode = *p - '0';
	p++;
	pm->event_grouping = *p - '0';
}

static int pmu_events_table__for_each_event_pmu(const struct pmu_events_table *table,
                                                const struct pmu_table_entry *pmu,
                                                pmu_event_iter_fn fn,
                                                void *data)
{
        int ret;
        struct pmu_event pe = {
                .pmu = &big_c_string[pmu->pmu_name.offset],
        };

        for (uint32_t i = 0; i < pmu->num_entries; i++) {
                decompress_event(pmu->entries[i].offset, &pe);
                if (!pe.name)
                        continue;
                ret = fn(&pe, table, data);
                if (ret)
                        return ret;
        }
        return 0;
 }

static int pmu_events_table__find_event_pmu(const struct pmu_events_table *table,
                                            const struct pmu_table_entry *pmu,
                                            const char *name,
                                            pmu_event_iter_fn fn,
                                            void *data)
{
        struct pmu_event pe = {
                .pmu = &big_c_string[pmu->pmu_name.offset],
        };
        int low = 0, high = pmu->num_entries - 1;

        while (low <= high) {
                int cmp, mid = (low + high) / 2;

                decompress_event(pmu->entries[mid].offset, &pe);

                if (!pe.name && !name)
                        goto do_call;

                if (!pe.name && name) {
                        low = mid + 1;
                        continue;
                }
                if (pe.name && !name) {
                        high = mid - 1;
                        continue;
                }

                cmp = strcasecmp(pe.name, name);
                if (cmp < 0) {
                        low = mid + 1;
                        continue;
                }
                if (cmp > 0) {
                        high = mid - 1;
                        continue;
                }
  do_call:
                return fn ? fn(&pe, table, data) : 0;
        }
        return -1000;
}

int pmu_events_table__for_each_event(const struct pmu_events_table *table,
                                    struct perf_pmu *pmu,
                                    pmu_event_iter_fn fn,
                                    void *data)
{
        for (size_t i = 0; i < table->num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &table->pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];
                int ret;

                if (pmu && !pmu__name_match(pmu, pmu_name))
                        continue;

                ret = pmu_events_table__for_each_event_pmu(table, table_pmu, fn, data);
                if (pmu || ret)
                        return ret;
        }
        return 0;
}

int pmu_events_table__find_event(const struct pmu_events_table *table,
                                 struct perf_pmu *pmu,
                                 const char *name,
                                 pmu_event_iter_fn fn,
                                 void *data)
{
        for (size_t i = 0; i < table->num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &table->pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];
                int ret;

                if (!pmu__name_match(pmu, pmu_name))
                        continue;

                ret = pmu_events_table__find_event_pmu(table, table_pmu, name, fn, data);
                if (ret != -1000)
                        return ret;
        }
        return -1000;
}

size_t pmu_events_table__num_events(const struct pmu_events_table *table,
                                    struct perf_pmu *pmu)
{
        size_t count = 0;

        for (size_t i = 0; i < table->num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &table->pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];

                if (pmu__name_match(pmu, pmu_name))
                        count += table_pmu->num_entries;
        }
        return count;
}

static int pmu_metrics_table__for_each_metric_pmu(const struct pmu_metrics_table *table,
                                                const struct pmu_table_entry *pmu,
                                                pmu_metric_iter_fn fn,
                                                void *data)
{
        int ret;
        struct pmu_metric pm = {
                .pmu = &big_c_string[pmu->pmu_name.offset],
        };

        for (uint32_t i = 0; i < pmu->num_entries; i++) {
                decompress_metric(pmu->entries[i].offset, &pm);
                if (!pm.metric_expr)
                        continue;
                ret = fn(&pm, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_metrics_table__for_each_metric(const struct pmu_metrics_table *table,
                                     pmu_metric_iter_fn fn,
                                     void *data)
{
        for (size_t i = 0; i < table->num_pmus; i++) {
                int ret = pmu_metrics_table__for_each_metric_pmu(table, &table->pmus[i],
                                                                 fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

static const struct pmu_events_map *map_for_pmu(struct perf_pmu *pmu)
{
        static struct {
                const struct pmu_events_map *map;
                struct perf_pmu *pmu;
        } last_result;
        static struct {
                const struct pmu_events_map *map;
                char *cpuid;
        } last_map_search;
        static bool has_last_result, has_last_map_search;
        const struct pmu_events_map *map = NULL;
        char *cpuid = NULL;
        size_t i;

        if (has_last_result && last_result.pmu == pmu)
                return last_result.map;

        cpuid = perf_pmu__getcpuid(pmu);

        /*
         * On some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                goto out_update_last_result;

        if (has_last_map_search && !strcmp(last_map_search.cpuid, cpuid)) {
                map = last_map_search.map;
                free(cpuid);
        } else {
                i = 0;
                for (;;) {
                        map = &pmu_events_map[i++];

                        if (!map->arch) {
                                map = NULL;
                                break;
                        }

                        if (!strcmp_cpuid_str(map->cpuid, cpuid))
                                break;
               }
               free(last_map_search.cpuid);
               last_map_search.cpuid = cpuid;
               last_map_search.map = map;
               has_last_map_search = true;
        }
out_update_last_result:
        last_result.pmu = pmu;
        last_result.map = map;
        has_last_result = true;
        return map;
}

const struct pmu_events_table *perf_pmu__find_events_table(struct perf_pmu *pmu)
{
        const struct pmu_events_map *map = map_for_pmu(pmu);

        if (!map)
                return NULL;

        if (!pmu)
                return &map->event_table;

        for (size_t i = 0; i < map->event_table.num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &map->event_table.pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];

                if (pmu__name_match(pmu, pmu_name))
                         return &map->event_table;
        }
        return NULL;
}

const struct pmu_metrics_table *perf_pmu__find_metrics_table(struct perf_pmu *pmu)
{
        const struct pmu_events_map *map = map_for_pmu(pmu);

        if (!map)
                return NULL;

        if (!pmu)
                return &map->metric_table;

        for (size_t i = 0; i < map->metric_table.num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &map->metric_table.pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];

                if (pmu__name_match(pmu, pmu_name))
                           return &map->metric_table;
        }
        return NULL;
}

const struct pmu_events_table *find_core_events_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->event_table;
        }
        return NULL;
}

const struct pmu_metrics_table *find_core_metrics_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->metric_table;
        }
        return NULL;
}

int pmu_for_each_core_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_events_table__for_each_event(&tables->event_table,
                                                           /*pmu=*/ NULL, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_core_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_metrics_table__for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *find_sys_events_table(const char *name)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                if (!strcmp(tables->name, name))
                        return &tables->event_table;
        }
        return NULL;
}

int pmu_for_each_sys_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_events_table__for_each_event(&tables->event_table,
                                                           /*pmu=*/ NULL, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_sys_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_metrics_table__for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

static const int metricgroups[][2] = {

};

const char *describe_metricgroup(const char *group)
{
        int low = 0, high = (int)ARRAY_SIZE(metricgroups) - 1;

        while (low <= high) {
                int mid = (low + high) / 2;
                const char *mgroup = &big_c_string[metricgroups[mid][0]];
                int cmp = strcmp(mgroup, group);

                if (cmp == 0) {
                        return &big_c_string[metricgroups[mid][1]];
                } else if (cmp < 0) {
                        low = mid + 1;
                } else {
                        high = mid - 1;
                }
        }
        return NULL;
}
